Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1AliasRevisionConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1AliasRevisionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Instance Attribute Summary collapse
-
#location ⇒ String
Location of the alias file.
-
#name ⇒ String
Name of the alias revision included in the keystore in the following format:
organizations/org/environments/env/keystores/keystore/aliases/alias/ revisions/rev`Corresponds to the JSON propertyname`. -
#type ⇒ String
Corresponds to the JSON property
type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1AliasRevisionConfig
constructor
A new instance of GoogleCloudApigeeV1AliasRevisionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1AliasRevisionConfig
Returns a new instance of GoogleCloudApigeeV1AliasRevisionConfig.
472 473 474 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 472 def initialize(**args) update!(**args) end |
Instance Attribute Details
#location ⇒ String
Location of the alias file. For example, a Google Cloud Storage URI.
Corresponds to the JSON property location
458 459 460 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 458 def location @location end |
#name ⇒ String
Name of the alias revision included in the keystore in the following format:
organizations/org/environments/env/keystores/keystore/aliases/alias/
revisions/rev`
Corresponds to the JSON propertyname`
465 466 467 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 465 def name @name end |
#type ⇒ String
Corresponds to the JSON property type
470 471 472 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 470 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
477 478 479 480 481 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 477 def update!(**args) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @type = args[:type] if args.key?(:type) end |