Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiCategory
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiCategory
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
ApiCategory represents an API category. Catalog items can be tagged with
API categories; users viewing the API catalog in the portal will have the
option to browse the catalog by category.
Instance Attribute Summary collapse
-
#id ⇒ String
ID of the category (a UUID).
-
#name ⇒ String
Name of the category.
-
#site_id ⇒ String
Name of the portal.
-
#update_time ⇒ Fixnum
Time the category was last modified in milliseconds since epoch.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1ApiCategory
constructor
A new instance of GoogleCloudApigeeV1ApiCategory.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1ApiCategory
Returns a new instance of GoogleCloudApigeeV1ApiCategory.
599 600 601 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 599 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
ID of the category (a UUID).
Corresponds to the JSON property id
582 583 584 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 582 def id @id end |
#name ⇒ String
Name of the category.
Corresponds to the JSON property name
587 588 589 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 587 def name @name end |
#site_id ⇒ String
Name of the portal.
Corresponds to the JSON property siteId
592 593 594 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 592 def site_id @site_id end |
#update_time ⇒ Fixnum
Time the category was last modified in milliseconds since epoch.
Corresponds to the JSON property updateTime
597 598 599 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 597 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
604 605 606 607 608 609 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 604 def update!(**args) @id = args[:id] if args.key?(:id) @name = args[:name] if args.key?(:name) @site_id = args[:site_id] if args.key?(:site_id) @update_time = args[:update_time] if args.key?(:update_time) end |