Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiDebugSession

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Session carries the debug session id and its creation time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1ApiDebugSession

Returns a new instance of GoogleCloudApigeeV1ApiDebugSession.



682
683
684
# File 'lib/google/apis/apigee_v1/classes.rb', line 682

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_proxy_revision_idString

The revision ID of the deployed API proxy. Corresponds to the JSON property apiProxyRevisionId

Returns:

  • (String)


665
666
667
# File 'lib/google/apis/apigee_v1/classes.rb', line 665

def api_proxy_revision_id
  @api_proxy_revision_id
end

#create_timeString

The first transaction creation timestamp in millisecond, recorded by UAP. Corresponds to the JSON property createTime

Returns:

  • (String)


670
671
672
# File 'lib/google/apis/apigee_v1/classes.rb', line 670

def create_time
  @create_time
end

#environment_idString

The environment ID of the deployed API proxy. Corresponds to the JSON property environmentId

Returns:

  • (String)


675
676
677
# File 'lib/google/apis/apigee_v1/classes.rb', line 675

def environment_id
  @environment_id
end

#idString

The debug session ID. Corresponds to the JSON property id

Returns:

  • (String)


680
681
682
# File 'lib/google/apis/apigee_v1/classes.rb', line 680

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



687
688
689
690
691
692
# File 'lib/google/apis/apigee_v1/classes.rb', line 687

def update!(**args)
  @api_proxy_revision_id = args[:api_proxy_revision_id] if args.key?(:api_proxy_revision_id)
  @create_time = args[:create_time] if args.key?(:create_time)
  @environment_id = args[:environment_id] if args.key?(:environment_id)
  @id = args[:id] if args.key?(:id)
end