Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1AppGroupBalanceWallet
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1AppGroupBalanceWallet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Wallet used to manage an account balance for a particular currency.
Instance Attribute Summary collapse
-
#balance ⇒ Google::Apis::ApigeeV1::GoogleTypeMoney
Represents an amount of money with its currency type.
-
#last_credit_time ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1AppGroupBalanceWallet
constructor
A new instance of GoogleCloudApigeeV1AppGroupBalanceWallet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1AppGroupBalanceWallet
Returns a new instance of GoogleCloudApigeeV1AppGroupBalanceWallet.
2096 2097 2098 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2096 def initialize(**args) update!(**args) end |
Instance Attribute Details
#balance ⇒ Google::Apis::ApigeeV1::GoogleTypeMoney
Represents an amount of money with its currency type.
Corresponds to the JSON property balance
2088 2089 2090 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2088 def balance @balance end |
#last_credit_time ⇒ Fixnum
Output only. Time at which the AppGroup last added credit to the account in
milliseconds since epoch.
Corresponds to the JSON property lastCreditTime
2094 2095 2096 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2094 def last_credit_time @last_credit_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2101 2102 2103 2104 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2101 def update!(**args) @balance = args[:balance] if args.key?(:balance) @last_credit_time = args[:last_credit_time] if args.key?(:last_credit_time) end |