Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1AppGroupSubscription

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

AppGroup Subscription details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1AppGroupSubscription

Returns a new instance of GoogleCloudApigeeV1AppGroupSubscription.



2165
2166
2167
# File 'lib/google/apis/apigee_v1/classes.rb', line 2165

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#apiproductString

Required. Name of the API product for which the appgroup is purchasing a subscription. Corresponds to the JSON property apiproduct

Returns:

  • (String)


2134
2135
2136
# File 'lib/google/apis/apigee_v1/classes.rb', line 2134

def apiproduct
  @apiproduct
end

#created_atFixnum

Output only. Time when the API product subscription was created in milliseconds since epoch. Corresponds to the JSON property createdAt

Returns:

  • (Fixnum)


2140
2141
2142
# File 'lib/google/apis/apigee_v1/classes.rb', line 2140

def created_at
  @created_at
end

#end_timeFixnum

Output only. Time when the API product subscription ends in milliseconds since epoch. Corresponds to the JSON property endTime

Returns:

  • (Fixnum)


2146
2147
2148
# File 'lib/google/apis/apigee_v1/classes.rb', line 2146

def end_time
  @end_time
end

#last_modified_atFixnum

Output only. Time when the API product subscription was last modified in milliseconds since epoch. Corresponds to the JSON property lastModifiedAt

Returns:

  • (Fixnum)


2152
2153
2154
# File 'lib/google/apis/apigee_v1/classes.rb', line 2152

def last_modified_at
  @last_modified_at
end

#nameString

Output only. Name of the API product subscription. Corresponds to the JSON property name

Returns:

  • (String)


2157
2158
2159
# File 'lib/google/apis/apigee_v1/classes.rb', line 2157

def name
  @name
end

#start_timeFixnum

Output only. Time when the API product subscription starts in milliseconds since epoch. Corresponds to the JSON property startTime

Returns:

  • (Fixnum)


2163
2164
2165
# File 'lib/google/apis/apigee_v1/classes.rb', line 2163

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2170
2171
2172
2173
2174
2175
2176
2177
# File 'lib/google/apis/apigee_v1/classes.rb', line 2170

def update!(**args)
  @apiproduct = args[:apiproduct] if args.key?(:apiproduct)
  @created_at = args[:created_at] if args.key?(:created_at)
  @end_time = args[:end_time] if args.key?(:end_time)
  @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at)
  @name = args[:name] if args.key?(:name)
  @start_time = args[:start_time] if args.key?(:start_time)
end