Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ArchiveDeployment
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1ArchiveDeployment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Archive Deployment information.
Instance Attribute Summary collapse
-
#created_at ⇒ Fixnum
Output only.
-
#gcs_uri ⇒ String
Input only.
-
#labels ⇒ Hash<String,String>
User-supplied key-value pairs used to organize ArchiveDeployments.
-
#name ⇒ String
Name of the Archive Deployment in the following format:
organizations/org/ environments/env/archiveDeployments/id``. -
#operation ⇒ String
Output only.
-
#updated_at ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1ArchiveDeployment
constructor
A new instance of GoogleCloudApigeeV1ArchiveDeployment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1ArchiveDeployment
Returns a new instance of GoogleCloudApigeeV1ArchiveDeployment.
2225 2226 2227 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2225 def initialize(**args) update!(**args) end |
Instance Attribute Details
#created_at ⇒ Fixnum
Output only. The time at which the Archive Deployment was created in
milliseconds since the epoch.
Corresponds to the JSON property createdAt
2188 2189 2190 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2188 def created_at @created_at end |
#gcs_uri ⇒ String
Input only. The Google Cloud Storage signed URL returned from
GenerateUploadUrl and used to upload the Archive zip file.
Corresponds to the JSON property gcsUri
2194 2195 2196 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2194 def gcs_uri @gcs_uri end |
#labels ⇒ Hash<String,String>
User-supplied key-value pairs used to organize ArchiveDeployments. Label keys
must be between 1 and 63 characters long, have a UTF-8 encoding of maximum 128
bytes, and must conform to the following PCRE regular expression: \pLl\pLo
0,62 Label values must be between 1 and 63 characters long, have a UTF-8
encoding of maximum 128 bytes, and must conform to the following PCRE regular
expression: [\pLl\pLo\pN_-]0,63 No more than 64 labels can be
associated with a given store.
Corresponds to the JSON property labels
2205 2206 2207 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2205 def labels @labels end |
#name ⇒ String
Name of the Archive Deployment in the following format: organizations/org/
environments/env/archiveDeployments/id`.
Corresponds to the JSON propertyname`
2211 2212 2213 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2211 def name @name end |
#operation ⇒ String
Output only. A reference to the LRO that created this Archive Deployment in
the following format: organizations/org/operations/id`
Corresponds to the JSON propertyoperation`
2217 2218 2219 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2217 def operation @operation end |
#updated_at ⇒ Fixnum
Output only. The time at which the Archive Deployment was updated in
milliseconds since the epoch.
Corresponds to the JSON property updatedAt
2223 2224 2225 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2223 def updated_at @updated_at end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2230 2231 2232 2233 2234 2235 2236 2237 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2230 def update!(**args) @created_at = args[:created_at] if args.key?(:created_at) @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @operation = args[:operation] if args.key?(:operation) @updated_at = args[:updated_at] if args.key?(:updated_at) end |