Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1AsyncQuery
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1AsyncQuery
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Instance Attribute Summary collapse
-
#created ⇒ String
Creation time of the query.
-
#envgroup_hostname ⇒ String
Hostname is available only when query is executed at host level.
-
#error ⇒ String
Error is set when query fails.
-
#execution_time ⇒ String
ExecutionTime is available only after the query is completed.
-
#name ⇒ String
Asynchronous Query Name.
-
#query_params ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1QueryMetadata
Contains information like metrics, dimenstions etc of the AsyncQuery.
-
#report_definition_id ⇒ String
Asynchronous Report ID.
-
#result ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1AsyncQueryResult
Result is available only after the query is completed.
-
#result_file_size ⇒ String
ResultFileSize is available only after the query is completed.
-
#result_rows ⇒ Fixnum
ResultRows is available only after the query is completed.
-
#self ⇒ String
Self link of the query.
-
#state ⇒ String
Query state could be "enqueued", "running", "completed", "failed".
-
#updated ⇒ String
Last updated timestamp for the query.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1AsyncQuery
constructor
A new instance of GoogleCloudApigeeV1AsyncQuery.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1AsyncQuery
Returns a new instance of GoogleCloudApigeeV1AsyncQuery.
2300 2301 2302 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2300 def initialize(**args) update!(**args) end |
Instance Attribute Details
#created ⇒ String
Creation time of the query.
Corresponds to the JSON property created
2235 2236 2237 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2235 def created @created end |
#envgroup_hostname ⇒ String
Hostname is available only when query is executed at host level.
Corresponds to the JSON property envgroupHostname
2240 2241 2242 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2240 def envgroup_hostname @envgroup_hostname end |
#error ⇒ String
Error is set when query fails.
Corresponds to the JSON property error
2245 2246 2247 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2245 def error @error end |
#execution_time ⇒ String
ExecutionTime is available only after the query is completed.
Corresponds to the JSON property executionTime
2250 2251 2252 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2250 def execution_time @execution_time end |
#name ⇒ String
Asynchronous Query Name.
Corresponds to the JSON property name
2255 2256 2257 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2255 def name @name end |
#query_params ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1QueryMetadata
Contains information like metrics, dimenstions etc of the AsyncQuery.
Corresponds to the JSON property queryParams
2260 2261 2262 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2260 def query_params @query_params end |
#report_definition_id ⇒ String
Asynchronous Report ID.
Corresponds to the JSON property reportDefinitionId
2265 2266 2267 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2265 def report_definition_id @report_definition_id end |
#result ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1AsyncQueryResult
Result is available only after the query is completed.
Corresponds to the JSON property result
2270 2271 2272 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2270 def result @result end |
#result_file_size ⇒ String
ResultFileSize is available only after the query is completed.
Corresponds to the JSON property resultFileSize
2275 2276 2277 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2275 def result_file_size @result_file_size end |
#result_rows ⇒ Fixnum
ResultRows is available only after the query is completed.
Corresponds to the JSON property resultRows
2280 2281 2282 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2280 def result_rows @result_rows end |
#self ⇒ String
Self link of the query. Example: /organizations/myorg/environments/myenv/
queries/9cfc0d85-0f30-46d6-ae6f-318d0cb961bd or following format if query is
running at host level: /organizations/myorg/hostQueries/9cfc0d85-0f30-46d6-
ae6f-318d0cb961bd
Corresponds to the JSON property self
2288 2289 2290 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2288 def self @self end |
#state ⇒ String
Query state could be "enqueued", "running", "completed", "failed".
Corresponds to the JSON property state
2293 2294 2295 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2293 def state @state end |
#updated ⇒ String
Last updated timestamp for the query.
Corresponds to the JSON property updated
2298 2299 2300 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2298 def updated @updated end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2305 2306 2307 2308 2309 2310 2311 2312 2313 2314 2315 2316 2317 2318 2319 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2305 def update!(**args) @created = args[:created] if args.key?(:created) @envgroup_hostname = args[:envgroup_hostname] if args.key?(:envgroup_hostname) @error = args[:error] if args.key?(:error) @execution_time = args[:execution_time] if args.key?(:execution_time) @name = args[:name] if args.key?(:name) @query_params = args[:query_params] if args.key?(:query_params) @report_definition_id = args[:report_definition_id] if args.key?(:report_definition_id) @result = args[:result] if args.key?(:result) @result_file_size = args[:result_file_size] if args.key?(:result_file_size) @result_rows = args[:result_rows] if args.key?(:result_rows) @self = args[:self] if args.key?(:self) @state = args[:state] if args.key?(:state) @updated = args[:updated] if args.key?(:updated) end |