Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1AsyncQueryResultView
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1AsyncQueryResultView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Instance Attribute Summary collapse
-
#code ⇒ Fixnum
Error code when there is a failure.
-
#error ⇒ String
Error message when there is a failure.
-
#metadata ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1QueryMetadata
Metadata contains information like metrics, dimenstions etc of the AsyncQuery.
-
#rows ⇒ Array<Object>
Rows of query result.
-
#state ⇒ String
State of retrieving ResultView.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1AsyncQueryResultView
constructor
A new instance of GoogleCloudApigeeV1AsyncQueryResultView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1AsyncQueryResultView
Returns a new instance of GoogleCloudApigeeV1AsyncQueryResultView.
2411 2412 2413 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2411 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ Fixnum
Error code when there is a failure.
Corresponds to the JSON property code
2388 2389 2390 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2388 def code @code end |
#error ⇒ String
Error message when there is a failure.
Corresponds to the JSON property error
2393 2394 2395 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2393 def error @error end |
#metadata ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1QueryMetadata
Metadata contains information like metrics, dimenstions etc of the AsyncQuery.
Corresponds to the JSON property metadata
2398 2399 2400 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2398 def @metadata end |
#rows ⇒ Array<Object>
Rows of query result. Each row is a JSON object. Example: sum(message_count):
1, developer_app: "(not set)",…
Corresponds to the JSON property rows
2404 2405 2406 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2404 def rows @rows end |
#state ⇒ String
State of retrieving ResultView.
Corresponds to the JSON property state
2409 2410 2411 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2409 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2416 2417 2418 2419 2420 2421 2422 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2416 def update!(**args) @code = args[:code] if args.key?(:code) @error = args[:error] if args.key?(:error) @metadata = args[:metadata] if args.key?(:metadata) @rows = args[:rows] if args.key?(:rows) @state = args[:state] if args.key?(:state) end |