Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequestResourceArrayResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Resource for which we are computing security assessment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequestResourceArrayResource

Returns a new instance of GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequestResourceArrayResource.



2593
2594
2595
# File 'lib/google/apis/apigee_v1/classes.rb', line 2593

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Required. Name of this resource. For an Apigee API Proxy, this should be the id of the API proxy. For an API Hub Deployment, this should be the id of the deployment. Corresponds to the JSON property name

Returns:

  • (String)


2586
2587
2588
# File 'lib/google/apis/apigee_v1/classes.rb', line 2586

def name
  @name
end

#typeString

Required. Type of this resource. Corresponds to the JSON property type

Returns:

  • (String)


2591
2592
2593
# File 'lib/google/apis/apigee_v1/classes.rb', line 2591

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2598
2599
2600
2601
# File 'lib/google/apis/apigee_v1/classes.rb', line 2598

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end