Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1CreditAppGroupBalanceRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Request for CreditAppGroupBalance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1CreditAppGroupBalanceRequest

Returns a new instance of GoogleCloudApigeeV1CreditAppGroupBalanceRequest.



3172
3173
3174
# File 'lib/google/apis/apigee_v1/classes.rb', line 3172

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#transaction_amountGoogle::Apis::ApigeeV1::GoogleTypeMoney

Represents an amount of money with its currency type. Corresponds to the JSON property transactionAmount



3163
3164
3165
# File 'lib/google/apis/apigee_v1/classes.rb', line 3163

def transaction_amount
  @transaction_amount
end

#transaction_idString

Required. Each transaction_id uniquely identifies a credit balance request. If multiple requests are received with the same transaction_id, only one of them will be considered. Corresponds to the JSON property transactionId

Returns:

  • (String)


3170
3171
3172
# File 'lib/google/apis/apigee_v1/classes.rb', line 3170

def transaction_id
  @transaction_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3177
3178
3179
3180
# File 'lib/google/apis/apigee_v1/classes.rb', line 3177

def update!(**args)
  @transaction_amount = args[:transaction_amount] if args.key?(:transaction_amount)
  @transaction_id = args[:transaction_id] if args.key?(:transaction_id)
end