Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1CustomReport
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1CustomReport
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Instance Attribute Summary collapse
-
#chart_type ⇒ String
This field contains the chart type for the report Corresponds to the JSON property
chartType. -
#comments ⇒ Array<String>
Legacy field: not used.
-
#created_at ⇒ Fixnum
Output only.
-
#dimensions ⇒ Array<String>
This contains the list of dimensions for the report Corresponds to the JSON property
dimensions. -
#display_name ⇒ String
This is the display name for the report Corresponds to the JSON property
displayName. -
#environment ⇒ String
Output only.
-
#filter ⇒ String
This field contains the filter expression Corresponds to the JSON property
filter. -
#from_time ⇒ String
Legacy field: not used.
-
#last_modified_at ⇒ Fixnum
Output only.
-
#last_viewed_at ⇒ Fixnum
Output only.
-
#limit ⇒ String
Legacy field: not used This field contains the limit for the result retrieved Corresponds to the JSON property
limit. -
#metrics ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1CustomReportMetric>
Required.
-
#name ⇒ String
Required.
-
#offset ⇒ String
Legacy field: not used.
-
#organization ⇒ String
Output only.
-
#properties ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ReportProperty>
This field contains report properties such as ui metadata etc.
-
#sort_by_cols ⇒ Array<String>
Legacy field: not used much.
-
#sort_order ⇒ String
Legacy field: not used much.
-
#tags ⇒ Array<String>
Legacy field: not used.
-
#time_unit ⇒ String
This field contains the time unit of aggregation for the report Corresponds to the JSON property
timeUnit. -
#to_time ⇒ String
Legacy field: not used.
-
#topk ⇒ String
Legacy field: not used.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1CustomReport
constructor
A new instance of GoogleCloudApigeeV1CustomReport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1CustomReport
Returns a new instance of GoogleCloudApigeeV1CustomReport.
3329 3330 3331 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3329 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chart_type ⇒ String
This field contains the chart type for the report
Corresponds to the JSON property chartType
3217 3218 3219 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3217 def chart_type @chart_type end |
#comments ⇒ Array<String>
Legacy field: not used. This field contains a list of comments associated with
custom report
Corresponds to the JSON property comments
3223 3224 3225 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3223 def comments @comments end |
#created_at ⇒ Fixnum
Output only. Unix time when the app was created json key: createdAt
Corresponds to the JSON property createdAt
3228 3229 3230 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3228 def created_at @created_at end |
#dimensions ⇒ Array<String>
This contains the list of dimensions for the report
Corresponds to the JSON property dimensions
3233 3234 3235 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3233 def dimensions @dimensions end |
#display_name ⇒ String
This is the display name for the report
Corresponds to the JSON property displayName
3238 3239 3240 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3238 def display_name @display_name end |
#environment ⇒ String
Output only. Environment name
Corresponds to the JSON property environment
3243 3244 3245 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3243 def environment @environment end |
#filter ⇒ String
This field contains the filter expression
Corresponds to the JSON property filter
3248 3249 3250 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3248 def filter @filter end |
#from_time ⇒ String
Legacy field: not used. Contains the from time for the report
Corresponds to the JSON property fromTime
3253 3254 3255 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3253 def from_time @from_time end |
#last_modified_at ⇒ Fixnum
Output only. Modified time of this entity as milliseconds since epoch. json
key: lastModifiedAt
Corresponds to the JSON property lastModifiedAt
3259 3260 3261 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3259 def last_modified_at @last_modified_at end |
#last_viewed_at ⇒ Fixnum
Output only. Last viewed time of this entity as milliseconds since epoch
Corresponds to the JSON property lastViewedAt
3264 3265 3266 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3264 def last_viewed_at @last_viewed_at end |
#limit ⇒ String
Legacy field: not used This field contains the limit for the result retrieved
Corresponds to the JSON property limit
3269 3270 3271 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3269 def limit @limit end |
#metrics ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1CustomReportMetric>
Required. This contains the list of metrics
Corresponds to the JSON property metrics
3274 3275 3276 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3274 def metrics @metrics end |
#name ⇒ String
Required. Unique identifier for the report T his is a legacy field used to
encode custom report unique id
Corresponds to the JSON property name
3280 3281 3282 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3280 def name @name end |
#offset ⇒ String
Legacy field: not used. This field contains the offset for the data
Corresponds to the JSON property offset
3285 3286 3287 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3285 def offset @offset end |
#organization ⇒ String
Output only. Organization name
Corresponds to the JSON property organization
3290 3291 3292 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3290 def organization @organization end |
#properties ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ReportProperty>
This field contains report properties such as ui metadata etc.
Corresponds to the JSON property properties
3295 3296 3297 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3295 def properties @properties end |
#sort_by_cols ⇒ Array<String>
Legacy field: not used much. Contains the list of sort by columns
Corresponds to the JSON property sortByCols
3300 3301 3302 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3300 def sort_by_cols @sort_by_cols end |
#sort_order ⇒ String
Legacy field: not used much. Contains the sort order for the sort columns
Corresponds to the JSON property sortOrder
3305 3306 3307 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3305 def sort_order @sort_order end |
#tags ⇒ Array<String>
Legacy field: not used. This field contains a list of tags associated with
custom report
Corresponds to the JSON property tags
3311 3312 3313 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3311 def @tags end |
#time_unit ⇒ String
This field contains the time unit of aggregation for the report
Corresponds to the JSON property timeUnit
3316 3317 3318 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3316 def time_unit @time_unit end |
#to_time ⇒ String
Legacy field: not used. Contains the end time for the report
Corresponds to the JSON property toTime
3321 3322 3323 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3321 def to_time @to_time end |
#topk ⇒ String
Legacy field: not used. This field contains the top k parameter value for
restricting the result
Corresponds to the JSON property topk
3327 3328 3329 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3327 def topk @topk end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3334 3335 3336 3337 3338 3339 3340 3341 3342 3343 3344 3345 3346 3347 3348 3349 3350 3351 3352 3353 3354 3355 3356 3357 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3334 def update!(**args) @chart_type = args[:chart_type] if args.key?(:chart_type) @comments = args[:comments] if args.key?(:comments) @created_at = args[:created_at] if args.key?(:created_at) @dimensions = args[:dimensions] if args.key?(:dimensions) @display_name = args[:display_name] if args.key?(:display_name) @environment = args[:environment] if args.key?(:environment) @filter = args[:filter] if args.key?(:filter) @from_time = args[:from_time] if args.key?(:from_time) @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at) @last_viewed_at = args[:last_viewed_at] if args.key?(:last_viewed_at) @limit = args[:limit] if args.key?(:limit) @metrics = args[:metrics] if args.key?(:metrics) @name = args[:name] if args.key?(:name) @offset = args[:offset] if args.key?(:offset) @organization = args[:organization] if args.key?(:organization) @properties = args[:properties] if args.key?(:properties) @sort_by_cols = args[:sort_by_cols] if args.key?(:sort_by_cols) @sort_order = args[:sort_order] if args.key?(:sort_order) @tags = args[:tags] if args.key?(:tags) @time_unit = args[:time_unit] if args.key?(:time_unit) @to_time = args[:to_time] if args.key?(:to_time) @topk = args[:topk] if args.key?(:topk) end |