Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1DataCollector

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Data collector configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1DataCollector

Returns a new instance of GoogleCloudApigeeV1DataCollector.



3448
3449
3450
# File 'lib/google/apis/apigee_v1/classes.rb', line 3448

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#created_atFixnum

Output only. The time at which the data collector was created in milliseconds since the epoch. Corresponds to the JSON property createdAt

Returns:

  • (Fixnum)


3425
3426
3427
# File 'lib/google/apis/apigee_v1/classes.rb', line 3425

def created_at
  @created_at
end

#descriptionString

A description of the data collector. Corresponds to the JSON property description

Returns:

  • (String)


3430
3431
3432
# File 'lib/google/apis/apigee_v1/classes.rb', line 3430

def description
  @description
end

#last_modified_atFixnum

Output only. The time at which the Data Collector was last updated in milliseconds since the epoch. Corresponds to the JSON property lastModifiedAt

Returns:

  • (Fixnum)


3436
3437
3438
# File 'lib/google/apis/apigee_v1/classes.rb', line 3436

def last_modified_at
  @last_modified_at
end

#nameString

ID of the data collector. Must begin with dc_. Corresponds to the JSON property name

Returns:

  • (String)


3441
3442
3443
# File 'lib/google/apis/apigee_v1/classes.rb', line 3441

def name
  @name
end

#typeString

Immutable. The type of data this data collector will collect. Corresponds to the JSON property type

Returns:

  • (String)


3446
3447
3448
# File 'lib/google/apis/apigee_v1/classes.rb', line 3446

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3453
3454
3455
3456
3457
3458
3459
# File 'lib/google/apis/apigee_v1/classes.rb', line 3453

def update!(**args)
  @created_at = args[:created_at] if args.key?(:created_at)
  @description = args[:description] if args.key?(:description)
  @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end