Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1DatastoreConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Configuration detail for datastore

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1DatastoreConfig

Returns a new instance of GoogleCloudApigeeV1DatastoreConfig.



3545
3546
3547
# File 'lib/google/apis/apigee_v1/classes.rb', line 3545

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bucket_nameString

Name of the Cloud Storage bucket. Required for gcs target_type. Corresponds to the JSON property bucketName

Returns:

  • (String)


3523
3524
3525
# File 'lib/google/apis/apigee_v1/classes.rb', line 3523

def bucket_name
  @bucket_name
end

#dataset_nameString

BigQuery dataset name Required for bigquery target_type. Corresponds to the JSON property datasetName

Returns:

  • (String)


3528
3529
3530
# File 'lib/google/apis/apigee_v1/classes.rb', line 3528

def dataset_name
  @dataset_name
end

#pathString

Path of Cloud Storage bucket Required for gcs target_type. Corresponds to the JSON property path

Returns:

  • (String)


3533
3534
3535
# File 'lib/google/apis/apigee_v1/classes.rb', line 3533

def path
  @path
end

#project_idString

Required. Google Cloud project in which the datastore exists Corresponds to the JSON property projectId

Returns:

  • (String)


3538
3539
3540
# File 'lib/google/apis/apigee_v1/classes.rb', line 3538

def project_id
  @project_id
end

#table_prefixString

Prefix of BigQuery table Required for bigquery target_type. Corresponds to the JSON property tablePrefix

Returns:

  • (String)


3543
3544
3545
# File 'lib/google/apis/apigee_v1/classes.rb', line 3543

def table_prefix
  @table_prefix
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3550
3551
3552
3553
3554
3555
3556
# File 'lib/google/apis/apigee_v1/classes.rb', line 3550

def update!(**args)
  @bucket_name = args[:bucket_name] if args.key?(:bucket_name)
  @dataset_name = args[:dataset_name] if args.key?(:dataset_name)
  @path = args[:path] if args.key?(:path)
  @project_id = args[:project_id] if args.key?(:project_id)
  @table_prefix = args[:table_prefix] if args.key?(:table_prefix)
end