Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1DebugMask
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1DebugMask
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Instance Attribute Summary collapse
-
#fault_json_paths ⇒ Array<String>
List of JSON paths that specify the JSON elements to be filtered from JSON payloads in error flows.
-
#fault_x_paths ⇒ Array<String>
List of XPaths that specify the XML elements to be filtered from XML payloads in error flows.
-
#name ⇒ String
Name of the debug mask.
-
#namespaces ⇒ Hash<String,String>
Map of namespaces to URIs.
-
#request_json_paths ⇒ Array<String>
List of JSON paths that specify the JSON elements to be filtered from JSON request message payloads.
-
#request_x_paths ⇒ Array<String>
List of XPaths that specify the XML elements to be filtered from XML request message payloads.
-
#response_json_paths ⇒ Array<String>
List of JSON paths that specify the JSON elements to be filtered from JSON response message payloads.
-
#response_x_paths ⇒ Array<String>
List of XPaths that specify the XML elements to be filtered from XML response message payloads.
-
#variables ⇒ Array<String>
List of variables that should be masked from the debug output.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1DebugMask
constructor
A new instance of GoogleCloudApigeeV1DebugMask.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1DebugMask
Returns a new instance of GoogleCloudApigeeV1DebugMask.
3624 3625 3626 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3624 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fault_json_paths ⇒ Array<String>
List of JSON paths that specify the JSON elements to be filtered from JSON
payloads in error flows.
Corresponds to the JSON property faultJSONPaths
3577 3578 3579 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3577 def fault_json_paths @fault_json_paths end |
#fault_x_paths ⇒ Array<String>
List of XPaths that specify the XML elements to be filtered from XML payloads
in error flows.
Corresponds to the JSON property faultXPaths
3583 3584 3585 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3583 def fault_x_paths @fault_x_paths end |
#name ⇒ String
Name of the debug mask.
Corresponds to the JSON property name
3588 3589 3590 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3588 def name @name end |
#namespaces ⇒ Hash<String,String>
Map of namespaces to URIs.
Corresponds to the JSON property namespaces
3593 3594 3595 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3593 def namespaces @namespaces end |
#request_json_paths ⇒ Array<String>
List of JSON paths that specify the JSON elements to be filtered from JSON
request message payloads.
Corresponds to the JSON property requestJSONPaths
3599 3600 3601 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3599 def request_json_paths @request_json_paths end |
#request_x_paths ⇒ Array<String>
List of XPaths that specify the XML elements to be filtered from XML request
message payloads.
Corresponds to the JSON property requestXPaths
3605 3606 3607 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3605 def request_x_paths @request_x_paths end |
#response_json_paths ⇒ Array<String>
List of JSON paths that specify the JSON elements to be filtered from JSON
response message payloads.
Corresponds to the JSON property responseJSONPaths
3611 3612 3613 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3611 def response_json_paths @response_json_paths end |
#response_x_paths ⇒ Array<String>
List of XPaths that specify the XML elements to be filtered from XML response
message payloads.
Corresponds to the JSON property responseXPaths
3617 3618 3619 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3617 def response_x_paths @response_x_paths end |
#variables ⇒ Array<String>
List of variables that should be masked from the debug output.
Corresponds to the JSON property variables
3622 3623 3624 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3622 def variables @variables end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3629 3630 3631 3632 3633 3634 3635 3636 3637 3638 3639 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3629 def update!(**args) @fault_json_paths = args[:fault_json_paths] if args.key?(:fault_json_paths) @fault_x_paths = args[:fault_x_paths] if args.key?(:fault_x_paths) @name = args[:name] if args.key?(:name) @namespaces = args[:namespaces] if args.key?(:namespaces) @request_json_paths = args[:request_json_paths] if args.key?(:request_json_paths) @request_x_paths = args[:request_x_paths] if args.key?(:request_x_paths) @response_json_paths = args[:response_json_paths] if args.key?(:response_json_paths) @response_x_paths = args[:response_x_paths] if args.key?(:response_x_paths) @variables = args[:variables] if args.key?(:variables) end |