Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeploymentChangeReportRoutingConflict
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeploymentChangeReportRoutingConflict
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Describes a routing conflict that may cause a deployment not to receive traffic at some base path.
Instance Attribute Summary collapse
-
#conflicting_deployment ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeploymentChangeReportRoutingDeployment
Tuple representing a base path and the deployment containing it.
-
#description ⇒ String
Human-readable description of this conflict.
-
#environment_group ⇒ String
Name of the environment group in which this conflict exists.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1DeploymentChangeReportRoutingConflict
constructor
A new instance of GoogleCloudApigeeV1DeploymentChangeReportRoutingConflict.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1DeploymentChangeReportRoutingConflict
Returns a new instance of GoogleCloudApigeeV1DeploymentChangeReportRoutingConflict.
4017 4018 4019 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4017 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conflicting_deployment ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeploymentChangeReportRoutingDeployment
Tuple representing a base path and the deployment containing it.
Corresponds to the JSON property conflictingDeployment
4005 4006 4007 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4005 def conflicting_deployment @conflicting_deployment end |
#description ⇒ String
Human-readable description of this conflict.
Corresponds to the JSON property description
4010 4011 4012 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4010 def description @description end |
#environment_group ⇒ String
Name of the environment group in which this conflict exists.
Corresponds to the JSON property environmentGroup
4015 4016 4017 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4015 def environment_group @environment_group end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4022 4023 4024 4025 4026 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4022 def update!(**args) @conflicting_deployment = args[:conflicting_deployment] if args.key?(:conflicting_deployment) @description = args[:description] if args.key?(:description) @environment_group = args[:environment_group] if args.key?(:environment_group) end |