Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeploymentConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

NEXT ID: 11

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1DeploymentConfig

Returns a new instance of GoogleCloudApigeeV1DeploymentConfig.



4111
4112
4113
# File 'lib/google/apis/apigee_v1/classes.rb', line 4111

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributesHash<String,String>

Additional key-value metadata for the deployment. Corresponds to the JSON property attributes

Returns:

  • (Hash<String,String>)


4064
4065
4066
# File 'lib/google/apis/apigee_v1/classes.rb', line 4064

def attributes
  @attributes
end

#base_pathString

Base path where the application will be hosted. Defaults to "/". Corresponds to the JSON property basePath

Returns:

  • (String)


4069
4070
4071
# File 'lib/google/apis/apigee_v1/classes.rb', line 4069

def base_path
  @base_path
end

#deployment_groupsArray<String>

The list of deployment groups in which this proxy should be deployed. Not currently populated for shared flows. Corresponds to the JSON property deploymentGroups

Returns:

  • (Array<String>)


4075
4076
4077
# File 'lib/google/apis/apigee_v1/classes.rb', line 4075

def deployment_groups
  @deployment_groups
end

#endpointsHash<String,String>

A mapping from basepaths to proxy endpoint names in this proxy. Not populated for shared flows. Corresponds to the JSON property endpoints

Returns:

  • (Hash<String,String>)


4081
4082
4083
# File 'lib/google/apis/apigee_v1/classes.rb', line 4081

def endpoints
  @endpoints
end

#locationString

Location of the API proxy bundle as a URI. Corresponds to the JSON property location

Returns:

  • (String)


4086
4087
4088
# File 'lib/google/apis/apigee_v1/classes.rb', line 4086

def location
  @location
end

#nameString

Name of the API or shared flow revision to be deployed in the following format: organizations/org/apis/api/revisions/revor `organizations/`org`/ sharedflows/`sharedflow`/revisions/`rev Corresponds to the JSON property name

Returns:

  • (String)


4093
4094
4095
# File 'lib/google/apis/apigee_v1/classes.rb', line 4093

def name
  @name
end

#proxy_uidString

Unique ID of the API proxy revision. Corresponds to the JSON property proxyUid

Returns:

  • (String)


4098
4099
4100
# File 'lib/google/apis/apigee_v1/classes.rb', line 4098

def proxy_uid
  @proxy_uid
end

#service_accountString

The service account identity associated with this deployment. If non-empty, will be in the following format: projects/-/serviceAccounts/account_email` Corresponds to the JSON propertyserviceAccount`

Returns:

  • (String)


4104
4105
4106
# File 'lib/google/apis/apigee_v1/classes.rb', line 4104

def 
  @service_account
end

#uidString

Unique ID. The ID will only change if the deployment is deleted and recreated. Corresponds to the JSON property uid

Returns:

  • (String)


4109
4110
4111
# File 'lib/google/apis/apigee_v1/classes.rb', line 4109

def uid
  @uid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4116
4117
4118
4119
4120
4121
4122
4123
4124
4125
4126
# File 'lib/google/apis/apigee_v1/classes.rb', line 4116

def update!(**args)
  @attributes = args[:attributes] if args.key?(:attributes)
  @base_path = args[:base_path] if args.key?(:base_path)
  @deployment_groups = args[:deployment_groups] if args.key?(:deployment_groups)
  @endpoints = args[:endpoints] if args.key?(:endpoints)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @proxy_uid = args[:proxy_uid] if args.key?(:proxy_uid)
  @service_account = args[:service_account] if args.key?(:service_account)
  @uid = args[:uid] if args.key?(:uid)
end