Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Developer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1Developer

Returns a new instance of GoogleCloudApigeeV1Developer.



4259
4260
4261
# File 'lib/google/apis/apigee_v1/classes.rb', line 4259

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_typeString

Access type. Corresponds to the JSON property accessType

Returns:

  • (String)


4186
4187
4188
# File 'lib/google/apis/apigee_v1/classes.rb', line 4186

def access_type
  @access_type
end

#app_familyString

Developer app family. Corresponds to the JSON property appFamily

Returns:

  • (String)


4191
4192
4193
# File 'lib/google/apis/apigee_v1/classes.rb', line 4191

def app_family
  @app_family
end

#appsArray<String>

List of apps associated with the developer. Corresponds to the JSON property apps

Returns:

  • (Array<String>)


4196
4197
4198
# File 'lib/google/apis/apigee_v1/classes.rb', line 4196

def apps
  @apps
end

#attributesArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>

Optional. Developer attributes (name/value pairs). The custom attribute limit is 18. Corresponds to the JSON property attributes



4202
4203
4204
# File 'lib/google/apis/apigee_v1/classes.rb', line 4202

def attributes
  @attributes
end

#companiesArray<String>

List of companies associated with the developer. Corresponds to the JSON property companies

Returns:

  • (Array<String>)


4207
4208
4209
# File 'lib/google/apis/apigee_v1/classes.rb', line 4207

def companies
  @companies
end

#created_atFixnum

Output only. Time at which the developer was created in milliseconds since epoch. Corresponds to the JSON property createdAt

Returns:

  • (Fixnum)


4213
4214
4215
# File 'lib/google/apis/apigee_v1/classes.rb', line 4213

def created_at
  @created_at
end

#developer_idString

ID of the developer. Note: IDs are generated internally by Apigee and are not guaranteed to stay the same over time. Corresponds to the JSON property developerId

Returns:

  • (String)


4219
4220
4221
# File 'lib/google/apis/apigee_v1/classes.rb', line 4219

def developer_id
  @developer_id
end

#emailString

Required. Email address of the developer. This value is used to uniquely identify the developer in Apigee hybrid. Note that the email address has to be in lowercase only. Corresponds to the JSON property email

Returns:

  • (String)


4226
4227
4228
# File 'lib/google/apis/apigee_v1/classes.rb', line 4226

def email
  @email
end

#first_nameString

Required. First name of the developer. Corresponds to the JSON property firstName

Returns:

  • (String)


4231
4232
4233
# File 'lib/google/apis/apigee_v1/classes.rb', line 4231

def first_name
  @first_name
end

#last_modified_atFixnum

Output only. Time at which the developer was last modified in milliseconds since epoch. Corresponds to the JSON property lastModifiedAt

Returns:

  • (Fixnum)


4237
4238
4239
# File 'lib/google/apis/apigee_v1/classes.rb', line 4237

def last_modified_at
  @last_modified_at
end

#last_nameString

Required. Last name of the developer. Corresponds to the JSON property lastName

Returns:

  • (String)


4242
4243
4244
# File 'lib/google/apis/apigee_v1/classes.rb', line 4242

def last_name
  @last_name
end

#organization_nameString

Output only. Name of the Apigee organization in which the developer resides. Corresponds to the JSON property organizationName

Returns:

  • (String)


4247
4248
4249
# File 'lib/google/apis/apigee_v1/classes.rb', line 4247

def organization_name
  @organization_name
end

#statusString

Output only. Status of the developer. Valid values are active and inactive. Corresponds to the JSON property status

Returns:

  • (String)


4252
4253
4254
# File 'lib/google/apis/apigee_v1/classes.rb', line 4252

def status
  @status
end

#user_nameString

Required. User name of the developer. Not used by Apigee hybrid. Corresponds to the JSON property userName

Returns:

  • (String)


4257
4258
4259
# File 'lib/google/apis/apigee_v1/classes.rb', line 4257

def user_name
  @user_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4264
4265
4266
4267
4268
4269
4270
4271
4272
4273
4274
4275
4276
4277
4278
4279
# File 'lib/google/apis/apigee_v1/classes.rb', line 4264

def update!(**args)
  @access_type = args[:access_type] if args.key?(:access_type)
  @app_family = args[:app_family] if args.key?(:app_family)
  @apps = args[:apps] if args.key?(:apps)
  @attributes = args[:attributes] if args.key?(:attributes)
  @companies = args[:companies] if args.key?(:companies)
  @created_at = args[:created_at] if args.key?(:created_at)
  @developer_id = args[:developer_id] if args.key?(:developer_id)
  @email = args[:email] if args.key?(:email)
  @first_name = args[:first_name] if args.key?(:first_name)
  @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at)
  @last_name = args[:last_name] if args.key?(:last_name)
  @organization_name = args[:organization_name] if args.key?(:organization_name)
  @status = args[:status] if args.key?(:status)
  @user_name = args[:user_name] if args.key?(:user_name)
end