Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeveloperBalanceWallet
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeveloperBalanceWallet
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Wallet used to manage an account balance for a particular currency.
Instance Attribute Summary collapse
-
#balance ⇒ Google::Apis::ApigeeV1::GoogleTypeMoney
Represents an amount of money with its currency type.
-
#last_credit_time ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1DeveloperBalanceWallet
constructor
A new instance of GoogleCloudApigeeV1DeveloperBalanceWallet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1DeveloperBalanceWallet
Returns a new instance of GoogleCloudApigeeV1DeveloperBalanceWallet.
4518 4519 4520 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4518 def initialize(**args) update!(**args) end |
Instance Attribute Details
#balance ⇒ Google::Apis::ApigeeV1::GoogleTypeMoney
Represents an amount of money with its currency type.
Corresponds to the JSON property balance
4510 4511 4512 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4510 def balance @balance end |
#last_credit_time ⇒ Fixnum
Output only. Time at which the developer last added credit to the account in
milliseconds since epoch.
Corresponds to the JSON property lastCreditTime
4516 4517 4518 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4516 def last_credit_time @last_credit_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4523 4524 4525 4526 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4523 def update!(**args) @balance = args[:balance] if args.key?(:balance) @last_credit_time = args[:last_credit_time] if args.key?(:last_credit_time) end |