Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeveloperSubscription

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Structure of a DeveloperSubscription.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1DeveloperSubscription

Returns a new instance of GoogleCloudApigeeV1DeveloperSubscription.



4553
4554
4555
# File 'lib/google/apis/apigee_v1/classes.rb', line 4553

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#apiproductString

Name of the API product for which the developer is purchasing a subscription. Corresponds to the JSON property apiproduct

Returns:

  • (String)


4524
4525
4526
# File 'lib/google/apis/apigee_v1/classes.rb', line 4524

def apiproduct
  @apiproduct
end

#created_atFixnum

Output only. Time when the API product subscription was created in milliseconds since epoch. Corresponds to the JSON property createdAt

Returns:

  • (Fixnum)


4530
4531
4532
# File 'lib/google/apis/apigee_v1/classes.rb', line 4530

def created_at
  @created_at
end

#end_timeFixnum

Time when the API product subscription ends in milliseconds since epoch. Corresponds to the JSON property endTime

Returns:

  • (Fixnum)


4535
4536
4537
# File 'lib/google/apis/apigee_v1/classes.rb', line 4535

def end_time
  @end_time
end

#last_modified_atFixnum

Output only. Time when the API product subscription was last modified in milliseconds since epoch. Corresponds to the JSON property lastModifiedAt

Returns:

  • (Fixnum)


4541
4542
4543
# File 'lib/google/apis/apigee_v1/classes.rb', line 4541

def last_modified_at
  @last_modified_at
end

#nameString

Output only. Name of the API product subscription. Corresponds to the JSON property name

Returns:

  • (String)


4546
4547
4548
# File 'lib/google/apis/apigee_v1/classes.rb', line 4546

def name
  @name
end

#start_timeFixnum

Time when the API product subscription starts in milliseconds since epoch. Corresponds to the JSON property startTime

Returns:

  • (Fixnum)


4551
4552
4553
# File 'lib/google/apis/apigee_v1/classes.rb', line 4551

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4558
4559
4560
4561
4562
4563
4564
4565
# File 'lib/google/apis/apigee_v1/classes.rb', line 4558

def update!(**args)
  @apiproduct = args[:apiproduct] if args.key?(:apiproduct)
  @created_at = args[:created_at] if args.key?(:created_at)
  @end_time = args[:end_time] if args.key?(:end_time)
  @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at)
  @name = args[:name] if args.key?(:name)
  @start_time = args[:start_time] if args.key?(:start_time)
end