Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1DnsZone
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1DnsZone
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
A DNS zone is a resource under an Apigee organization that is used to create a DNS peering with Apigee's network. DNS peering will let Apigee instances resolve the hostnames created in a peered network.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Required.
-
#domain ⇒ String
Required.
-
#name ⇒ String
Identifier.
-
#peering_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1DnsZonePeeringConfig
Fields for DNS PEERING zone.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1DnsZone
constructor
A new instance of GoogleCloudApigeeV1DnsZone.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1DnsZone
Returns a new instance of GoogleCloudApigeeV1DnsZone.
4650 4651 4652 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4650 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time that this resource was created on the server.
Corresponds to the JSON property createTime
4614 4615 4616 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4614 def create_time @create_time end |
#description ⇒ String
Required. Description of the resource. String of at most 1024 characters
associated with this resource for the user's convenience.
Corresponds to the JSON property description
4620 4621 4622 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4620 def description @description end |
#domain ⇒ String
Required. The domain name for hosts in this private zone, for instance "
example.com.".
Corresponds to the JSON property domain
4626 4627 4628 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4626 def domain @domain end |
#name ⇒ String
Identifier. Unique name for the resource. Defined by the server Format: "
organizations/organization/dnsZones/dns_zone".
Corresponds to the JSON property name
4632 4633 4634 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4632 def name @name end |
#peering_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1DnsZonePeeringConfig
Fields for DNS PEERING zone.
Corresponds to the JSON property peeringConfig
4637 4638 4639 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4637 def peering_config @peering_config end |
#state ⇒ String
Output only. State of the DNS Peering. Values other than ACTIVE mean the
resource is not ready to use.
Corresponds to the JSON property state
4643 4644 4645 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4643 def state @state end |
#update_time ⇒ String
Output only. The time that this resource was updated on the server.
Corresponds to the JSON property updateTime
4648 4649 4650 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4648 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4655 4656 4657 4658 4659 4660 4661 4662 4663 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4655 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @domain = args[:domain] if args.key?(:domain) @name = args[:name] if args.key?(:name) @peering_config = args[:peering_config] if args.key?(:peering_config) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |