Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1EndpointAttachment
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1EndpointAttachment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Apigee endpoint attachment. For more information, see Southbound networking patterns.
Instance Attribute Summary collapse
-
#connection_state ⇒ String
Output only.
-
#host ⇒ String
Output only.
-
#location ⇒ String
Required.
-
#name ⇒ String
Name of the endpoint attachment.
-
#service_attachment ⇒ String
Format: projects//regions//serviceAttachments/* Corresponds to the JSON property
serviceAttachment. -
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1EndpointAttachment
constructor
A new instance of GoogleCloudApigeeV1EndpointAttachment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1EndpointAttachment
Returns a new instance of GoogleCloudApigeeV1EndpointAttachment.
4782 4783 4784 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4782 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connection_state ⇒ String
Output only. State of the endpoint attachment connection to the service
attachment.
Corresponds to the JSON property connectionState
4752 4753 4754 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4752 def connection_state @connection_state end |
#host ⇒ String
Output only. Host that can be used in either the HTTP target endpoint directly
or as the host in target server.
Corresponds to the JSON property host
4758 4759 4760 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4758 def host @host end |
#location ⇒ String
Required. Location of the endpoint attachment.
Corresponds to the JSON property location
4763 4764 4765 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4763 def location @location end |
#name ⇒ String
Name of the endpoint attachment. Use the following structure in your request:
organizations/org/endpointAttachments/endpoint_attachment`
Corresponds to the JSON propertyname`
4769 4770 4771 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4769 def name @name end |
#service_attachment ⇒ String
Format: projects//regions//serviceAttachments/*
Corresponds to the JSON property serviceAttachment
4774 4775 4776 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4774 def @service_attachment end |
#state ⇒ String
Output only. State of the endpoint attachment. Values other than ACTIVE mean
the resource is not ready to use.
Corresponds to the JSON property state
4780 4781 4782 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4780 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4787 4788 4789 4790 4791 4792 4793 4794 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4787 def update!(**args) @connection_state = args[:connection_state] if args.key?(:connection_state) @host = args[:host] if args.key?(:host) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @service_attachment = args[:service_attachment] if args.key?(:service_attachment) @state = args[:state] if args.key?(:state) end |