Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1EndpointChainingRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

EndpointChainingRule specifies the proxies contained in a particular deployment group, so that other deployment groups can find them in chaining calls.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1EndpointChainingRule

Returns a new instance of GoogleCloudApigeeV1EndpointChainingRule.



4804
4805
4806
# File 'lib/google/apis/apigee_v1/classes.rb', line 4804

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deployment_groupString

The deployment group to target for cross-shard chaining calls to these proxies. Corresponds to the JSON property deploymentGroup

Returns:

  • (String)


4797
4798
4799
# File 'lib/google/apis/apigee_v1/classes.rb', line 4797

def deployment_group
  @deployment_group
end

#proxy_idsArray<String>

List of proxy ids which may be found in the given deployment group. Corresponds to the JSON property proxyIds

Returns:

  • (Array<String>)


4802
4803
4804
# File 'lib/google/apis/apigee_v1/classes.rb', line 4802

def proxy_ids
  @proxy_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4809
4810
4811
4812
# File 'lib/google/apis/apigee_v1/classes.rb', line 4809

def update!(**args)
  @deployment_group = args[:deployment_group] if args.key?(:deployment_group)
  @proxy_ids = args[:proxy_ids] if args.key?(:proxy_ids)
end