Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1EntityMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1EntityMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Metadata common to many entities in this API.
Instance Attribute Summary collapse
-
#created_at ⇒ Fixnum
Time at which the API proxy was created, in milliseconds since epoch.
-
#last_modified_at ⇒ Fixnum
Time at which the API proxy was most recently modified, in milliseconds since epoch.
-
#sub_type ⇒ String
The type of entity described Corresponds to the JSON property
subType.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1EntityMetadata
constructor
A new instance of GoogleCloudApigeeV1EntityMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1EntityMetadata
Returns a new instance of GoogleCloudApigeeV1EntityMetadata.
4826 4827 4828 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4826 def initialize(**args) update!(**args) end |
Instance Attribute Details
#created_at ⇒ Fixnum
Time at which the API proxy was created, in milliseconds since epoch.
Corresponds to the JSON property createdAt
4813 4814 4815 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4813 def created_at @created_at end |
#last_modified_at ⇒ Fixnum
Time at which the API proxy was most recently modified, in milliseconds since
epoch.
Corresponds to the JSON property lastModifiedAt
4819 4820 4821 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4819 def last_modified_at @last_modified_at end |
#sub_type ⇒ String
The type of entity described
Corresponds to the JSON property subType
4824 4825 4826 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4824 def sub_type @sub_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4831 4832 4833 4834 4835 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4831 def update!(**args) @created_at = args[:created_at] if args.key?(:created_at) @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at) @sub_type = args[:sub_type] if args.key?(:sub_type) end |