Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1EnvironmentClientIpResolutionConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1EnvironmentClientIpResolutionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Configuration for resolving the client ip.
Instance Attribute Summary collapse
-
#header_index_algorithm ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1EnvironmentClientIpResolutionConfigHeaderIndexAlgorithm
Resolves the client ip based on a custom header.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1EnvironmentClientIpResolutionConfig
constructor
A new instance of GoogleCloudApigeeV1EnvironmentClientIpResolutionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1EnvironmentClientIpResolutionConfig
Returns a new instance of GoogleCloudApigeeV1EnvironmentClientIpResolutionConfig.
4963 4964 4965 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4963 def initialize(**args) update!(**args) end |
Instance Attribute Details
#header_index_algorithm ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1EnvironmentClientIpResolutionConfigHeaderIndexAlgorithm
Resolves the client ip based on a custom header.
Corresponds to the JSON property headerIndexAlgorithm
4961 4962 4963 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4961 def header_index_algorithm @header_index_algorithm end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4968 4969 4970 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4968 def update!(**args) @header_index_algorithm = args[:header_index_algorithm] if args.key?(:header_index_algorithm) end |