Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1EnvironmentGroup
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1EnvironmentGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
EnvironmentGroup configuration. An environment group is used to group one or more Apigee environments under a single host name.
Instance Attribute Summary collapse
-
#created_at ⇒ Fixnum
Output only.
-
#hostnames ⇒ Array<String>
Required.
-
#last_modified_at ⇒ Fixnum
Output only.
-
#name ⇒ String
ID of the environment group.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1EnvironmentGroup
constructor
A new instance of GoogleCloudApigeeV1EnvironmentGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1EnvironmentGroup
Returns a new instance of GoogleCloudApigeeV1EnvironmentGroup.
5266 5267 5268 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5266 def initialize(**args) update!(**args) end |
Instance Attribute Details
#created_at ⇒ Fixnum
Output only. The time at which the environment group was created as
milliseconds since epoch.
Corresponds to the JSON property createdAt
5242 5243 5244 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5242 def created_at @created_at end |
#hostnames ⇒ Array<String>
Required. Host names for this environment group.
Corresponds to the JSON property hostnames
5247 5248 5249 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5247 def hostnames @hostnames end |
#last_modified_at ⇒ Fixnum
Output only. The time at which the environment group was last updated as
milliseconds since epoch.
Corresponds to the JSON property lastModifiedAt
5253 5254 5255 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5253 def last_modified_at @last_modified_at end |
#name ⇒ String
ID of the environment group.
Corresponds to the JSON property name
5258 5259 5260 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5258 def name @name end |
#state ⇒ String
Output only. State of the environment group. Values other than ACTIVE means
the resource is not ready to use.
Corresponds to the JSON property state
5264 5265 5266 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5264 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5271 5272 5273 5274 5275 5276 5277 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5271 def update!(**args) @created_at = args[:created_at] if args.key?(:created_at) @hostnames = args[:hostnames] if args.key?(:hostnames) @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) end |