Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1EnvironmentGroupAttachment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

EnvironmentGroupAttachment is a resource which defines an attachment of an environment to an environment group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1EnvironmentGroupAttachment

Returns a new instance of GoogleCloudApigeeV1EnvironmentGroupAttachment.



5289
5290
5291
# File 'lib/google/apis/apigee_v1/classes.rb', line 5289

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#created_atFixnum

Output only. The time at which the environment group attachment was created as milliseconds since epoch. Corresponds to the JSON property createdAt

Returns:

  • (Fixnum)


5272
5273
5274
# File 'lib/google/apis/apigee_v1/classes.rb', line 5272

def created_at
  @created_at
end

#environmentString

Required. ID of the attached environment. Corresponds to the JSON property environment

Returns:

  • (String)


5277
5278
5279
# File 'lib/google/apis/apigee_v1/classes.rb', line 5277

def environment
  @environment
end

#environment_group_idString

Output only. ID of the environment group. Corresponds to the JSON property environmentGroupId

Returns:

  • (String)


5282
5283
5284
# File 'lib/google/apis/apigee_v1/classes.rb', line 5282

def environment_group_id
  @environment_group_id
end

#nameString

ID of the environment group attachment. Corresponds to the JSON property name

Returns:

  • (String)


5287
5288
5289
# File 'lib/google/apis/apigee_v1/classes.rb', line 5287

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5294
5295
5296
5297
5298
5299
# File 'lib/google/apis/apigee_v1/classes.rb', line 5294

def update!(**args)
  @created_at = args[:created_at] if args.key?(:created_at)
  @environment = args[:environment] if args.key?(:environment)
  @environment_group_id = args[:environment_group_id] if args.key?(:environment_group_id)
  @name = args[:name] if args.key?(:name)
end