Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1GenerateUploadUrlResponse
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1GenerateUploadUrlResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Response for GenerateUploadUrl method.
Instance Attribute Summary collapse
-
#upload_uri ⇒ String
The Google Cloud Storage signed URL that can be used to upload a new Archive zip file.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1GenerateUploadUrlResponse
constructor
A new instance of GoogleCloudApigeeV1GenerateUploadUrlResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1GenerateUploadUrlResponse
Returns a new instance of GoogleCloudApigeeV1GenerateUploadUrlResponse.
5650 5651 5652 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5650 def initialize(**args) update!(**args) end |
Instance Attribute Details
#upload_uri ⇒ String
The Google Cloud Storage signed URL that can be used to upload a new Archive
zip file.
Corresponds to the JSON property uploadUri
5648 5649 5650 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5648 def upload_uri @upload_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5655 5656 5657 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5655 def update!(**args) @upload_uri = args[:upload_uri] if args.key?(:upload_uri) end |