Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1GraphQlOperation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Represents the pairing of GraphQL operation types and the GraphQL operation name.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1GraphQlOperation

Returns a new instance of GoogleCloudApigeeV1GraphQlOperation.



5769
5770
5771
# File 'lib/google/apis/apigee_v1/classes.rb', line 5769

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operationString

GraphQL operation name. The name and operation type will be used to apply quotas. If no name is specified, the quota will be applied to all GraphQL operations irrespective of their operation names in the payload. Corresponds to the JSON property operation

Returns:

  • (String)


5761
5762
5763
# File 'lib/google/apis/apigee_v1/classes.rb', line 5761

def operation
  @operation
end

#operation_typesArray<String>

Required. GraphQL operation types. Valid values include query or mutation. Note: Apigee does not currently support subscription types. Corresponds to the JSON property operationTypes

Returns:

  • (Array<String>)


5767
5768
5769
# File 'lib/google/apis/apigee_v1/classes.rb', line 5767

def operation_types
  @operation_types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5774
5775
5776
5777
# File 'lib/google/apis/apigee_v1/classes.rb', line 5774

def update!(**args)
  @operation = args[:operation] if args.key?(:operation)
  @operation_types = args[:operation_types] if args.key?(:operation_types)
end