Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1GraphQlOperationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Binds the resources in a proxy or remote service with the GraphQL operation and its associated quota enforcement.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1GraphQlOperationConfig

Returns a new instance of GoogleCloudApigeeV1GraphQlOperationConfig.



5813
5814
5815
# File 'lib/google/apis/apigee_v1/classes.rb', line 5813

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_sourceString

Required. Name of the API proxy endpoint or remote service with which the GraphQL operation and quota are associated. Corresponds to the JSON property apiSource

Returns:

  • (String)


5789
5790
5791
# File 'lib/google/apis/apigee_v1/classes.rb', line 5789

def api_source
  @api_source
end

#attributesArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>

Custom attributes associated with the operation. Corresponds to the JSON property attributes



5794
5795
5796
# File 'lib/google/apis/apigee_v1/classes.rb', line 5794

def attributes
  @attributes
end

#operationsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1GraphQlOperation>

Required. List of GraphQL name/operation type pairs for the proxy or remote service to which quota will be applied. If only operation types are specified, the quota will be applied to all GraphQL requests irrespective of the GraphQL name. Note: Currently, you can specify only a single GraphQLOperation. Specifying more than one will cause the operation to fail. Corresponds to the JSON property operations



5803
5804
5805
# File 'lib/google/apis/apigee_v1/classes.rb', line 5803

def operations
  @operations
end

#quotaGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1Quota

Quota contains the essential parameters needed that can be applied on the resources, methods, API source combination associated with this API product. While Quota is optional, setting it prevents requests from exceeding the provisioned parameters. Corresponds to the JSON property quota



5811
5812
5813
# File 'lib/google/apis/apigee_v1/classes.rb', line 5811

def quota
  @quota
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5818
5819
5820
5821
5822
5823
# File 'lib/google/apis/apigee_v1/classes.rb', line 5818

def update!(**args)
  @api_source = args[:api_source] if args.key?(:api_source)
  @attributes = args[:attributes] if args.key?(:attributes)
  @operations = args[:operations] if args.key?(:operations)
  @quota = args[:quota] if args.key?(:quota)
end