Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1GrpcOperationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Binds the resources in a proxy or remote service with the gRPC operation and its associated quota enforcement.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1GrpcOperationConfig

Returns a new instance of GoogleCloudApigeeV1GrpcOperationConfig.



5924
5925
5926
# File 'lib/google/apis/apigee_v1/classes.rb', line 5924

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_sourceString

Required. Name of the API proxy with which the gRPC operation and quota are associated. Corresponds to the JSON property apiSource

Returns:

  • (String)


5893
5894
5895
# File 'lib/google/apis/apigee_v1/classes.rb', line 5893

def api_source
  @api_source
end

#attributesArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>

Custom attributes associated with the operation. Corresponds to the JSON property attributes



5898
5899
5900
# File 'lib/google/apis/apigee_v1/classes.rb', line 5898

def attributes
  @attributes
end

#methods_propArray<String>

List of unqualified gRPC method names for the proxy to which quota will be applied. If this field is empty, the Quota will apply to all operations on the gRPC service defined on the proxy. Example: Given a proxy that is configured to serve com.petstore.PetService, the methods com.petstore.PetService.ListPets and com.petstore.PetService.GetPet would be specified here as simply [" ListPets", "GetPet"]. Corresponds to the JSON property methods

Returns:

  • (Array<String>)


5908
5909
5910
# File 'lib/google/apis/apigee_v1/classes.rb', line 5908

def methods_prop
  @methods_prop
end

#quotaGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1Quota

Quota contains the essential parameters needed that can be applied on the resources, methods, API source combination associated with this API product. While Quota is optional, setting it prevents requests from exceeding the provisioned parameters. Corresponds to the JSON property quota



5916
5917
5918
# File 'lib/google/apis/apigee_v1/classes.rb', line 5916

def quota
  @quota
end

#serviceString

Required. gRPC Service name associated to be associated with the API proxy, on which quota rules can be applied upon. Corresponds to the JSON property service

Returns:

  • (String)


5922
5923
5924
# File 'lib/google/apis/apigee_v1/classes.rb', line 5922

def service
  @service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5929
5930
5931
5932
5933
5934
5935
# File 'lib/google/apis/apigee_v1/classes.rb', line 5929

def update!(**args)
  @api_source = args[:api_source] if args.key?(:api_source)
  @attributes = args[:attributes] if args.key?(:attributes)
  @methods_prop = args[:methods_prop] if args.key?(:methods_prop)
  @quota = args[:quota] if args.key?(:quota)
  @service = args[:service] if args.key?(:service)
end