Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1IngressConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1IngressConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Instance Attribute Summary collapse
-
#environment_groups ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1EnvironmentGroupConfig>
List of environment groups in the organization.
-
#name ⇒ String
Name of the resource in the following format:
organizations/org/ deployedIngressConfig. -
#revision_create_time ⇒ String
Time at which the IngressConfig revision was created.
-
#revision_id ⇒ Fixnum
Revision id that defines the ordering on IngressConfig resources.
-
#uid ⇒ String
A unique id for the ingress config that will only change if the organization is deleted and recreated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1IngressConfig
constructor
A new instance of GoogleCloudApigeeV1IngressConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1IngressConfig
Returns a new instance of GoogleCloudApigeeV1IngressConfig.
5973 5974 5975 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5973 def initialize(**args) update!(**args) end |
Instance Attribute Details
#environment_groups ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1EnvironmentGroupConfig>
List of environment groups in the organization.
Corresponds to the JSON property environmentGroups
5948 5949 5950 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5948 def environment_groups @environment_groups end |
#name ⇒ String
Name of the resource in the following format: organizations/org/
deployedIngressConfig.
Corresponds to the JSON property name
5954 5955 5956 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5954 def name @name end |
#revision_create_time ⇒ String
Time at which the IngressConfig revision was created.
Corresponds to the JSON property revisionCreateTime
5959 5960 5961 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5959 def revision_create_time @revision_create_time end |
#revision_id ⇒ Fixnum
Revision id that defines the ordering on IngressConfig resources. The higher
the revision, the more recently the configuration was deployed.
Corresponds to the JSON property revisionId
5965 5966 5967 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5965 def revision_id @revision_id end |
#uid ⇒ String
A unique id for the ingress config that will only change if the organization
is deleted and recreated.
Corresponds to the JSON property uid
5971 5972 5973 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5971 def uid @uid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5978 5979 5980 5981 5982 5983 5984 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5978 def update!(**args) @environment_groups = args[:environment_groups] if args.key?(:environment_groups) @name = args[:name] if args.key?(:name) @revision_create_time = args[:revision_create_time] if args.key?(:revision_create_time) @revision_id = args[:revision_id] if args.key?(:revision_id) @uid = args[:uid] if args.key?(:uid) end |