Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1InstanceAttachment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

InstanceAttachment represents the installation of an environment onto an instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1InstanceAttachment

Returns a new instance of GoogleCloudApigeeV1InstanceAttachment.



6183
6184
6185
# File 'lib/google/apis/apigee_v1/classes.rb', line 6183

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#created_atFixnum

Output only. Time the attachment was created in milliseconds since epoch. Corresponds to the JSON property createdAt

Returns:

  • (Fixnum)


6171
6172
6173
# File 'lib/google/apis/apigee_v1/classes.rb', line 6171

def created_at
  @created_at
end

#environmentString

ID of the attached environment. Corresponds to the JSON property environment

Returns:

  • (String)


6176
6177
6178
# File 'lib/google/apis/apigee_v1/classes.rb', line 6176

def environment
  @environment
end

#nameString

Output only. ID of the attachment. Corresponds to the JSON property name

Returns:

  • (String)


6181
6182
6183
# File 'lib/google/apis/apigee_v1/classes.rb', line 6181

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6188
6189
6190
6191
6192
# File 'lib/google/apis/apigee_v1/classes.rb', line 6188

def update!(**args)
  @created_at = args[:created_at] if args.key?(:created_at)
  @environment = args[:environment] if args.key?(:environment)
  @name = args[:name] if args.key?(:name)
end