Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ListApiDebugSessionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1ListApiDebugSessionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Response for ListApiDebugSessions.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Page token that you can include in a ListApiDebugSessionsRequest to retrieve the next page.
-
#sessions ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiDebugSession>
Session info that includes debug session ID, environment ID, api proxy revision ID and the first transaction creation timestamp.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1ListApiDebugSessionsResponse
constructor
A new instance of GoogleCloudApigeeV1ListApiDebugSessionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1ListApiDebugSessionsResponse
Returns a new instance of GoogleCloudApigeeV1ListApiDebugSessionsResponse.
6543 6544 6545 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6543 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Page token that you can include in a ListApiDebugSessionsRequest to retrieve
the next page. If omitted, no subsequent pages exist.
Corresponds to the JSON property nextPageToken
6535 6536 6537 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6535 def next_page_token @next_page_token end |
#sessions ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiDebugSession>
Session info that includes debug session ID, environment ID, api proxy
revision ID and the first transaction creation timestamp.
Corresponds to the JSON property sessions
6541 6542 6543 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6541 def sessions @sessions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6548 6549 6550 6551 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6548 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @sessions = args[:sessions] if args.key?(:sessions) end |