Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ListAppGroupsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

ListAppGroupsResponse contains the 0 or more AppGroups, along with the optional page token and the total count of apps.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1ListAppGroupsResponse

Returns a new instance of GoogleCloudApigeeV1ListAppGroupsResponse.



6741
6742
6743
# File 'lib/google/apis/apigee_v1/classes.rb', line 6741

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_groupsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1AppGroup>

List of AppGroups. Corresponds to the JSON property appGroups



6728
6729
6730
# File 'lib/google/apis/apigee_v1/classes.rb', line 6728

def app_groups
  @app_groups
end

#next_page_tokenString

Token that can be sent as next_page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


6734
6735
6736
# File 'lib/google/apis/apigee_v1/classes.rb', line 6734

def next_page_token
  @next_page_token
end

#total_sizeFixnum

Total count of AppGroups. Corresponds to the JSON property totalSize

Returns:

  • (Fixnum)


6739
6740
6741
# File 'lib/google/apis/apigee_v1/classes.rb', line 6739

def total_size
  @total_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6746
6747
6748
6749
6750
# File 'lib/google/apis/apigee_v1/classes.rb', line 6746

def update!(**args)
  @app_groups = args[:app_groups] if args.key?(:app_groups)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @total_size = args[:total_size] if args.key?(:total_size)
end