Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ListArchiveDeploymentsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1ListArchiveDeploymentsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Response for ListArchiveDeployments method.
Instance Attribute Summary collapse
-
#archive_deployments ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ArchiveDeployment>
Archive Deployments in the specified environment.
-
#next_page_token ⇒ String
Page token that you can include in a ListArchiveDeployments request to retrieve the next page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1ListArchiveDeploymentsResponse
constructor
A new instance of GoogleCloudApigeeV1ListArchiveDeploymentsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1ListArchiveDeploymentsResponse
Returns a new instance of GoogleCloudApigeeV1ListArchiveDeploymentsResponse.
6751 6752 6753 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6751 def initialize(**args) update!(**args) end |
Instance Attribute Details
#archive_deployments ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ArchiveDeployment>
Archive Deployments in the specified environment.
Corresponds to the JSON property archiveDeployments
6743 6744 6745 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6743 def archive_deployments @archive_deployments end |
#next_page_token ⇒ String
Page token that you can include in a ListArchiveDeployments request to
retrieve the next page. If omitted, no subsequent pages exist.
Corresponds to the JSON property nextPageToken
6749 6750 6751 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6749 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6756 6757 6758 6759 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6756 def update!(**args) @archive_deployments = args[:archive_deployments] if args.key?(:archive_deployments) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |