Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ListInstanceAttachmentsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1ListInstanceAttachmentsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Response for ListInstanceAttachments.
Instance Attribute Summary collapse
-
#attachments ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1InstanceAttachment>
Attachments for the instance.
-
#next_page_token ⇒ String
Page token that you can include in a ListInstanceAttachments request to retrieve the next page of content.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1ListInstanceAttachmentsResponse
constructor
A new instance of GoogleCloudApigeeV1ListInstanceAttachmentsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1ListInstanceAttachmentsResponse
Returns a new instance of GoogleCloudApigeeV1ListInstanceAttachmentsResponse.
7112 7113 7114 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7112 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachments ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1InstanceAttachment>
Attachments for the instance.
Corresponds to the JSON property attachments
7104 7105 7106 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7104 def @attachments end |
#next_page_token ⇒ String
Page token that you can include in a ListInstanceAttachments request to
retrieve the next page of content. If omitted, no subsequent pages exist.
Corresponds to the JSON property nextPageToken
7110 7111 7112 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7110 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7117 7118 7119 7120 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7117 def update!(**args) @attachments = args[:attachments] if args.key?(:attachments) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |