Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ListNatAddressesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Response for ListNatAddresses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1ListNatAddressesResponse

Returns a new instance of GoogleCloudApigeeV1ListNatAddressesResponse.



7191
7192
7193
# File 'lib/google/apis/apigee_v1/classes.rb', line 7191

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nat_addressesArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1NatAddress>

List of NAT Addresses for the instance. Corresponds to the JSON property natAddresses



7183
7184
7185
# File 'lib/google/apis/apigee_v1/classes.rb', line 7183

def nat_addresses
  @nat_addresses
end

#next_page_tokenString

Page token that you can include in a ListNatAddresses request to retrieve the next page of content. If omitted, no subsequent pages exist. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7189
7190
7191
# File 'lib/google/apis/apigee_v1/classes.rb', line 7189

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7196
7197
7198
7199
# File 'lib/google/apis/apigee_v1/classes.rb', line 7196

def update!(**args)
  @nat_addresses = args[:nat_addresses] if args.key?(:nat_addresses)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end