Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ListSecurityIncidentsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Response for ListSecurityIncidents.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1ListSecurityIncidentsResponse

Returns a new instance of GoogleCloudApigeeV1ListSecurityIncidentsResponse.



7383
7384
7385
# File 'lib/google/apis/apigee_v1/classes.rb', line 7383

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7376
7377
7378
# File 'lib/google/apis/apigee_v1/classes.rb', line 7376

def next_page_token
  @next_page_token
end

#security_incidentsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityIncident>

List of security incidents in the organization Corresponds to the JSON property securityIncidents



7381
7382
7383
# File 'lib/google/apis/apigee_v1/classes.rb', line 7381

def security_incidents
  @security_incidents
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7388
7389
7390
7391
# File 'lib/google/apis/apigee_v1/classes.rb', line 7388

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @security_incidents = args[:security_incidents] if args.key?(:security_incidents)
end