Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ListSecurityProfileRevisionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Response for ListSecurityProfileRevisions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1ListSecurityProfileRevisionsResponse

Returns a new instance of GoogleCloudApigeeV1ListSecurityProfileRevisionsResponse.



7387
7388
7389
# File 'lib/google/apis/apigee_v1/classes.rb', line 7387

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7379
7380
7381
# File 'lib/google/apis/apigee_v1/classes.rb', line 7379

def next_page_token
  @next_page_token
end

#security_profilesArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityProfile>

List of security profile revisions. The revisions may be attached or unattached to any environment. Corresponds to the JSON property securityProfiles



7385
7386
7387
# File 'lib/google/apis/apigee_v1/classes.rb', line 7385

def security_profiles
  @security_profiles
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7392
7393
7394
7395
# File 'lib/google/apis/apigee_v1/classes.rb', line 7392

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @security_profiles = args[:security_profiles] if args.key?(:security_profiles)
end