Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ListSecurityReportsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1ListSecurityReportsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
The response for SecurityReports.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
If the number of security reports exceeded the page size requested, the token can be used to fetch the next page in a subsequent call.
-
#security_reports ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityReport>
The security reports belong to requested resource name.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1ListSecurityReportsResponse
constructor
A new instance of GoogleCloudApigeeV1ListSecurityReportsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1ListSecurityReportsResponse
Returns a new instance of GoogleCloudApigeeV1ListSecurityReportsResponse.
7476 7477 7478 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7476 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
If the number of security reports exceeded the page size requested, the token
can be used to fetch the next page in a subsequent call. If the response is
the last page and there are no more reports to return this field is left empty.
Corresponds to the JSON property nextPageToken
7469 7470 7471 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7469 def next_page_token @next_page_token end |
#security_reports ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityReport>
The security reports belong to requested resource name.
Corresponds to the JSON property securityReports
7474 7475 7476 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7474 def security_reports @security_reports end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7481 7482 7483 7484 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7481 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @security_reports = args[:security_reports] if args.key?(:security_reports) end |