Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ListSpacesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

A response to a ListSpaces request containing the list of organization spaces and a page token for the next page.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1ListSpacesResponse

Returns a new instance of GoogleCloudApigeeV1ListSpacesResponse.



7514
7515
7516
# File 'lib/google/apis/apigee_v1/classes.rb', line 7514

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7507
7508
7509
# File 'lib/google/apis/apigee_v1/classes.rb', line 7507

def next_page_token
  @next_page_token
end

#spacesArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Space>

List of Apigee organization spaces. Corresponds to the JSON property spaces



7512
7513
7514
# File 'lib/google/apis/apigee_v1/classes.rb', line 7512

def spaces
  @spaces
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7519
7520
7521
7522
# File 'lib/google/apis/apigee_v1/classes.rb', line 7519

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @spaces = args[:spaces] if args.key?(:spaces)
end