Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1LlmOperationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Binds the resources in an API proxy or remote service with the allowed REST methods and associated quota enforcement.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1LlmOperationConfig

Returns a new instance of GoogleCloudApigeeV1LlmOperationConfig.



7634
7635
7636
# File 'lib/google/apis/apigee_v1/classes.rb', line 7634

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_sourceString

Required. Name of the API proxy or remote service with which the resources, methods, and quota are associated. Corresponds to the JSON property apiSource

Returns:

  • (String)


7611
7612
7613
# File 'lib/google/apis/apigee_v1/classes.rb', line 7611

def api_source
  @api_source
end

#attributesArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>

Optional. Custom attributes associated with the operation. Corresponds to the JSON property attributes



7616
7617
7618
# File 'lib/google/apis/apigee_v1/classes.rb', line 7616

def attributes
  @attributes
end

#llm_operationsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1LlmOperation>

Required. List of resource/method/model for the API proxy to which quota will applied. Note: Currently, you can specify only a single resource/method/ model mapping. The call will fail if more than one resource/method/model mappings are provided. Corresponds to the JSON property llmOperations



7624
7625
7626
# File 'lib/google/apis/apigee_v1/classes.rb', line 7624

def llm_operations
  @llm_operations
end

#llm_token_quotaGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1LlmTokenQuota

LLM Token Quota contains the essential parameters needed that can be applied on the resources, methods, models, API source combination associated with this API product. While LLM Token Quota is optional, setting it prevents requests from exceeding the provisioned parameters. Corresponds to the JSON property llmTokenQuota



7632
7633
7634
# File 'lib/google/apis/apigee_v1/classes.rb', line 7632

def llm_token_quota
  @llm_token_quota
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7639
7640
7641
7642
7643
7644
# File 'lib/google/apis/apigee_v1/classes.rb', line 7639

def update!(**args)
  @api_source = args[:api_source] if args.key?(:api_source)
  @attributes = args[:attributes] if args.key?(:attributes)
  @llm_operations = args[:llm_operations] if args.key?(:llm_operations)
  @llm_token_quota = args[:llm_token_quota] if args.key?(:llm_token_quota)
end