Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1LlmTokenQuota

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

LLM Token Quota contains the essential parameters needed that can be applied on the resources, methods, models, API source combination associated with this API product. While LLM Token Quota is optional, setting it prevents requests from exceeding the provisioned parameters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1LlmTokenQuota

Returns a new instance of GoogleCloudApigeeV1LlmTokenQuota.



7693
7694
7695
# File 'lib/google/apis/apigee_v1/classes.rb', line 7693

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#intervalString

Required. Time interval over which the number of request messages is calculated. Corresponds to the JSON property interval

Returns:

  • (String)


7678
7679
7680
# File 'lib/google/apis/apigee_v1/classes.rb', line 7678

def interval
  @interval
end

#limitString

Required. Upper limit of LLM tokens allowed for the time interval and time unit specified. Requests exceeding this limit will be rejected. Corresponds to the JSON property limit

Returns:

  • (String)


7684
7685
7686
# File 'lib/google/apis/apigee_v1/classes.rb', line 7684

def limit
  @limit
end

#time_unitString

Optional. Time unit defined for the interval. Valid values include minute, hour, day, or month. If limit and interval are valid, the default value is hour; otherwise, the default is null. Corresponds to the JSON property timeUnit

Returns:

  • (String)


7691
7692
7693
# File 'lib/google/apis/apigee_v1/classes.rb', line 7691

def time_unit
  @time_unit
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7698
7699
7700
7701
7702
# File 'lib/google/apis/apigee_v1/classes.rb', line 7698

def update!(**args)
  @interval = args[:interval] if args.key?(:interval)
  @limit = args[:limit] if args.key?(:limit)
  @time_unit = args[:time_unit] if args.key?(:time_unit)
end