Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1MoveApiProxyRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Moves an API Proxy to a different Space.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1MoveApiProxyRequest

Returns a new instance of GoogleCloudApigeeV1MoveApiProxyRequest.



7898
7899
7900
# File 'lib/google/apis/apigee_v1/classes.rb', line 7898

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#spaceString

Optional. Resource ID of the space to move the proxy to. If unspecified, the proxy will be moved to the organization level. Corresponds to the JSON property space

Returns:

  • (String)


7896
7897
7898
# File 'lib/google/apis/apigee_v1/classes.rb', line 7896

def space
  @space
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7903
7904
7905
# File 'lib/google/apis/apigee_v1/classes.rb', line 7903

def update!(**args)
  @space = args[:space] if args.key?(:space)
end