Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1MoveSharedFlowRequest
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1MoveSharedFlowRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Moves a Shared Flow to a different space.
Instance Attribute Summary collapse
-
#space ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1MoveSharedFlowRequest
constructor
A new instance of GoogleCloudApigeeV1MoveSharedFlowRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1MoveSharedFlowRequest
Returns a new instance of GoogleCloudApigeeV1MoveSharedFlowRequest.
7918 7919 7920 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7918 def initialize(**args) update!(**args) end |
Instance Attribute Details
#space ⇒ String
Optional. Resource ID of the space to move the shared flow to. If unspecified,
the shared flow will be moved to the organization level.
Corresponds to the JSON property space
7916 7917 7918 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7916 def space @space end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7923 7924 7925 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7923 def update!(**args) @space = args[:space] if args.key?(:space) end |