Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1OperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1OperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Metadata describing an Operation.
Instance Attribute Summary collapse
-
#operation_type ⇒ String
Corresponds to the JSON property
operationType. -
#progress ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1OperationMetadataProgress
Information about operation progress.
-
#state ⇒ String
Corresponds to the JSON property
state. -
#target_resource_name ⇒ String
Name of the resource for which the operation is operating on.
-
#warnings ⇒ Array<String>
Warnings encountered while executing the operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1OperationMetadata
constructor
A new instance of GoogleCloudApigeeV1OperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1OperationMetadata
Returns a new instance of GoogleCloudApigeeV1OperationMetadata.
8139 8140 8141 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8139 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operation_type ⇒ String
Corresponds to the JSON property operationType
8117 8118 8119 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8117 def operation_type @operation_type end |
#progress ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1OperationMetadataProgress
Information about operation progress.
Corresponds to the JSON property progress
8122 8123 8124 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8122 def progress @progress end |
#state ⇒ String
Corresponds to the JSON property state
8127 8128 8129 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8127 def state @state end |
#target_resource_name ⇒ String
Name of the resource for which the operation is operating on.
Corresponds to the JSON property targetResourceName
8132 8133 8134 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8132 def target_resource_name @target_resource_name end |
#warnings ⇒ Array<String>
Warnings encountered while executing the operation.
Corresponds to the JSON property warnings
8137 8138 8139 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8137 def warnings @warnings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8144 8145 8146 8147 8148 8149 8150 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8144 def update!(**args) @operation_type = args[:operation_type] if args.key?(:operation_type) @progress = args[:progress] if args.key?(:progress) @state = args[:state] if args.key?(:state) @target_resource_name = args[:target_resource_name] if args.key?(:target_resource_name) @warnings = args[:warnings] if args.key?(:warnings) end |