Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Organization

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1Organization

Returns a new instance of GoogleCloudApigeeV1Organization.



8517
8518
8519
# File 'lib/google/apis/apigee_v1/classes.rb', line 8517

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addons_configGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1AddonsConfig

Add-on configurations for the Apigee organization. Corresponds to the JSON property addonsConfig



8301
8302
8303
# File 'lib/google/apis/apigee_v1/classes.rb', line 8301

def addons_config
  @addons_config
end

#analytics_regionString

Required. DEPRECATED: This field will eventually be deprecated and replaced with a differently-named field. Primary Google Cloud region for analytics data storage. For valid values, see Create an Apigee organization. Corresponds to the JSON property analyticsRegion

Returns:

  • (String)


8309
8310
8311
# File 'lib/google/apis/apigee_v1/classes.rb', line 8309

def analytics_region
  @analytics_region
end

#api_consumer_data_encryption_key_nameString

Optional. Cloud KMS key name used for encrypting API consumer data. If not specified or BillingType is EVALUATION, a Google-Managed encryption key will be used. Format: projects/*/locations/*/keyRings/*/ cryptoKeys/* Corresponds to the JSON property apiConsumerDataEncryptionKeyName

Returns:

  • (String)


8317
8318
8319
# File 'lib/google/apis/apigee_v1/classes.rb', line 8317

def api_consumer_data_encryption_key_name
  @api_consumer_data_encryption_key_name
end

#api_consumer_data_locationString

Optional. This field is needed only for customers using non-default data residency regions. Apigee stores some control plane data only in single region. This field determines which single region Apigee should use. For example: "us- west1" when control plane is in US or "europe-west2" when control plane is in EU. Corresponds to the JSON property apiConsumerDataLocation

Returns:

  • (String)


8326
8327
8328
# File 'lib/google/apis/apigee_v1/classes.rb', line 8326

def api_consumer_data_location
  @api_consumer_data_location
end

#apigee_project_idString

Output only. Apigee Project ID associated with the organization. Use this project to allowlist Apigee in the Service Attachment when using private service connect with Apigee. Corresponds to the JSON property apigeeProjectId

Returns:

  • (String)


8333
8334
8335
# File 'lib/google/apis/apigee_v1/classes.rb', line 8333

def apigee_project_id
  @apigee_project_id
end

#attributesArray<String>

Not used by Apigee. Corresponds to the JSON property attributes

Returns:

  • (Array<String>)


8338
8339
8340
# File 'lib/google/apis/apigee_v1/classes.rb', line 8338

def attributes
  @attributes
end

#authorized_networkString

Optional. Compute Engine network used for Service Networking to be peered with Apigee runtime instances. See Getting started with the Service Networking API. Valid only when RuntimeType is set to CLOUD . The value must be set before the creation of a runtime instance and can be updated only when there are no runtime instances. For example: default. When changing authorizedNetwork, you must reconfigure VPC peering. After VPC peering with previous network is deleted, run the following command: gcloud services vpc-peerings delete --network=NETWORK, where NETWORK is the name of the previous network. This will delete the previous Service Networking. Otherwise, you will get the following error: The resource 'projects/...-tp' is already linked to another shared VPC host 'projects/...-tp. Apigee also supports shared VPC (that is, the host network project is not the same as the one that is peering with Apigee). See Shared VPC overview. To use a shared VPC network, use the following format: projects/host-project-id/region/networks/network-name` . For example:projects/my-sharedvpc-host/global/networks/mynetwork**Note:** Not supported for Apigee hybrid. Corresponds to the JSON propertyauthorizedNetwork`

Returns:

  • (String)


8361
8362
8363
# File 'lib/google/apis/apigee_v1/classes.rb', line 8361

def authorized_network
  @authorized_network
end

#billing_typeString

Optional. Billing type of the Apigee organization. See Apigee pricing. Corresponds to the JSON property billingType

Returns:

  • (String)


8367
8368
8369
# File 'lib/google/apis/apigee_v1/classes.rb', line 8367

def billing_type
  @billing_type
end

#ca_certificateString

Output only. Deprecated: Use ca_certificates instead. Base64-encoded public certificate for the root CA of the Apigee organization. Valid only when RuntimeType is CLOUD. Corresponds to the JSON property caCertificate NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


8375
8376
8377
# File 'lib/google/apis/apigee_v1/classes.rb', line 8375

def ca_certificate
  @ca_certificate
end

#ca_certificatesArray<String>

Output only. Base64-encoded public certificates for the root CA of the Apigee organization. Valid only when RuntimeType is CLOUD. Multiple certificates are used to support certificate rotation. Corresponds to the JSON property caCertificates

Returns:

  • (Array<String>)


8382
8383
8384
# File 'lib/google/apis/apigee_v1/classes.rb', line 8382

def ca_certificates
  @ca_certificates
end

#control_plane_encryption_key_nameString

Optional. Cloud KMS key name used for encrypting control plane data that is stored in a multi region. Only used for the data residency region "US" or "EU". If not specified or BillingType is EVALUATION, a Google- Managed encryption key will be used. Format: projects/*/locations/*/keyRings/* /cryptoKeys/* Corresponds to the JSON property controlPlaneEncryptionKeyName

Returns:

  • (String)


8391
8392
8393
# File 'lib/google/apis/apigee_v1/classes.rb', line 8391

def control_plane_encryption_key_name
  @control_plane_encryption_key_name
end

#created_atFixnum

Output only. Time that the Apigee organization was created in milliseconds since epoch. Corresponds to the JSON property createdAt

Returns:

  • (Fixnum)


8397
8398
8399
# File 'lib/google/apis/apigee_v1/classes.rb', line 8397

def created_at
  @created_at
end

#customer_nameString

Not used by Apigee. Corresponds to the JSON property customerName

Returns:

  • (String)


8402
8403
8404
# File 'lib/google/apis/apigee_v1/classes.rb', line 8402

def customer_name
  @customer_name
end

#descriptionString

Optional. Description of the Apigee organization. Corresponds to the JSON property description

Returns:

  • (String)


8407
8408
8409
# File 'lib/google/apis/apigee_v1/classes.rb', line 8407

def description
  @description
end

#disable_vpc_peeringBoolean Also known as: disable_vpc_peering?

Optional. Flag that specifies whether the VPC Peering through Private Google Access should be disabled between the consumer network and Apigee. Valid only when RuntimeType is set to CLOUD. Required if an authorizedNetwork on the consumer project is not provided, in which case the flag should be set to true. The value must be set before the creation of any Apigee runtime instance and can be updated only when there are no runtime instances. Note: Apigee will be deprecating the vpc peering model that requires you to provide ' authorizedNetwork', by making the non-peering model as the default way of provisioning Apigee organization in future. So, this will be a temporary flag to enable the transition. Not supported for Apigee hybrid. Corresponds to the JSON property disableVpcPeering

Returns:

  • (Boolean)


8421
8422
8423
# File 'lib/google/apis/apigee_v1/classes.rb', line 8421

def disable_vpc_peering
  @disable_vpc_peering
end

#display_nameString

Optional. Display name for the Apigee organization. Unused, but reserved for future use. Corresponds to the JSON property displayName

Returns:

  • (String)


8428
8429
8430
# File 'lib/google/apis/apigee_v1/classes.rb', line 8428

def display_name
  @display_name
end

#environmentsArray<String>

Output only. List of environments in the Apigee organization. Corresponds to the JSON property environments

Returns:

  • (Array<String>)


8433
8434
8435
# File 'lib/google/apis/apigee_v1/classes.rb', line 8433

def environments
  @environments
end

#expires_atFixnum

Output only. Time that the Apigee organization is scheduled for deletion. Corresponds to the JSON property expiresAt

Returns:

  • (Fixnum)


8438
8439
8440
# File 'lib/google/apis/apigee_v1/classes.rb', line 8438

def expires_at
  @expires_at
end

#last_modified_atFixnum

Output only. Time that the Apigee organization was last modified in milliseconds since epoch. Corresponds to the JSON property lastModifiedAt

Returns:

  • (Fixnum)


8444
8445
8446
# File 'lib/google/apis/apigee_v1/classes.rb', line 8444

def last_modified_at
  @last_modified_at
end

#nameString

Output only. Name of the Apigee organization. Corresponds to the JSON property name

Returns:

  • (String)


8449
8450
8451
# File 'lib/google/apis/apigee_v1/classes.rb', line 8449

def name
  @name
end

#network_egress_restrictedBoolean Also known as: network_egress_restricted?

Optional. Flag that specifies if internet egress is restricted for VPC Service Controls. Valid only when runtime_type is CLOUD and disable_vpc_peering is true. Corresponds to the JSON property networkEgressRestricted

Returns:

  • (Boolean)


8456
8457
8458
# File 'lib/google/apis/apigee_v1/classes.rb', line 8456

def network_egress_restricted
  @network_egress_restricted
end

#portal_disabledBoolean Also known as: portal_disabled?

Optional. Configuration for the Portals settings. Corresponds to the JSON property portalDisabled

Returns:

  • (Boolean)


8462
8463
8464
# File 'lib/google/apis/apigee_v1/classes.rb', line 8462

def portal_disabled
  @portal_disabled
end

#project_idString

Output only. Project ID associated with the Apigee organization. Corresponds to the JSON property projectId

Returns:

  • (String)


8468
8469
8470
# File 'lib/google/apis/apigee_v1/classes.rb', line 8468

def project_id
  @project_id
end

#propertiesGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1Properties

Message for compatibility with legacy Edge specification for Java Properties object in JSON. Corresponds to the JSON property properties



8474
8475
8476
# File 'lib/google/apis/apigee_v1/classes.rb', line 8474

def properties
  @properties
end

#runtime_database_encryption_key_nameString

Optional. Cloud KMS key name used for encrypting the data that is stored and replicated across runtime instances. Update is not allowed after the organization is created. If not specified or RuntimeType is TRIAL, a Google-Managed encryption key will be used. For example: "projects/ foo/locations/us/keyRings/bar/cryptoKeys/baz". Note: Not supported for Apigee hybrid. Corresponds to the JSON property runtimeDatabaseEncryptionKeyName

Returns:

  • (String)


8484
8485
8486
# File 'lib/google/apis/apigee_v1/classes.rb', line 8484

def runtime_database_encryption_key_name
  @runtime_database_encryption_key_name
end

#runtime_typeString

Required. Runtime type of the Apigee organization based on the Apigee subscription purchased. Corresponds to the JSON property runtimeType

Returns:

  • (String)


8490
8491
8492
# File 'lib/google/apis/apigee_v1/classes.rb', line 8490

def runtime_type
  @runtime_type
end

#stateString

Output only. State of the organization. Values other than ACTIVE means the resource is not ready to use. Corresponds to the JSON property state

Returns:

  • (String)


8496
8497
8498
# File 'lib/google/apis/apigee_v1/classes.rb', line 8496

def state
  @state
end

#subscription_planString

Output only. Subscription plan that the customer has purchased. Output only. Corresponds to the JSON property subscriptionPlan

Returns:

  • (String)


8501
8502
8503
# File 'lib/google/apis/apigee_v1/classes.rb', line 8501

def subscription_plan
  @subscription_plan
end

#subscription_typeString

Output only. DEPRECATED: This will eventually be replaced by BillingType. Subscription type of the Apigee organization. Valid values include trial (free, limited, and for evaluation purposes only) or paid (full subscription has been purchased). See Apigee pricing . Corresponds to the JSON property subscriptionType

Returns:

  • (String)


8510
8511
8512
# File 'lib/google/apis/apigee_v1/classes.rb', line 8510

def subscription_type
  @subscription_type
end

#typeString

Not used by Apigee. Corresponds to the JSON property type

Returns:

  • (String)


8515
8516
8517
# File 'lib/google/apis/apigee_v1/classes.rb', line 8515

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8522
8523
8524
8525
8526
8527
8528
8529
8530
8531
8532
8533
8534
8535
8536
8537
8538
8539
8540
8541
8542
8543
8544
8545
8546
8547
8548
8549
8550
8551
8552
8553
# File 'lib/google/apis/apigee_v1/classes.rb', line 8522

def update!(**args)
  @addons_config = args[:addons_config] if args.key?(:addons_config)
  @analytics_region = args[:analytics_region] if args.key?(:analytics_region)
  @api_consumer_data_encryption_key_name = args[:api_consumer_data_encryption_key_name] if args.key?(:api_consumer_data_encryption_key_name)
  @api_consumer_data_location = args[:api_consumer_data_location] if args.key?(:api_consumer_data_location)
  @apigee_project_id = args[:apigee_project_id] if args.key?(:apigee_project_id)
  @attributes = args[:attributes] if args.key?(:attributes)
  @authorized_network = args[:authorized_network] if args.key?(:authorized_network)
  @billing_type = args[:billing_type] if args.key?(:billing_type)
  @ca_certificate = args[:ca_certificate] if args.key?(:ca_certificate)
  @ca_certificates = args[:ca_certificates] if args.key?(:ca_certificates)
  @control_plane_encryption_key_name = args[:control_plane_encryption_key_name] if args.key?(:control_plane_encryption_key_name)
  @created_at = args[:created_at] if args.key?(:created_at)
  @customer_name = args[:customer_name] if args.key?(:customer_name)
  @description = args[:description] if args.key?(:description)
  @disable_vpc_peering = args[:disable_vpc_peering] if args.key?(:disable_vpc_peering)
  @display_name = args[:display_name] if args.key?(:display_name)
  @environments = args[:environments] if args.key?(:environments)
  @expires_at = args[:expires_at] if args.key?(:expires_at)
  @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at)
  @name = args[:name] if args.key?(:name)
  @network_egress_restricted = args[:network_egress_restricted] if args.key?(:network_egress_restricted)
  @portal_disabled = args[:portal_disabled] if args.key?(:portal_disabled)
  @project_id = args[:project_id] if args.key?(:project_id)
  @properties = args[:properties] if args.key?(:properties)
  @runtime_database_encryption_key_name = args[:runtime_database_encryption_key_name] if args.key?(:runtime_database_encryption_key_name)
  @runtime_type = args[:runtime_type] if args.key?(:runtime_type)
  @state = args[:state] if args.key?(:state)
  @subscription_plan = args[:subscription_plan] if args.key?(:subscription_plan)
  @subscription_type = args[:subscription_type] if args.key?(:subscription_type)
  @type = args[:type] if args.key?(:type)
end