Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1OrganizationProjectMapping

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1OrganizationProjectMapping

Returns a new instance of GoogleCloudApigeeV1OrganizationProjectMapping.



8573
8574
8575
# File 'lib/google/apis/apigee_v1/classes.rb', line 8573

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#locationString

Output only. The Google Cloud region where control plane data is located. For more information, see https://cloud.google.com/about/locations/. Corresponds to the JSON property location

Returns:

  • (String)


8555
8556
8557
# File 'lib/google/apis/apigee_v1/classes.rb', line 8555

def location
  @location
end

#organizationString

Name of the Apigee organization. Corresponds to the JSON property organization

Returns:

  • (String)


8560
8561
8562
# File 'lib/google/apis/apigee_v1/classes.rb', line 8560

def organization
  @organization
end

#project_idString

Google Cloud project associated with the Apigee organization Corresponds to the JSON property projectId

Returns:

  • (String)


8565
8566
8567
# File 'lib/google/apis/apigee_v1/classes.rb', line 8565

def project_id
  @project_id
end

#project_idsArray<String>

DEPRECATED: Use project_id. An Apigee Organization is mapped to a single project. Corresponds to the JSON property projectIds

Returns:

  • (Array<String>)


8571
8572
8573
# File 'lib/google/apis/apigee_v1/classes.rb', line 8571

def project_ids
  @project_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8578
8579
8580
8581
8582
8583
# File 'lib/google/apis/apigee_v1/classes.rb', line 8578

def update!(**args)
  @location = args[:location] if args.key?(:location)
  @organization = args[:organization] if args.key?(:organization)
  @project_id = args[:project_id] if args.key?(:project_id)
  @project_ids = args[:project_ids] if args.key?(:project_ids)
end