Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1PayloadOperationConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Binds the payload operations in an API proxy with the associated quota enforcement.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1PayloadOperationConfig

Returns a new instance of GoogleCloudApigeeV1PayloadOperationConfig.



8646
8647
8648
# File 'lib/google/apis/apigee_v1/classes.rb', line 8646

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_sourceString

Required. Name of the API proxy with which the payload operations and quota are associated. Corresponds to the JSON property apiSource

Returns:

  • (String)


8625
8626
8627
# File 'lib/google/apis/apigee_v1/classes.rb', line 8625

def api_source
  @api_source
end

#attributesArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>

Optional. Custom attributes associated with the operation. Corresponds to the JSON property attributes



8630
8631
8632
# File 'lib/google/apis/apigee_v1/classes.rb', line 8630

def attributes
  @attributes
end

#operationsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1PayloadOperation>

Required. List of payload operations for the API proxy to which quota will be applied. Corresponds to the JSON property operations



8636
8637
8638
# File 'lib/google/apis/apigee_v1/classes.rb', line 8636

def operations
  @operations
end

#quotaGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1Quota

Quota contains the essential parameters needed that can be applied on the resources, methods, API source combination associated with this API product. While Quota is optional, setting it prevents requests from exceeding the provisioned parameters. Corresponds to the JSON property quota



8644
8645
8646
# File 'lib/google/apis/apigee_v1/classes.rb', line 8644

def quota
  @quota
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8651
8652
8653
8654
8655
8656
# File 'lib/google/apis/apigee_v1/classes.rb', line 8651

def update!(**args)
  @api_source = args[:api_source] if args.key?(:api_source)
  @attributes = args[:attributes] if args.key?(:attributes)
  @operations = args[:operations] if args.key?(:operations)
  @quota = args[:quota] if args.key?(:quota)
end