Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1PayloadOperationGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

List of payload operation configuration details associated with Apigee API proxies. Payload operations enable governance of protocols where operations are embedded in the request body (such as JSON-RPC) rather than defined by the URL path.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1PayloadOperationGroup

Returns a new instance of GoogleCloudApigeeV1PayloadOperationGroup.



8672
8673
8674
# File 'lib/google/apis/apigee_v1/classes.rb', line 8672

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#operation_configsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1PayloadOperationConfig>

Required. List of payload operation configurations for Apigee API proxies that are associated with this API product. Corresponds to the JSON property operationConfigs



8670
8671
8672
# File 'lib/google/apis/apigee_v1/classes.rb', line 8670

def operation_configs
  @operation_configs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8677
8678
8679
# File 'lib/google/apis/apigee_v1/classes.rb', line 8677

def update!(**args)
  @operation_configs = args[:operation_configs] if args.key?(:operation_configs)
end