Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigCategory

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Advanced API Security provides security profile that scores the following categories.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1ProfileConfigCategory

Returns a new instance of GoogleCloudApigeeV1ProfileConfigCategory.



8887
8888
8889
# File 'lib/google/apis/apigee_v1/classes.rb', line 8887

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#abuseGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigAbuse

Checks for abuse, which includes any requests sent to the API for purposes other than what it is intended for, such as high volumes of requests, data scraping, and abuse related to authorization. Corresponds to the JSON property abuse



8857
8858
8859
# File 'lib/google/apis/apigee_v1/classes.rb', line 8857

def abuse
  @abuse
end

#authorizationGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigAuthorization

By default, following policies will be included: - JWS - JWT - OAuth - BasicAuth - APIKey Corresponds to the JSON property authorization



8863
8864
8865
# File 'lib/google/apis/apigee_v1/classes.rb', line 8863

def authorization
  @authorization
end

#corsGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigCors

Checks to see if you have CORS policy in place. Corresponds to the JSON property cors



8868
8869
8870
# File 'lib/google/apis/apigee_v1/classes.rb', line 8868

def cors
  @cors
end

#mediationGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigMediation

By default, following policies will be included: - OASValidation - SOAPMessageValidation Corresponds to the JSON property mediation



8874
8875
8876
# File 'lib/google/apis/apigee_v1/classes.rb', line 8874

def mediation
  @mediation
end

#mtlsGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigMtls

Checks to see if you have configured mTLS for the target server. Corresponds to the JSON property mtls



8879
8880
8881
# File 'lib/google/apis/apigee_v1/classes.rb', line 8879

def mtls
  @mtls
end

#threatGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigThreat

By default, following policies will be included: - XMLThreatProtection - JSONThreatProtection Corresponds to the JSON property threat



8885
8886
8887
# File 'lib/google/apis/apigee_v1/classes.rb', line 8885

def threat
  @threat
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8892
8893
8894
8895
8896
8897
8898
8899
# File 'lib/google/apis/apigee_v1/classes.rb', line 8892

def update!(**args)
  @abuse = args[:abuse] if args.key?(:abuse)
  @authorization = args[:authorization] if args.key?(:authorization)
  @cors = args[:cors] if args.key?(:cors)
  @mediation = args[:mediation] if args.key?(:mediation)
  @mtls = args[:mtls] if args.key?(:mtls)
  @threat = args[:threat] if args.key?(:threat)
end