Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Properties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Message for compatibility with legacy Edge specification for Java Properties object in JSON.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1Properties

Returns a new instance of GoogleCloudApigeeV1Properties.



8898
8899
8900
# File 'lib/google/apis/apigee_v1/classes.rb', line 8898

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#propertyArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Property>

List of all properties in the object Corresponds to the JSON property property



8896
8897
8898
# File 'lib/google/apis/apigee_v1/classes.rb', line 8896

def property
  @property
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8903
8904
8905
# File 'lib/google/apis/apigee_v1/classes.rb', line 8903

def update!(**args)
  @property = args[:property] if args.key?(:property)
end