Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProvisionOrganizationRequest
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProvisionOrganizationRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Request for ProvisionOrganization.
Instance Attribute Summary collapse
-
#analytics_region ⇒ String
Primary Cloud Platform region for analytics data storage.
-
#authorized_network ⇒ String
Compute Engine network used for Service Networking to be peered with Apigee runtime instances.
-
#disable_vpc_peering ⇒ Boolean
(also: #disable_vpc_peering?)
Optional.
-
#runtime_location ⇒ String
Cloud Platform location for the runtime instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1ProvisionOrganizationRequest
constructor
A new instance of GoogleCloudApigeeV1ProvisionOrganizationRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1ProvisionOrganizationRequest
Returns a new instance of GoogleCloudApigeeV1ProvisionOrganizationRequest.
8930 8931 8932 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8930 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analytics_region ⇒ String
Primary Cloud Platform region for analytics data storage. For valid values,
see Create an organization. Defaults to us-west1.
Corresponds to the JSON property analyticsRegion
8893 8894 8895 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8893 def analytics_region @analytics_region end |
#authorized_network ⇒ String
Compute Engine network used for Service Networking to be peered with Apigee
runtime instances. See Getting started with the Service Networking API. Apigee also supports shared VPC (that is, the host network project
is not the same as the one that is peering with Apigee). See Shared VPC
overview. To use a shared VPC
network, use the following format: projects/host-project-id/region/
networks/network-name`. For example:projects/my-sharedvpc-host/global/
networks/mynetwork
Corresponds to the JSON propertyauthorizedNetwork`
8906 8907 8908 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8906 def @authorized_network end |
#disable_vpc_peering ⇒ Boolean Also known as: disable_vpc_peering?
Optional. Flag that specifies whether the VPC Peering through Private Google
Access should be disabled between the consumer network and Apigee. Required if
an authorizedNetwork on the consumer project is not provided, in which case
the flag should be set to true. The value must be set before the creation of
any Apigee runtime instance and can be updated only when there are no runtime
instances. Note: Apigee will be deprecating the vpc peering model that
requires you to provide 'authorizedNetwork', by making the non-peering model
as the default way of provisioning Apigee organization in future. So, this
will be a temporary flag to enable the transition. Not supported for Apigee
hybrid.
Corresponds to the JSON property disableVpcPeering
8920 8921 8922 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8920 def disable_vpc_peering @disable_vpc_peering end |
#runtime_location ⇒ String
Cloud Platform location for the runtime instance. Defaults to zone us-west1-a
. If a region is provided, EVAL organizations will use the region for
automatically selecting a zone for the runtime instance.
Corresponds to the JSON property runtimeLocation
8928 8929 8930 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8928 def runtime_location @runtime_location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8935 8936 8937 8938 8939 8940 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8935 def update!(**args) @analytics_region = args[:analytics_region] if args.key?(:analytics_region) @authorized_network = args[:authorized_network] if args.key?(:authorized_network) @disable_vpc_peering = args[:disable_vpc_peering] if args.key?(:disable_vpc_peering) @runtime_location = args[:runtime_location] if args.key?(:runtime_location) end |