Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Query

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1Query

Returns a new instance of GoogleCloudApigeeV1Query.



9127
9128
9129
# File 'lib/google/apis/apigee_v1/classes.rb', line 9127

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#csv_delimiterString

Delimiter used in the CSV file, if outputFormat is set to csv. Defaults to the , (comma) character. Supported delimiter characters include comma (,), pipe (|), and tab (\t). Corresponds to the JSON property csvDelimiter

Returns:

  • (String)


9056
9057
9058
# File 'lib/google/apis/apigee_v1/classes.rb', line 9056

def csv_delimiter
  @csv_delimiter
end

#dimensionsArray<String>

A list of dimensions. https://docs.apigee.com/api-platform/analytics/analytics- reference#dimensions Corresponds to the JSON property dimensions

Returns:

  • (Array<String>)


9062
9063
9064
# File 'lib/google/apis/apigee_v1/classes.rb', line 9062

def dimensions
  @dimensions
end

#envgroup_hostnameString

Hostname needs to be specified if query intends to run at host level. This field is only allowed when query is submitted by CreateHostAsyncQuery where analytics data will be grouped by organization and hostname. Corresponds to the JSON property envgroupHostname

Returns:

  • (String)


9069
9070
9071
# File 'lib/google/apis/apigee_v1/classes.rb', line 9069

def envgroup_hostname
  @envgroup_hostname
end

#filterString

Boolean expression that can be used to filter data. Filter expressions can be combined using AND/OR terms and should be fully parenthesized to avoid ambiguity. See Analytics metrics, dimensions, and filters reference https:// docs.apigee.com/api-platform/analytics/analytics-reference for more information on the fields available to filter on. For more information on the tokens that you use to build filter expressions, see Filter expression syntax. https://docs.apigee.com/api-platform/analytics/asynch-reports-api#filter- expression-syntax Corresponds to the JSON property filter

Returns:

  • (String)


9081
9082
9083
# File 'lib/google/apis/apigee_v1/classes.rb', line 9081

def filter
  @filter
end

#group_by_time_unitString

Time unit used to group the result set. Valid values include: second, minute, hour, day, week, or month. If a query includes groupByTimeUnit, then the result is an aggregation based on the specified time unit and the resultant timestamp does not include milliseconds precision. If a query omits groupByTimeUnit, then the resultant timestamp includes milliseconds precision. Corresponds to the JSON property groupByTimeUnit

Returns:

  • (String)


9090
9091
9092
# File 'lib/google/apis/apigee_v1/classes.rb', line 9090

def group_by_time_unit
  @group_by_time_unit
end

#limitFixnum

Maximum number of rows that can be returned in the result. Corresponds to the JSON property limit

Returns:

  • (Fixnum)


9095
9096
9097
# File 'lib/google/apis/apigee_v1/classes.rb', line 9095

def limit
  @limit
end

#metricsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1QueryMetric>

A list of Metrics. Corresponds to the JSON property metrics



9100
9101
9102
# File 'lib/google/apis/apigee_v1/classes.rb', line 9100

def metrics
  @metrics
end

#nameString

Asynchronous Query Name. Corresponds to the JSON property name

Returns:

  • (String)


9105
9106
9107
# File 'lib/google/apis/apigee_v1/classes.rb', line 9105

def name
  @name
end

#output_formatString

Valid values include: csv or json. Defaults to json. Note: Configure the delimiter for CSV output using the csvDelimiter property. Corresponds to the JSON property outputFormat

Returns:

  • (String)


9111
9112
9113
# File 'lib/google/apis/apigee_v1/classes.rb', line 9111

def output_format
  @output_format
end

#report_definition_idString

Asynchronous Report ID. Corresponds to the JSON property reportDefinitionId

Returns:

  • (String)


9116
9117
9118
# File 'lib/google/apis/apigee_v1/classes.rb', line 9116

def report_definition_id
  @report_definition_id
end

#time_rangeObject

Required. Time range for the query. Can use the following predefined strings to specify the time range: last60minutes last24hours last7days Or, specify the timeRange as a structure describing start and end timestamps in the ISO format: yyyy-mm-ddThh:mm:ssZ. Example: "timeRange": "start": "2018- 07-29T00:13:00Z", "end": "2018-08-01T00:18:00Z" Corresponds to the JSON property timeRange

Returns:

  • (Object)


9125
9126
9127
# File 'lib/google/apis/apigee_v1/classes.rb', line 9125

def time_range
  @time_range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9132
9133
9134
9135
9136
9137
9138
9139
9140
9141
9142
9143
9144
# File 'lib/google/apis/apigee_v1/classes.rb', line 9132

def update!(**args)
  @csv_delimiter = args[:csv_delimiter] if args.key?(:csv_delimiter)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @envgroup_hostname = args[:envgroup_hostname] if args.key?(:envgroup_hostname)
  @filter = args[:filter] if args.key?(:filter)
  @group_by_time_unit = args[:group_by_time_unit] if args.key?(:group_by_time_unit)
  @limit = args[:limit] if args.key?(:limit)
  @metrics = args[:metrics] if args.key?(:metrics)
  @name = args[:name] if args.key?(:name)
  @output_format = args[:output_format] if args.key?(:output_format)
  @report_definition_id = args[:report_definition_id] if args.key?(:report_definition_id)
  @time_range = args[:time_range] if args.key?(:time_range)
end