Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1QueryTabularStatsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Encapsulates two kinds of stats that are results of the dimensions and aggregations requested. - Tabular rows. - Time series data. Example of tabular rows, Represents security stats results as a row of flat values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1QueryTabularStatsResponse

Returns a new instance of GoogleCloudApigeeV1QueryTabularStatsResponse.



9216
9217
9218
# File 'lib/google/apis/apigee_v1/classes.rb', line 9216

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnsArray<String>

Column names corresponding to the same order as the inner values in the stats field. Corresponds to the JSON property columns

Returns:

  • (Array<String>)


9204
9205
9206
# File 'lib/google/apis/apigee_v1/classes.rb', line 9204

def columns
  @columns
end

#next_page_tokenString

Next page token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


9209
9210
9211
# File 'lib/google/apis/apigee_v1/classes.rb', line 9209

def next_page_token
  @next_page_token
end

#valuesArray<Array<Object>>

Resultant rows from the executed query. Corresponds to the JSON property values

Returns:

  • (Array<Array<Object>>)


9214
9215
9216
# File 'lib/google/apis/apigee_v1/classes.rb', line 9214

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9221
9222
9223
9224
9225
# File 'lib/google/apis/apigee_v1/classes.rb', line 9221

def update!(**args)
  @columns = args[:columns] if args.key?(:columns)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @values = args[:values] if args.key?(:values)
end