Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1QueryTimeSeriesStatsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Represents security stats result as a collection of time series sequences.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1QueryTimeSeriesStatsResponse

Returns a new instance of GoogleCloudApigeeV1QueryTimeSeriesStatsResponse.



9328
9329
9330
# File 'lib/google/apis/apigee_v1/classes.rb', line 9328

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#columnsArray<String>

Column names corresponding to the same order as the inner values in the stats field. Corresponds to the JSON property columns

Returns:

  • (Array<String>)


9316
9317
9318
# File 'lib/google/apis/apigee_v1/classes.rb', line 9316

def columns
  @columns
end

#next_page_tokenString

Next page token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


9321
9322
9323
# File 'lib/google/apis/apigee_v1/classes.rb', line 9321

def next_page_token
  @next_page_token
end

#valuesArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1QueryTimeSeriesStatsResponseSequence>

Results of the query returned as a JSON array. Corresponds to the JSON property values



9326
9327
9328
# File 'lib/google/apis/apigee_v1/classes.rb', line 9326

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9333
9334
9335
9336
9337
# File 'lib/google/apis/apigee_v1/classes.rb', line 9333

def update!(**args)
  @columns = args[:columns] if args.key?(:columns)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @values = args[:values] if args.key?(:values)
end