Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1QueryTimeSeriesStatsResponseSequence
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1QueryTimeSeriesStatsResponseSequence
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
A sequence of time series.
Instance Attribute Summary collapse
-
#dimensions ⇒ Hash<String,String>
Map of dimensions and their values that uniquely identifies a time series sequence.
-
#points ⇒ Array<Array<Object>>
List of points.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1QueryTimeSeriesStatsResponseSequence
constructor
A new instance of GoogleCloudApigeeV1QueryTimeSeriesStatsResponseSequence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1QueryTimeSeriesStatsResponseSequence
Returns a new instance of GoogleCloudApigeeV1QueryTimeSeriesStatsResponseSequence.
9451 9452 9453 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9451 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dimensions ⇒ Hash<String,String>
Map of dimensions and their values that uniquely identifies a time series
sequence.
Corresponds to the JSON property dimensions
9444 9445 9446 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9444 def dimensions @dimensions end |
#points ⇒ Array<Array<Object>>
List of points. First value of each inner list is a timestamp.
Corresponds to the JSON property points
9449 9450 9451 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9449 def points @points end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9456 9457 9458 9459 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9456 def update!(**args) @dimensions = args[:dimensions] if args.key?(:dimensions) @points = args[:points] if args.key?(:points) end |