Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Reference

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

A Reference configuration. References must refer to a keystore that also exists in the parent environment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1Reference

Returns a new instance of GoogleCloudApigeeV1Reference.



9599
9600
9601
# File 'lib/google/apis/apigee_v1/classes.rb', line 9599

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. A human-readable description of this reference. Corresponds to the JSON property description

Returns:

  • (String)


9578
9579
9580
# File 'lib/google/apis/apigee_v1/classes.rb', line 9578

def description
  @description
end

#nameString

Required. The resource id of this reference. Values must match the regular expression [\w\s-.]+. Corresponds to the JSON property name

Returns:

  • (String)


9584
9585
9586
# File 'lib/google/apis/apigee_v1/classes.rb', line 9584

def name
  @name
end

#refersString

Required. The id of the resource to which this reference refers. Must be the id of a resource that exists in the parent environment and is of the given resource_type. Corresponds to the JSON property refers

Returns:

  • (String)


9591
9592
9593
# File 'lib/google/apis/apigee_v1/classes.rb', line 9591

def refers
  @refers
end

#resource_typeString

The type of resource referred to by this reference. Valid values are 'KeyStore' or 'TrustStore'. Corresponds to the JSON property resourceType

Returns:

  • (String)


9597
9598
9599
# File 'lib/google/apis/apigee_v1/classes.rb', line 9597

def resource_type
  @resource_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9604
9605
9606
9607
9608
9609
# File 'lib/google/apis/apigee_v1/classes.rb', line 9604

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @name = args[:name] if args.key?(:name)
  @refers = args[:refers] if args.key?(:refers)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
end