Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ReportInstanceStatusRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Request for ReportInstanceStatus.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1ReportInstanceStatusRequest

Returns a new instance of GoogleCloudApigeeV1ReportInstanceStatusRequest.



9670
9671
9672
# File 'lib/google/apis/apigee_v1/classes.rb', line 9670

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_uidString

A unique ID for the instance which is guaranteed to be unique in case the user installs multiple hybrid runtimes with the same instance ID. Corresponds to the JSON property instanceUid

Returns:

  • (String)


9656
9657
9658
# File 'lib/google/apis/apigee_v1/classes.rb', line 9656

def instance_uid
  @instance_uid
end

#report_timeString

The time the report was generated in the runtime. Used to prevent an old status from overwriting a newer one. An instance should space out it's status reports so that clock skew does not play a factor. Corresponds to the JSON property reportTime

Returns:

  • (String)


9663
9664
9665
# File 'lib/google/apis/apigee_v1/classes.rb', line 9663

def report_time
  @report_time
end

#resourcesArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ResourceStatus>

Status for config resources Corresponds to the JSON property resources



9668
9669
9670
# File 'lib/google/apis/apigee_v1/classes.rb', line 9668

def resources
  @resources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9675
9676
9677
9678
9679
# File 'lib/google/apis/apigee_v1/classes.rb', line 9675

def update!(**args)
  @instance_uid = args[:instance_uid] if args.key?(:instance_uid)
  @report_time = args[:report_time] if args.key?(:report_time)
  @resources = args[:resources] if args.key?(:resources)
end