Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ResourceStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

The status of a resource loaded in the runtime.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1ResourceStatus

Returns a new instance of GoogleCloudApigeeV1ResourceStatus.



9915
9916
9917
# File 'lib/google/apis/apigee_v1/classes.rb', line 9915

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resourceString

The resource name. Currently only two resources are supported: EnvironmentGroup - organizations/org/envgroups/envgroup EnvironmentConfig - organizations/org/environments/environment/deployedConfig Corresponds to the JSON property resource

Returns:

  • (String)


9896
9897
9898
# File 'lib/google/apis/apigee_v1/classes.rb', line 9896

def resource
  @resource
end

#revisionsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1RevisionStatus>

Revisions of the resource currently deployed in the instance. Corresponds to the JSON property revisions



9901
9902
9903
# File 'lib/google/apis/apigee_v1/classes.rb', line 9901

def revisions
  @revisions
end

#total_replicasFixnum

The total number of replicas that should have this resource. Corresponds to the JSON property totalReplicas

Returns:

  • (Fixnum)


9906
9907
9908
# File 'lib/google/apis/apigee_v1/classes.rb', line 9906

def total_replicas
  @total_replicas
end

#uidString

The uid of the resource. In the unexpected case that the instance has multiple uids for the same name, they should be reported under separate ResourceStatuses. Corresponds to the JSON property uid

Returns:

  • (String)


9913
9914
9915
# File 'lib/google/apis/apigee_v1/classes.rb', line 9913

def uid
  @uid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9920
9921
9922
9923
9924
9925
# File 'lib/google/apis/apigee_v1/classes.rb', line 9920

def update!(**args)
  @resource = args[:resource] if args.key?(:resource)
  @revisions = args[:revisions] if args.key?(:revisions)
  @total_replicas = args[:total_replicas] if args.key?(:total_replicas)
  @uid = args[:uid] if args.key?(:uid)
end