Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1RevenueShareRange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

API call volume range and the percentage of revenue to share with the developer when the total number of API calls is within the range.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1RevenueShareRange

Returns a new instance of GoogleCloudApigeeV1RevenueShareRange.



10044
10045
10046
# File 'lib/google/apis/apigee_v1/classes.rb', line 10044

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endFixnum

Ending value of the range. Set to 0 or null for the last range of values. Corresponds to the JSON property end

Returns:

  • (Fixnum)


10028
10029
10030
# File 'lib/google/apis/apigee_v1/classes.rb', line 10028

def end
  @end
end

#share_percentageFloat

Percentage of the revenue to be shared with the developer. For example, to share 21 percent of the total revenue with the developer, set this value to 21. Specify a decimal number with a maximum of two digits following the decimal point. Corresponds to the JSON property sharePercentage

Returns:

  • (Float)


10036
10037
10038
# File 'lib/google/apis/apigee_v1/classes.rb', line 10036

def share_percentage
  @share_percentage
end

#startFixnum

Starting value of the range. Set to 0 or null for the initial range of values. Corresponds to the JSON property start

Returns:

  • (Fixnum)


10042
10043
10044
# File 'lib/google/apis/apigee_v1/classes.rb', line 10042

def start
  @start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10049
10050
10051
10052
10053
# File 'lib/google/apis/apigee_v1/classes.rb', line 10049

def update!(**args)
  @end = args[:end] if args.key?(:end)
  @share_percentage = args[:share_percentage] if args.key?(:share_percentage)
  @start = args[:start] if args.key?(:start)
end