Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1RevisionStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

The status of a specific resource revision.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1RevisionStatus

Returns a new instance of GoogleCloudApigeeV1RevisionStatus.



10081
10082
10083
# File 'lib/google/apis/apigee_v1/classes.rb', line 10081

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1UpdateError>

Errors reported when attempting to load this revision. Corresponds to the JSON property errors



10063
10064
10065
# File 'lib/google/apis/apigee_v1/classes.rb', line 10063

def errors
  @errors
end

#json_specString

The json content of the resource revision. Large specs should be sent individually via the spec field to avoid hitting request size limits. Corresponds to the JSON property jsonSpec

Returns:

  • (String)


10069
10070
10071
# File 'lib/google/apis/apigee_v1/classes.rb', line 10069

def json_spec
  @json_spec
end

#replicasFixnum

The number of replicas that have successfully loaded this revision. Corresponds to the JSON property replicas

Returns:

  • (Fixnum)


10074
10075
10076
# File 'lib/google/apis/apigee_v1/classes.rb', line 10074

def replicas
  @replicas
end

#revision_idString

The revision of the resource. Corresponds to the JSON property revisionId

Returns:

  • (String)


10079
10080
10081
# File 'lib/google/apis/apigee_v1/classes.rb', line 10079

def revision_id
  @revision_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10086
10087
10088
10089
10090
10091
# File 'lib/google/apis/apigee_v1/classes.rb', line 10086

def update!(**args)
  @errors = args[:errors] if args.key?(:errors)
  @json_spec = args[:json_spec] if args.key?(:json_spec)
  @replicas = args[:replicas] if args.key?(:replicas)
  @revision_id = args[:revision_id] if args.key?(:revision_id)
end