Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1RoutingRule
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1RoutingRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Instance Attribute Summary collapse
-
#basepath ⇒ String
URI path prefix used to route to the specified environment.
-
#deployment_group ⇒ String
Name of a deployment group in an environment bound to the environment group in the following format:
organizations/org/environment/env/deploymentGroups/group`` Only one of environment or deployment_group will be set. -
#env_group_revision ⇒ Fixnum
The env group config revision_id when this rule was added or last updated.
-
#environment ⇒ String
Name of an environment bound to the environment group in the following format:
organizations/org/environments/env``. -
#other_targets ⇒ Array<String>
Conflicting targets, which will be resource names specifying either deployment groups or environments.
-
#receiver ⇒ String
The resource name of the proxy revision that is receiving this basepath in the following format:
organizations/org/apis/api/revisions/rev``. -
#update_time ⇒ String
The unix timestamp when this rule was updated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1RoutingRule
constructor
A new instance of GoogleCloudApigeeV1RoutingRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1RoutingRule
Returns a new instance of GoogleCloudApigeeV1RoutingRule.
10149 10150 10151 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10149 def initialize(**args) update!(**args) end |
Instance Attribute Details
#basepath ⇒ String
URI path prefix used to route to the specified environment. May contain one or
more wildcards. For example, path segments consisting of a single *
character will match any string.
Corresponds to the JSON property basepath
10103 10104 10105 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10103 def basepath @basepath end |
#deployment_group ⇒ String
Name of a deployment group in an environment bound to the environment group in
the following format: organizations/org/environment/env/deploymentGroups/
group`Only one of environment or deployment_group will be set.
Corresponds to the JSON propertydeploymentGroup`
10110 10111 10112 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10110 def deployment_group @deployment_group end |
#env_group_revision ⇒ Fixnum
The env group config revision_id when this rule was added or last updated.
This value is set when the rule is created and will only update if the the
environment_id changes. It is used to determine if the runtime is up to date
with respect to this rule. This field is omitted from the IngressConfig unless
the GetDeployedIngressConfig API is called with view=FULL.
Corresponds to the JSON property envGroupRevision
10119 10120 10121 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10119 def env_group_revision @env_group_revision end |
#environment ⇒ String
Name of an environment bound to the environment group in the following format:
organizations/org/environments/env`. Only one of environment or
deployment_group will be set.
Corresponds to the JSON propertyenvironment`
10126 10127 10128 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10126 def environment @environment end |
#other_targets ⇒ Array<String>
Conflicting targets, which will be resource names specifying either deployment
groups or environments.
Corresponds to the JSON property otherTargets
10132 10133 10134 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10132 def other_targets @other_targets end |
#receiver ⇒ String
The resource name of the proxy revision that is receiving this basepath in the
following format: organizations/org/apis/api/revisions/rev`. This field
is omitted from the IngressConfig unless the GetDeployedIngressConfig API is
called with view=FULL.
Corresponds to the JSON propertyreceiver`
10140 10141 10142 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10140 def receiver @receiver end |
#update_time ⇒ String
The unix timestamp when this rule was updated. This is updated whenever
env_group_revision is updated. This field is omitted from the IngressConfig
unless the GetDeployedIngressConfig API is called with view=FULL.
Corresponds to the JSON property updateTime
10147 10148 10149 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10147 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10154 10155 10156 10157 10158 10159 10160 10161 10162 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10154 def update!(**args) @basepath = args[:basepath] if args.key?(:basepath) @deployment_group = args[:deployment_group] if args.key?(:deployment_group) @env_group_revision = args[:env_group_revision] if args.key?(:env_group_revision) @environment = args[:environment] if args.key?(:environment) @other_targets = args[:other_targets] if args.key?(:other_targets) @receiver = args[:receiver] if args.key?(:receiver) @update_time = args[:update_time] if args.key?(:update_time) end |