Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeAddonsConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeAddonsConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
RuntimeAddonsConfig defines the runtime configurations for add-ons in an environment.
Instance Attribute Summary collapse
-
#analytics_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeAnalyticsConfig
Runtime configuration for the Analytics add-on.
-
#api_security_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeApiSecurityConfig
Runtime configuration for the API Security add-on.
-
#name ⇒ String
Name of the addons config in the format:
organizations/org/environments/env/addonsConfigCorresponds to the JSON propertyname. -
#revision_id ⇒ String
Revision number used by the runtime to detect config changes.
-
#spec_generation_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeSpecGenerationAddonConfig
Runtime configuration for the Spec Generation add-on.
-
#uid ⇒ String
UID is to detect if config is recreated after deletion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1RuntimeAddonsConfig
constructor
A new instance of GoogleCloudApigeeV1RuntimeAddonsConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1RuntimeAddonsConfig
Returns a new instance of GoogleCloudApigeeV1RuntimeAddonsConfig.
10207 10208 10209 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10207 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analytics_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeAnalyticsConfig
Runtime configuration for the Analytics add-on.
Corresponds to the JSON property analyticsConfig
10173 10174 10175 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10173 def analytics_config @analytics_config end |
#api_security_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeApiSecurityConfig
Runtime configuration for the API Security add-on.
Corresponds to the JSON property apiSecurityConfig
10178 10179 10180 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10178 def api_security_config @api_security_config end |
#name ⇒ String
Name of the addons config in the format: organizations/org/environments/
env/addonsConfig
Corresponds to the JSON property name
10184 10185 10186 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10184 def name @name end |
#revision_id ⇒ String
Revision number used by the runtime to detect config changes.
Corresponds to the JSON property revisionId
10189 10190 10191 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10189 def revision_id @revision_id end |
#spec_generation_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeSpecGenerationAddonConfig
Runtime configuration for the Spec Generation add-on. All fields are proto3
primitives (bool, string, double) rather than google.protobuf.*Value wrappers
because the runtime consumer deserializes the JSON via Gson field reflection
with no registered type adapters. Wrapper types would serialize as JSON
objects/null that Gson cannot bind to Java primitive fields.
Corresponds to the JSON property specGenerationConfig
10198 10199 10200 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10198 def spec_generation_config @spec_generation_config end |
#uid ⇒ String
UID is to detect if config is recreated after deletion. The add-on config will
only be deleted when the environment itself gets deleted, thus it will always
be the same as the UID of EnvironmentConfig.
Corresponds to the JSON property uid
10205 10206 10207 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10205 def uid @uid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10212 10213 10214 10215 10216 10217 10218 10219 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10212 def update!(**args) @analytics_config = args[:analytics_config] if args.key?(:analytics_config) @api_security_config = args[:api_security_config] if args.key?(:api_security_config) @name = args[:name] if args.key?(:name) @revision_id = args[:revision_id] if args.key?(:revision_id) @spec_generation_config = args[:spec_generation_config] if args.key?(:spec_generation_config) @uid = args[:uid] if args.key?(:uid) end |