Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Runtime configuration for the organization. Response for GetRuntimeConfig.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1RuntimeConfig

Returns a new instance of GoogleCloudApigeeV1RuntimeConfig.



10289
10290
10291
# File 'lib/google/apis/apigee_v1/classes.rb', line 10289

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analytics_bucketString

Cloud Storage bucket used for uploading Analytics records. Corresponds to the JSON property analyticsBucket

Returns:

  • (String)


10266
10267
10268
# File 'lib/google/apis/apigee_v1/classes.rb', line 10266

def analytics_bucket
  @analytics_bucket
end

#nameString

Name of the resource in the following format: organizations/org/ runtimeConfig. Corresponds to the JSON property name

Returns:

  • (String)


10272
10273
10274
# File 'lib/google/apis/apigee_v1/classes.rb', line 10272

def name
  @name
end

#tenant_project_idString

Output only. Tenant project ID associated with the Apigee organization. The tenant project is used to host Google-managed resources that are dedicated to this Apigee organization. Clients have limited access to resources within the tenant project used to support Apigee runtime instances. Access to the tenant project is managed using SetSyncAuthorization. It can be empty if the tenant project hasn't been created yet. Corresponds to the JSON property tenantProjectId

Returns:

  • (String)


10282
10283
10284
# File 'lib/google/apis/apigee_v1/classes.rb', line 10282

def tenant_project_id
  @tenant_project_id
end

#trace_bucketString

Cloud Storage bucket used for uploading Trace records. Corresponds to the JSON property traceBucket

Returns:

  • (String)


10287
10288
10289
# File 'lib/google/apis/apigee_v1/classes.rb', line 10287

def trace_bucket
  @trace_bucket
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10294
10295
10296
10297
10298
10299
# File 'lib/google/apis/apigee_v1/classes.rb', line 10294

def update!(**args)
  @analytics_bucket = args[:analytics_bucket] if args.key?(:analytics_bucket)
  @name = args[:name] if args.key?(:name)
  @tenant_project_id = args[:tenant_project_id] if args.key?(:tenant_project_id)
  @trace_bucket = args[:trace_bucket] if args.key?(:trace_bucket)
end