Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceConfigOverride

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

NEXT ID: 10 Trace configuration override for a specific API proxy in an environment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1RuntimeTraceConfigOverride

Returns a new instance of GoogleCloudApigeeV1RuntimeTraceConfigOverride.



10600
10601
10602
# File 'lib/google/apis/apigee_v1/classes.rb', line 10600

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_proxyString

Name of the API proxy that will have its trace configuration overridden following format: organizations/org/apis/api` Corresponds to the JSON propertyapiProxy`

Returns:

  • (String)


10545
10546
10547
# File 'lib/google/apis/apigee_v1/classes.rb', line 10545

def api_proxy
  @api_proxy
end

#nameString

Name of the trace config override in the following format: organizations/org /environment/env/traceConfig/overrides/override` Corresponds to the JSON propertyname`

Returns:

  • (String)


10551
10552
10553
# File 'lib/google/apis/apigee_v1/classes.rb', line 10551

def name
  @name
end

#open_telemetry_protocol_enabledBoolean Also known as: open_telemetry_protocol_enabled?

Optional. If true, the runtime uses OpenTelemetry Protocol (OTLP) to send trace data. Configuration Requirements (if open_telemetry_protocol_enabled is true): - Allowed Exporters: CLOUD_TRACE or OPEN_TELEMETRY_COLLECTOR.

  • If Exporter is OPEN_TELEMETRY_COLLECTOR: - endpoint refers to a valid OTLP collector URL. - If Exporter is CLOUD_TRACE: - endpoint refers to a valid project ID Deprecated: Use trace_protocol instead. Corresponds to the JSON property openTelemetryProtocolEnabled

Returns:

  • (Boolean)


10561
10562
10563
# File 'lib/google/apis/apigee_v1/classes.rb', line 10561

def open_telemetry_protocol_enabled
  @open_telemetry_protocol_enabled
end

#revision_create_timeString

The timestamp that the revision was created or updated. Corresponds to the JSON property revisionCreateTime

Returns:

  • (String)


10567
10568
10569
# File 'lib/google/apis/apigee_v1/classes.rb', line 10567

def revision_create_time
  @revision_create_time
end

#revision_idString

Revision number which can be used by the runtime to detect if the trace config override has changed between two versions. Corresponds to the JSON property revisionId

Returns:

  • (String)


10573
10574
10575
# File 'lib/google/apis/apigee_v1/classes.rb', line 10573

def revision_id
  @revision_id
end

#sampling_configGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceSamplingConfig

NEXT ID: 3 RuntimeTraceSamplingConfig represents the detail settings of distributed tracing. Only the fields that are defined in the distributed trace configuration can be overridden using the distribute trace configuration override APIs. Corresponds to the JSON property samplingConfig



10581
10582
10583
# File 'lib/google/apis/apigee_v1/classes.rb', line 10581

def sampling_config
  @sampling_config
end

#span_semanticsString

Optional. The span semantics to use. Configuration Requirements (if span_semantics is OTEL): - trace_protocol must be OTLP. Corresponds to the JSON property spanSemantics

Returns:

  • (String)


10587
10588
10589
# File 'lib/google/apis/apigee_v1/classes.rb', line 10587

def span_semantics
  @span_semantics
end

#trace_protocolString

Optional. The trace protocol to use. Corresponds to the JSON property traceProtocol

Returns:

  • (String)


10592
10593
10594
# File 'lib/google/apis/apigee_v1/classes.rb', line 10592

def trace_protocol
  @trace_protocol
end

#uidString

Unique ID for the configuration override. The ID will only change if the override is deleted and recreated. Corresponds to name's "override" field. Corresponds to the JSON property uid

Returns:

  • (String)


10598
10599
10600
# File 'lib/google/apis/apigee_v1/classes.rb', line 10598

def uid
  @uid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10605
10606
10607
10608
10609
10610
10611
10612
10613
10614
10615
# File 'lib/google/apis/apigee_v1/classes.rb', line 10605

def update!(**args)
  @api_proxy = args[:api_proxy] if args.key?(:api_proxy)
  @name = args[:name] if args.key?(:name)
  @open_telemetry_protocol_enabled = args[:open_telemetry_protocol_enabled] if args.key?(:open_telemetry_protocol_enabled)
  @revision_create_time = args[:revision_create_time] if args.key?(:revision_create_time)
  @revision_id = args[:revision_id] if args.key?(:revision_id)
  @sampling_config = args[:sampling_config] if args.key?(:sampling_config)
  @span_semantics = args[:span_semantics] if args.key?(:span_semantics)
  @trace_protocol = args[:trace_protocol] if args.key?(:trace_protocol)
  @uid = args[:uid] if args.key?(:uid)
end