Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Schema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Response for Schema call

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1Schema

Returns a new instance of GoogleCloudApigeeV1Schema.



10687
10688
10689
# File 'lib/google/apis/apigee_v1/classes.rb', line 10687

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimensionsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SchemaSchemaElement>

List of schema fields grouped as dimensions. Corresponds to the JSON property dimensions



10673
10674
10675
# File 'lib/google/apis/apigee_v1/classes.rb', line 10673

def dimensions
  @dimensions
end

#metaArray<String>

Additional metadata associated with schema. This is a legacy field and usually consists of an empty array of strings. Corresponds to the JSON property meta

Returns:

  • (Array<String>)


10679
10680
10681
# File 'lib/google/apis/apigee_v1/classes.rb', line 10679

def meta
  @meta
end

#metricsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SchemaSchemaElement>

List of schema fields grouped as dimensions that can be used with an aggregate function such as sum, avg, min, and max. Corresponds to the JSON property metrics



10685
10686
10687
# File 'lib/google/apis/apigee_v1/classes.rb', line 10685

def metrics
  @metrics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10692
10693
10694
10695
10696
# File 'lib/google/apis/apigee_v1/classes.rb', line 10692

def update!(**args)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @meta = args[:meta] if args.key?(:meta)
  @metrics = args[:metrics] if args.key?(:metrics)
end