Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Score

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Represents Security Score.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1Score

Returns a new instance of GoogleCloudApigeeV1Score.



10779
10780
10781
# File 'lib/google/apis/apigee_v1/classes.rb', line 10779

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#componentGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponent

Component is an individual security element that is scored. Corresponds to the JSON property component



10764
10765
10766
# File 'lib/google/apis/apigee_v1/classes.rb', line 10764

def component
  @component
end

#subcomponentsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponent>

List of all the drilldown score components. Corresponds to the JSON property subcomponents



10769
10770
10771
# File 'lib/google/apis/apigee_v1/classes.rb', line 10769

def subcomponents
  @subcomponents
end

#time_rangeGoogle::Apis::ApigeeV1::GoogleTypeInterval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property timeRange



10777
10778
10779
# File 'lib/google/apis/apigee_v1/classes.rb', line 10777

def time_range
  @time_range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10784
10785
10786
10787
10788
# File 'lib/google/apis/apigee_v1/classes.rb', line 10784

def update!(**args)
  @component = args[:component] if args.key?(:component)
  @subcomponents = args[:subcomponents] if args.key?(:subcomponents)
  @time_range = args[:time_range] if args.key?(:time_range)
end