Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponent
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Component is an individual security element that is scored.
Instance Attribute Summary collapse
-
#calculate_time ⇒ String
Time when score was calculated.
-
#data_capture_time ⇒ String
Time in the requested time period when data was last captured to compute the score.
-
#drilldown_paths ⇒ Array<String>
List of paths for next components.
-
#recommendations ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponentRecommendation>
List of recommendations to improve API security.
-
#score ⇒ Fixnum
Score for the component.
-
#score_path ⇒ String
Path of the component.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1ScoreComponent
constructor
A new instance of GoogleCloudApigeeV1ScoreComponent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1ScoreComponent
Returns a new instance of GoogleCloudApigeeV1ScoreComponent.
10827 10828 10829 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10827 def initialize(**args) update!(**args) end |
Instance Attribute Details
#calculate_time ⇒ String
Time when score was calculated.
Corresponds to the JSON property calculateTime
10798 10799 10800 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10798 def calculate_time @calculate_time end |
#data_capture_time ⇒ String
Time in the requested time period when data was last captured to compute the
score.
Corresponds to the JSON property dataCaptureTime
10804 10805 10806 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10804 def data_capture_time @data_capture_time end |
#drilldown_paths ⇒ Array<String>
List of paths for next components.
Corresponds to the JSON property drilldownPaths
10809 10810 10811 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10809 def drilldown_paths @drilldown_paths end |
#recommendations ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponentRecommendation>
List of recommendations to improve API security.
Corresponds to the JSON property recommendations
10814 10815 10816 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10814 def recommendations @recommendations end |
#score ⇒ Fixnum
Score for the component.
Corresponds to the JSON property score
10819 10820 10821 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10819 def score @score end |
#score_path ⇒ String
Path of the component. Example: /org@myorg/envgroup@myenvgroup/proxies/proxy@
myproxy
Corresponds to the JSON property scorePath
10825 10826 10827 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10825 def score_path @score_path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10832 10833 10834 10835 10836 10837 10838 10839 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10832 def update!(**args) @calculate_time = args[:calculate_time] if args.key?(:calculate_time) @data_capture_time = args[:data_capture_time] if args.key?(:data_capture_time) @drilldown_paths = args[:drilldown_paths] if args.key?(:drilldown_paths) @recommendations = args[:recommendations] if args.key?(:recommendations) @score = args[:score] if args.key?(:score) @score_path = args[:score_path] if args.key?(:score_path) end |