Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponentRecommendationAction
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponentRecommendationAction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Action to improve security score.
Instance Attribute Summary collapse
-
#action_context ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponentRecommendationActionActionContext
Action context are all the relevant details for the action.
-
#description ⇒ String
Description of the action.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1ScoreComponentRecommendationAction
constructor
A new instance of GoogleCloudApigeeV1ScoreComponentRecommendationAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1ScoreComponentRecommendationAction
Returns a new instance of GoogleCloudApigeeV1ScoreComponentRecommendationAction.
10734 10735 10736 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10734 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action_context ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponentRecommendationActionActionContext
Action context are all the relevant details for the action.
Corresponds to the JSON property actionContext
10727 10728 10729 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10727 def action_context @action_context end |
#description ⇒ String
Description of the action.
Corresponds to the JSON property description
10732 10733 10734 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10732 def description @description end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10739 10740 10741 10742 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10739 def update!(**args) @action_context = args[:action_context] if args.key?(:action_context) @description = args[:description] if args.key?(:description) end |