Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

A SecurityAction is rule that can be enforced at an environment level. The result is one of: - A denied API call - An explicitly allowed API call - A flagged API call (HTTP headers added before the target receives it) At least one condition is required to create a SecurityAction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityAction

Returns a new instance of GoogleCloudApigeeV1SecurityAction.



11009
11010
11011
# File 'lib/google/apis/apigee_v1/classes.rb', line 11009

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityActionAllow

Message that should be set in case of an Allow Action. This does not have any fields. Corresponds to the JSON property allow



10935
10936
10937
# File 'lib/google/apis/apigee_v1/classes.rb', line 10935

def allow
  @allow
end

#api_proxiesArray<String>

Optional. If unset, this would apply to all proxies in the environment. If set, this action is enforced only if at least one proxy in the repeated list is deployed at the time of enforcement. If set, several restrictions are enforced on SecurityActions. There can be at most 100 enabled actions with proxies set in an env. Several other restrictions apply on conditions and are detailed later. Corresponds to the JSON property apiProxies

Returns:

  • (Array<String>)


10945
10946
10947
# File 'lib/google/apis/apigee_v1/classes.rb', line 10945

def api_proxies
  @api_proxies
end

#condition_configGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityActionConditionConfig

The following are a list of conditions. A valid SecurityAction must contain at least one condition. Within a condition, each element is ORed. Across conditions elements are ANDed. For example if a SecurityAction has the following: ip_address_ranges: ["ip1", "ip2"] and bot_reasons: ["Flooder", " Robot Abuser"] then this is interpreted as: enforce the action if the incoming request has ((ip_address_ranges = "ip1" OR ip_address_ranges = "ip2") AND ( bot_reasons="Flooder" OR bot_reasons="Robot Abuser")). Conditions other than ip_address_ranges and bot_reasons cannot be ANDed. Corresponds to the JSON property conditionConfig



10957
10958
10959
# File 'lib/google/apis/apigee_v1/classes.rb', line 10957

def condition_config
  @condition_config
end

#create_timeString

Output only. The create time for this SecurityAction. Corresponds to the JSON property createTime

Returns:

  • (String)


10962
10963
10964
# File 'lib/google/apis/apigee_v1/classes.rb', line 10962

def create_time
  @create_time
end

#denyGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityActionDeny

Message that should be set in case of a Deny Action. Corresponds to the JSON property deny



10967
10968
10969
# File 'lib/google/apis/apigee_v1/classes.rb', line 10967

def deny
  @deny
end

#descriptionString

Optional. An optional user provided description of the SecurityAction. Corresponds to the JSON property description

Returns:

  • (String)


10972
10973
10974
# File 'lib/google/apis/apigee_v1/classes.rb', line 10972

def description
  @description
end

#expire_timeString

The expiration for this SecurityAction. Corresponds to the JSON property expireTime

Returns:

  • (String)


10977
10978
10979
# File 'lib/google/apis/apigee_v1/classes.rb', line 10977

def expire_time
  @expire_time
end

#flagGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityActionFlag

The message that should be set in the case of a Flag action. Corresponds to the JSON property flag



10982
10983
10984
# File 'lib/google/apis/apigee_v1/classes.rb', line 10982

def flag
  @flag
end

#nameString

Immutable. This field is ignored during creation as per AIP-133. Please set the security_action_id field in the CreateSecurityActionRequest when creating a new SecurityAction. Format: organizations/org/environments/env/ securityActions/security_action Corresponds to the JSON property name

Returns:

  • (String)


10990
10991
10992
# File 'lib/google/apis/apigee_v1/classes.rb', line 10990

def name
  @name
end

#stateString

Required. Only an ENABLED SecurityAction is enforced. An ENABLED SecurityAction past its expiration time will not be enforced. Corresponds to the JSON property state

Returns:

  • (String)


10996
10997
10998
# File 'lib/google/apis/apigee_v1/classes.rb', line 10996

def state
  @state
end

#ttlString

Input only. The TTL for this SecurityAction. Corresponds to the JSON property ttl

Returns:

  • (String)


11001
11002
11003
# File 'lib/google/apis/apigee_v1/classes.rb', line 11001

def ttl
  @ttl
end

#update_timeString

Output only. The update time for this SecurityAction. This reflects when this SecurityAction changed states. Corresponds to the JSON property updateTime

Returns:

  • (String)


11007
11008
11009
# File 'lib/google/apis/apigee_v1/classes.rb', line 11007

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11014
11015
11016
11017
11018
11019
11020
11021
11022
11023
11024
11025
11026
11027
# File 'lib/google/apis/apigee_v1/classes.rb', line 11014

def update!(**args)
  @allow = args[:allow] if args.key?(:allow)
  @api_proxies = args[:api_proxies] if args.key?(:api_proxies)
  @condition_config = args[:condition_config] if args.key?(:condition_config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @deny = args[:deny] if args.key?(:deny)
  @description = args[:description] if args.key?(:description)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @flag = args[:flag] if args.key?(:flag)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @ttl = args[:ttl] if args.key?(:ttl)
  @update_time = args[:update_time] if args.key?(:update_time)
end