Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityActionHttpHeader

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

An HTTP header.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityActionHttpHeader

Returns a new instance of GoogleCloudApigeeV1SecurityActionHttpHeader.



11193
11194
11195
# File 'lib/google/apis/apigee_v1/classes.rb', line 11193

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The header name to be sent to the target. Corresponds to the JSON property name

Returns:

  • (String)


11186
11187
11188
# File 'lib/google/apis/apigee_v1/classes.rb', line 11186

def name
  @name
end

#valueString

The header value to be sent to the target. Corresponds to the JSON property value

Returns:

  • (String)


11191
11192
11193
# File 'lib/google/apis/apigee_v1/classes.rb', line 11191

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11198
11199
11200
11201
# File 'lib/google/apis/apigee_v1/classes.rb', line 11198

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @value = args[:value] if args.key?(:value)
end