Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Resource for which we are computing security assessment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityAssessmentResultResource

Returns a new instance of GoogleCloudApigeeV1SecurityAssessmentResultResource.



11315
11316
11317
# File 'lib/google/apis/apigee_v1/classes.rb', line 11315

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_hub_deployment_detailsGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultResourceApiHubDeploymentDetails

Additional details if the resource is an API Hub deployment. Corresponds to the JSON property apiHubDeploymentDetails



11291
11292
11293
# File 'lib/google/apis/apigee_v1/classes.rb', line 11291

def api_hub_deployment_details
  @api_hub_deployment_details
end

#api_hub_gateway_typeString

Optional. Corresponds to the JSON property apiHubGatewayType

Returns:

  • (String)


11296
11297
11298
# File 'lib/google/apis/apigee_v1/classes.rb', line 11296

def api_hub_gateway_type
  @api_hub_gateway_type
end

#nameString

Required. Name of this resource. For an Apigee API Proxy, this should be the id of the API proxy. For an API Hub Deployment, this should be the id of the deployment. Corresponds to the JSON property name

Returns:

  • (String)


11303
11304
11305
# File 'lib/google/apis/apigee_v1/classes.rb', line 11303

def name
  @name
end

#resource_revision_idString

The revision id for the resource. In case of Apigee, this is proxy revision id. Corresponds to the JSON property resourceRevisionId

Returns:

  • (String)


11308
11309
11310
# File 'lib/google/apis/apigee_v1/classes.rb', line 11308

def resource_revision_id
  @resource_revision_id
end

#typeString

Required. Type of this resource. Corresponds to the JSON property type

Returns:

  • (String)


11313
11314
11315
# File 'lib/google/apis/apigee_v1/classes.rb', line 11313

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11320
11321
11322
11323
11324
11325
11326
# File 'lib/google/apis/apigee_v1/classes.rb', line 11320

def update!(**args)
  @api_hub_deployment_details = args[:api_hub_deployment_details] if args.key?(:api_hub_deployment_details)
  @api_hub_gateway_type = args[:api_hub_gateway_type] if args.key?(:api_hub_gateway_type)
  @name = args[:name] if args.key?(:name)
  @resource_revision_id = args[:resource_revision_id] if args.key?(:resource_revision_id)
  @type = args[:type] if args.key?(:type)
end