Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultScoringResultAssessmentRecommendation
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultScoringResultAssessmentRecommendation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
The message format of a recommendation from the assessment.
Instance Attribute Summary collapse
-
#display_name ⇒ String
The display name of the assessment.
-
#recommendations ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultScoringResultAssessmentRecommendationRecommendation>
The recommended steps of the assessment.
-
#score_impact ⇒ Fixnum
Score impact indicates the impact on the overall score if the assessment were to pass.
-
#verdict ⇒ String
Verdict indicates the assessment result.
-
#weight ⇒ String
The weight of the assessment which was set in the profile.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityAssessmentResultScoringResultAssessmentRecommendation
constructor
A new instance of GoogleCloudApigeeV1SecurityAssessmentResultScoringResultAssessmentRecommendation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityAssessmentResultScoringResultAssessmentRecommendation
Returns a new instance of GoogleCloudApigeeV1SecurityAssessmentResultScoringResultAssessmentRecommendation.
11194 11195 11196 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11194 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
The display name of the assessment.
Corresponds to the JSON property displayName
11171 11172 11173 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11171 def display_name @display_name end |
#recommendations ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultScoringResultAssessmentRecommendationRecommendation>
The recommended steps of the assessment.
Corresponds to the JSON property recommendations
11176 11177 11178 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11176 def recommendations @recommendations end |
#score_impact ⇒ Fixnum
Score impact indicates the impact on the overall score if the assessment were
to pass.
Corresponds to the JSON property scoreImpact
11182 11183 11184 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11182 def score_impact @score_impact end |
#verdict ⇒ String
Verdict indicates the assessment result.
Corresponds to the JSON property verdict
11187 11188 11189 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11187 def verdict @verdict end |
#weight ⇒ String
The weight of the assessment which was set in the profile.
Corresponds to the JSON property weight
11192 11193 11194 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11192 def weight @weight end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11199 11200 11201 11202 11203 11204 11205 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11199 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @recommendations = args[:recommendations] if args.key?(:recommendations) @score_impact = args[:score_impact] if args.key?(:score_impact) @verdict = args[:verdict] if args.key?(:verdict) @weight = args[:weight] if args.key?(:weight) end |