Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityFeedback

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Represents a feedback report from an Advanced API Security customer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityFeedback

Returns a new instance of GoogleCloudApigeeV1SecurityFeedback.



11560
11561
11562
# File 'lib/google/apis/apigee_v1/classes.rb', line 11560

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commentString

Optional. Optional text the user can provide for additional, unstructured context. Corresponds to the JSON property comment

Returns:

  • (String)


11522
11523
11524
# File 'lib/google/apis/apigee_v1/classes.rb', line 11522

def comment
  @comment
end

#create_timeString

Output only. The time when this specific feedback id was created. Corresponds to the JSON property createTime

Returns:

  • (String)


11527
11528
11529
# File 'lib/google/apis/apigee_v1/classes.rb', line 11527

def create_time
  @create_time
end

#display_nameString

Optional. The display name of the feedback. Corresponds to the JSON property displayName

Returns:

  • (String)


11532
11533
11534
# File 'lib/google/apis/apigee_v1/classes.rb', line 11532

def display_name
  @display_name
end

#feedback_contextsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityFeedbackFeedbackContext>

Required. One or more attribute/value pairs for constraining the feedback. Corresponds to the JSON property feedbackContexts



11537
11538
11539
# File 'lib/google/apis/apigee_v1/classes.rb', line 11537

def feedback_contexts
  @feedback_contexts
end

#feedback_typeString

Required. The type of feedback being submitted. Corresponds to the JSON property feedbackType

Returns:

  • (String)


11542
11543
11544
# File 'lib/google/apis/apigee_v1/classes.rb', line 11542

def feedback_type
  @feedback_type
end

#nameString

Output only. Identifier. The feedback name is intended to be a system- generated uuid. Corresponds to the JSON property name

Returns:

  • (String)


11548
11549
11550
# File 'lib/google/apis/apigee_v1/classes.rb', line 11548

def name
  @name
end

#reasonString

Optional. The reason for the feedback. Corresponds to the JSON property reason

Returns:

  • (String)


11553
11554
11555
# File 'lib/google/apis/apigee_v1/classes.rb', line 11553

def reason
  @reason
end

#update_timeString

Output only. The time when this specific feedback id was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


11558
11559
11560
# File 'lib/google/apis/apigee_v1/classes.rb', line 11558

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11565
11566
11567
11568
11569
11570
11571
11572
11573
11574
# File 'lib/google/apis/apigee_v1/classes.rb', line 11565

def update!(**args)
  @comment = args[:comment] if args.key?(:comment)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @feedback_contexts = args[:feedback_contexts] if args.key?(:feedback_contexts)
  @feedback_type = args[:feedback_type] if args.key?(:feedback_type)
  @name = args[:name] if args.key?(:name)
  @reason = args[:reason] if args.key?(:reason)
  @update_time = args[:update_time] if args.key?(:update_time)
end