Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityIncident
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityIncident
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Represents an SecurityIncident resource.
Instance Attribute Summary collapse
-
#detection_types ⇒ Array<String>
Output only.
-
#display_name ⇒ String
Optional.
-
#first_detected_time ⇒ String
Output only.
-
#last_detected_time ⇒ String
Output only.
-
#last_observability_change_time ⇒ String
Output only.
-
#name ⇒ String
Immutable.
-
#observability ⇒ String
Optional.
-
#risk_level ⇒ String
Output only.
-
#traffic_count ⇒ Fixnum
Total traffic detected as part of the incident.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityIncident
constructor
A new instance of GoogleCloudApigeeV1SecurityIncident.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityIncident
Returns a new instance of GoogleCloudApigeeV1SecurityIncident.
11656 11657 11658 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11656 def initialize(**args) update!(**args) end |
Instance Attribute Details
#detection_types ⇒ Array<String>
Output only. Detection types which are part of the incident. Examples: Flooder,
OAuth Abuser, Static Content Scraper, Anomaly Detection.
Corresponds to the JSON property detectionTypes
11610 11611 11612 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11610 def detection_types @detection_types end |
#display_name ⇒ String
Optional. Display name of the security incident.
Corresponds to the JSON property displayName
11615 11616 11617 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11615 def display_name @display_name end |
#first_detected_time ⇒ String
Output only. The time when events associated with the incident were first
detected.
Corresponds to the JSON property firstDetectedTime
11621 11622 11623 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11621 def first_detected_time @first_detected_time end |
#last_detected_time ⇒ String
Output only. The time when events associated with the incident were last
detected.
Corresponds to the JSON property lastDetectedTime
11627 11628 11629 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11627 def last_detected_time @last_detected_time end |
#last_observability_change_time ⇒ String
Output only. The time when the incident observability was last changed.
Corresponds to the JSON property lastObservabilityChangeTime
11632 11633 11634 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11632 def last_observability_change_time @last_observability_change_time end |
#name ⇒ String
Immutable. Name of the security incident resource. Format: organizations/org/
environments/environment/securityIncidents/incident Example: organizations/
apigee-org/environments/dev/securityIncidents/1234-5678-9101-1111
Corresponds to the JSON property name
11639 11640 11641 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11639 def name @name end |
#observability ⇒ String
Optional. Indicates if the user archived this incident.
Corresponds to the JSON property observability
11644 11645 11646 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11644 def observability @observability end |
#risk_level ⇒ String
Output only. Risk level of the incident.
Corresponds to the JSON property riskLevel
11649 11650 11651 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11649 def risk_level @risk_level end |
#traffic_count ⇒ Fixnum
Total traffic detected as part of the incident.
Corresponds to the JSON property trafficCount
11654 11655 11656 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11654 def traffic_count @traffic_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11661 11662 11663 11664 11665 11666 11667 11668 11669 11670 11671 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11661 def update!(**args) @detection_types = args[:detection_types] if args.key?(:detection_types) @display_name = args[:display_name] if args.key?(:display_name) @first_detected_time = args[:first_detected_time] if args.key?(:first_detected_time) @last_detected_time = args[:last_detected_time] if args.key?(:last_detected_time) @last_observability_change_time = args[:last_observability_change_time] if args.key?(:last_observability_change_time) @name = args[:name] if args.key?(:name) @observability = args[:observability] if args.key?(:observability) @risk_level = args[:risk_level] if args.key?(:risk_level) @traffic_count = args[:traffic_count] if args.key?(:traffic_count) end |