Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Represents a SecurityProfile resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityProfile

Returns a new instance of GoogleCloudApigeeV1SecurityProfile.



11828
11829
11830
# File 'lib/google/apis/apigee_v1/classes.rb', line 11828

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Description of the security profile. Corresponds to the JSON property description

Returns:

  • (String)


11767
11768
11769
# File 'lib/google/apis/apigee_v1/classes.rb', line 11767

def description
  @description
end

#display_nameString

DEPRECATED: DO NOT USE Display name of the security profile. Corresponds to the JSON property displayName

Returns:

  • (String)


11772
11773
11774
# File 'lib/google/apis/apigee_v1/classes.rb', line 11772

def display_name
  @display_name
end

#environmentsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityProfileEnvironment>

List of environments attached to security profile. Corresponds to the JSON property environments



11777
11778
11779
# File 'lib/google/apis/apigee_v1/classes.rb', line 11777

def environments
  @environments
end

#max_scoreFixnum

Output only. Maximum security score that can be generated by this profile. Corresponds to the JSON property maxScore

Returns:

  • (Fixnum)


11782
11783
11784
# File 'lib/google/apis/apigee_v1/classes.rb', line 11782

def max_score
  @max_score
end

#min_scoreFixnum

Output only. Minimum security score that can be generated by this profile. Corresponds to the JSON property minScore

Returns:

  • (Fixnum)


11787
11788
11789
# File 'lib/google/apis/apigee_v1/classes.rb', line 11787

def min_score
  @min_score
end

#nameString

Immutable. Name of the security profile resource. Format: organizations/org/ securityProfiles/profile Corresponds to the JSON property name

Returns:

  • (String)


11793
11794
11795
# File 'lib/google/apis/apigee_v1/classes.rb', line 11793

def name
  @name
end

#profile_configGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfig

ProfileConfig defines a set of categories and policies which will be used to compute security score. Corresponds to the JSON property profileConfig



11799
11800
11801
# File 'lib/google/apis/apigee_v1/classes.rb', line 11799

def profile_config
  @profile_config
end

#revision_create_timeString

Output only. The time when revision was created. Corresponds to the JSON property revisionCreateTime

Returns:

  • (String)


11804
11805
11806
# File 'lib/google/apis/apigee_v1/classes.rb', line 11804

def revision_create_time
  @revision_create_time
end

#revision_idFixnum

Output only. Revision ID of the security profile. Corresponds to the JSON property revisionId

Returns:

  • (Fixnum)


11809
11810
11811
# File 'lib/google/apis/apigee_v1/classes.rb', line 11809

def revision_id
  @revision_id
end

#revision_publish_timeString

Output only. DEPRECATED: DO NOT USE The time when revision was published. Once published, the security profile revision cannot be updated further and can be attached to environments. Corresponds to the JSON property revisionPublishTime

Returns:

  • (String)


11816
11817
11818
# File 'lib/google/apis/apigee_v1/classes.rb', line 11816

def revision_publish_time
  @revision_publish_time
end

#revision_update_timeString

Output only. The time when revision was updated. Corresponds to the JSON property revisionUpdateTime

Returns:

  • (String)


11821
11822
11823
# File 'lib/google/apis/apigee_v1/classes.rb', line 11821

def revision_update_time
  @revision_update_time
end

#scoring_configsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityProfileScoringConfig>

List of profile scoring configs in this revision. Corresponds to the JSON property scoringConfigs



11826
11827
11828
# File 'lib/google/apis/apigee_v1/classes.rb', line 11826

def scoring_configs
  @scoring_configs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11833
11834
11835
11836
11837
11838
11839
11840
11841
11842
11843
11844
11845
11846
# File 'lib/google/apis/apigee_v1/classes.rb', line 11833

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @environments = args[:environments] if args.key?(:environments)
  @max_score = args[:max_score] if args.key?(:max_score)
  @min_score = args[:min_score] if args.key?(:min_score)
  @name = args[:name] if args.key?(:name)
  @profile_config = args[:profile_config] if args.key?(:profile_config)
  @revision_create_time = args[:revision_create_time] if args.key?(:revision_create_time)
  @revision_id = args[:revision_id] if args.key?(:revision_id)
  @revision_publish_time = args[:revision_publish_time] if args.key?(:revision_publish_time)
  @revision_update_time = args[:revision_update_time] if args.key?(:revision_update_time)
  @scoring_configs = args[:scoring_configs] if args.key?(:scoring_configs)
end