Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityProfileEnvironment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Environment information of attached environments. Scoring an environment is enabled only if it is attached to a security profile.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityProfileEnvironment

Returns a new instance of GoogleCloudApigeeV1SecurityProfileEnvironment.



11704
11705
11706
# File 'lib/google/apis/apigee_v1/classes.rb', line 11704

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attach_timeString

Output only. Time at which environment was attached to the security profile. Corresponds to the JSON property attachTime

Returns:

  • (String)


11697
11698
11699
# File 'lib/google/apis/apigee_v1/classes.rb', line 11697

def attach_time
  @attach_time
end

#environmentString

Output only. Name of the environment. Corresponds to the JSON property environment

Returns:

  • (String)


11702
11703
11704
# File 'lib/google/apis/apigee_v1/classes.rb', line 11702

def environment
  @environment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11709
11710
11711
11712
# File 'lib/google/apis/apigee_v1/classes.rb', line 11709

def update!(**args)
  @attach_time = args[:attach_time] if args.key?(:attach_time)
  @environment = args[:environment] if args.key?(:environment)
end