Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityProfileEnvironmentAssociation
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityProfileEnvironmentAssociation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Represents a SecurityProfileEnvironmentAssociation resource.
Instance Attribute Summary collapse
-
#attach_time ⇒ String
Output only.
-
#name ⇒ String
Immutable.
-
#security_profile_revision_id ⇒ Fixnum
DEPRECATED: DO NOT USE Revision ID of the security profile.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityProfileEnvironmentAssociation
constructor
A new instance of GoogleCloudApigeeV1SecurityProfileEnvironmentAssociation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityProfileEnvironmentAssociation
Returns a new instance of GoogleCloudApigeeV1SecurityProfileEnvironmentAssociation.
11734 11735 11736 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11734 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attach_time ⇒ String
Output only. The time when environment was attached to the security profile.
Corresponds to the JSON property attachTime
11722 11723 11724 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11722 def attach_time @attach_time end |
#name ⇒ String
Immutable. Name of the environment that the profile is attached to.
Corresponds to the JSON property name
11727 11728 11729 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11727 def name @name end |
#security_profile_revision_id ⇒ Fixnum
DEPRECATED: DO NOT USE Revision ID of the security profile.
Corresponds to the JSON property securityProfileRevisionId
11732 11733 11734 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11732 def security_profile_revision_id @security_profile_revision_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11739 11740 11741 11742 11743 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11739 def update!(**args) @attach_time = args[:attach_time] if args.key?(:attach_time) @name = args[:name] if args.key?(:name) @security_profile_revision_id = args[:security_profile_revision_id] if args.key?(:security_profile_revision_id) end |