Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityReport
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityReport
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
SecurityReport saves all the information about the created security report.
Instance Attribute Summary collapse
-
#created ⇒ String
Creation time of the query.
-
#display_name ⇒ String
Display Name specified by the user.
-
#envgroup_hostname ⇒ String
Hostname is available only when query is executed at host level.
-
#error ⇒ String
Error is set when query fails.
-
#execution_time ⇒ String
ExecutionTime is available only after the query is completed.
-
#query_params ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityReportMetadata
Metadata for the security report.
-
#report_definition_id ⇒ String
Report Definition ID.
-
#result ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityReportResultMetadata
Contains informations about the security report results.
-
#result_file_size ⇒ String
ResultFileSize is available only after the query is completed.
-
#result_rows ⇒ Fixnum
ResultRows is available only after the query is completed.
-
#self ⇒ String
Self link of the query.
-
#state ⇒ String
Query state could be "enqueued", "running", "completed", "expired" and "failed" .
-
#updated ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityReport
constructor
A new instance of GoogleCloudApigeeV1SecurityReport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityReport
Returns a new instance of GoogleCloudApigeeV1SecurityReport.
12113 12114 12115 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12113 def initialize(**args) update!(**args) end |
Instance Attribute Details
#created ⇒ String
Creation time of the query.
Corresponds to the JSON property created
12047 12048 12049 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12047 def created @created end |
#display_name ⇒ String
Display Name specified by the user.
Corresponds to the JSON property displayName
12052 12053 12054 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12052 def display_name @display_name end |
#envgroup_hostname ⇒ String
Hostname is available only when query is executed at host level.
Corresponds to the JSON property envgroupHostname
12057 12058 12059 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12057 def envgroup_hostname @envgroup_hostname end |
#error ⇒ String
Error is set when query fails.
Corresponds to the JSON property error
12062 12063 12064 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12062 def error @error end |
#execution_time ⇒ String
ExecutionTime is available only after the query is completed.
Corresponds to the JSON property executionTime
12067 12068 12069 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12067 def execution_time @execution_time end |
#query_params ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityReportMetadata
Metadata for the security report.
Corresponds to the JSON property queryParams
12072 12073 12074 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12072 def query_params @query_params end |
#report_definition_id ⇒ String
Report Definition ID.
Corresponds to the JSON property reportDefinitionId
12077 12078 12079 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12077 def report_definition_id @report_definition_id end |
#result ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityReportResultMetadata
Contains informations about the security report results.
Corresponds to the JSON property result
12082 12083 12084 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12082 def result @result end |
#result_file_size ⇒ String
ResultFileSize is available only after the query is completed.
Corresponds to the JSON property resultFileSize
12087 12088 12089 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12087 def result_file_size @result_file_size end |
#result_rows ⇒ Fixnum
ResultRows is available only after the query is completed.
Corresponds to the JSON property resultRows
12092 12093 12094 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12092 def result_rows @result_rows end |
#self ⇒ String
Self link of the query. Example: /organizations/myorg/environments/myenv/
securityReports/9cfc0d85-0f30-46d6-ae6f-318d0cb961bd or following format if
query is running at host level: /organizations/myorg/hostSecurityReports/
9cfc0d85-0f30-46d6-ae6f-318d0cb961bd
Corresponds to the JSON property self
12100 12101 12102 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12100 def self @self end |
#state ⇒ String
Query state could be "enqueued", "running", "completed", "expired" and "failed"
.
Corresponds to the JSON property state
12106 12107 12108 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12106 def state @state end |
#updated ⇒ String
Output only. Last updated timestamp for the query.
Corresponds to the JSON property updated
12111 12112 12113 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12111 def updated @updated end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12118 12119 12120 12121 12122 12123 12124 12125 12126 12127 12128 12129 12130 12131 12132 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12118 def update!(**args) @created = args[:created] if args.key?(:created) @display_name = args[:display_name] if args.key?(:display_name) @envgroup_hostname = args[:envgroup_hostname] if args.key?(:envgroup_hostname) @error = args[:error] if args.key?(:error) @execution_time = args[:execution_time] if args.key?(:execution_time) @query_params = args[:query_params] if args.key?(:query_params) @report_definition_id = args[:report_definition_id] if args.key?(:report_definition_id) @result = args[:result] if args.key?(:result) @result_file_size = args[:result_file_size] if args.key?(:result_file_size) @result_rows = args[:result_rows] if args.key?(:result_rows) @self = args[:self] if args.key?(:self) @state = args[:state] if args.key?(:state) @updated = args[:updated] if args.key?(:updated) end |