Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityReportQueryMetric

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Metric of the Query

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityReportQueryMetric

Returns a new instance of GoogleCloudApigeeV1SecurityReportQueryMetric.



12315
12316
12317
# File 'lib/google/apis/apigee_v1/classes.rb', line 12315

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregation_functionString

Aggregation function: avg, min, max, or sum. Corresponds to the JSON property aggregationFunction

Returns:

  • (String)


12292
12293
12294
# File 'lib/google/apis/apigee_v1/classes.rb', line 12292

def aggregation_function
  @aggregation_function
end

#aliasString

Alias for the metric. Alias will be used to replace metric name in query results. Corresponds to the JSON property alias

Returns:

  • (String)


12298
12299
12300
# File 'lib/google/apis/apigee_v1/classes.rb', line 12298

def alias
  @alias
end

#nameString

Required. Metric name. Corresponds to the JSON property name

Returns:

  • (String)


12303
12304
12305
# File 'lib/google/apis/apigee_v1/classes.rb', line 12303

def name
  @name
end

#operatorString

One of +, -, /, %, *. Corresponds to the JSON property operator

Returns:

  • (String)


12308
12309
12310
# File 'lib/google/apis/apigee_v1/classes.rb', line 12308

def operator
  @operator
end

#valueString

Operand value should be provided when operator is set. Corresponds to the JSON property value

Returns:

  • (String)


12313
12314
12315
# File 'lib/google/apis/apigee_v1/classes.rb', line 12313

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12320
12321
12322
12323
12324
12325
12326
# File 'lib/google/apis/apigee_v1/classes.rb', line 12320

def update!(**args)
  @aggregation_function = args[:aggregation_function] if args.key?(:aggregation_function)
  @alias = args[:alias] if args.key?(:alias)
  @name = args[:name] if args.key?(:name)
  @operator = args[:operator] if args.key?(:operator)
  @value = args[:value] if args.key?(:value)
end