Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SetAddonEnablementRequest
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1SetAddonEnablementRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Request for SetAddonEnablement.
Instance Attribute Summary collapse
-
#analytics_enabled ⇒ Boolean
(also: #analytics_enabled?)
If the Analytics should be enabled in the environment.
-
#api_security_enabled ⇒ Boolean
(also: #api_security_enabled?)
If the API Security should be enabled in the environment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1SetAddonEnablementRequest
constructor
A new instance of GoogleCloudApigeeV1SetAddonEnablementRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1SetAddonEnablementRequest
Returns a new instance of GoogleCloudApigeeV1SetAddonEnablementRequest.
12231 12232 12233 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12231 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analytics_enabled ⇒ Boolean Also known as: analytics_enabled?
If the Analytics should be enabled in the environment.
Corresponds to the JSON property analyticsEnabled
12222 12223 12224 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12222 def analytics_enabled @analytics_enabled end |
#api_security_enabled ⇒ Boolean Also known as: api_security_enabled?
If the API Security should be enabled in the environment.
Corresponds to the JSON property apiSecurityEnabled
12228 12229 12230 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12228 def api_security_enabled @api_security_enabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12236 12237 12238 12239 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12236 def update!(**args) @analytics_enabled = args[:analytics_enabled] if args.key?(:analytics_enabled) @api_security_enabled = args[:api_security_enabled] if args.key?(:api_security_enabled) end |