Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SharedFlowRevision

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

The metadata describing a shared flow revision.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SharedFlowRevision

Returns a new instance of GoogleCloudApigeeV1SharedFlowRevision.



12505
12506
12507
# File 'lib/google/apis/apigee_v1/classes.rb', line 12505

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configuration_versionGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1ConfigVersion

Version of the API proxy configuration schema. Currently, only 4.0 is supported. Corresponds to the JSON property configurationVersion



12435
12436
12437
# File 'lib/google/apis/apigee_v1/classes.rb', line 12435

def configuration_version
  @configuration_version
end

#context_infoString

A textual description of the shared flow revision. Corresponds to the JSON property contextInfo

Returns:

  • (String)


12440
12441
12442
# File 'lib/google/apis/apigee_v1/classes.rb', line 12440

def context_info
  @context_info
end

#created_atFixnum

Time at which this shared flow revision was created, in milliseconds since epoch. Corresponds to the JSON property createdAt

Returns:

  • (Fixnum)


12446
12447
12448
# File 'lib/google/apis/apigee_v1/classes.rb', line 12446

def created_at
  @created_at
end

#descriptionString

Description of the shared flow revision. Corresponds to the JSON property description

Returns:

  • (String)


12451
12452
12453
# File 'lib/google/apis/apigee_v1/classes.rb', line 12451

def description
  @description
end

#display_nameString

The human readable name of this shared flow. Corresponds to the JSON property displayName

Returns:

  • (String)


12456
12457
12458
# File 'lib/google/apis/apigee_v1/classes.rb', line 12456

def display_name
  @display_name
end

#entity_meta_data_as_propertiesHash<String,String>

A Key-Value map of metadata about this shared flow revision. Corresponds to the JSON property entityMetaDataAsProperties

Returns:

  • (Hash<String,String>)


12461
12462
12463
# File 'lib/google/apis/apigee_v1/classes.rb', line 12461

def 
  @entity_meta_data_as_properties
end

#last_modified_atFixnum

Time at which this shared flow revision was most recently modified, in milliseconds since epoch. Corresponds to the JSON property lastModifiedAt

Returns:

  • (Fixnum)


12467
12468
12469
# File 'lib/google/apis/apigee_v1/classes.rb', line 12467

def last_modified_at
  @last_modified_at
end

#nameString

The resource ID of the parent shared flow. Corresponds to the JSON property name

Returns:

  • (String)


12472
12473
12474
# File 'lib/google/apis/apigee_v1/classes.rb', line 12472

def name
  @name
end

#policiesArray<String>

A list of policy names included in this shared flow revision. Corresponds to the JSON property policies

Returns:

  • (Array<String>)


12477
12478
12479
# File 'lib/google/apis/apigee_v1/classes.rb', line 12477

def policies
  @policies
end

#resource_filesGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1ResourceFiles

List of resource files. Corresponds to the JSON property resourceFiles



12482
12483
12484
# File 'lib/google/apis/apigee_v1/classes.rb', line 12482

def resource_files
  @resource_files
end

#resourcesArray<String>

A list of the resources included in this shared flow revision formatted as " type://name". Corresponds to the JSON property resources

Returns:

  • (Array<String>)


12488
12489
12490
# File 'lib/google/apis/apigee_v1/classes.rb', line 12488

def resources
  @resources
end

#revisionString

The resource ID of this revision. Corresponds to the JSON property revision

Returns:

  • (String)


12493
12494
12495
# File 'lib/google/apis/apigee_v1/classes.rb', line 12493

def revision
  @revision
end

#shared_flowsArray<String>

A list of the shared flow names included in this shared flow revision. Corresponds to the JSON property sharedFlows

Returns:

  • (Array<String>)


12498
12499
12500
# File 'lib/google/apis/apigee_v1/classes.rb', line 12498

def shared_flows
  @shared_flows
end

#typeString

The string "Application" Corresponds to the JSON property type

Returns:

  • (String)


12503
12504
12505
# File 'lib/google/apis/apigee_v1/classes.rb', line 12503

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12510
12511
12512
12513
12514
12515
12516
12517
12518
12519
12520
12521
12522
12523
12524
12525
# File 'lib/google/apis/apigee_v1/classes.rb', line 12510

def update!(**args)
  @configuration_version = args[:configuration_version] if args.key?(:configuration_version)
  @context_info = args[:context_info] if args.key?(:context_info)
  @created_at = args[:created_at] if args.key?(:created_at)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entity_meta_data_as_properties = args[:entity_meta_data_as_properties] if args.key?(:entity_meta_data_as_properties)
  @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at)
  @name = args[:name] if args.key?(:name)
  @policies = args[:policies] if args.key?(:policies)
  @resource_files = args[:resource_files] if args.key?(:resource_files)
  @resources = args[:resources] if args.key?(:resources)
  @revision = args[:revision] if args.key?(:revision)
  @shared_flows = args[:shared_flows] if args.key?(:shared_flows)
  @type = args[:type] if args.key?(:type)
end