Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1TlsInfoCommonName
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1TlsInfoCommonName
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Instance Attribute Summary collapse
-
#value ⇒ String
The TLS Common Name string of the certificate.
-
#wildcard_match ⇒ Boolean
(also: #wildcard_match?)
Indicates whether the cert should be matched against as a wildcard cert.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1TlsInfoCommonName
constructor
A new instance of GoogleCloudApigeeV1TlsInfoCommonName.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1TlsInfoCommonName
Returns a new instance of GoogleCloudApigeeV1TlsInfoCommonName.
12809 12810 12811 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12809 def initialize(**args) update!(**args) end |
Instance Attribute Details
#value ⇒ String
The TLS Common Name string of the certificate.
Corresponds to the JSON property value
12801 12802 12803 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12801 def value @value end |
#wildcard_match ⇒ Boolean Also known as: wildcard_match?
Indicates whether the cert should be matched against as a wildcard cert.
Corresponds to the JSON property wildcardMatch
12806 12807 12808 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12806 def wildcard_match @wildcard_match end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12814 12815 12816 12817 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12814 def update!(**args) @value = args[:value] if args.key?(:value) @wildcard_match = args[:wildcard_match] if args.key?(:wildcard_match) end |