Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1TraceConfigOverride

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

A representation of a configuration override.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1TraceConfigOverride

Returns a new instance of GoogleCloudApigeeV1TraceConfigOverride.



13386
13387
13388
# File 'lib/google/apis/apigee_v1/classes.rb', line 13386

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_proxyString

ID of the API proxy that will have its trace configuration overridden. Corresponds to the JSON property apiProxy

Returns:

  • (String)


13372
13373
13374
# File 'lib/google/apis/apigee_v1/classes.rb', line 13372

def api_proxy
  @api_proxy
end

#nameString

ID of the trace configuration override specified as a system-generated UUID. Corresponds to the JSON property name

Returns:

  • (String)


13377
13378
13379
# File 'lib/google/apis/apigee_v1/classes.rb', line 13377

def name
  @name
end

#sampling_configGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1TraceSamplingConfig

TraceSamplingConfig represents the detail settings of distributed tracing. Only the fields that are defined in the distributed trace configuration can be overridden using the distribute trace configuration override APIs. Corresponds to the JSON property samplingConfig



13384
13385
13386
# File 'lib/google/apis/apigee_v1/classes.rb', line 13384

def sampling_config
  @sampling_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13391
13392
13393
13394
13395
# File 'lib/google/apis/apigee_v1/classes.rb', line 13391

def update!(**args)
  @api_proxy = args[:api_proxy] if args.key?(:api_proxy)
  @name = args[:name] if args.key?(:name)
  @sampling_config = args[:sampling_config] if args.key?(:sampling_config)
end