Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1UpdateError

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Details on why a resource update failed in the runtime.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1UpdateError

Returns a new instance of GoogleCloudApigeeV1UpdateError.



13255
13256
13257
# File 'lib/google/apis/apigee_v1/classes.rb', line 13255

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

Status code. Corresponds to the JSON property code

Returns:

  • (String)


13236
13237
13238
# File 'lib/google/apis/apigee_v1/classes.rb', line 13236

def code
  @code
end

#messageString

User-friendly error message. Corresponds to the JSON property message

Returns:

  • (String)


13241
13242
13243
# File 'lib/google/apis/apigee_v1/classes.rb', line 13241

def message
  @message
end

#resourceString

The sub resource specific to this error (e.g. a proxy deployed within the EnvironmentConfig). If empty the error refers to the top level resource. Corresponds to the JSON property resource

Returns:

  • (String)


13247
13248
13249
# File 'lib/google/apis/apigee_v1/classes.rb', line 13247

def resource
  @resource
end

#typeString

A string that uniquely identifies the type of error. This provides a more reliable means to deduplicate errors across revisions and instances. Corresponds to the JSON property type

Returns:

  • (String)


13253
13254
13255
# File 'lib/google/apis/apigee_v1/classes.rb', line 13253

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13260
13261
13262
13263
13264
13265
# File 'lib/google/apis/apigee_v1/classes.rb', line 13260

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @message = args[:message] if args.key?(:message)
  @resource = args[:resource] if args.key?(:resource)
  @type = args[:type] if args.key?(:type)
end