Class: Google::Apis::ApigeeV1::GoogleRpcPreconditionFailure
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleRpcPreconditionFailure
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Describes what preconditions have failed. For example, if an RPC failed because it required the Terms of Service to be acknowledged, it could list the terms of service violation in the PreconditionFailure message.
Instance Attribute Summary collapse
-
#violations ⇒ Array<Google::Apis::ApigeeV1::GoogleRpcPreconditionFailureViolation>
Describes all precondition violations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleRpcPreconditionFailure
constructor
A new instance of GoogleRpcPreconditionFailure.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleRpcPreconditionFailure
Returns a new instance of GoogleRpcPreconditionFailure.
14009 14010 14011 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 14009 def initialize(**args) update!(**args) end |
Instance Attribute Details
#violations ⇒ Array<Google::Apis::ApigeeV1::GoogleRpcPreconditionFailureViolation>
Describes all precondition violations.
Corresponds to the JSON property violations
14007 14008 14009 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 14007 def violations @violations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14014 14015 14016 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 14014 def update!(**args) @violations = args[:violations] if args.key?(:violations) end |