Class: Google::Apis::ApigeeV1::GoogleRpcPreconditionFailureViolation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

A message type used to describe a single precondition failure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleRpcPreconditionFailureViolation

Returns a new instance of GoogleRpcPreconditionFailureViolation.



13791
13792
13793
# File 'lib/google/apis/apigee_v1/classes.rb', line 13791

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

A description of how the precondition failed. Developers can use this description to understand how to fix the failure. For example: "Terms of service not accepted". Corresponds to the JSON property description

Returns:

  • (String)


13775
13776
13777
# File 'lib/google/apis/apigee_v1/classes.rb', line 13775

def description
  @description
end

#subjectString

The subject, relative to the type, that failed. For example, "google.com/cloud" relative to the "TOS" type would indicate which terms of service is being referenced. Corresponds to the JSON property subject

Returns:

  • (String)


13782
13783
13784
# File 'lib/google/apis/apigee_v1/classes.rb', line 13782

def subject
  @subject
end

#typeString

The type of PreconditionFailure. We recommend using a service-specific enum type to define the supported precondition violation subjects. For example, " TOS" for "Terms of Service violation". Corresponds to the JSON property type

Returns:

  • (String)


13789
13790
13791
# File 'lib/google/apis/apigee_v1/classes.rb', line 13789

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13796
13797
13798
13799
13800
# File 'lib/google/apis/apigee_v1/classes.rb', line 13796

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @subject = args[:subject] if args.key?(:subject)
  @type = args[:type] if args.key?(:type)
end