Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1AccessLoggingConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1AccessLoggingConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Access logging configuration enables customers to ship the access logs from the tenant projects to their own project's cloud logging. The feature is at the instance level ad disabled by default. It can be enabled during CreateInstance or UpdateInstance.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
Optional.
-
#filter ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1AccessLoggingConfig
constructor
A new instance of GoogleCloudApigeeV1AccessLoggingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1AccessLoggingConfig
Returns a new instance of GoogleCloudApigeeV1AccessLoggingConfig.
277 278 279 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 277 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
Optional. Boolean flag that specifies whether the customer access log feature
is enabled.
Corresponds to the JSON property enabled
265 266 267 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 265 def enabled @enabled end |
#filter ⇒ String
Optional. Ship the access log entries that match the status_code defined in
the filter. The status_code is the only expected/supported filter field. (Ex:
status_code) The filter will parse it to the Common Expression Language
semantics for expression evaluation to build the filter condition. (Ex: "
filter": status_code >= 200 && status_code < 300 )
Corresponds to the JSON property filter
275 276 277 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 275 def filter @filter end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
282 283 284 285 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 282 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) @filter = args[:filter] if args.key?(:filter) end |