Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiCategory

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

ApiCategory represents an API category. Catalog items can be tagged with API categories; users viewing the API catalog in the portal will have the option to browse the catalog by category.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1ApiCategory

Returns a new instance of GoogleCloudApigeeV1ApiCategory.



550
551
552
# File 'lib/google/apis/apigee_v1/classes.rb', line 550

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

ID of the category (a UUID). Corresponds to the JSON property id

Returns:

  • (String)


533
534
535
# File 'lib/google/apis/apigee_v1/classes.rb', line 533

def id
  @id
end

#nameString

Name of the category. Corresponds to the JSON property name

Returns:

  • (String)


538
539
540
# File 'lib/google/apis/apigee_v1/classes.rb', line 538

def name
  @name
end

#site_idString

Name of the portal. Corresponds to the JSON property siteId

Returns:

  • (String)


543
544
545
# File 'lib/google/apis/apigee_v1/classes.rb', line 543

def site_id
  @site_id
end

#update_timeFixnum

Time the category was last modified in milliseconds since epoch. Corresponds to the JSON property updateTime

Returns:

  • (Fixnum)


548
549
550
# File 'lib/google/apis/apigee_v1/classes.rb', line 548

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



555
556
557
558
559
560
# File 'lib/google/apis/apigee_v1/classes.rb', line 555

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @site_id = args[:site_id] if args.key?(:site_id)
  @update_time = args[:update_time] if args.key?(:update_time)
end