Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiDebugSession

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Session carries the debug session id and its creation time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1ApiDebugSession

Returns a new instance of GoogleCloudApigeeV1ApiDebugSession.



633
634
635
# File 'lib/google/apis/apigee_v1/classes.rb', line 633

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_proxy_revision_idString

The revision ID of the deployed API proxy. Corresponds to the JSON property apiProxyRevisionId

Returns:

  • (String)


616
617
618
# File 'lib/google/apis/apigee_v1/classes.rb', line 616

def api_proxy_revision_id
  @api_proxy_revision_id
end

#create_timeString

The first transaction creation timestamp in millisecond, recorded by UAP. Corresponds to the JSON property createTime

Returns:

  • (String)


621
622
623
# File 'lib/google/apis/apigee_v1/classes.rb', line 621

def create_time
  @create_time
end

#environment_idString

The environment ID of the deployed API proxy. Corresponds to the JSON property environmentId

Returns:

  • (String)


626
627
628
# File 'lib/google/apis/apigee_v1/classes.rb', line 626

def environment_id
  @environment_id
end

#idString

The debug session ID. Corresponds to the JSON property id

Returns:

  • (String)


631
632
633
# File 'lib/google/apis/apigee_v1/classes.rb', line 631

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



638
639
640
641
642
643
# File 'lib/google/apis/apigee_v1/classes.rb', line 638

def update!(**args)
  @api_proxy_revision_id = args[:api_proxy_revision_id] if args.key?(:api_proxy_revision_id)
  @create_time = args[:create_time] if args.key?(:create_time)
  @environment_id = args[:environment_id] if args.key?(:environment_id)
  @id = args[:id] if args.key?(:id)
end