Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiDoc
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiDoc
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
ApiDoc represents an API catalog item. Catalog items are used in two ways in
a portal: - Users can browse and interact with a visual representation of the
API documentation - The api_product_name field provides a link to a backing
API product. Through this link, portal users can create and manage developer
apps linked to one or more API products.
Instance Attribute Summary collapse
-
#anon_allowed ⇒ Boolean
(also: #anon_allowed?)
Optional.
-
#api_product_name ⇒ String
Required.
-
#category_ids ⇒ Array<String>
Optional.
-
#description ⇒ String
Optional.
-
#edge_api_product_name ⇒ String
Optional.
-
#graphql_endpoint_url ⇒ String
Optional.
-
#graphql_schema ⇒ String
Optional.
-
#graphql_schema_display_name ⇒ String
Optional.
-
#id ⇒ Fixnum
Output only.
-
#image_url ⇒ String
Optional.
-
#modified ⇒ Fixnum
Output only.
-
#published ⇒ Boolean
(also: #published?)
Optional.
-
#require_callback_url ⇒ Boolean
(also: #require_callback_url?)
Optional.
-
#site_id ⇒ String
Output only.
-
#spec_id ⇒ String
Optional.
-
#title ⇒ String
Required.
-
#visibility ⇒ Boolean
(also: #visibility?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1ApiDoc
constructor
A new instance of GoogleCloudApigeeV1ApiDoc.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1ApiDoc
Returns a new instance of GoogleCloudApigeeV1ApiDoc.
831 832 833 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 831 def initialize(**args) update!(**args) end |
Instance Attribute Details
#anon_allowed ⇒ Boolean Also known as: anon_allowed?
Optional. Boolean flag that manages user access to the catalog item. When true,
the catalog item has public visibility and can be viewed anonymously;
otherwise, only registered users may view it. Note: when the parent portal is
enrolled in the audience management feature, and this
flag is set to false, visibility is set to an indeterminate state and must be
explicitly specified in the management UI (see Manage the visibility of an
API in your portal). Additionally, when enrolled in the audience
management feature, updates to this flag will be ignored as visibility
permissions must be updated in the management UI.
Corresponds to the JSON property anonAllowed
718 719 720 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 718 def anon_allowed @anon_allowed end |
#api_product_name ⇒ String
Required. Immutable. The name field of the associated API product. A portal may
have only one catalog item associated with a given API product.
Corresponds to the JSON property apiProductName
726 727 728 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 726 def api_product_name @api_product_name end |
#category_ids ⇒ Array<String>
Optional. The IDs of the API categories to which this catalog item belongs.
Corresponds to the JSON property categoryIds
731 732 733 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 731 def category_ids @category_ids end |
#description ⇒ String
Optional. Description of the catalog item. Max length is 10,000 characters.
Corresponds to the JSON property description
736 737 738 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 736 def description @description end |
#edge_api_product_name ⇒ String
Optional. Immutable. DEPRECATED: use the apiProductName field instead
Corresponds to the JSON property edgeAPIProductName
741 742 743 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 741 def edge_api_product_name @edge_api_product_name end |
#graphql_endpoint_url ⇒ String
Optional. DEPRECATED: manage documentation through the getDocumentation and
updateDocumentation methods
Corresponds to the JSON property graphqlEndpointUrl
747 748 749 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 747 def graphql_endpoint_url @graphql_endpoint_url end |
#graphql_schema ⇒ String
Optional. DEPRECATED: manage documentation through the getDocumentation and
updateDocumentation methods
Corresponds to the JSON property graphqlSchema
753 754 755 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 753 def graphql_schema @graphql_schema end |
#graphql_schema_display_name ⇒ String
Optional. DEPRECATED: manage documentation through the getDocumentation and
updateDocumentation methods
Corresponds to the JSON property graphqlSchemaDisplayName
759 760 761 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 759 def graphql_schema_display_name @graphql_schema_display_name end |
#id ⇒ Fixnum
Output only. The ID of the catalog item.
Corresponds to the JSON property id
764 765 766 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 764 def id @id end |
#image_url ⇒ String
Optional. Location of the image used for the catalog item in the catalog. This
can be either an image with an external URL or a file path for image files
stored in the portal,
for example, /files/book-tree.jpg. When specifying the URL of an external
image, the image won't be uploaded to your assets; additionally, loading the
image in the integrated portal will be subject to its availability, which may
be blocked or restricted by content security policies. Max length of file path is 2,083 characters.
Corresponds to the JSON property imageUrl
776 777 778 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 776 def image_url @image_url end |
#modified ⇒ Fixnum
Output only. Time the catalog item was last modified in milliseconds since
epoch.
Corresponds to the JSON property modified
782 783 784 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 782 def modified @modified end |
#published ⇒ Boolean Also known as: published?
Optional. Denotes whether the catalog item is published to the portal or is in
a draft state. When the parent portal is enrolled in the audience management
feature, the
visibility can be set to public on creation by setting the anonAllowed flag to
true or further managed in the management UI (see Manage the visibility of an
API in your portal) before it can be visible to any users. If not
enrolled in the audience management feature, the visibility is managed by the
anonAllowed flag.
Corresponds to the JSON property published
797 798 799 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 797 def published @published end |
#require_callback_url ⇒ Boolean Also known as: require_callback_url?
Optional. Whether a callback URL is required when this catalog item's API
product is enabled in a developer app. When true, a portal user will be
required to input a URL when managing the app (this is typically used for the
app's OAuth flow).
Corresponds to the JSON property requireCallbackUrl
806 807 808 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 806 def require_callback_url @require_callback_url end |
#site_id ⇒ String
Output only. The ID of the parent portal.
Corresponds to the JSON property siteId
812 813 814 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 812 def site_id @site_id end |
#spec_id ⇒ String
Optional. DEPRECATED: DO NOT USE
Corresponds to the JSON property specId
817 818 819 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 817 def spec_id @spec_id end |
#title ⇒ String
Required. The user-facing name of the catalog item. title must be a non-
empty string with a max length of 255 characters.
Corresponds to the JSON property title
823 824 825 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 823 def title @title end |
#visibility ⇒ Boolean Also known as: visibility?
Optional. DEPRECATED: use the published field instead
Corresponds to the JSON property visibility
828 829 830 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 828 def visibility @visibility end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 836 def update!(**args) @anon_allowed = args[:anon_allowed] if args.key?(:anon_allowed) @api_product_name = args[:api_product_name] if args.key?(:api_product_name) @category_ids = args[:category_ids] if args.key?(:category_ids) @description = args[:description] if args.key?(:description) @edge_api_product_name = args[:edge_api_product_name] if args.key?(:edge_api_product_name) @graphql_endpoint_url = args[:graphql_endpoint_url] if args.key?(:graphql_endpoint_url) @graphql_schema = args[:graphql_schema] if args.key?(:graphql_schema) @graphql_schema_display_name = args[:graphql_schema_display_name] if args.key?(:graphql_schema_display_name) @id = args[:id] if args.key?(:id) @image_url = args[:image_url] if args.key?(:image_url) @modified = args[:modified] if args.key?(:modified) @published = args[:published] if args.key?(:published) @require_callback_url = args[:require_callback_url] if args.key?(:require_callback_url) @site_id = args[:site_id] if args.key?(:site_id) @spec_id = args[:spec_id] if args.key?(:spec_id) @title = args[:title] if args.key?(:title) @visibility = args[:visibility] if args.key?(:visibility) end |