Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiDoc

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

ApiDoc represents an API catalog item. Catalog items are used in two ways in a portal: - Users can browse and interact with a visual representation of the API documentation - The api_product_name field provides a link to a backing API product. Through this link, portal users can create and manage developer apps linked to one or more API products.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1ApiDoc

Returns a new instance of GoogleCloudApigeeV1ApiDoc.



782
783
784
# File 'lib/google/apis/apigee_v1/classes.rb', line 782

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#anon_allowedBoolean Also known as: anon_allowed?

Optional. Boolean flag that manages user access to the catalog item. When true, the catalog item has public visibility and can be viewed anonymously; otherwise, only registered users may view it. Note: when the parent portal is enrolled in the audience management feature, and this flag is set to false, visibility is set to an indeterminate state and must be explicitly specified in the management UI (see Manage the visibility of an API in your portal). Additionally, when enrolled in the audience management feature, updates to this flag will be ignored as visibility permissions must be updated in the management UI. Corresponds to the JSON property anonAllowed

Returns:

  • (Boolean)


669
670
671
# File 'lib/google/apis/apigee_v1/classes.rb', line 669

def anon_allowed
  @anon_allowed
end

#api_product_nameString

Required. Immutable. The name field of the associated API product. A portal may have only one catalog item associated with a given API product. Corresponds to the JSON property apiProductName

Returns:

  • (String)


677
678
679
# File 'lib/google/apis/apigee_v1/classes.rb', line 677

def api_product_name
  @api_product_name
end

#category_idsArray<String>

Optional. The IDs of the API categories to which this catalog item belongs. Corresponds to the JSON property categoryIds

Returns:

  • (Array<String>)


682
683
684
# File 'lib/google/apis/apigee_v1/classes.rb', line 682

def category_ids
  @category_ids
end

#descriptionString

Optional. Description of the catalog item. Max length is 10,000 characters. Corresponds to the JSON property description

Returns:

  • (String)


687
688
689
# File 'lib/google/apis/apigee_v1/classes.rb', line 687

def description
  @description
end

#edge_api_product_nameString

Optional. Immutable. DEPRECATED: use the apiProductName field instead Corresponds to the JSON property edgeAPIProductName

Returns:

  • (String)


692
693
694
# File 'lib/google/apis/apigee_v1/classes.rb', line 692

def edge_api_product_name
  @edge_api_product_name
end

#graphql_endpoint_urlString

Optional. DEPRECATED: manage documentation through the getDocumentation and updateDocumentation methods Corresponds to the JSON property graphqlEndpointUrl

Returns:

  • (String)


698
699
700
# File 'lib/google/apis/apigee_v1/classes.rb', line 698

def graphql_endpoint_url
  @graphql_endpoint_url
end

#graphql_schemaString

Optional. DEPRECATED: manage documentation through the getDocumentation and updateDocumentation methods Corresponds to the JSON property graphqlSchema

Returns:

  • (String)


704
705
706
# File 'lib/google/apis/apigee_v1/classes.rb', line 704

def graphql_schema
  @graphql_schema
end

#graphql_schema_display_nameString

Optional. DEPRECATED: manage documentation through the getDocumentation and updateDocumentation methods Corresponds to the JSON property graphqlSchemaDisplayName

Returns:

  • (String)


710
711
712
# File 'lib/google/apis/apigee_v1/classes.rb', line 710

def graphql_schema_display_name
  @graphql_schema_display_name
end

#idFixnum

Output only. The ID of the catalog item. Corresponds to the JSON property id

Returns:

  • (Fixnum)


715
716
717
# File 'lib/google/apis/apigee_v1/classes.rb', line 715

def id
  @id
end

#image_urlString

Optional. Location of the image used for the catalog item in the catalog. This can be either an image with an external URL or a file path for image files stored in the portal, for example, /files/book-tree.jpg. When specifying the URL of an external image, the image won't be uploaded to your assets; additionally, loading the image in the integrated portal will be subject to its availability, which may be blocked or restricted by content security policies. Max length of file path is 2,083 characters. Corresponds to the JSON property imageUrl

Returns:

  • (String)


727
728
729
# File 'lib/google/apis/apigee_v1/classes.rb', line 727

def image_url
  @image_url
end

#modifiedFixnum

Output only. Time the catalog item was last modified in milliseconds since epoch. Corresponds to the JSON property modified

Returns:

  • (Fixnum)


733
734
735
# File 'lib/google/apis/apigee_v1/classes.rb', line 733

def modified
  @modified
end

#publishedBoolean Also known as: published?

Optional. Denotes whether the catalog item is published to the portal or is in a draft state. When the parent portal is enrolled in the audience management feature, the visibility can be set to public on creation by setting the anonAllowed flag to true or further managed in the management UI (see Manage the visibility of an API in your portal) before it can be visible to any users. If not enrolled in the audience management feature, the visibility is managed by the anonAllowed flag. Corresponds to the JSON property published

Returns:

  • (Boolean)


748
749
750
# File 'lib/google/apis/apigee_v1/classes.rb', line 748

def published
  @published
end

#require_callback_urlBoolean Also known as: require_callback_url?

Optional. Whether a callback URL is required when this catalog item's API product is enabled in a developer app. When true, a portal user will be required to input a URL when managing the app (this is typically used for the app's OAuth flow). Corresponds to the JSON property requireCallbackUrl

Returns:

  • (Boolean)


757
758
759
# File 'lib/google/apis/apigee_v1/classes.rb', line 757

def require_callback_url
  @require_callback_url
end

#site_idString

Output only. The ID of the parent portal. Corresponds to the JSON property siteId

Returns:

  • (String)


763
764
765
# File 'lib/google/apis/apigee_v1/classes.rb', line 763

def site_id
  @site_id
end

#spec_idString

Optional. DEPRECATED: DO NOT USE Corresponds to the JSON property specId

Returns:

  • (String)


768
769
770
# File 'lib/google/apis/apigee_v1/classes.rb', line 768

def spec_id
  @spec_id
end

#titleString

Required. The user-facing name of the catalog item. title must be a non- empty string with a max length of 255 characters. Corresponds to the JSON property title

Returns:

  • (String)


774
775
776
# File 'lib/google/apis/apigee_v1/classes.rb', line 774

def title
  @title
end

#visibilityBoolean Also known as: visibility?

Optional. DEPRECATED: use the published field instead Corresponds to the JSON property visibility

Returns:

  • (Boolean)


779
780
781
# File 'lib/google/apis/apigee_v1/classes.rb', line 779

def visibility
  @visibility
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
# File 'lib/google/apis/apigee_v1/classes.rb', line 787

def update!(**args)
  @anon_allowed = args[:anon_allowed] if args.key?(:anon_allowed)
  @api_product_name = args[:api_product_name] if args.key?(:api_product_name)
  @category_ids = args[:category_ids] if args.key?(:category_ids)
  @description = args[:description] if args.key?(:description)
  @edge_api_product_name = args[:edge_api_product_name] if args.key?(:edge_api_product_name)
  @graphql_endpoint_url = args[:graphql_endpoint_url] if args.key?(:graphql_endpoint_url)
  @graphql_schema = args[:graphql_schema] if args.key?(:graphql_schema)
  @graphql_schema_display_name = args[:graphql_schema_display_name] if args.key?(:graphql_schema_display_name)
  @id = args[:id] if args.key?(:id)
  @image_url = args[:image_url] if args.key?(:image_url)
  @modified = args[:modified] if args.key?(:modified)
  @published = args[:published] if args.key?(:published)
  @require_callback_url = args[:require_callback_url] if args.key?(:require_callback_url)
  @site_id = args[:site_id] if args.key?(:site_id)
  @spec_id = args[:spec_id] if args.key?(:spec_id)
  @title = args[:title] if args.key?(:title)
  @visibility = args[:visibility] if args.key?(:visibility)
end