Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiDocResponse
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiDocResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
The catalog item resource wrapped with response status, error_code, etc.
Instance Attribute Summary collapse
-
#data ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiDoc
ApiDocrepresents an API catalog item. -
#error_code ⇒ String
Unique error code for the request, if any.
-
#message ⇒ String
Description of the operation.
-
#request_id ⇒ String
Unique ID of the request.
-
#status ⇒ String
Status of the operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1ApiDocResponse
constructor
A new instance of GoogleCloudApigeeV1ApiDocResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1ApiDocResponse
Returns a new instance of GoogleCloudApigeeV1ApiDocResponse.
916 917 918 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 916 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiDoc
ApiDoc represents an API catalog item. Catalog items are used in two ways in
a portal: - Users can browse and interact with a visual representation of the
API documentation - The api_product_name field provides a link to a backing
API product. Through this link, portal users can create and manage developer
apps linked to one or more API products.
Corresponds to the JSON property data
894 895 896 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 894 def data @data end |
#error_code ⇒ String
Unique error code for the request, if any.
Corresponds to the JSON property errorCode
899 900 901 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 899 def error_code @error_code end |
#message ⇒ String
Description of the operation.
Corresponds to the JSON property message
904 905 906 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 904 def @message end |
#request_id ⇒ String
Unique ID of the request.
Corresponds to the JSON property requestId
909 910 911 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 909 def request_id @request_id end |
#status ⇒ String
Status of the operation.
Corresponds to the JSON property status
914 915 916 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 914 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
921 922 923 924 925 926 927 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 921 def update!(**args) @data = args[:data] if args.key?(:data) @error_code = args[:error_code] if args.key?(:error_code) @message = args[:message] if args.key?(:message) @request_id = args[:request_id] if args.key?(:request_id) @status = args[:status] if args.key?(:status) end |