Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiProduct

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1ApiProduct

Returns a new instance of GoogleCloudApigeeV1ApiProduct.



1117
1118
1119
# File 'lib/google/apis/apigee_v1/classes.rb', line 1117

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_resourcesArray<String>

Comma-separated list of API resources to be bundled in the API product. By default, the resource paths are mapped from the proxy.pathsuffix variable. The proxy path suffix is defined as the URI fragment following the ProxyEndpoint base path. For example, if the apiResources element is defined to be /forecastrss and the base path defined for the API proxy is /weather, then only requests to /weather/forecastrss are permitted by the API product. You can select a specific path, or you can select all subpaths with the following wildcard: - /**: Indicates that all sub-URIs are included. - /* : Indicates that only URIs one level down are included. By default, / supports the same resources as /** as well as the base path defined by the API proxy. For example, if the base path of the API proxy is /v1/weatherapikey, then the API product supports requests to /v1/weatherapikey and to any sub-URIs, such as /v1/weatherapikey/forecastrss, /v1/weatherapikey/region/CA, and so on. For more information, see Managing API products. Corresponds to the JSON property apiResources

Returns:

  • (Array<String>)


950
951
952
# File 'lib/google/apis/apigee_v1/classes.rb', line 950

def api_resources
  @api_resources
end

#approval_typeString

Flag that specifies how API keys are approved to access the APIs defined by the API product. If set to manual, the consumer key is generated and returned in "pending" state. In this case, the API keys won't work until they have been explicitly approved. If set to auto, the consumer key is generated and returned in "approved" state and can be used immediately. Note: Typically, auto is used to provide access to free or trial API products that provide limited quota or capabilities. Corresponds to the JSON property approvalType

Returns:

  • (String)


961
962
963
# File 'lib/google/apis/apigee_v1/classes.rb', line 961

def approval_type
  @approval_type
end

#attributesArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>

Array of attributes that may be used to extend the default API product profile with customer-specific metadata. You can specify a maximum of 18 attributes. Use this property to specify the access level of the API product as either public, private, or internal. Only products marked public are available to developers in the Apigee developer portal. For example, you can set a product to internal while it is in development and then change access to public when it is ready to release on the portal. API products marked as private do not appear on the portal, but can be accessed by external developers. Corresponds to the JSON property attributes



974
975
976
# File 'lib/google/apis/apigee_v1/classes.rb', line 974

def attributes
  @attributes
end

#created_atFixnum

Response only. Creation time of this environment as milliseconds since epoch. Corresponds to the JSON property createdAt

Returns:

  • (Fixnum)


979
980
981
# File 'lib/google/apis/apigee_v1/classes.rb', line 979

def created_at
  @created_at
end

#descriptionString

Description of the API product. Include key information about the API product that is not captured by other fields. Corresponds to the JSON property description

Returns:

  • (String)


985
986
987
# File 'lib/google/apis/apigee_v1/classes.rb', line 985

def description
  @description
end

#display_nameString

Name displayed in the UI or developer portal to developers registering for API access. Corresponds to the JSON property displayName

Returns:

  • (String)


991
992
993
# File 'lib/google/apis/apigee_v1/classes.rb', line 991

def display_name
  @display_name
end

#environmentsArray<String>

Comma-separated list of environment names to which the API product is bound. Requests to environments that are not listed are rejected. By specifying one or more environments, you can bind the resources listed in the API product to a specific environment, preventing developers from accessing those resources through API proxies deployed in another environment. This setting is used, for example, to prevent resources associated with API proxies in prod from being accessed by API proxies deployed in test. Corresponds to the JSON property environments

Returns:

  • (Array<String>)


1002
1003
1004
# File 'lib/google/apis/apigee_v1/classes.rb', line 1002

def environments
  @environments
end

#graphql_operation_groupGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1GraphQlOperationGroup

List of graphQL operation configuration details associated with Apigee API proxies or remote services. Remote services are non-Apigee proxies, such as Istio-Envoy. Corresponds to the JSON property graphqlOperationGroup



1009
1010
1011
# File 'lib/google/apis/apigee_v1/classes.rb', line 1009

def graphql_operation_group
  @graphql_operation_group
end

#grpc_operation_groupGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1GrpcOperationGroup

List of gRPC operation configuration details associated with Apigee API proxies. Corresponds to the JSON property grpcOperationGroup



1015
1016
1017
# File 'lib/google/apis/apigee_v1/classes.rb', line 1015

def grpc_operation_group
  @grpc_operation_group
end

#last_modified_atFixnum

Response only. Modified time of this environment as milliseconds since epoch. Corresponds to the JSON property lastModifiedAt

Returns:

  • (Fixnum)


1020
1021
1022
# File 'lib/google/apis/apigee_v1/classes.rb', line 1020

def last_modified_at
  @last_modified_at
end

#llm_operation_groupGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1LlmOperationGroup

List of LLM operation configuration details associated with Apigee API proxies. Corresponds to the JSON property llmOperationGroup



1025
1026
1027
# File 'lib/google/apis/apigee_v1/classes.rb', line 1025

def llm_operation_group
  @llm_operation_group
end

#llm_quotaString

Optional. Number of LLM tokens permitted per app by this API product for the specified llm_quota_interval and llm_quota_time_unit. For example, an llm_quota of 50,000, for an llm_quota_interval of 12 and an llm_quota_time_unit of hours means 50,000 llm tokens are allowed to be used every 12 hours. Corresponds to the JSON property llmQuota

Returns:

  • (String)


1034
1035
1036
# File 'lib/google/apis/apigee_v1/classes.rb', line 1034

def llm_quota
  @llm_quota
end

#llm_quota_intervalString

Optional. Time interval over which the number of tokens from LLM responses is calculated. Corresponds to the JSON property llmQuotaInterval

Returns:

  • (String)


1040
1041
1042
# File 'lib/google/apis/apigee_v1/classes.rb', line 1040

def llm_quota_interval
  @llm_quota_interval
end

#llm_quota_time_unitString

Optional. Time unit defined for the llm_quota_interval. Valid values include minute, hour, day, or month. Corresponds to the JSON property llmQuotaTimeUnit

Returns:

  • (String)


1046
1047
1048
# File 'lib/google/apis/apigee_v1/classes.rb', line 1046

def llm_quota_time_unit
  @llm_quota_time_unit
end

#nameString

Internal name of the API product. Characters you can use in the name are restricted to: A-Z0-9._\-$ %. Note: The internal name cannot be edited when updating the API product. Corresponds to the JSON property name

Returns:

  • (String)


1053
1054
1055
# File 'lib/google/apis/apigee_v1/classes.rb', line 1053

def name
  @name
end

#operation_groupGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1OperationGroup

List of operation configuration details associated with Apigee API proxies or remote services. Remote services are non-Apigee proxies, such as Istio-Envoy. Corresponds to the JSON property operationGroup



1059
1060
1061
# File 'lib/google/apis/apigee_v1/classes.rb', line 1059

def operation_group
  @operation_group
end

#proxiesArray<String>

Comma-separated list of API proxy names to which this API product is bound. By specifying API proxies, you can associate resources in the API product with specific API proxies, preventing developers from accessing those resources through other API proxies. Apigee rejects requests to API proxies that are not listed. Note: The API proxy names must already exist in the specified environment as they will be validated upon creation. Corresponds to the JSON property proxies

Returns:

  • (Array<String>)


1069
1070
1071
# File 'lib/google/apis/apigee_v1/classes.rb', line 1069

def proxies
  @proxies
end

#quotaString

Number of request messages permitted per app by this API product for the specified quotaInterval and quotaTimeUnit. For example, a quota of 50, for a quotaInterval of 12 and a quotaTimeUnit of hours means 50 requests are allowed every 12 hours. Corresponds to the JSON property quota

Returns:

  • (String)


1077
1078
1079
# File 'lib/google/apis/apigee_v1/classes.rb', line 1077

def quota
  @quota
end

#quota_counter_scopeString

Scope of the quota decides how the quota counter gets applied and evaluate for quota violation. If the Scope is set as PROXY, then all the operations defined for the APIproduct that are associated with the same proxy will share the same quota counter set at the APIproduct level, making it a global counter at a proxy level. If the Scope is set as OPERATION, then each operations get the counter set at the API product dedicated, making it a local counter. Note that, the QuotaCounterScope applies only when an operation does not have dedicated quota set for itself. Corresponds to the JSON property quotaCounterScope

Returns:

  • (String)


1089
1090
1091
# File 'lib/google/apis/apigee_v1/classes.rb', line 1089

def quota_counter_scope
  @quota_counter_scope
end

#quota_intervalString

Time interval over which the number of request messages is calculated. Corresponds to the JSON property quotaInterval

Returns:

  • (String)


1094
1095
1096
# File 'lib/google/apis/apigee_v1/classes.rb', line 1094

def quota_interval
  @quota_interval
end

#quota_time_unitString

Time unit defined for the quotaInterval. Valid values include minute, hour, day, or month. Corresponds to the JSON property quotaTimeUnit

Returns:

  • (String)


1100
1101
1102
# File 'lib/google/apis/apigee_v1/classes.rb', line 1100

def quota_time_unit
  @quota_time_unit
end

#scopesArray<String>

Comma-separated list of OAuth scopes that are validated at runtime. Apigee validates that the scopes in any access token presented match the scopes defined in the OAuth policy associated with the API product. Corresponds to the JSON property scopes

Returns:

  • (Array<String>)


1107
1108
1109
# File 'lib/google/apis/apigee_v1/classes.rb', line 1107

def scopes
  @scopes
end

#spaceString

Optional. The resource ID of the parent Space. If not set, the parent resource will be the Organization. To learn how Spaces can be used to manage resources, read the Apigee Spaces Overview. Corresponds to the JSON property space

Returns:

  • (String)


1115
1116
1117
# File 'lib/google/apis/apigee_v1/classes.rb', line 1115

def space
  @space
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1122
1123
1124
1125
1126
1127
1128
1129
1130
1131
1132
1133
1134
1135
1136
1137
1138
1139
1140
1141
1142
1143
1144
1145
1146
# File 'lib/google/apis/apigee_v1/classes.rb', line 1122

def update!(**args)
  @api_resources = args[:api_resources] if args.key?(:api_resources)
  @approval_type = args[:approval_type] if args.key?(:approval_type)
  @attributes = args[:attributes] if args.key?(:attributes)
  @created_at = args[:created_at] if args.key?(:created_at)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @environments = args[:environments] if args.key?(:environments)
  @graphql_operation_group = args[:graphql_operation_group] if args.key?(:graphql_operation_group)
  @grpc_operation_group = args[:grpc_operation_group] if args.key?(:grpc_operation_group)
  @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at)
  @llm_operation_group = args[:llm_operation_group] if args.key?(:llm_operation_group)
  @llm_quota = args[:llm_quota] if args.key?(:llm_quota)
  @llm_quota_interval = args[:llm_quota_interval] if args.key?(:llm_quota_interval)
  @llm_quota_time_unit = args[:llm_quota_time_unit] if args.key?(:llm_quota_time_unit)
  @name = args[:name] if args.key?(:name)
  @operation_group = args[:operation_group] if args.key?(:operation_group)
  @proxies = args[:proxies] if args.key?(:proxies)
  @quota = args[:quota] if args.key?(:quota)
  @quota_counter_scope = args[:quota_counter_scope] if args.key?(:quota_counter_scope)
  @quota_interval = args[:quota_interval] if args.key?(:quota_interval)
  @quota_time_unit = args[:quota_time_unit] if args.key?(:quota_time_unit)
  @scopes = args[:scopes] if args.key?(:scopes)
  @space = args[:space] if args.key?(:space)
end