Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiProxy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Metadata describing the API proxy

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1ApiProxy

Returns a new instance of GoogleCloudApigeeV1ApiProxy.



1225
1226
1227
# File 'lib/google/apis/apigee_v1/classes.rb', line 1225

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_proxy_typeString

Output only. The type of the API proxy. Corresponds to the JSON property apiProxyType

Returns:

  • (String)


1181
1182
1183
# File 'lib/google/apis/apigee_v1/classes.rb', line 1181

def api_proxy_type
  @api_proxy_type
end

#labelsHash<String,String>

User labels applied to this API Proxy. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1186
1187
1188
# File 'lib/google/apis/apigee_v1/classes.rb', line 1186

def labels
  @labels
end

#latest_revision_idString

Output only. The id of the most recently created revision for this api proxy. Corresponds to the JSON property latestRevisionId

Returns:

  • (String)


1191
1192
1193
# File 'lib/google/apis/apigee_v1/classes.rb', line 1191

def latest_revision_id
  @latest_revision_id
end

#meta_dataGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1EntityMetadata

Metadata common to many entities in this API. Corresponds to the JSON property metaData



1196
1197
1198
# File 'lib/google/apis/apigee_v1/classes.rb', line 1196

def 
  @meta_data
end

#nameString

Output only. Name of the API proxy. Corresponds to the JSON property name

Returns:

  • (String)


1201
1202
1203
# File 'lib/google/apis/apigee_v1/classes.rb', line 1201

def name
  @name
end

#read_onlyBoolean Also known as: read_only?

Output only. Whether this proxy is read-only. A read-only proxy cannot have new revisions created through calls to CreateApiProxyRevision. A proxy is read- only if it was generated by an archive. Corresponds to the JSON property readOnly

Returns:

  • (Boolean)


1208
1209
1210
# File 'lib/google/apis/apigee_v1/classes.rb', line 1208

def read_only
  @read_only
end

#revisionArray<String>

Output only. List of revisions defined for the API proxy. Corresponds to the JSON property revision

Returns:

  • (Array<String>)


1214
1215
1216
# File 'lib/google/apis/apigee_v1/classes.rb', line 1214

def revision
  @revision
end

#spaceString

Optional. The id of the space this proxy is associated with. Any IAM policies applied to the space will control access to this proxy. To learn how Spaces can be used to manage resources, read the Apigee Spaces Overview. Corresponds to the JSON property space

Returns:

  • (String)


1223
1224
1225
# File 'lib/google/apis/apigee_v1/classes.rb', line 1223

def space
  @space
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1230
1231
1232
1233
1234
1235
1236
1237
1238
1239
# File 'lib/google/apis/apigee_v1/classes.rb', line 1230

def update!(**args)
  @api_proxy_type = args[:api_proxy_type] if args.key?(:api_proxy_type)
  @labels = args[:labels] if args.key?(:labels)
  @latest_revision_id = args[:latest_revision_id] if args.key?(:latest_revision_id)
  @meta_data = args[:meta_data] if args.key?(:meta_data)
  @name = args[:name] if args.key?(:name)
  @read_only = args[:read_only] if args.key?(:read_only)
  @revision = args[:revision] if args.key?(:revision)
  @space = args[:space] if args.key?(:space)
end