Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiProxyRevision
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiProxyRevision
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
API proxy revision.
Instance Attribute Summary collapse
-
#archive ⇒ String
Output only.
-
#basepaths ⇒ Array<String>
Base URL of the API proxy.
-
#configuration_version ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ConfigVersion
Version of the API proxy configuration schema.
-
#context_info ⇒ String
Revision number, app name, and organization for the API proxy.
-
#created_at ⇒ Fixnum
Time that the API proxy revision was created in milliseconds since epoch.
-
#description ⇒ String
Description of the API proxy revision.
-
#display_name ⇒ String
Human-readable name of the API proxy.
-
#entity_meta_data_as_properties ⇒ Hash<String,String>
Metadata describing the API proxy revision as a key-value map.
-
#has_extensible_policy ⇒ Boolean
(also: #has_extensible_policy?)
Output only.
-
#integration_endpoints ⇒ Array<String>
List of IntegrationEndpoints in the '/integration-endpoints' directory of the API proxy.
-
#last_modified_at ⇒ Fixnum
Time that the API proxy revision was last modified in milliseconds since epoch.
-
#mcp ⇒ Boolean
(also: #mcp?)
Output only.
-
#name ⇒ String
Name of the API proxy.
-
#policies ⇒ Array<String>
List of policy names included in the API proxy revision..
-
#proxies ⇒ Array<String>
List of proxy names included in the API proxy revision.
-
#proxy_endpoints ⇒ Array<String>
List of ProxyEndpoints in the
/proxiesdirectory of the API proxy. -
#resource_files ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ResourceFiles
List of resource files.
-
#resources ⇒ Array<String>
List of the resources included in the API proxy revision formatted as "
type:/ /name". -
#revision ⇒ String
API proxy revision.
-
#shared_flows ⇒ Array<String>
List of the shared flows included in the API proxy revision.
-
#spec ⇒ String
OpenAPI Specification that is associated with the API proxy.
-
#target_endpoints ⇒ Array<String>
List of TargetEndpoints in the
/targetsdirectory of the API proxy. -
#target_servers ⇒ Array<String>
List of TargetServers referenced in any TargetEndpoint in the API proxy.
-
#targets ⇒ Array<String>
List of the targets included in the API proxy revision.
-
#teams ⇒ Array<String>
List of the teams included in the API proxy revision.
-
#type ⇒ String
Type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1ApiProxyRevision
constructor
A new instance of GoogleCloudApigeeV1ApiProxyRevision.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1ApiProxyRevision
Returns a new instance of GoogleCloudApigeeV1ApiProxyRevision.
1408 1409 1410 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1408 def initialize(**args) update!(**args) end |
Instance Attribute Details
#archive ⇒ String
Output only. The archive that generated this proxy revision. This field is
only present on proxy revisions that were generated by an archive. Proxies
generated by archives cannot be updated, deleted, or deployed to other
environments. Format: organizations/*/environments/*/archiveDeployments/*
Corresponds to the JSON property archive
1261 1262 1263 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1261 def archive @archive end |
#basepaths ⇒ Array<String>
Base URL of the API proxy.
Corresponds to the JSON property basepaths
1266 1267 1268 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1266 def basepaths @basepaths end |
#configuration_version ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ConfigVersion
Version of the API proxy configuration schema. Currently, only 4.0 is
supported.
Corresponds to the JSON property configurationVersion
1272 1273 1274 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1272 def configuration_version @configuration_version end |
#context_info ⇒ String
Revision number, app name, and organization for the API proxy.
Corresponds to the JSON property contextInfo
1277 1278 1279 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1277 def context_info @context_info end |
#created_at ⇒ Fixnum
Time that the API proxy revision was created in milliseconds since epoch.
Corresponds to the JSON property createdAt
1282 1283 1284 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1282 def created_at @created_at end |
#description ⇒ String
Description of the API proxy revision.
Corresponds to the JSON property description
1287 1288 1289 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1287 def description @description end |
#display_name ⇒ String
Human-readable name of the API proxy.
Corresponds to the JSON property displayName
1292 1293 1294 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1292 def display_name @display_name end |
#entity_meta_data_as_properties ⇒ Hash<String,String>
Metadata describing the API proxy revision as a key-value map.
Corresponds to the JSON property entityMetaDataAsProperties
1297 1298 1299 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1297 def @entity_meta_data_as_properties end |
#has_extensible_policy ⇒ Boolean Also known as: has_extensible_policy?
Output only. This field will be marked as true if revision contains any
policies marked as extensible.
Corresponds to the JSON property hasExtensiblePolicy
1303 1304 1305 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1303 def has_extensible_policy @has_extensible_policy end |
#integration_endpoints ⇒ Array<String>
List of IntegrationEndpoints in the '/integration-endpoints' directory of the
API proxy. This is a 'manifest' setting designed to provide visibility into
the contents of the API proxy.
Corresponds to the JSON property integrationEndpoints
1311 1312 1313 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1311 def integration_endpoints @integration_endpoints end |
#last_modified_at ⇒ Fixnum
Time that the API proxy revision was last modified in milliseconds since epoch.
Corresponds to the JSON property lastModifiedAt
1316 1317 1318 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1316 def last_modified_at @last_modified_at end |
#mcp ⇒ Boolean Also known as: mcp?
Output only. Whether this proxy revision is detected as an MCP (Model Context
Protocol) proxy. A proxy revision is identified as MCP if it has a proxy
endpoint with the /mcp base path that routes to the MCP target URL.
Corresponds to the JSON property mcp
1323 1324 1325 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1323 def mcp @mcp end |
#name ⇒ String
Name of the API proxy.
Corresponds to the JSON property name
1329 1330 1331 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1329 def name @name end |
#policies ⇒ Array<String>
List of policy names included in the API proxy revision..
Corresponds to the JSON property policies
1334 1335 1336 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1334 def policies @policies end |
#proxies ⇒ Array<String>
List of proxy names included in the API proxy revision.
Corresponds to the JSON property proxies
1339 1340 1341 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1339 def proxies @proxies end |
#proxy_endpoints ⇒ Array<String>
List of ProxyEndpoints in the /proxies directory of the API proxy. Typically,
this element is included only when the API proxy was created using the Edge
UI. This is a 'manifest' setting designed to provide visibility into the
contents of the API proxy.
Corresponds to the JSON property proxyEndpoints
1347 1348 1349 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1347 def proxy_endpoints @proxy_endpoints end |
#resource_files ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ResourceFiles
List of resource files.
Corresponds to the JSON property resourceFiles
1352 1353 1354 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1352 def resource_files @resource_files end |
#resources ⇒ Array<String>
List of the resources included in the API proxy revision formatted as "type:/
/name".
Corresponds to the JSON property resources
1358 1359 1360 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1358 def resources @resources end |
#revision ⇒ String
API proxy revision.
Corresponds to the JSON property revision
1363 1364 1365 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1363 def revision @revision end |
#shared_flows ⇒ Array<String>
List of the shared flows included in the API proxy revision.
Corresponds to the JSON property sharedFlows
1368 1369 1370 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1368 def shared_flows @shared_flows end |
#spec ⇒ String
OpenAPI Specification that is associated with the API proxy. The value is set
to a URL or to a path in the specification store.
Corresponds to the JSON property spec
1374 1375 1376 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1374 def spec @spec end |
#target_endpoints ⇒ Array<String>
List of TargetEndpoints in the /targets directory of the API proxy.
Typically, this element is included only when the API proxy was created using
the Edge UI. This is a 'manifest' setting designed to provide visibility into
the contents of the API proxy.
Corresponds to the JSON property targetEndpoints
1382 1383 1384 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1382 def target_endpoints @target_endpoints end |
#target_servers ⇒ Array<String>
List of TargetServers referenced in any TargetEndpoint in the API proxy.
Typically, you will see this element only when the API proxy was created using
the Edge UI. This is a 'manifest' setting designed to provide visibility into
the contents of the API proxy.
Corresponds to the JSON property targetServers
1390 1391 1392 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1390 def target_servers @target_servers end |
#targets ⇒ Array<String>
List of the targets included in the API proxy revision.
Corresponds to the JSON property targets
1395 1396 1397 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1395 def targets @targets end |
#teams ⇒ Array<String>
List of the teams included in the API proxy revision.
Corresponds to the JSON property teams
1400 1401 1402 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1400 def teams @teams end |
#type ⇒ String
Type. Set to Application. Maintained for compatibility with the Apigee Edge
API.
Corresponds to the JSON property type
1406 1407 1408 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1406 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1413 def update!(**args) @archive = args[:archive] if args.key?(:archive) @basepaths = args[:basepaths] if args.key?(:basepaths) @configuration_version = args[:configuration_version] if args.key?(:configuration_version) @context_info = args[:context_info] if args.key?(:context_info) @created_at = args[:created_at] if args.key?(:created_at) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @entity_meta_data_as_properties = args[:entity_meta_data_as_properties] if args.key?(:entity_meta_data_as_properties) @has_extensible_policy = args[:has_extensible_policy] if args.key?(:has_extensible_policy) @integration_endpoints = args[:integration_endpoints] if args.key?(:integration_endpoints) @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at) @mcp = args[:mcp] if args.key?(:mcp) @name = args[:name] if args.key?(:name) @policies = args[:policies] if args.key?(:policies) @proxies = args[:proxies] if args.key?(:proxies) @proxy_endpoints = args[:proxy_endpoints] if args.key?(:proxy_endpoints) @resource_files = args[:resource_files] if args.key?(:resource_files) @resources = args[:resources] if args.key?(:resources) @revision = args[:revision] if args.key?(:revision) @shared_flows = args[:shared_flows] if args.key?(:shared_flows) @spec = args[:spec] if args.key?(:spec) @target_endpoints = args[:target_endpoints] if args.key?(:target_endpoints) @target_servers = args[:target_servers] if args.key?(:target_servers) @targets = args[:targets] if args.key?(:targets) @teams = args[:teams] if args.key?(:teams) @type = args[:type] if args.key?(:type) end |