Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiProxyRevision
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiProxyRevision
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
API proxy revision.
Instance Attribute Summary collapse
-
#archive ⇒ String
Output only.
-
#basepaths ⇒ Array<String>
Base URL of the API proxy.
-
#configuration_version ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ConfigVersion
Version of the API proxy configuration schema.
-
#context_info ⇒ String
Revision number, app name, and organization for the API proxy.
-
#created_at ⇒ Fixnum
Time that the API proxy revision was created in milliseconds since epoch.
-
#description ⇒ String
Description of the API proxy revision.
-
#display_name ⇒ String
Human-readable name of the API proxy.
-
#entity_meta_data_as_properties ⇒ Hash<String,String>
Metadata describing the API proxy revision as a key-value map.
-
#has_extensible_policy ⇒ Boolean
(also: #has_extensible_policy?)
Output only.
-
#integration_endpoints ⇒ Array<String>
List of IntegrationEndpoints in the '/integration-endpoints' directory of the API proxy.
-
#last_modified_at ⇒ Fixnum
Time that the API proxy revision was last modified in milliseconds since epoch.
-
#name ⇒ String
Name of the API proxy.
-
#policies ⇒ Array<String>
List of policy names included in the API proxy revision..
-
#proxies ⇒ Array<String>
List of proxy names included in the API proxy revision.
-
#proxy_endpoints ⇒ Array<String>
List of ProxyEndpoints in the
/proxiesdirectory of the API proxy. -
#resource_files ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ResourceFiles
List of resource files.
-
#resources ⇒ Array<String>
List of the resources included in the API proxy revision formatted as "
type:/ /name". -
#revision ⇒ String
API proxy revision.
-
#shared_flows ⇒ Array<String>
List of the shared flows included in the API proxy revision.
-
#spec ⇒ String
OpenAPI Specification that is associated with the API proxy.
-
#target_endpoints ⇒ Array<String>
List of TargetEndpoints in the
/targetsdirectory of the API proxy. -
#target_servers ⇒ Array<String>
List of TargetServers referenced in any TargetEndpoint in the API proxy.
-
#targets ⇒ Array<String>
List of the targets included in the API proxy revision.
-
#teams ⇒ Array<String>
List of the teams included in the API proxy revision.
-
#type ⇒ String
Type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1ApiProxyRevision
constructor
A new instance of GoogleCloudApigeeV1ApiProxyRevision.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1ApiProxyRevision
Returns a new instance of GoogleCloudApigeeV1ApiProxyRevision.
1440 1441 1442 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1440 def initialize(**args) update!(**args) end |
Instance Attribute Details
#archive ⇒ String
Output only. The archive that generated this proxy revision. This field is
only present on proxy revisions that were generated by an archive. Proxies
generated by archives cannot be updated, deleted, or deployed to other
environments. Format: organizations/*/environments/*/archiveDeployments/*
Corresponds to the JSON property archive
1301 1302 1303 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1301 def archive @archive end |
#basepaths ⇒ Array<String>
Base URL of the API proxy.
Corresponds to the JSON property basepaths
1306 1307 1308 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1306 def basepaths @basepaths end |
#configuration_version ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ConfigVersion
Version of the API proxy configuration schema. Currently, only 4.0 is
supported.
Corresponds to the JSON property configurationVersion
1312 1313 1314 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1312 def configuration_version @configuration_version end |
#context_info ⇒ String
Revision number, app name, and organization for the API proxy.
Corresponds to the JSON property contextInfo
1317 1318 1319 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1317 def context_info @context_info end |
#created_at ⇒ Fixnum
Time that the API proxy revision was created in milliseconds since epoch.
Corresponds to the JSON property createdAt
1322 1323 1324 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1322 def created_at @created_at end |
#description ⇒ String
Description of the API proxy revision.
Corresponds to the JSON property description
1327 1328 1329 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1327 def description @description end |
#display_name ⇒ String
Human-readable name of the API proxy.
Corresponds to the JSON property displayName
1332 1333 1334 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1332 def display_name @display_name end |
#entity_meta_data_as_properties ⇒ Hash<String,String>
Metadata describing the API proxy revision as a key-value map.
Corresponds to the JSON property entityMetaDataAsProperties
1337 1338 1339 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1337 def @entity_meta_data_as_properties end |
#has_extensible_policy ⇒ Boolean Also known as: has_extensible_policy?
Output only. This field will be marked as true if revision contains any
policies marked as extensible.
Corresponds to the JSON property hasExtensiblePolicy
1343 1344 1345 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1343 def has_extensible_policy @has_extensible_policy end |
#integration_endpoints ⇒ Array<String>
List of IntegrationEndpoints in the '/integration-endpoints' directory of the
API proxy. This is a 'manifest' setting designed to provide visibility into
the contents of the API proxy.
Corresponds to the JSON property integrationEndpoints
1351 1352 1353 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1351 def integration_endpoints @integration_endpoints end |
#last_modified_at ⇒ Fixnum
Time that the API proxy revision was last modified in milliseconds since epoch.
Corresponds to the JSON property lastModifiedAt
1356 1357 1358 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1356 def last_modified_at @last_modified_at end |
#name ⇒ String
Name of the API proxy.
Corresponds to the JSON property name
1361 1362 1363 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1361 def name @name end |
#policies ⇒ Array<String>
List of policy names included in the API proxy revision..
Corresponds to the JSON property policies
1366 1367 1368 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1366 def policies @policies end |
#proxies ⇒ Array<String>
List of proxy names included in the API proxy revision.
Corresponds to the JSON property proxies
1371 1372 1373 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1371 def proxies @proxies end |
#proxy_endpoints ⇒ Array<String>
List of ProxyEndpoints in the /proxies directory of the API proxy. Typically,
this element is included only when the API proxy was created using the Edge
UI. This is a 'manifest' setting designed to provide visibility into the
contents of the API proxy.
Corresponds to the JSON property proxyEndpoints
1379 1380 1381 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1379 def proxy_endpoints @proxy_endpoints end |
#resource_files ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ResourceFiles
List of resource files.
Corresponds to the JSON property resourceFiles
1384 1385 1386 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1384 def resource_files @resource_files end |
#resources ⇒ Array<String>
List of the resources included in the API proxy revision formatted as "type:/
/name".
Corresponds to the JSON property resources
1390 1391 1392 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1390 def resources @resources end |
#revision ⇒ String
API proxy revision.
Corresponds to the JSON property revision
1395 1396 1397 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1395 def revision @revision end |
#shared_flows ⇒ Array<String>
List of the shared flows included in the API proxy revision.
Corresponds to the JSON property sharedFlows
1400 1401 1402 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1400 def shared_flows @shared_flows end |
#spec ⇒ String
OpenAPI Specification that is associated with the API proxy. The value is set
to a URL or to a path in the specification store.
Corresponds to the JSON property spec
1406 1407 1408 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1406 def spec @spec end |
#target_endpoints ⇒ Array<String>
List of TargetEndpoints in the /targets directory of the API proxy.
Typically, this element is included only when the API proxy was created using
the Edge UI. This is a 'manifest' setting designed to provide visibility into
the contents of the API proxy.
Corresponds to the JSON property targetEndpoints
1414 1415 1416 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1414 def target_endpoints @target_endpoints end |
#target_servers ⇒ Array<String>
List of TargetServers referenced in any TargetEndpoint in the API proxy.
Typically, you will see this element only when the API proxy was created using
the Edge UI. This is a 'manifest' setting designed to provide visibility into
the contents of the API proxy.
Corresponds to the JSON property targetServers
1422 1423 1424 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1422 def target_servers @target_servers end |
#targets ⇒ Array<String>
List of the targets included in the API proxy revision.
Corresponds to the JSON property targets
1427 1428 1429 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1427 def targets @targets end |
#teams ⇒ Array<String>
List of the teams included in the API proxy revision.
Corresponds to the JSON property teams
1432 1433 1434 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1432 def teams @teams end |
#type ⇒ String
Type. Set to Application. Maintained for compatibility with the Apigee Edge
API.
Corresponds to the JSON property type
1438 1439 1440 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1438 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 1469 1470 1471 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1445 def update!(**args) @archive = args[:archive] if args.key?(:archive) @basepaths = args[:basepaths] if args.key?(:basepaths) @configuration_version = args[:configuration_version] if args.key?(:configuration_version) @context_info = args[:context_info] if args.key?(:context_info) @created_at = args[:created_at] if args.key?(:created_at) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @entity_meta_data_as_properties = args[:entity_meta_data_as_properties] if args.key?(:entity_meta_data_as_properties) @has_extensible_policy = args[:has_extensible_policy] if args.key?(:has_extensible_policy) @integration_endpoints = args[:integration_endpoints] if args.key?(:integration_endpoints) @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at) @name = args[:name] if args.key?(:name) @policies = args[:policies] if args.key?(:policies) @proxies = args[:proxies] if args.key?(:proxies) @proxy_endpoints = args[:proxy_endpoints] if args.key?(:proxy_endpoints) @resource_files = args[:resource_files] if args.key?(:resource_files) @resources = args[:resources] if args.key?(:resources) @revision = args[:revision] if args.key?(:revision) @shared_flows = args[:shared_flows] if args.key?(:shared_flows) @spec = args[:spec] if args.key?(:spec) @target_endpoints = args[:target_endpoints] if args.key?(:target_endpoints) @target_servers = args[:target_servers] if args.key?(:target_servers) @targets = args[:targets] if args.key?(:targets) @teams = args[:teams] if args.key?(:teams) @type = args[:type] if args.key?(:type) end |