Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiProxyRevision

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

API proxy revision.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1ApiProxyRevision

Returns a new instance of GoogleCloudApigeeV1ApiProxyRevision.



1391
1392
1393
# File 'lib/google/apis/apigee_v1/classes.rb', line 1391

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#archiveString

Output only. The archive that generated this proxy revision. This field is only present on proxy revisions that were generated by an archive. Proxies generated by archives cannot be updated, deleted, or deployed to other environments. Format: organizations/*/environments/*/archiveDeployments/* Corresponds to the JSON property archive

Returns:

  • (String)


1252
1253
1254
# File 'lib/google/apis/apigee_v1/classes.rb', line 1252

def archive
  @archive
end

#basepathsArray<String>

Base URL of the API proxy. Corresponds to the JSON property basepaths

Returns:

  • (Array<String>)


1257
1258
1259
# File 'lib/google/apis/apigee_v1/classes.rb', line 1257

def basepaths
  @basepaths
end

#configuration_versionGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1ConfigVersion

Version of the API proxy configuration schema. Currently, only 4.0 is supported. Corresponds to the JSON property configurationVersion



1263
1264
1265
# File 'lib/google/apis/apigee_v1/classes.rb', line 1263

def configuration_version
  @configuration_version
end

#context_infoString

Revision number, app name, and organization for the API proxy. Corresponds to the JSON property contextInfo

Returns:

  • (String)


1268
1269
1270
# File 'lib/google/apis/apigee_v1/classes.rb', line 1268

def context_info
  @context_info
end

#created_atFixnum

Time that the API proxy revision was created in milliseconds since epoch. Corresponds to the JSON property createdAt

Returns:

  • (Fixnum)


1273
1274
1275
# File 'lib/google/apis/apigee_v1/classes.rb', line 1273

def created_at
  @created_at
end

#descriptionString

Description of the API proxy revision. Corresponds to the JSON property description

Returns:

  • (String)


1278
1279
1280
# File 'lib/google/apis/apigee_v1/classes.rb', line 1278

def description
  @description
end

#display_nameString

Human-readable name of the API proxy. Corresponds to the JSON property displayName

Returns:

  • (String)


1283
1284
1285
# File 'lib/google/apis/apigee_v1/classes.rb', line 1283

def display_name
  @display_name
end

#entity_meta_data_as_propertiesHash<String,String>

Metadata describing the API proxy revision as a key-value map. Corresponds to the JSON property entityMetaDataAsProperties

Returns:

  • (Hash<String,String>)


1288
1289
1290
# File 'lib/google/apis/apigee_v1/classes.rb', line 1288

def 
  @entity_meta_data_as_properties
end

#has_extensible_policyBoolean Also known as: has_extensible_policy?

Output only. This field will be marked as true if revision contains any policies marked as extensible. Corresponds to the JSON property hasExtensiblePolicy

Returns:

  • (Boolean)


1294
1295
1296
# File 'lib/google/apis/apigee_v1/classes.rb', line 1294

def has_extensible_policy
  @has_extensible_policy
end

#integration_endpointsArray<String>

List of IntegrationEndpoints in the '/integration-endpoints' directory of the API proxy. This is a 'manifest' setting designed to provide visibility into the contents of the API proxy. Corresponds to the JSON property integrationEndpoints

Returns:

  • (Array<String>)


1302
1303
1304
# File 'lib/google/apis/apigee_v1/classes.rb', line 1302

def integration_endpoints
  @integration_endpoints
end

#last_modified_atFixnum

Time that the API proxy revision was last modified in milliseconds since epoch. Corresponds to the JSON property lastModifiedAt

Returns:

  • (Fixnum)


1307
1308
1309
# File 'lib/google/apis/apigee_v1/classes.rb', line 1307

def last_modified_at
  @last_modified_at
end

#nameString

Name of the API proxy. Corresponds to the JSON property name

Returns:

  • (String)


1312
1313
1314
# File 'lib/google/apis/apigee_v1/classes.rb', line 1312

def name
  @name
end

#policiesArray<String>

List of policy names included in the API proxy revision.. Corresponds to the JSON property policies

Returns:

  • (Array<String>)


1317
1318
1319
# File 'lib/google/apis/apigee_v1/classes.rb', line 1317

def policies
  @policies
end

#proxiesArray<String>

List of proxy names included in the API proxy revision. Corresponds to the JSON property proxies

Returns:

  • (Array<String>)


1322
1323
1324
# File 'lib/google/apis/apigee_v1/classes.rb', line 1322

def proxies
  @proxies
end

#proxy_endpointsArray<String>

List of ProxyEndpoints in the /proxies directory of the API proxy. Typically, this element is included only when the API proxy was created using the Edge UI. This is a 'manifest' setting designed to provide visibility into the contents of the API proxy. Corresponds to the JSON property proxyEndpoints

Returns:

  • (Array<String>)


1330
1331
1332
# File 'lib/google/apis/apigee_v1/classes.rb', line 1330

def proxy_endpoints
  @proxy_endpoints
end

#resource_filesGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1ResourceFiles

List of resource files. Corresponds to the JSON property resourceFiles



1335
1336
1337
# File 'lib/google/apis/apigee_v1/classes.rb', line 1335

def resource_files
  @resource_files
end

#resourcesArray<String>

List of the resources included in the API proxy revision formatted as "type:/ /name". Corresponds to the JSON property resources

Returns:

  • (Array<String>)


1341
1342
1343
# File 'lib/google/apis/apigee_v1/classes.rb', line 1341

def resources
  @resources
end

#revisionString

API proxy revision. Corresponds to the JSON property revision

Returns:

  • (String)


1346
1347
1348
# File 'lib/google/apis/apigee_v1/classes.rb', line 1346

def revision
  @revision
end

#shared_flowsArray<String>

List of the shared flows included in the API proxy revision. Corresponds to the JSON property sharedFlows

Returns:

  • (Array<String>)


1351
1352
1353
# File 'lib/google/apis/apigee_v1/classes.rb', line 1351

def shared_flows
  @shared_flows
end

#specString

OpenAPI Specification that is associated with the API proxy. The value is set to a URL or to a path in the specification store. Corresponds to the JSON property spec

Returns:

  • (String)


1357
1358
1359
# File 'lib/google/apis/apigee_v1/classes.rb', line 1357

def spec
  @spec
end

#target_endpointsArray<String>

List of TargetEndpoints in the /targets directory of the API proxy. Typically, this element is included only when the API proxy was created using the Edge UI. This is a 'manifest' setting designed to provide visibility into the contents of the API proxy. Corresponds to the JSON property targetEndpoints

Returns:

  • (Array<String>)


1365
1366
1367
# File 'lib/google/apis/apigee_v1/classes.rb', line 1365

def target_endpoints
  @target_endpoints
end

#target_serversArray<String>

List of TargetServers referenced in any TargetEndpoint in the API proxy. Typically, you will see this element only when the API proxy was created using the Edge UI. This is a 'manifest' setting designed to provide visibility into the contents of the API proxy. Corresponds to the JSON property targetServers

Returns:

  • (Array<String>)


1373
1374
1375
# File 'lib/google/apis/apigee_v1/classes.rb', line 1373

def target_servers
  @target_servers
end

#targetsArray<String>

List of the targets included in the API proxy revision. Corresponds to the JSON property targets

Returns:

  • (Array<String>)


1378
1379
1380
# File 'lib/google/apis/apigee_v1/classes.rb', line 1378

def targets
  @targets
end

#teamsArray<String>

List of the teams included in the API proxy revision. Corresponds to the JSON property teams

Returns:

  • (Array<String>)


1383
1384
1385
# File 'lib/google/apis/apigee_v1/classes.rb', line 1383

def teams
  @teams
end

#typeString

Type. Set to Application. Maintained for compatibility with the Apigee Edge API. Corresponds to the JSON property type

Returns:

  • (String)


1389
1390
1391
# File 'lib/google/apis/apigee_v1/classes.rb', line 1389

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1396
1397
1398
1399
1400
1401
1402
1403
1404
1405
1406
1407
1408
1409
1410
1411
1412
1413
1414
1415
1416
1417
1418
1419
1420
1421
1422
# File 'lib/google/apis/apigee_v1/classes.rb', line 1396

def update!(**args)
  @archive = args[:archive] if args.key?(:archive)
  @basepaths = args[:basepaths] if args.key?(:basepaths)
  @configuration_version = args[:configuration_version] if args.key?(:configuration_version)
  @context_info = args[:context_info] if args.key?(:context_info)
  @created_at = args[:created_at] if args.key?(:created_at)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entity_meta_data_as_properties = args[:entity_meta_data_as_properties] if args.key?(:entity_meta_data_as_properties)
  @has_extensible_policy = args[:has_extensible_policy] if args.key?(:has_extensible_policy)
  @integration_endpoints = args[:integration_endpoints] if args.key?(:integration_endpoints)
  @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at)
  @name = args[:name] if args.key?(:name)
  @policies = args[:policies] if args.key?(:policies)
  @proxies = args[:proxies] if args.key?(:proxies)
  @proxy_endpoints = args[:proxy_endpoints] if args.key?(:proxy_endpoints)
  @resource_files = args[:resource_files] if args.key?(:resource_files)
  @resources = args[:resources] if args.key?(:resources)
  @revision = args[:revision] if args.key?(:revision)
  @shared_flows = args[:shared_flows] if args.key?(:shared_flows)
  @spec = args[:spec] if args.key?(:spec)
  @target_endpoints = args[:target_endpoints] if args.key?(:target_endpoints)
  @target_servers = args[:target_servers] if args.key?(:target_servers)
  @targets = args[:targets] if args.key?(:targets)
  @teams = args[:teams] if args.key?(:teams)
  @type = args[:type] if args.key?(:type)
end