Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApimServiceExtension
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApimServiceExtension
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
APIM Service Extension is a resource under an Apigee Organization that is used to create APIM Service Extension to route traffic to existing X instances.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#extension_processor ⇒ String
Required.
-
#extensions ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApimServiceExtensionExtension>
Optional.
-
#lb_forwarding_rule ⇒ String
Required.
-
#name ⇒ String
Identifier.
-
#network ⇒ String
Required.
-
#network_configs ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApimServiceExtensionNetworkConfig>
Required.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1ApimServiceExtension
constructor
A new instance of GoogleCloudApigeeV1ApimServiceExtension.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1ApimServiceExtension
Returns a new instance of GoogleCloudApigeeV1ApimServiceExtension.
1557 1558 1559 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1557 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time that this resource was created on the server.
Corresponds to the JSON property createTime
1507 1508 1509 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1507 def create_time @create_time end |
#extension_processor ⇒ String
Required. Name of the proxy deployed in the Apigee X instance.
Corresponds to the JSON property extensionProcessor
1512 1513 1514 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1512 def extension_processor @extension_processor end |
#extensions ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApimServiceExtensionExtension>
Optional. List of extensions that are part of the service extension. Refer to
https://cloud.google.com/service-extensions/docs/quotas#limits for any limits.
Corresponds to the JSON property extensions
1518 1519 1520 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1518 def extensions @extensions end |
#lb_forwarding_rule ⇒ String
Required. Name of the Google Cloud LB forwarding rule. Format: projects/
project/regions/region/forwardingRules/forwarding_rule projects/project/
global/forwardingRules/forwarding_rule
Corresponds to the JSON property lbForwardingRule
1525 1526 1527 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1525 def lb_forwarding_rule @lb_forwarding_rule end |
#name ⇒ String
Identifier. unique name of the APIM service extension. The name must conform
with RFC-1034, is restricted to lower-cased letters, numbers and hyphens, and
can have a maximum length of 63 characters. Additionally, the first character
must be a letter and the last a letter or a number.
Corresponds to the JSON property name
1533 1534 1535 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1533 def name @name end |
#network ⇒ String
Required. The network where the forwarding rule is created. Format: projects/
project/global/networks/network
Corresponds to the JSON property network
1539 1540 1541 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1539 def network @network end |
#network_configs ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApimServiceExtensionNetworkConfig>
Required. List of network configurations for the APIM service extension.
Corresponds to the JSON property networkConfigs
1544 1545 1546 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1544 def network_configs @network_configs end |
#state ⇒ String
Output only. State of the APIM service extension. Values other than ACTIVE
mean the resource is not ready to use.
Corresponds to the JSON property state
1550 1551 1552 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1550 def state @state end |
#update_time ⇒ String
Output only. The time that this resource was updated on the server.
Corresponds to the JSON property updateTime
1555 1556 1557 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1555 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1562 1563 1564 1565 1566 1567 1568 1569 1570 1571 1572 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1562 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @extension_processor = args[:extension_processor] if args.key?(:extension_processor) @extensions = args[:extensions] if args.key?(:extensions) @lb_forwarding_rule = args[:lb_forwarding_rule] if args.key?(:lb_forwarding_rule) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @network_configs = args[:network_configs] if args.key?(:network_configs) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |