Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApimServiceExtensionExtension
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApimServiceExtensionExtension
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Extension configuration for Apigee extension processor service extension.
Instance Attribute Summary collapse
-
#fail_open ⇒ Boolean
(also: #fail_open?)
Optional.
-
#hostname ⇒ String
Required.
-
#match_condition ⇒ String
Optional.
-
#name ⇒ String
Required.
-
#supported_events ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1ApimServiceExtensionExtension
constructor
A new instance of GoogleCloudApigeeV1ApimServiceExtensionExtension.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1ApimServiceExtensionExtension
Returns a new instance of GoogleCloudApigeeV1ApimServiceExtensionExtension.
1631 1632 1633 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1631 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fail_open ⇒ Boolean Also known as: fail_open?
Optional. Whether this request should fail open.
Corresponds to the JSON property failOpen
1600 1601 1602 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1600 def fail_open @fail_open end |
#hostname ⇒ String
Required. One of the hostnames of Apigee EnvGroup where the proxy is deployed.
This hostname (i.e FDQN) will be used to route traffic from the specified
forwarding rule to the environment in Apigee X instance where the proxy is
deployed for handling extension traffic. Format: ^([a-zA-Z0-9. _-])+$
Corresponds to the JSON property hostname
1609 1610 1611 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1609 def hostname @hostname end |
#match_condition ⇒ String
Optional. Match Condition for CEL expression. Refer to https://cloud.google.
com/service-extensions/docs/cel-matcher-language-reference for more details.
Corresponds to the JSON property matchCondition
1615 1616 1617 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1615 def match_condition @match_condition end |
#name ⇒ String
Required. Name of the LbTrafficExtension resource. The name must conform
with RFC-1034, is restricted to lower-cased letters, numbers and hyphens, and
can have a maximum length of 63 characters. Additionally, the first character
must be a letter and the last a letter or a number.
Corresponds to the JSON property name
1623 1624 1625 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1623 def name @name end |
#supported_events ⇒ Array<String>
Optional. Supported events for the Service Extension. If not specified, all
events are supported.
Corresponds to the JSON property supportedEvents
1629 1630 1631 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1629 def supported_events @supported_events end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1636 1637 1638 1639 1640 1641 1642 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1636 def update!(**args) @fail_open = args[:fail_open] if args.key?(:fail_open) @hostname = args[:hostname] if args.key?(:hostname) @match_condition = args[:match_condition] if args.key?(:match_condition) @name = args[:name] if args.key?(:name) @supported_events = args[:supported_events] if args.key?(:supported_events) end |