Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApimServiceExtensionExtension

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Extension configuration for Apigee extension processor service extension.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1ApimServiceExtensionExtension

Returns a new instance of GoogleCloudApigeeV1ApimServiceExtensionExtension.



1613
1614
1615
# File 'lib/google/apis/apigee_v1/classes.rb', line 1613

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fail_openBoolean Also known as: fail_open?

Optional. Whether this request should fail open. Corresponds to the JSON property failOpen

Returns:

  • (Boolean)


1582
1583
1584
# File 'lib/google/apis/apigee_v1/classes.rb', line 1582

def fail_open
  @fail_open
end

#hostnameString

Required. One of the hostnames of Apigee EnvGroup where the proxy is deployed. This hostname (i.e FDQN) will be used to route traffic from the specified forwarding rule to the environment in Apigee X instance where the proxy is deployed for handling extension traffic. Format: ^([a-zA-Z0-9. _-])+$ Corresponds to the JSON property hostname

Returns:

  • (String)


1591
1592
1593
# File 'lib/google/apis/apigee_v1/classes.rb', line 1591

def hostname
  @hostname
end

#match_conditionString

Optional. Match Condition for CEL expression. Refer to https://cloud.google. com/service-extensions/docs/cel-matcher-language-reference for more details. Corresponds to the JSON property matchCondition

Returns:

  • (String)


1597
1598
1599
# File 'lib/google/apis/apigee_v1/classes.rb', line 1597

def match_condition
  @match_condition
end

#nameString

Required. Name of the LbTrafficExtension resource. The name must conform with RFC-1034, is restricted to lower-cased letters, numbers and hyphens, and can have a maximum length of 63 characters. Additionally, the first character must be a letter and the last a letter or a number. Corresponds to the JSON property name

Returns:

  • (String)


1605
1606
1607
# File 'lib/google/apis/apigee_v1/classes.rb', line 1605

def name
  @name
end

#supported_eventsArray<String>

Optional. Supported events for the Service Extension. If not specified, all events are supported. Corresponds to the JSON property supportedEvents

Returns:

  • (Array<String>)


1611
1612
1613
# File 'lib/google/apis/apigee_v1/classes.rb', line 1611

def supported_events
  @supported_events
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1618
1619
1620
1621
1622
1623
1624
# File 'lib/google/apis/apigee_v1/classes.rb', line 1618

def update!(**args)
  @fail_open = args[:fail_open] if args.key?(:fail_open)
  @hostname = args[:hostname] if args.key?(:hostname)
  @match_condition = args[:match_condition] if args.key?(:match_condition)
  @name = args[:name] if args.key?(:name)
  @supported_events = args[:supported_events] if args.key?(:supported_events)
end