Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1App

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1App

Returns a new instance of GoogleCloudApigeeV1App.



1746
1747
1748
# File 'lib/google/apis/apigee_v1/classes.rb', line 1746

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_productsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiProductRef>

List of API products associated with the app. Corresponds to the JSON property apiProducts



1669
1670
1671
# File 'lib/google/apis/apigee_v1/classes.rb', line 1669

def api_products
  @api_products
end

#app_groupString

Name of the AppGroup Corresponds to the JSON property appGroup

Returns:

  • (String)


1674
1675
1676
# File 'lib/google/apis/apigee_v1/classes.rb', line 1674

def app_group
  @app_group
end

#app_idString

ID of the app. Corresponds to the JSON property appId

Returns:

  • (String)


1679
1680
1681
# File 'lib/google/apis/apigee_v1/classes.rb', line 1679

def app_id
  @app_id
end

#attributesArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>

List of attributes. Corresponds to the JSON property attributes



1684
1685
1686
# File 'lib/google/apis/apigee_v1/classes.rb', line 1684

def attributes
  @attributes
end

#callback_urlString

Callback URL used by OAuth 2.0 authorization servers to communicate authorization codes back to apps. Corresponds to the JSON property callbackUrl

Returns:

  • (String)


1690
1691
1692
# File 'lib/google/apis/apigee_v1/classes.rb', line 1690

def callback_url
  @callback_url
end

#company_nameString

Name of the company that owns the app. Corresponds to the JSON property companyName

Returns:

  • (String)


1695
1696
1697
# File 'lib/google/apis/apigee_v1/classes.rb', line 1695

def company_name
  @company_name
end

#created_atFixnum

Output only. Unix time when the app was created. Corresponds to the JSON property createdAt

Returns:

  • (Fixnum)


1700
1701
1702
# File 'lib/google/apis/apigee_v1/classes.rb', line 1700

def created_at
  @created_at
end

#credentialsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Credential>

Output only. Set of credentials for the app. Credentials are API key/secret pairs associated with API products. Corresponds to the JSON property credentials



1706
1707
1708
# File 'lib/google/apis/apigee_v1/classes.rb', line 1706

def credentials
  @credentials
end

#developer_emailString

Email of the developer. Corresponds to the JSON property developerEmail

Returns:

  • (String)


1711
1712
1713
# File 'lib/google/apis/apigee_v1/classes.rb', line 1711

def developer_email
  @developer_email
end

#developer_idString

ID of the developer. Corresponds to the JSON property developerId

Returns:

  • (String)


1716
1717
1718
# File 'lib/google/apis/apigee_v1/classes.rb', line 1716

def developer_id
  @developer_id
end

#key_expires_inFixnum

Duration, in milliseconds, of the consumer key that will be generated for the app. The default value, -1, indicates an infinite validity period. Once set, the expiration can't be updated. json key: keyExpiresIn Corresponds to the JSON property keyExpiresIn

Returns:

  • (Fixnum)


1723
1724
1725
# File 'lib/google/apis/apigee_v1/classes.rb', line 1723

def key_expires_in
  @key_expires_in
end

#last_modified_atFixnum

Output only. Last modified time as milliseconds since epoch. Corresponds to the JSON property lastModifiedAt

Returns:

  • (Fixnum)


1728
1729
1730
# File 'lib/google/apis/apigee_v1/classes.rb', line 1728

def last_modified_at
  @last_modified_at
end

#nameString

Name of the app. Corresponds to the JSON property name

Returns:

  • (String)


1733
1734
1735
# File 'lib/google/apis/apigee_v1/classes.rb', line 1733

def name
  @name
end

#scopesArray<String>

Scopes to apply to the app. The specified scope names must already exist on the API product that you associate with the app. Corresponds to the JSON property scopes

Returns:

  • (Array<String>)


1739
1740
1741
# File 'lib/google/apis/apigee_v1/classes.rb', line 1739

def scopes
  @scopes
end

#statusString

Status of the credential. Corresponds to the JSON property status

Returns:

  • (String)


1744
1745
1746
# File 'lib/google/apis/apigee_v1/classes.rb', line 1744

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1751
1752
1753
1754
1755
1756
1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
# File 'lib/google/apis/apigee_v1/classes.rb', line 1751

def update!(**args)
  @api_products = args[:api_products] if args.key?(:api_products)
  @app_group = args[:app_group] if args.key?(:app_group)
  @app_id = args[:app_id] if args.key?(:app_id)
  @attributes = args[:attributes] if args.key?(:attributes)
  @callback_url = args[:callback_url] if args.key?(:callback_url)
  @company_name = args[:company_name] if args.key?(:company_name)
  @created_at = args[:created_at] if args.key?(:created_at)
  @credentials = args[:credentials] if args.key?(:credentials)
  @developer_email = args[:developer_email] if args.key?(:developer_email)
  @developer_id = args[:developer_id] if args.key?(:developer_id)
  @key_expires_in = args[:key_expires_in] if args.key?(:key_expires_in)
  @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at)
  @name = args[:name] if args.key?(:name)
  @scopes = args[:scopes] if args.key?(:scopes)
  @status = args[:status] if args.key?(:status)
end