Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1App
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1App
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Instance Attribute Summary collapse
-
#api_products ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiProductRef>
List of API products associated with the app.
-
#app_group ⇒ String
Name of the AppGroup Corresponds to the JSON property
appGroup. -
#app_id ⇒ String
ID of the app.
-
#attributes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>
List of attributes.
-
#callback_url ⇒ String
Callback URL used by OAuth 2.0 authorization servers to communicate authorization codes back to apps.
-
#company_name ⇒ String
Name of the company that owns the app.
-
#created_at ⇒ Fixnum
Output only.
-
#credentials ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Credential>
Output only.
-
#developer_email ⇒ String
Email of the developer.
-
#developer_id ⇒ String
ID of the developer.
-
#key_expires_in ⇒ Fixnum
Duration, in milliseconds, of the consumer key that will be generated for the app.
-
#last_modified_at ⇒ Fixnum
Output only.
-
#name ⇒ String
Name of the app.
-
#scopes ⇒ Array<String>
Scopes to apply to the app.
-
#status ⇒ String
Status of the credential.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1App
constructor
A new instance of GoogleCloudApigeeV1App.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1App
Returns a new instance of GoogleCloudApigeeV1App.
1786 1787 1788 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1786 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_products ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiProductRef>
List of API products associated with the app.
Corresponds to the JSON property apiProducts
1709 1710 1711 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1709 def api_products @api_products end |
#app_group ⇒ String
Name of the AppGroup
Corresponds to the JSON property appGroup
1714 1715 1716 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1714 def app_group @app_group end |
#app_id ⇒ String
ID of the app.
Corresponds to the JSON property appId
1719 1720 1721 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1719 def app_id @app_id end |
#attributes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>
List of attributes.
Corresponds to the JSON property attributes
1724 1725 1726 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1724 def attributes @attributes end |
#callback_url ⇒ String
Callback URL used by OAuth 2.0 authorization servers to communicate
authorization codes back to apps.
Corresponds to the JSON property callbackUrl
1730 1731 1732 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1730 def callback_url @callback_url end |
#company_name ⇒ String
Name of the company that owns the app.
Corresponds to the JSON property companyName
1735 1736 1737 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1735 def company_name @company_name end |
#created_at ⇒ Fixnum
Output only. Unix time when the app was created.
Corresponds to the JSON property createdAt
1740 1741 1742 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1740 def created_at @created_at end |
#credentials ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Credential>
Output only. Set of credentials for the app. Credentials are API key/secret
pairs associated with API products.
Corresponds to the JSON property credentials
1746 1747 1748 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1746 def credentials @credentials end |
#developer_email ⇒ String
Email of the developer.
Corresponds to the JSON property developerEmail
1751 1752 1753 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1751 def developer_email @developer_email end |
#developer_id ⇒ String
ID of the developer.
Corresponds to the JSON property developerId
1756 1757 1758 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1756 def developer_id @developer_id end |
#key_expires_in ⇒ Fixnum
Duration, in milliseconds, of the consumer key that will be generated for the
app. The default value, -1, indicates an infinite validity period. Once set,
the expiration can't be updated. json key: keyExpiresIn
Corresponds to the JSON property keyExpiresIn
1763 1764 1765 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1763 def key_expires_in @key_expires_in end |
#last_modified_at ⇒ Fixnum
Output only. Last modified time as milliseconds since epoch.
Corresponds to the JSON property lastModifiedAt
1768 1769 1770 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1768 def last_modified_at @last_modified_at end |
#name ⇒ String
Name of the app.
Corresponds to the JSON property name
1773 1774 1775 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1773 def name @name end |
#scopes ⇒ Array<String>
Scopes to apply to the app. The specified scope names must already exist on
the API product that you associate with the app.
Corresponds to the JSON property scopes
1779 1780 1781 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1779 def scopes @scopes end |
#status ⇒ String
Status of the credential.
Corresponds to the JSON property status
1784 1785 1786 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1784 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1791 def update!(**args) @api_products = args[:api_products] if args.key?(:api_products) @app_group = args[:app_group] if args.key?(:app_group) @app_id = args[:app_id] if args.key?(:app_id) @attributes = args[:attributes] if args.key?(:attributes) @callback_url = args[:callback_url] if args.key?(:callback_url) @company_name = args[:company_name] if args.key?(:company_name) @created_at = args[:created_at] if args.key?(:created_at) @credentials = args[:credentials] if args.key?(:credentials) @developer_email = args[:developer_email] if args.key?(:developer_email) @developer_id = args[:developer_id] if args.key?(:developer_id) @key_expires_in = args[:key_expires_in] if args.key?(:key_expires_in) @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at) @name = args[:name] if args.key?(:name) @scopes = args[:scopes] if args.key?(:scopes) @status = args[:status] if args.key?(:status) end |