Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1AppGroup
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1AppGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
AppGroup contains the request/response fields representing the logical grouping of apps. Note that appgroup_id, create_time and update_time cannot be changed by the user, and gets updated by the system. The name and the organization once provided cannot be edited subsequently.
Instance Attribute Summary collapse
-
#app_group_id ⇒ String
Output only.
-
#attributes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>
A list of attributes Corresponds to the JSON property
attributes. -
#channel_id ⇒ String
channel identifier identifies the owner maintaing this grouping.
-
#channel_uri ⇒ String
A reference to the associated storefront/marketplace.
-
#created_at ⇒ Fixnum
Output only.
-
#display_name ⇒ String
app group name displayed in the UI Corresponds to the JSON property
displayName. -
#email ⇒ String
Optional.
-
#last_modified_at ⇒ Fixnum
Output only.
-
#name ⇒ String
Immutable.
-
#organization ⇒ String
Immutable.
-
#status ⇒ String
Valid values are
activeorinactive.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1AppGroup
constructor
A new instance of GoogleCloudApigeeV1AppGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1AppGroup
Returns a new instance of GoogleCloudApigeeV1AppGroup.
1875 1876 1877 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1875 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_group_id ⇒ String
Output only. Internal identifier that cannot be edited
Corresponds to the JSON property appGroupId
1820 1821 1822 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1820 def app_group_id @app_group_id end |
#attributes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>
A list of attributes
Corresponds to the JSON property attributes
1825 1826 1827 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1825 def attributes @attributes end |
#channel_id ⇒ String
channel identifier identifies the owner maintaing this grouping.
Corresponds to the JSON property channelId
1830 1831 1832 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1830 def channel_id @channel_id end |
#channel_uri ⇒ String
A reference to the associated storefront/marketplace.
Corresponds to the JSON property channelUri
1835 1836 1837 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1835 def channel_uri @channel_uri end |
#created_at ⇒ Fixnum
Output only. Created time as milliseconds since epoch.
Corresponds to the JSON property createdAt
1840 1841 1842 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1840 def created_at @created_at end |
#display_name ⇒ String
app group name displayed in the UI
Corresponds to the JSON property displayName
1845 1846 1847 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1845 def display_name @display_name end |
#email ⇒ String
Optional. Email of the AppGroup.
Corresponds to the JSON property email
1850 1851 1852 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1850 def email @email end |
#last_modified_at ⇒ Fixnum
Output only. Modified time as milliseconds since epoch.
Corresponds to the JSON property lastModifiedAt
1855 1856 1857 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1855 def last_modified_at @last_modified_at end |
#name ⇒ String
Immutable. Name of the AppGroup. Characters you can use in the name are
restricted to: A-Z0-9._-$ %.
Corresponds to the JSON property name
1861 1862 1863 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1861 def name @name end |
#organization ⇒ String
Immutable. the org the app group is created
Corresponds to the JSON property organization
1866 1867 1868 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1866 def organization @organization end |
#status ⇒ String
Valid values are active or inactive. Note that the status of the AppGroup
should be updated via UpdateAppGroupRequest by setting the action as active
or inactive.
Corresponds to the JSON property status
1873 1874 1875 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1873 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1880 1881 1882 1883 1884 1885 1886 1887 1888 1889 1890 1891 1892 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1880 def update!(**args) @app_group_id = args[:app_group_id] if args.key?(:app_group_id) @attributes = args[:attributes] if args.key?(:attributes) @channel_id = args[:channel_id] if args.key?(:channel_id) @channel_uri = args[:channel_uri] if args.key?(:channel_uri) @created_at = args[:created_at] if args.key?(:created_at) @display_name = args[:display_name] if args.key?(:display_name) @email = args[:email] if args.key?(:email) @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at) @name = args[:name] if args.key?(:name) @organization = args[:organization] if args.key?(:organization) @status = args[:status] if args.key?(:status) end |