Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1AppGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

AppGroup contains the request/response fields representing the logical grouping of apps. Note that appgroup_id, create_time and update_time cannot be changed by the user, and gets updated by the system. The name and the organization once provided cannot be edited subsequently.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1AppGroup

Returns a new instance of GoogleCloudApigeeV1AppGroup.



1826
1827
1828
# File 'lib/google/apis/apigee_v1/classes.rb', line 1826

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_group_idString

Output only. Internal identifier that cannot be edited Corresponds to the JSON property appGroupId

Returns:

  • (String)


1771
1772
1773
# File 'lib/google/apis/apigee_v1/classes.rb', line 1771

def app_group_id
  @app_group_id
end

#attributesArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>

A list of attributes Corresponds to the JSON property attributes



1776
1777
1778
# File 'lib/google/apis/apigee_v1/classes.rb', line 1776

def attributes
  @attributes
end

#channel_idString

channel identifier identifies the owner maintaing this grouping. Corresponds to the JSON property channelId

Returns:

  • (String)


1781
1782
1783
# File 'lib/google/apis/apigee_v1/classes.rb', line 1781

def channel_id
  @channel_id
end

#channel_uriString

A reference to the associated storefront/marketplace. Corresponds to the JSON property channelUri

Returns:

  • (String)


1786
1787
1788
# File 'lib/google/apis/apigee_v1/classes.rb', line 1786

def channel_uri
  @channel_uri
end

#created_atFixnum

Output only. Created time as milliseconds since epoch. Corresponds to the JSON property createdAt

Returns:

  • (Fixnum)


1791
1792
1793
# File 'lib/google/apis/apigee_v1/classes.rb', line 1791

def created_at
  @created_at
end

#display_nameString

app group name displayed in the UI Corresponds to the JSON property displayName

Returns:

  • (String)


1796
1797
1798
# File 'lib/google/apis/apigee_v1/classes.rb', line 1796

def display_name
  @display_name
end

#emailString

Optional. Email of the AppGroup. Corresponds to the JSON property email

Returns:

  • (String)


1801
1802
1803
# File 'lib/google/apis/apigee_v1/classes.rb', line 1801

def email
  @email
end

#last_modified_atFixnum

Output only. Modified time as milliseconds since epoch. Corresponds to the JSON property lastModifiedAt

Returns:

  • (Fixnum)


1806
1807
1808
# File 'lib/google/apis/apigee_v1/classes.rb', line 1806

def last_modified_at
  @last_modified_at
end

#nameString

Immutable. Name of the AppGroup. Characters you can use in the name are restricted to: A-Z0-9._-$ %. Corresponds to the JSON property name

Returns:

  • (String)


1812
1813
1814
# File 'lib/google/apis/apigee_v1/classes.rb', line 1812

def name
  @name
end

#organizationString

Immutable. the org the app group is created Corresponds to the JSON property organization

Returns:

  • (String)


1817
1818
1819
# File 'lib/google/apis/apigee_v1/classes.rb', line 1817

def organization
  @organization
end

#statusString

Valid values are active or inactive. Note that the status of the AppGroup should be updated via UpdateAppGroupRequest by setting the action as active or inactive. Corresponds to the JSON property status

Returns:

  • (String)


1824
1825
1826
# File 'lib/google/apis/apigee_v1/classes.rb', line 1824

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1831
1832
1833
1834
1835
1836
1837
1838
1839
1840
1841
1842
1843
# File 'lib/google/apis/apigee_v1/classes.rb', line 1831

def update!(**args)
  @app_group_id = args[:app_group_id] if args.key?(:app_group_id)
  @attributes = args[:attributes] if args.key?(:attributes)
  @channel_id = args[:channel_id] if args.key?(:channel_id)
  @channel_uri = args[:channel_uri] if args.key?(:channel_uri)
  @created_at = args[:created_at] if args.key?(:created_at)
  @display_name = args[:display_name] if args.key?(:display_name)
  @email = args[:email] if args.key?(:email)
  @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at)
  @name = args[:name] if args.key?(:name)
  @organization = args[:organization] if args.key?(:organization)
  @status = args[:status] if args.key?(:status)
end