Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1AppGroupApp
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1AppGroupApp
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Response for [GetAppGroupApp].[AppGroupApps.GetAppGroupApp], [ CreateAppGroupAppRequest].[AppGroupApp.CreateAppGroupAppRequest] and [ DeleteAppGroupApp].[AppGroupApp.DeleteAppGroupApp]
Instance Attribute Summary collapse
-
#api_products ⇒ Array<String>
List of API products associated with the AppGroup app.
-
#app_group ⇒ String
Immutable.
-
#app_id ⇒ String
Immutable.
-
#attributes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>
List of attributes for the AppGroup app.
-
#callback_url ⇒ String
Callback URL used by OAuth 2.0 authorization servers to communicate authorization codes back to AppGroup apps.
-
#created_at ⇒ Fixnum
Output only.
-
#credentials ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Credential>
Output only.
-
#key_expires_in ⇒ Fixnum
Immutable.
-
#last_modified_at ⇒ Fixnum
Output only.
-
#name ⇒ String
Immutable.
-
#scopes ⇒ Array<String>
Scopes to apply to the AppGroup app.
-
#status ⇒ String
Status of the App.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1AppGroupApp
constructor
A new instance of GoogleCloudApigeeV1AppGroupApp.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1AppGroupApp
Returns a new instance of GoogleCloudApigeeV1AppGroupApp.
1928 1929 1930 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1928 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_products ⇒ Array<String>
List of API products associated with the AppGroup app.
Corresponds to the JSON property apiProducts
1864 1865 1866 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1864 def api_products @api_products end |
#app_group ⇒ String
Immutable. Name of the parent AppGroup whose resource name format is of syntax
(organizations//appgroups/).
Corresponds to the JSON property appGroup
1870 1871 1872 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1870 def app_group @app_group end |
#app_id ⇒ String
Immutable. ID of the AppGroup app.
Corresponds to the JSON property appId
1875 1876 1877 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1875 def app_id @app_id end |
#attributes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>
List of attributes for the AppGroup app.
Corresponds to the JSON property attributes
1880 1881 1882 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1880 def attributes @attributes end |
#callback_url ⇒ String
Callback URL used by OAuth 2.0 authorization servers to communicate
authorization codes back to AppGroup apps.
Corresponds to the JSON property callbackUrl
1886 1887 1888 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1886 def callback_url @callback_url end |
#created_at ⇒ Fixnum
Output only. Time the AppGroup app was created in milliseconds since epoch.
Corresponds to the JSON property createdAt
1891 1892 1893 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1891 def created_at @created_at end |
#credentials ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Credential>
Output only. Set of credentials for the AppGroup app consisting of the
consumer key/secret pairs associated with the API products.
Corresponds to the JSON property credentials
1897 1898 1899 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1897 def credentials @credentials end |
#key_expires_in ⇒ Fixnum
Immutable. Expiration time, in seconds, for the consumer key that is generated
for the AppGroup app. If not set or left to the default value of -1, the API
key never expires. The expiration time can't be updated after it is set.
Corresponds to the JSON property keyExpiresIn
1904 1905 1906 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1904 def key_expires_in @key_expires_in end |
#last_modified_at ⇒ Fixnum
Output only. Time the AppGroup app was modified in milliseconds since epoch.
Corresponds to the JSON property lastModifiedAt
1909 1910 1911 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1909 def last_modified_at @last_modified_at end |
#name ⇒ String
Immutable. Name of the AppGroup app whose resource name format is of syntax (
organizations//appgroups//apps/*).
Corresponds to the JSON property name
1915 1916 1917 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1915 def name @name end |
#scopes ⇒ Array<String>
Scopes to apply to the AppGroup app. The specified scopes must already exist
for the API product that you associate with the AppGroup app.
Corresponds to the JSON property scopes
1921 1922 1923 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1921 def scopes @scopes end |
#status ⇒ String
Status of the App. Valid values include approved or revoked.
Corresponds to the JSON property status
1926 1927 1928 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1926 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1933 1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 1944 1945 1946 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1933 def update!(**args) @api_products = args[:api_products] if args.key?(:api_products) @app_group = args[:app_group] if args.key?(:app_group) @app_id = args[:app_id] if args.key?(:app_id) @attributes = args[:attributes] if args.key?(:attributes) @callback_url = args[:callback_url] if args.key?(:callback_url) @created_at = args[:created_at] if args.key?(:created_at) @credentials = args[:credentials] if args.key?(:credentials) @key_expires_in = args[:key_expires_in] if args.key?(:key_expires_in) @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at) @name = args[:name] if args.key?(:name) @scopes = args[:scopes] if args.key?(:scopes) @status = args[:status] if args.key?(:status) end |