Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1AppGroupApp

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Response for [GetAppGroupApp].[AppGroupApps.GetAppGroupApp], [ CreateAppGroupAppRequest].[AppGroupApp.CreateAppGroupAppRequest] and [ DeleteAppGroupApp].[AppGroupApp.DeleteAppGroupApp]

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1AppGroupApp

Returns a new instance of GoogleCloudApigeeV1AppGroupApp.



1968
1969
1970
# File 'lib/google/apis/apigee_v1/classes.rb', line 1968

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_productsArray<String>

List of API products associated with the AppGroup app. Corresponds to the JSON property apiProducts

Returns:

  • (Array<String>)


1904
1905
1906
# File 'lib/google/apis/apigee_v1/classes.rb', line 1904

def api_products
  @api_products
end

#app_groupString

Immutable. Name of the parent AppGroup whose resource name format is of syntax (organizations//appgroups/). Corresponds to the JSON property appGroup

Returns:

  • (String)


1910
1911
1912
# File 'lib/google/apis/apigee_v1/classes.rb', line 1910

def app_group
  @app_group
end

#app_idString

Immutable. ID of the AppGroup app. Corresponds to the JSON property appId

Returns:

  • (String)


1915
1916
1917
# File 'lib/google/apis/apigee_v1/classes.rb', line 1915

def app_id
  @app_id
end

#attributesArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>

List of attributes for the AppGroup app. Corresponds to the JSON property attributes



1920
1921
1922
# File 'lib/google/apis/apigee_v1/classes.rb', line 1920

def attributes
  @attributes
end

#callback_urlString

Callback URL used by OAuth 2.0 authorization servers to communicate authorization codes back to AppGroup apps. Corresponds to the JSON property callbackUrl

Returns:

  • (String)


1926
1927
1928
# File 'lib/google/apis/apigee_v1/classes.rb', line 1926

def callback_url
  @callback_url
end

#created_atFixnum

Output only. Time the AppGroup app was created in milliseconds since epoch. Corresponds to the JSON property createdAt

Returns:

  • (Fixnum)


1931
1932
1933
# File 'lib/google/apis/apigee_v1/classes.rb', line 1931

def created_at
  @created_at
end

#credentialsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Credential>

Output only. Set of credentials for the AppGroup app consisting of the consumer key/secret pairs associated with the API products. Corresponds to the JSON property credentials



1937
1938
1939
# File 'lib/google/apis/apigee_v1/classes.rb', line 1937

def credentials
  @credentials
end

#key_expires_inFixnum

Immutable. Expiration time, in seconds, for the consumer key that is generated for the AppGroup app. If not set or left to the default value of -1, the API key never expires. The expiration time can't be updated after it is set. Corresponds to the JSON property keyExpiresIn

Returns:

  • (Fixnum)


1944
1945
1946
# File 'lib/google/apis/apigee_v1/classes.rb', line 1944

def key_expires_in
  @key_expires_in
end

#last_modified_atFixnum

Output only. Time the AppGroup app was modified in milliseconds since epoch. Corresponds to the JSON property lastModifiedAt

Returns:

  • (Fixnum)


1949
1950
1951
# File 'lib/google/apis/apigee_v1/classes.rb', line 1949

def last_modified_at
  @last_modified_at
end

#nameString

Immutable. Name of the AppGroup app whose resource name format is of syntax ( organizations//appgroups//apps/*). Corresponds to the JSON property name

Returns:

  • (String)


1955
1956
1957
# File 'lib/google/apis/apigee_v1/classes.rb', line 1955

def name
  @name
end

#scopesArray<String>

Scopes to apply to the AppGroup app. The specified scopes must already exist for the API product that you associate with the AppGroup app. Corresponds to the JSON property scopes

Returns:

  • (Array<String>)


1961
1962
1963
# File 'lib/google/apis/apigee_v1/classes.rb', line 1961

def scopes
  @scopes
end

#statusString

Status of the App. Valid values include approved or revoked. Corresponds to the JSON property status

Returns:

  • (String)


1966
1967
1968
# File 'lib/google/apis/apigee_v1/classes.rb', line 1966

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1973
1974
1975
1976
1977
1978
1979
1980
1981
1982
1983
1984
1985
1986
# File 'lib/google/apis/apigee_v1/classes.rb', line 1973

def update!(**args)
  @api_products = args[:api_products] if args.key?(:api_products)
  @app_group = args[:app_group] if args.key?(:app_group)
  @app_id = args[:app_id] if args.key?(:app_id)
  @attributes = args[:attributes] if args.key?(:attributes)
  @callback_url = args[:callback_url] if args.key?(:callback_url)
  @created_at = args[:created_at] if args.key?(:created_at)
  @credentials = args[:credentials] if args.key?(:credentials)
  @key_expires_in = args[:key_expires_in] if args.key?(:key_expires_in)
  @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at)
  @name = args[:name] if args.key?(:name)
  @scopes = args[:scopes] if args.key?(:scopes)
  @status = args[:status] if args.key?(:status)
end