Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1AppGroupAppKey
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1AppGroupAppKey
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
AppGroupAppKey contains all the information associated with the credentials.
Instance Attribute Summary collapse
-
#api_products ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiProductAssociation>
Output only.
-
#attributes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>
List of attributes associated with the credential.
-
#consumer_key ⇒ String
Immutable.
-
#consumer_secret ⇒ String
Secret key.
-
#expires_at ⇒ Fixnum
Output only.
-
#expires_in_seconds ⇒ Fixnum
Immutable.
-
#issued_at ⇒ Fixnum
Output only.
-
#scopes ⇒ Array<String>
Scopes to apply to the app.
-
#status ⇒ String
Status of the credential.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1AppGroupAppKey
constructor
A new instance of GoogleCloudApigeeV1AppGroupAppKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1AppGroupAppKey
Returns a new instance of GoogleCloudApigeeV1AppGroupAppKey.
2012 2013 2014 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2012 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_products ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiProductAssociation>
Output only. List of API products and its status for which the credential can
be used. Note: Use UpdateAppGroupAppKeyApiProductRequest API to make the
association after the consumer key and secret are created.
Corresponds to the JSON property apiProducts
1967 1968 1969 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1967 def api_products @api_products end |
#attributes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>
List of attributes associated with the credential.
Corresponds to the JSON property attributes
1972 1973 1974 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1972 def attributes @attributes end |
#consumer_key ⇒ String
Immutable. Consumer key.
Corresponds to the JSON property consumerKey
1977 1978 1979 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1977 def consumer_key @consumer_key end |
#consumer_secret ⇒ String
Secret key.
Corresponds to the JSON property consumerSecret
1982 1983 1984 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1982 def consumer_secret @consumer_secret end |
#expires_at ⇒ Fixnum
Output only. Time the AppGroup app expires in milliseconds since epoch.
Corresponds to the JSON property expiresAt
1987 1988 1989 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1987 def expires_at @expires_at end |
#expires_in_seconds ⇒ Fixnum
Immutable. Expiration time, in seconds, for the consumer key. If not set or
left to the default value of -1, the API key never expires. The expiration
time can't be updated after it is set.
Corresponds to the JSON property expiresInSeconds
1994 1995 1996 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1994 def expires_in_seconds @expires_in_seconds end |
#issued_at ⇒ Fixnum
Output only. Time the AppGroup app was created in milliseconds since epoch.
Corresponds to the JSON property issuedAt
1999 2000 2001 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1999 def issued_at @issued_at end |
#scopes ⇒ Array<String>
Scopes to apply to the app. The specified scope names must already be defined
for the API product that you associate with the app.
Corresponds to the JSON property scopes
2005 2006 2007 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2005 def scopes @scopes end |
#status ⇒ String
Status of the credential. Valid values include approved or revoked.
Corresponds to the JSON property status
2010 2011 2012 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2010 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2017 2018 2019 2020 2021 2022 2023 2024 2025 2026 2027 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2017 def update!(**args) @api_products = args[:api_products] if args.key?(:api_products) @attributes = args[:attributes] if args.key?(:attributes) @consumer_key = args[:consumer_key] if args.key?(:consumer_key) @consumer_secret = args[:consumer_secret] if args.key?(:consumer_secret) @expires_at = args[:expires_at] if args.key?(:expires_at) @expires_in_seconds = args[:expires_in_seconds] if args.key?(:expires_in_seconds) @issued_at = args[:issued_at] if args.key?(:issued_at) @scopes = args[:scopes] if args.key?(:scopes) @status = args[:status] if args.key?(:status) end |