Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1AppGroupAppKey

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

AppGroupAppKey contains all the information associated with the credentials.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1AppGroupAppKey

Returns a new instance of GoogleCloudApigeeV1AppGroupAppKey.



2003
2004
2005
# File 'lib/google/apis/apigee_v1/classes.rb', line 2003

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_productsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiProductAssociation>

Output only. List of API products and its status for which the credential can be used. Note: Use UpdateAppGroupAppKeyApiProductRequest API to make the association after the consumer key and secret are created. Corresponds to the JSON property apiProducts



1958
1959
1960
# File 'lib/google/apis/apigee_v1/classes.rb', line 1958

def api_products
  @api_products
end

#attributesArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>

List of attributes associated with the credential. Corresponds to the JSON property attributes



1963
1964
1965
# File 'lib/google/apis/apigee_v1/classes.rb', line 1963

def attributes
  @attributes
end

#consumer_keyString

Immutable. Consumer key. Corresponds to the JSON property consumerKey

Returns:

  • (String)


1968
1969
1970
# File 'lib/google/apis/apigee_v1/classes.rb', line 1968

def consumer_key
  @consumer_key
end

#consumer_secretString

Secret key. Corresponds to the JSON property consumerSecret

Returns:

  • (String)


1973
1974
1975
# File 'lib/google/apis/apigee_v1/classes.rb', line 1973

def consumer_secret
  @consumer_secret
end

#expires_atFixnum

Output only. Time the AppGroup app expires in milliseconds since epoch. Corresponds to the JSON property expiresAt

Returns:

  • (Fixnum)


1978
1979
1980
# File 'lib/google/apis/apigee_v1/classes.rb', line 1978

def expires_at
  @expires_at
end

#expires_in_secondsFixnum

Immutable. Expiration time, in seconds, for the consumer key. If not set or left to the default value of -1, the API key never expires. The expiration time can't be updated after it is set. Corresponds to the JSON property expiresInSeconds

Returns:

  • (Fixnum)


1985
1986
1987
# File 'lib/google/apis/apigee_v1/classes.rb', line 1985

def expires_in_seconds
  @expires_in_seconds
end

#issued_atFixnum

Output only. Time the AppGroup app was created in milliseconds since epoch. Corresponds to the JSON property issuedAt

Returns:

  • (Fixnum)


1990
1991
1992
# File 'lib/google/apis/apigee_v1/classes.rb', line 1990

def issued_at
  @issued_at
end

#scopesArray<String>

Scopes to apply to the app. The specified scope names must already be defined for the API product that you associate with the app. Corresponds to the JSON property scopes

Returns:

  • (Array<String>)


1996
1997
1998
# File 'lib/google/apis/apigee_v1/classes.rb', line 1996

def scopes
  @scopes
end

#statusString

Status of the credential. Valid values include approved or revoked. Corresponds to the JSON property status

Returns:

  • (String)


2001
2002
2003
# File 'lib/google/apis/apigee_v1/classes.rb', line 2001

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2008
2009
2010
2011
2012
2013
2014
2015
2016
2017
2018
# File 'lib/google/apis/apigee_v1/classes.rb', line 2008

def update!(**args)
  @api_products = args[:api_products] if args.key?(:api_products)
  @attributes = args[:attributes] if args.key?(:attributes)
  @consumer_key = args[:consumer_key] if args.key?(:consumer_key)
  @consumer_secret = args[:consumer_secret] if args.key?(:consumer_secret)
  @expires_at = args[:expires_at] if args.key?(:expires_at)
  @expires_in_seconds = args[:expires_in_seconds] if args.key?(:expires_in_seconds)
  @issued_at = args[:issued_at] if args.key?(:issued_at)
  @scopes = args[:scopes] if args.key?(:scopes)
  @status = args[:status] if args.key?(:status)
end