Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1AppGroupAppKey
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1AppGroupAppKey
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
AppGroupAppKey contains all the information associated with the credentials.
Instance Attribute Summary collapse
-
#api_products ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiProductAssociation>
Output only.
-
#attributes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>
List of attributes associated with the credential.
-
#consumer_key ⇒ String
Immutable.
-
#consumer_secret ⇒ String
Secret key.
-
#expires_at ⇒ Fixnum
Output only.
-
#expires_in_seconds ⇒ Fixnum
Immutable.
-
#issued_at ⇒ Fixnum
Output only.
-
#scopes ⇒ Array<String>
Scopes to apply to the app.
-
#status ⇒ String
Status of the credential.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1AppGroupAppKey
constructor
A new instance of GoogleCloudApigeeV1AppGroupAppKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1AppGroupAppKey
Returns a new instance of GoogleCloudApigeeV1AppGroupAppKey.
2043 2044 2045 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2043 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_products ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiProductAssociation>
Output only. List of API products and its status for which the credential can
be used. Note: Use UpdateAppGroupAppKeyApiProductRequest API to make the
association after the consumer key and secret are created.
Corresponds to the JSON property apiProducts
1998 1999 2000 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 1998 def api_products @api_products end |
#attributes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>
List of attributes associated with the credential.
Corresponds to the JSON property attributes
2003 2004 2005 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2003 def attributes @attributes end |
#consumer_key ⇒ String
Immutable. Consumer key.
Corresponds to the JSON property consumerKey
2008 2009 2010 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2008 def consumer_key @consumer_key end |
#consumer_secret ⇒ String
Secret key.
Corresponds to the JSON property consumerSecret
2013 2014 2015 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2013 def consumer_secret @consumer_secret end |
#expires_at ⇒ Fixnum
Output only. Time the AppGroup app expires in milliseconds since epoch.
Corresponds to the JSON property expiresAt
2018 2019 2020 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2018 def expires_at @expires_at end |
#expires_in_seconds ⇒ Fixnum
Immutable. Expiration time, in seconds, for the consumer key. If not set or
left to the default value of -1, the API key never expires. The expiration
time can't be updated after it is set.
Corresponds to the JSON property expiresInSeconds
2025 2026 2027 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2025 def expires_in_seconds @expires_in_seconds end |
#issued_at ⇒ Fixnum
Output only. Time the AppGroup app was created in milliseconds since epoch.
Corresponds to the JSON property issuedAt
2030 2031 2032 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2030 def issued_at @issued_at end |
#scopes ⇒ Array<String>
Scopes to apply to the app. The specified scope names must already be defined
for the API product that you associate with the app.
Corresponds to the JSON property scopes
2036 2037 2038 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2036 def scopes @scopes end |
#status ⇒ String
Status of the credential. Valid values include approved or revoked.
Corresponds to the JSON property status
2041 2042 2043 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2041 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2048 2049 2050 2051 2052 2053 2054 2055 2056 2057 2058 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2048 def update!(**args) @api_products = args[:api_products] if args.key?(:api_products) @attributes = args[:attributes] if args.key?(:attributes) @consumer_key = args[:consumer_key] if args.key?(:consumer_key) @consumer_secret = args[:consumer_secret] if args.key?(:consumer_secret) @expires_at = args[:expires_at] if args.key?(:expires_at) @expires_in_seconds = args[:expires_in_seconds] if args.key?(:expires_in_seconds) @issued_at = args[:issued_at] if args.key?(:issued_at) @scopes = args[:scopes] if args.key?(:scopes) @status = args[:status] if args.key?(:status) end |