Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1AppGroupAppKey

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

AppGroupAppKey contains all the information associated with the credentials.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1AppGroupAppKey

Returns a new instance of GoogleCloudApigeeV1AppGroupAppKey.



1994
1995
1996
# File 'lib/google/apis/apigee_v1/classes.rb', line 1994

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_productsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiProductAssociation>

Output only. List of API products and its status for which the credential can be used. Note: Use UpdateAppGroupAppKeyApiProductRequest API to make the association after the consumer key and secret are created. Corresponds to the JSON property apiProducts



1949
1950
1951
# File 'lib/google/apis/apigee_v1/classes.rb', line 1949

def api_products
  @api_products
end

#attributesArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>

List of attributes associated with the credential. Corresponds to the JSON property attributes



1954
1955
1956
# File 'lib/google/apis/apigee_v1/classes.rb', line 1954

def attributes
  @attributes
end

#consumer_keyString

Immutable. Consumer key. Corresponds to the JSON property consumerKey

Returns:

  • (String)


1959
1960
1961
# File 'lib/google/apis/apigee_v1/classes.rb', line 1959

def consumer_key
  @consumer_key
end

#consumer_secretString

Secret key. Corresponds to the JSON property consumerSecret

Returns:

  • (String)


1964
1965
1966
# File 'lib/google/apis/apigee_v1/classes.rb', line 1964

def consumer_secret
  @consumer_secret
end

#expires_atFixnum

Output only. Time the AppGroup app expires in milliseconds since epoch. Corresponds to the JSON property expiresAt

Returns:

  • (Fixnum)


1969
1970
1971
# File 'lib/google/apis/apigee_v1/classes.rb', line 1969

def expires_at
  @expires_at
end

#expires_in_secondsFixnum

Immutable. Expiration time, in seconds, for the consumer key. If not set or left to the default value of -1, the API key never expires. The expiration time can't be updated after it is set. Corresponds to the JSON property expiresInSeconds

Returns:

  • (Fixnum)


1976
1977
1978
# File 'lib/google/apis/apigee_v1/classes.rb', line 1976

def expires_in_seconds
  @expires_in_seconds
end

#issued_atFixnum

Output only. Time the AppGroup app was created in milliseconds since epoch. Corresponds to the JSON property issuedAt

Returns:

  • (Fixnum)


1981
1982
1983
# File 'lib/google/apis/apigee_v1/classes.rb', line 1981

def issued_at
  @issued_at
end

#scopesArray<String>

Scopes to apply to the app. The specified scope names must already be defined for the API product that you associate with the app. Corresponds to the JSON property scopes

Returns:

  • (Array<String>)


1987
1988
1989
# File 'lib/google/apis/apigee_v1/classes.rb', line 1987

def scopes
  @scopes
end

#statusString

Status of the credential. Valid values include approved or revoked. Corresponds to the JSON property status

Returns:

  • (String)


1992
1993
1994
# File 'lib/google/apis/apigee_v1/classes.rb', line 1992

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1999
2000
2001
2002
2003
2004
2005
2006
2007
2008
2009
# File 'lib/google/apis/apigee_v1/classes.rb', line 1999

def update!(**args)
  @api_products = args[:api_products] if args.key?(:api_products)
  @attributes = args[:attributes] if args.key?(:attributes)
  @consumer_key = args[:consumer_key] if args.key?(:consumer_key)
  @consumer_secret = args[:consumer_secret] if args.key?(:consumer_secret)
  @expires_at = args[:expires_at] if args.key?(:expires_at)
  @expires_in_seconds = args[:expires_in_seconds] if args.key?(:expires_in_seconds)
  @issued_at = args[:issued_at] if args.key?(:issued_at)
  @scopes = args[:scopes] if args.key?(:scopes)
  @status = args[:status] if args.key?(:status)
end