Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1AppGroupBalanceWallet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Wallet used to manage an account balance for a particular currency.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1AppGroupBalanceWallet

Returns a new instance of GoogleCloudApigeeV1AppGroupBalanceWallet.



2047
2048
2049
# File 'lib/google/apis/apigee_v1/classes.rb', line 2047

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#balanceGoogle::Apis::ApigeeV1::GoogleTypeMoney

Represents an amount of money with its currency type. Corresponds to the JSON property balance



2039
2040
2041
# File 'lib/google/apis/apigee_v1/classes.rb', line 2039

def balance
  @balance
end

#last_credit_timeFixnum

Output only. Time at which the AppGroup last added credit to the account in milliseconds since epoch. Corresponds to the JSON property lastCreditTime

Returns:

  • (Fixnum)


2045
2046
2047
# File 'lib/google/apis/apigee_v1/classes.rb', line 2045

def last_credit_time
  @last_credit_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2052
2053
2054
2055
# File 'lib/google/apis/apigee_v1/classes.rb', line 2052

def update!(**args)
  @balance = args[:balance] if args.key?(:balance)
  @last_credit_time = args[:last_credit_time] if args.key?(:last_credit_time)
end