Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1AppGroupSubscription

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

AppGroup Subscription details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1AppGroupSubscription

Returns a new instance of GoogleCloudApigeeV1AppGroupSubscription.



2116
2117
2118
# File 'lib/google/apis/apigee_v1/classes.rb', line 2116

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#apiproductString

Required. Name of the API product for which the appgroup is purchasing a subscription. Corresponds to the JSON property apiproduct

Returns:

  • (String)


2085
2086
2087
# File 'lib/google/apis/apigee_v1/classes.rb', line 2085

def apiproduct
  @apiproduct
end

#created_atFixnum

Output only. Time when the API product subscription was created in milliseconds since epoch. Corresponds to the JSON property createdAt

Returns:

  • (Fixnum)


2091
2092
2093
# File 'lib/google/apis/apigee_v1/classes.rb', line 2091

def created_at
  @created_at
end

#end_timeFixnum

Output only. Time when the API product subscription ends in milliseconds since epoch. Corresponds to the JSON property endTime

Returns:

  • (Fixnum)


2097
2098
2099
# File 'lib/google/apis/apigee_v1/classes.rb', line 2097

def end_time
  @end_time
end

#last_modified_atFixnum

Output only. Time when the API product subscription was last modified in milliseconds since epoch. Corresponds to the JSON property lastModifiedAt

Returns:

  • (Fixnum)


2103
2104
2105
# File 'lib/google/apis/apigee_v1/classes.rb', line 2103

def last_modified_at
  @last_modified_at
end

#nameString

Output only. Name of the API product subscription. Corresponds to the JSON property name

Returns:

  • (String)


2108
2109
2110
# File 'lib/google/apis/apigee_v1/classes.rb', line 2108

def name
  @name
end

#start_timeFixnum

Output only. Time when the API product subscription starts in milliseconds since epoch. Corresponds to the JSON property startTime

Returns:

  • (Fixnum)


2114
2115
2116
# File 'lib/google/apis/apigee_v1/classes.rb', line 2114

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2121
2122
2123
2124
2125
2126
2127
2128
# File 'lib/google/apis/apigee_v1/classes.rb', line 2121

def update!(**args)
  @apiproduct = args[:apiproduct] if args.key?(:apiproduct)
  @created_at = args[:created_at] if args.key?(:created_at)
  @end_time = args[:end_time] if args.key?(:end_time)
  @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at)
  @name = args[:name] if args.key?(:name)
  @start_time = args[:start_time] if args.key?(:start_time)
end