Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ArchiveDeployment
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1ArchiveDeployment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Archive Deployment information.
Instance Attribute Summary collapse
-
#created_at ⇒ Fixnum
Output only.
-
#gcs_uri ⇒ String
Input only.
-
#labels ⇒ Hash<String,String>
User-supplied key-value pairs used to organize ArchiveDeployments.
-
#name ⇒ String
Name of the Archive Deployment in the following format:
organizations/org/ environments/env/archiveDeployments/id``. -
#operation ⇒ String
Output only.
-
#updated_at ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1ArchiveDeployment
constructor
A new instance of GoogleCloudApigeeV1ArchiveDeployment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1ArchiveDeployment
Returns a new instance of GoogleCloudApigeeV1ArchiveDeployment.
2176 2177 2178 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2176 def initialize(**args) update!(**args) end |
Instance Attribute Details
#created_at ⇒ Fixnum
Output only. The time at which the Archive Deployment was created in
milliseconds since the epoch.
Corresponds to the JSON property createdAt
2139 2140 2141 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2139 def created_at @created_at end |
#gcs_uri ⇒ String
Input only. The Google Cloud Storage signed URL returned from
GenerateUploadUrl and used to upload the Archive zip file.
Corresponds to the JSON property gcsUri
2145 2146 2147 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2145 def gcs_uri @gcs_uri end |
#labels ⇒ Hash<String,String>
User-supplied key-value pairs used to organize ArchiveDeployments. Label keys
must be between 1 and 63 characters long, have a UTF-8 encoding of maximum 128
bytes, and must conform to the following PCRE regular expression: \pLl\pLo
0,62 Label values must be between 1 and 63 characters long, have a UTF-8
encoding of maximum 128 bytes, and must conform to the following PCRE regular
expression: [\pLl\pLo\pN_-]0,63 No more than 64 labels can be
associated with a given store.
Corresponds to the JSON property labels
2156 2157 2158 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2156 def labels @labels end |
#name ⇒ String
Name of the Archive Deployment in the following format: organizations/org/
environments/env/archiveDeployments/id`.
Corresponds to the JSON propertyname`
2162 2163 2164 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2162 def name @name end |
#operation ⇒ String
Output only. A reference to the LRO that created this Archive Deployment in
the following format: organizations/org/operations/id`
Corresponds to the JSON propertyoperation`
2168 2169 2170 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2168 def operation @operation end |
#updated_at ⇒ Fixnum
Output only. The time at which the Archive Deployment was updated in
milliseconds since the epoch.
Corresponds to the JSON property updatedAt
2174 2175 2176 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2174 def updated_at @updated_at end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2181 2182 2183 2184 2185 2186 2187 2188 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2181 def update!(**args) @created_at = args[:created_at] if args.key?(:created_at) @gcs_uri = args[:gcs_uri] if args.key?(:gcs_uri) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @operation = args[:operation] if args.key?(:operation) @updated_at = args[:updated_at] if args.key?(:updated_at) end |