Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1AsyncQuery

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1AsyncQuery

Returns a new instance of GoogleCloudApigeeV1AsyncQuery.



2282
2283
2284
# File 'lib/google/apis/apigee_v1/classes.rb', line 2282

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createdString

Creation time of the query. Corresponds to the JSON property created

Returns:

  • (String)


2217
2218
2219
# File 'lib/google/apis/apigee_v1/classes.rb', line 2217

def created
  @created
end

#envgroup_hostnameString

Hostname is available only when query is executed at host level. Corresponds to the JSON property envgroupHostname

Returns:

  • (String)


2222
2223
2224
# File 'lib/google/apis/apigee_v1/classes.rb', line 2222

def envgroup_hostname
  @envgroup_hostname
end

#errorString

Error is set when query fails. Corresponds to the JSON property error

Returns:

  • (String)


2227
2228
2229
# File 'lib/google/apis/apigee_v1/classes.rb', line 2227

def error
  @error
end

#execution_timeString

ExecutionTime is available only after the query is completed. Corresponds to the JSON property executionTime

Returns:

  • (String)


2232
2233
2234
# File 'lib/google/apis/apigee_v1/classes.rb', line 2232

def execution_time
  @execution_time
end

#nameString

Asynchronous Query Name. Corresponds to the JSON property name

Returns:

  • (String)


2237
2238
2239
# File 'lib/google/apis/apigee_v1/classes.rb', line 2237

def name
  @name
end

#query_paramsGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1QueryMetadata

Contains information like metrics, dimenstions etc of the AsyncQuery. Corresponds to the JSON property queryParams



2242
2243
2244
# File 'lib/google/apis/apigee_v1/classes.rb', line 2242

def query_params
  @query_params
end

#report_definition_idString

Asynchronous Report ID. Corresponds to the JSON property reportDefinitionId

Returns:

  • (String)


2247
2248
2249
# File 'lib/google/apis/apigee_v1/classes.rb', line 2247

def report_definition_id
  @report_definition_id
end

#resultGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1AsyncQueryResult

Result is available only after the query is completed. Corresponds to the JSON property result



2252
2253
2254
# File 'lib/google/apis/apigee_v1/classes.rb', line 2252

def result
  @result
end

#result_file_sizeString

ResultFileSize is available only after the query is completed. Corresponds to the JSON property resultFileSize

Returns:

  • (String)


2257
2258
2259
# File 'lib/google/apis/apigee_v1/classes.rb', line 2257

def result_file_size
  @result_file_size
end

#result_rowsFixnum

ResultRows is available only after the query is completed. Corresponds to the JSON property resultRows

Returns:

  • (Fixnum)


2262
2263
2264
# File 'lib/google/apis/apigee_v1/classes.rb', line 2262

def result_rows
  @result_rows
end

#selfString

Self link of the query. Example: /organizations/myorg/environments/myenv/ queries/9cfc0d85-0f30-46d6-ae6f-318d0cb961bd or following format if query is running at host level: /organizations/myorg/hostQueries/9cfc0d85-0f30-46d6- ae6f-318d0cb961bd Corresponds to the JSON property self

Returns:

  • (String)


2270
2271
2272
# File 'lib/google/apis/apigee_v1/classes.rb', line 2270

def self
  @self
end

#stateString

Query state could be "enqueued", "running", "completed", "failed". Corresponds to the JSON property state

Returns:

  • (String)


2275
2276
2277
# File 'lib/google/apis/apigee_v1/classes.rb', line 2275

def state
  @state
end

#updatedString

Last updated timestamp for the query. Corresponds to the JSON property updated

Returns:

  • (String)


2280
2281
2282
# File 'lib/google/apis/apigee_v1/classes.rb', line 2280

def updated
  @updated
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
# File 'lib/google/apis/apigee_v1/classes.rb', line 2287

def update!(**args)
  @created = args[:created] if args.key?(:created)
  @envgroup_hostname = args[:envgroup_hostname] if args.key?(:envgroup_hostname)
  @error = args[:error] if args.key?(:error)
  @execution_time = args[:execution_time] if args.key?(:execution_time)
  @name = args[:name] if args.key?(:name)
  @query_params = args[:query_params] if args.key?(:query_params)
  @report_definition_id = args[:report_definition_id] if args.key?(:report_definition_id)
  @result = args[:result] if args.key?(:result)
  @result_file_size = args[:result_file_size] if args.key?(:result_file_size)
  @result_rows = args[:result_rows] if args.key?(:result_rows)
  @self = args[:self] if args.key?(:self)
  @state = args[:state] if args.key?(:state)
  @updated = args[:updated] if args.key?(:updated)
end