Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1AsyncQueryResultView
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1AsyncQueryResultView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Instance Attribute Summary collapse
-
#code ⇒ Fixnum
Error code when there is a failure.
-
#error ⇒ String
Error message when there is a failure.
-
#metadata ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1QueryMetadata
Metadata contains information like metrics, dimenstions etc of the AsyncQuery.
-
#rows ⇒ Array<Object>
Rows of query result.
-
#state ⇒ String
State of retrieving ResultView.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1AsyncQueryResultView
constructor
A new instance of GoogleCloudApigeeV1AsyncQueryResultView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1AsyncQueryResultView
Returns a new instance of GoogleCloudApigeeV1AsyncQueryResultView.
2362 2363 2364 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2362 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ Fixnum
Error code when there is a failure.
Corresponds to the JSON property code
2339 2340 2341 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2339 def code @code end |
#error ⇒ String
Error message when there is a failure.
Corresponds to the JSON property error
2344 2345 2346 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2344 def error @error end |
#metadata ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1QueryMetadata
Metadata contains information like metrics, dimenstions etc of the AsyncQuery.
Corresponds to the JSON property metadata
2349 2350 2351 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2349 def @metadata end |
#rows ⇒ Array<Object>
Rows of query result. Each row is a JSON object. Example: sum(message_count):
1, developer_app: "(not set)",…
Corresponds to the JSON property rows
2355 2356 2357 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2355 def rows @rows end |
#state ⇒ String
State of retrieving ResultView.
Corresponds to the JSON property state
2360 2361 2362 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2360 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2367 2368 2369 2370 2371 2372 2373 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2367 def update!(**args) @code = args[:code] if args.key?(:code) @error = args[:error] if args.key?(:error) @metadata = args[:metadata] if args.key?(:metadata) @rows = args[:rows] if args.key?(:rows) @state = args[:state] if args.key?(:state) end |