Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Request for BatchComputeSecurityAssessmentResults.
Instance Attribute Summary collapse
-
#api_hub_apis ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequestApiHubApiArray
Message for the array of API Hub APIs.
-
#api_hub_gateways ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequestApiHubGatewayArray
Message for the array of API Hub Gateways.
-
#include ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequestResourceArray
Message for the array of resources.
-
#include_all_resources ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequestIncludeAll
Message for include_all_resources option.
-
#page_size ⇒ Fixnum
Optional.
-
#page_token ⇒ String
Optional.
-
#profile ⇒ String
Required.
-
#scope ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequest
constructor
A new instance of GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequest
Returns a new instance of GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequest.
2519 2520 2521 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2519 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_hub_apis ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequestApiHubApiArray
Message for the array of API Hub APIs.
Corresponds to the JSON property apiHubApis
2476 2477 2478 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2476 def api_hub_apis @api_hub_apis end |
#api_hub_gateways ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequestApiHubGatewayArray
Message for the array of API Hub Gateways.
Corresponds to the JSON property apiHubGateways
2481 2482 2483 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2481 def api_hub_gateways @api_hub_gateways end |
#include ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequestResourceArray
Message for the array of resources. For Apigee, the proxies are resources.
Corresponds to the JSON property include
2486 2487 2488 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2486 def include @include end |
#include_all_resources ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequestIncludeAll
Message for include_all_resources option.
Corresponds to the JSON property includeAllResources
2491 2492 2493 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2491 def include_all_resources @include_all_resources end |
#page_size ⇒ Fixnum
Optional. The maximum number of results to return. The service may return
fewer than this value. If unspecified, at most 50 results will be returned.
Corresponds to the JSON property pageSize
2497 2498 2499 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2497 def page_size @page_size end |
#page_token ⇒ String
Optional. A page token, received from a previous
BatchComputeSecurityAssessmentResults call. Provide this to retrieve the
subsequent page.
Corresponds to the JSON property pageToken
2504 2505 2506 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2504 def page_token @page_token end |
#profile ⇒ String
Required. Name of the profile that is used for computation.
Corresponds to the JSON property profile
2509 2510 2511 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2509 def profile @profile end |
#scope ⇒ String
Optional. Scope of the resources for the computation. When computing scores
for Apigee proxies, the scope should be set to the environment of the
resources. When computing scores for API Hub deployments, api_hub_scope should
be set instead.
Corresponds to the JSON property scope
2517 2518 2519 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2517 def scope @scope end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2524 2525 2526 2527 2528 2529 2530 2531 2532 2533 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2524 def update!(**args) @api_hub_apis = args[:api_hub_apis] if args.key?(:api_hub_apis) @api_hub_gateways = args[:api_hub_gateways] if args.key?(:api_hub_gateways) @include = args[:include] if args.key?(:include) @include_all_resources = args[:include_all_resources] if args.key?(:include_all_resources) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @profile = args[:profile] if args.key?(:profile) @scope = args[:scope] if args.key?(:scope) end |