Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Response for BatchComputeSecurityAssessmentResults.
Instance Attribute Summary collapse
-
#assessment_time ⇒ String
The time of the assessment api call.
-
#next_page_token ⇒ String
A token that can be sent as
page_tokento retrieve the next page. -
#security_assessment_results ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResult>
Default sort order is by resource name in alphabetic order.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsResponse
constructor
A new instance of GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsResponse
Returns a new instance of GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsResponse.
2615 2616 2617 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2615 def initialize(**args) update!(**args) end |
Instance Attribute Details
#assessment_time ⇒ String
The time of the assessment api call.
Corresponds to the JSON property assessmentTime
2602 2603 2604 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2602 def assessment_time @assessment_time end |
#next_page_token ⇒ String
A token that can be sent as page_token to retrieve the next page. If this
field is blank, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
2608 2609 2610 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2608 def next_page_token @next_page_token end |
#security_assessment_results ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResult>
Default sort order is by resource name in alphabetic order.
Corresponds to the JSON property securityAssessmentResults
2613 2614 2615 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2613 def security_assessment_results @security_assessment_results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2620 2621 2622 2623 2624 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2620 def update!(**args) @assessment_time = args[:assessment_time] if args.key?(:assessment_time) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @security_assessment_results = args[:security_assessment_results] if args.key?(:security_assessment_results) end |