Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1CanaryEvaluation
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1CanaryEvaluation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
CanaryEvaluation represents the canary analysis between two versions of the runtime that is serving requests.
Instance Attribute Summary collapse
-
#control ⇒ String
Required.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Required.
-
#metric_labels ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1CanaryEvaluationMetricLabels
Labels that can be used to filter Apigee metrics.
-
#name ⇒ String
Output only.
-
#start_time ⇒ String
Required.
-
#state ⇒ String
Output only.
-
#treatment ⇒ String
Required.
-
#verdict ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1CanaryEvaluation
constructor
A new instance of GoogleCloudApigeeV1CanaryEvaluation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1CanaryEvaluation
Returns a new instance of GoogleCloudApigeeV1CanaryEvaluation.
2757 2758 2759 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2757 def initialize(**args) update!(**args) end |
Instance Attribute Details
#control ⇒ String
Required. The stable version that is serving requests.
Corresponds to the JSON property control
2714 2715 2716 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2714 def control @control end |
#create_time ⇒ String
Output only. Create time of the canary evaluation.
Corresponds to the JSON property createTime
2719 2720 2721 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2719 def create_time @create_time end |
#end_time ⇒ String
Required. End time for the evaluation's analysis.
Corresponds to the JSON property endTime
2724 2725 2726 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2724 def end_time @end_time end |
#metric_labels ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1CanaryEvaluationMetricLabels
Labels that can be used to filter Apigee metrics.
Corresponds to the JSON property metricLabels
2729 2730 2731 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2729 def metric_labels @metric_labels end |
#name ⇒ String
Output only. Name of the canary evalution.
Corresponds to the JSON property name
2734 2735 2736 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2734 def name @name end |
#start_time ⇒ String
Required. Start time for the canary evaluation's analysis.
Corresponds to the JSON property startTime
2739 2740 2741 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2739 def start_time @start_time end |
#state ⇒ String
Output only. The current state of the canary evaluation.
Corresponds to the JSON property state
2744 2745 2746 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2744 def state @state end |
#treatment ⇒ String
Required. The newer version that is serving requests.
Corresponds to the JSON property treatment
2749 2750 2751 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2749 def treatment @treatment end |
#verdict ⇒ String
Output only. The resulting verdict of the canary evaluations: NONE, PASS, or
FAIL.
Corresponds to the JSON property verdict
2755 2756 2757 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2755 def verdict @verdict end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2762 2763 2764 2765 2766 2767 2768 2769 2770 2771 2772 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2762 def update!(**args) @control = args[:control] if args.key?(:control) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @metric_labels = args[:metric_labels] if args.key?(:metric_labels) @name = args[:name] if args.key?(:name) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) @treatment = args[:treatment] if args.key?(:treatment) @verdict = args[:verdict] if args.key?(:verdict) end |