Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1CertInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

X.509 certificate as defined in RFC 5280.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1CertInfo

Returns a new instance of GoogleCloudApigeeV1CertInfo.



2827
2828
2829
# File 'lib/google/apis/apigee_v1/classes.rb', line 2827

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#basic_constraintsString

X.509 basic constraints extension. Corresponds to the JSON property basicConstraints

Returns:

  • (String)


2774
2775
2776
# File 'lib/google/apis/apigee_v1/classes.rb', line 2774

def basic_constraints
  @basic_constraints
end

#expiry_dateFixnum

X.509 notAfter validity period in milliseconds since epoch. Corresponds to the JSON property expiryDate

Returns:

  • (Fixnum)


2779
2780
2781
# File 'lib/google/apis/apigee_v1/classes.rb', line 2779

def expiry_date
  @expiry_date
end

#is_validString

Flag that specifies whether the certificate is valid. Flag is set to Yes if the certificate is valid, No if expired, or Not yet if not yet valid. Corresponds to the JSON property isValid

Returns:

  • (String)


2785
2786
2787
# File 'lib/google/apis/apigee_v1/classes.rb', line 2785

def is_valid
  @is_valid
end

#issuerString

X.509 issuer. Corresponds to the JSON property issuer

Returns:

  • (String)


2790
2791
2792
# File 'lib/google/apis/apigee_v1/classes.rb', line 2790

def issuer
  @issuer
end

#public_keyString

Public key component of the X.509 subject public key info. Corresponds to the JSON property publicKey

Returns:

  • (String)


2795
2796
2797
# File 'lib/google/apis/apigee_v1/classes.rb', line 2795

def public_key
  @public_key
end

#serial_numberString

X.509 serial number. Corresponds to the JSON property serialNumber

Returns:

  • (String)


2800
2801
2802
# File 'lib/google/apis/apigee_v1/classes.rb', line 2800

def serial_number
  @serial_number
end

#sig_alg_nameString

X.509 signatureAlgorithm. Corresponds to the JSON property sigAlgName

Returns:

  • (String)


2805
2806
2807
# File 'lib/google/apis/apigee_v1/classes.rb', line 2805

def sig_alg_name
  @sig_alg_name
end

#subjectString

X.509 subject. Corresponds to the JSON property subject

Returns:

  • (String)


2810
2811
2812
# File 'lib/google/apis/apigee_v1/classes.rb', line 2810

def subject
  @subject
end

#subject_alternative_namesArray<String>

X.509 subject alternative names (SANs) extension. Corresponds to the JSON property subjectAlternativeNames

Returns:

  • (Array<String>)


2815
2816
2817
# File 'lib/google/apis/apigee_v1/classes.rb', line 2815

def subject_alternative_names
  @subject_alternative_names
end

#valid_fromFixnum

X.509 notBefore validity period in milliseconds since epoch. Corresponds to the JSON property validFrom

Returns:

  • (Fixnum)


2820
2821
2822
# File 'lib/google/apis/apigee_v1/classes.rb', line 2820

def valid_from
  @valid_from
end

#versionFixnum

X.509 version. Corresponds to the JSON property version

Returns:

  • (Fixnum)


2825
2826
2827
# File 'lib/google/apis/apigee_v1/classes.rb', line 2825

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2832
2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
# File 'lib/google/apis/apigee_v1/classes.rb', line 2832

def update!(**args)
  @basic_constraints = args[:basic_constraints] if args.key?(:basic_constraints)
  @expiry_date = args[:expiry_date] if args.key?(:expiry_date)
  @is_valid = args[:is_valid] if args.key?(:is_valid)
  @issuer = args[:issuer] if args.key?(:issuer)
  @public_key = args[:public_key] if args.key?(:public_key)
  @serial_number = args[:serial_number] if args.key?(:serial_number)
  @sig_alg_name = args[:sig_alg_name] if args.key?(:sig_alg_name)
  @subject = args[:subject] if args.key?(:subject)
  @subject_alternative_names = args[:subject_alternative_names] if args.key?(:subject_alternative_names)
  @valid_from = args[:valid_from] if args.key?(:valid_from)
  @version = args[:version] if args.key?(:version)
end