Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ComputeEnvironmentScoresRequest
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1ComputeEnvironmentScoresRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Request for ComputeEnvironmentScores.
Instance Attribute Summary collapse
-
#filters ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ComputeEnvironmentScoresRequestFilter>
Optional.
-
#page_size ⇒ Fixnum
Optional.
-
#page_token ⇒ String
Optional.
-
#time_range ⇒ Google::Apis::ApigeeV1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1ComputeEnvironmentScoresRequest
constructor
A new instance of GoogleCloudApigeeV1ComputeEnvironmentScoresRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1ComputeEnvironmentScoresRequest
Returns a new instance of GoogleCloudApigeeV1ComputeEnvironmentScoresRequest.
2919 2920 2921 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2919 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filters ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ComputeEnvironmentScoresRequestFilter>
Optional. Filters are used to filter scored components. Return all the
components if no filter is mentioned. Example: ["scorePath": "/org@myorg/
envgroup@myenvgroup/env@myenv/proxies/proxy@myproxy/source", "scorePath": "
/org@myorg/envgroup@myenvgroup/env@myenv/proxies/proxy@myproxy/target",]
This will return components with path: "/org@myorg/envgroup@myenvgroup/env@
myenv/proxies/proxy@myproxy/source" OR "/org@myorg/envgroup@myenvgroup/env@
myenv/proxies/proxy@myproxy/target"
Corresponds to the JSON property filters
2896 2897 2898 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2896 def filters @filters end |
#page_size ⇒ Fixnum
Optional. The maximum number of subcomponents to be returned in a single page.
The service may return fewer than this value. If unspecified, at most 100
subcomponents will be returned in a single page.
Corresponds to the JSON property pageSize
2903 2904 2905 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2903 def page_size @page_size end |
#page_token ⇒ String
Optional. A token that can be sent as page_token to retrieve the next page.
If this field is omitted, there are no subsequent pages.
Corresponds to the JSON property pageToken
2909 2910 2911 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2909 def page_token @page_token end |
#time_range ⇒ Google::Apis::ApigeeV1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive). The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time). When
both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property timeRange
2917 2918 2919 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2917 def time_range @time_range end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2924 2925 2926 2927 2928 2929 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 2924 def update!(**args) @filters = args[:filters] if args.key?(:filters) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @time_range = args[:time_range] if args.key?(:time_range) end |