Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ControlPlaneAccess
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1ControlPlaneAccess
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
ControlPlaneAccess is the request body and response body of
UpdateControlPlaneAccess. and the response body of GetControlPlaneAccess. The
input identities contains an array of service accounts to grant access to the
respective control plane resource, with each service account specified using
the following format: serviceAccount:service-account-name. The ***
service-account-name*** is formatted like an email address. For example: my-
control-plane-service_account@my_project_id.iam.gserviceaccount.com You might
specify multiple service accounts, for example, if you have multiple
environments and wish to assign a unique service account to each one.
Instance Attribute Summary collapse
-
#analytics_publisher_identities ⇒ Array<String>
Optional.
-
#name ⇒ String
Identifier.
-
#synchronizer_identities ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1ControlPlaneAccess
constructor
A new instance of GoogleCloudApigeeV1ControlPlaneAccess.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1ControlPlaneAccess
Returns a new instance of GoogleCloudApigeeV1ControlPlaneAccess.
3064 3065 3066 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3064 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analytics_publisher_identities ⇒ Array<String>
Optional. Array of service accounts authorized to publish analytics data to
the control plane (for the Message Processor component).
Corresponds to the JSON property analyticsPublisherIdentities
3048 3049 3050 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3048 def analytics_publisher_identities @analytics_publisher_identities end |
#name ⇒ String
Identifier. The resource name of the ControlPlaneAccess. Format: "
organizations/org/controlPlaneAccess"
Corresponds to the JSON property name
3054 3055 3056 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3054 def name @name end |
#synchronizer_identities ⇒ Array<String>
Optional. Array of service accounts to grant access to control plane resources
(for the Synchronizer component). The service accounts must have Apigee
Synchronizer Manager role. See also Create service accounts.
Corresponds to the JSON property synchronizerIdentities
3062 3063 3064 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3062 def synchronizer_identities @synchronizer_identities end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3069 3070 3071 3072 3073 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3069 def update!(**args) @analytics_publisher_identities = args[:analytics_publisher_identities] if args.key?(:analytics_publisher_identities) @name = args[:name] if args.key?(:name) @synchronizer_identities = args[:synchronizer_identities] if args.key?(:synchronizer_identities) end |