Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Credential
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1Credential
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Instance Attribute Summary collapse
-
#api_products ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiProductRef>
List of API products this credential can be used for.
-
#attributes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>
List of attributes associated with this credential.
-
#consumer_key ⇒ String
Consumer key.
-
#consumer_secret ⇒ String
Secret key.
-
#expires_at ⇒ Fixnum
Time the credential will expire in milliseconds since epoch.
-
#issued_at ⇒ Fixnum
Time the credential was issued in milliseconds since epoch.
-
#scopes ⇒ Array<String>
List of scopes to apply to the app.
-
#status ⇒ String
Status of the credential.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1Credential
constructor
A new instance of GoogleCloudApigeeV1Credential.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1Credential
Returns a new instance of GoogleCloudApigeeV1Credential.
3170 3171 3172 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3170 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_products ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiProductRef>
List of API products this credential can be used for.
Corresponds to the JSON property apiProducts
3132 3133 3134 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3132 def api_products @api_products end |
#attributes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>
List of attributes associated with this credential.
Corresponds to the JSON property attributes
3137 3138 3139 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3137 def attributes @attributes end |
#consumer_key ⇒ String
Consumer key.
Corresponds to the JSON property consumerKey
3142 3143 3144 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3142 def consumer_key @consumer_key end |
#consumer_secret ⇒ String
Secret key.
Corresponds to the JSON property consumerSecret
3147 3148 3149 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3147 def consumer_secret @consumer_secret end |
#expires_at ⇒ Fixnum
Time the credential will expire in milliseconds since epoch.
Corresponds to the JSON property expiresAt
3152 3153 3154 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3152 def expires_at @expires_at end |
#issued_at ⇒ Fixnum
Time the credential was issued in milliseconds since epoch.
Corresponds to the JSON property issuedAt
3157 3158 3159 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3157 def issued_at @issued_at end |
#scopes ⇒ Array<String>
List of scopes to apply to the app. Specified scopes must already exist on the
API product that you associate with the app.
Corresponds to the JSON property scopes
3163 3164 3165 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3163 def scopes @scopes end |
#status ⇒ String
Status of the credential. Valid values include approved or revoked.
Corresponds to the JSON property status
3168 3169 3170 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3168 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3175 3176 3177 3178 3179 3180 3181 3182 3183 3184 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3175 def update!(**args) @api_products = args[:api_products] if args.key?(:api_products) @attributes = args[:attributes] if args.key?(:attributes) @consumer_key = args[:consumer_key] if args.key?(:consumer_key) @consumer_secret = args[:consumer_secret] if args.key?(:consumer_secret) @expires_at = args[:expires_at] if args.key?(:expires_at) @issued_at = args[:issued_at] if args.key?(:issued_at) @scopes = args[:scopes] if args.key?(:scopes) @status = args[:status] if args.key?(:status) end |