Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Credential
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1Credential
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Instance Attribute Summary collapse
-
#api_products ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiProductRef>
List of API products this credential can be used for.
-
#attributes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>
List of attributes associated with this credential.
-
#consumer_key ⇒ String
Consumer key.
-
#consumer_secret ⇒ String
Secret key.
-
#expires_at ⇒ Fixnum
Time the credential will expire in milliseconds since epoch.
-
#issued_at ⇒ Fixnum
Time the credential was issued in milliseconds since epoch.
-
#scopes ⇒ Array<String>
List of scopes to apply to the app.
-
#status ⇒ String
Status of the credential.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1Credential
constructor
A new instance of GoogleCloudApigeeV1Credential.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1Credential
Returns a new instance of GoogleCloudApigeeV1Credential.
3121 3122 3123 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3121 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_products ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiProductRef>
List of API products this credential can be used for.
Corresponds to the JSON property apiProducts
3083 3084 3085 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3083 def api_products @api_products end |
#attributes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>
List of attributes associated with this credential.
Corresponds to the JSON property attributes
3088 3089 3090 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3088 def attributes @attributes end |
#consumer_key ⇒ String
Consumer key.
Corresponds to the JSON property consumerKey
3093 3094 3095 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3093 def consumer_key @consumer_key end |
#consumer_secret ⇒ String
Secret key.
Corresponds to the JSON property consumerSecret
3098 3099 3100 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3098 def consumer_secret @consumer_secret end |
#expires_at ⇒ Fixnum
Time the credential will expire in milliseconds since epoch.
Corresponds to the JSON property expiresAt
3103 3104 3105 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3103 def expires_at @expires_at end |
#issued_at ⇒ Fixnum
Time the credential was issued in milliseconds since epoch.
Corresponds to the JSON property issuedAt
3108 3109 3110 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3108 def issued_at @issued_at end |
#scopes ⇒ Array<String>
List of scopes to apply to the app. Specified scopes must already exist on the
API product that you associate with the app.
Corresponds to the JSON property scopes
3114 3115 3116 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3114 def scopes @scopes end |
#status ⇒ String
Status of the credential. Valid values include approved or revoked.
Corresponds to the JSON property status
3119 3120 3121 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3119 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3126 3127 3128 3129 3130 3131 3132 3133 3134 3135 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3126 def update!(**args) @api_products = args[:api_products] if args.key?(:api_products) @attributes = args[:attributes] if args.key?(:attributes) @consumer_key = args[:consumer_key] if args.key?(:consumer_key) @consumer_secret = args[:consumer_secret] if args.key?(:consumer_secret) @expires_at = args[:expires_at] if args.key?(:expires_at) @issued_at = args[:issued_at] if args.key?(:issued_at) @scopes = args[:scopes] if args.key?(:scopes) @status = args[:status] if args.key?(:status) end |