Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1CreditAppGroupBalanceRequest
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1CreditAppGroupBalanceRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Request for CreditAppGroupBalance.
Instance Attribute Summary collapse
-
#transaction_amount ⇒ Google::Apis::ApigeeV1::GoogleTypeMoney
Represents an amount of money with its currency type.
-
#transaction_id ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1CreditAppGroupBalanceRequest
constructor
A new instance of GoogleCloudApigeeV1CreditAppGroupBalanceRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1CreditAppGroupBalanceRequest
Returns a new instance of GoogleCloudApigeeV1CreditAppGroupBalanceRequest.
3154 3155 3156 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3154 def initialize(**args) update!(**args) end |
Instance Attribute Details
#transaction_amount ⇒ Google::Apis::ApigeeV1::GoogleTypeMoney
Represents an amount of money with its currency type.
Corresponds to the JSON property transactionAmount
3145 3146 3147 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3145 def transaction_amount @transaction_amount end |
#transaction_id ⇒ String
Required. Each transaction_id uniquely identifies a credit balance request. If
multiple requests are received with the same transaction_id, only one of them
will be considered.
Corresponds to the JSON property transactionId
3152 3153 3154 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3152 def transaction_id @transaction_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3159 3160 3161 3162 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3159 def update!(**args) @transaction_amount = args[:transaction_amount] if args.key?(:transaction_amount) @transaction_id = args[:transaction_id] if args.key?(:transaction_id) end |