Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1CustomReport

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1CustomReport

Returns a new instance of GoogleCloudApigeeV1CustomReport.



3320
3321
3322
# File 'lib/google/apis/apigee_v1/classes.rb', line 3320

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chart_typeString

This field contains the chart type for the report Corresponds to the JSON property chartType

Returns:

  • (String)


3208
3209
3210
# File 'lib/google/apis/apigee_v1/classes.rb', line 3208

def chart_type
  @chart_type
end

#commentsArray<String>

Legacy field: not used. This field contains a list of comments associated with custom report Corresponds to the JSON property comments

Returns:

  • (Array<String>)


3214
3215
3216
# File 'lib/google/apis/apigee_v1/classes.rb', line 3214

def comments
  @comments
end

#created_atFixnum

Output only. Unix time when the app was created json key: createdAt Corresponds to the JSON property createdAt

Returns:

  • (Fixnum)


3219
3220
3221
# File 'lib/google/apis/apigee_v1/classes.rb', line 3219

def created_at
  @created_at
end

#dimensionsArray<String>

This contains the list of dimensions for the report Corresponds to the JSON property dimensions

Returns:

  • (Array<String>)


3224
3225
3226
# File 'lib/google/apis/apigee_v1/classes.rb', line 3224

def dimensions
  @dimensions
end

#display_nameString

This is the display name for the report Corresponds to the JSON property displayName

Returns:

  • (String)


3229
3230
3231
# File 'lib/google/apis/apigee_v1/classes.rb', line 3229

def display_name
  @display_name
end

#environmentString

Output only. Environment name Corresponds to the JSON property environment

Returns:

  • (String)


3234
3235
3236
# File 'lib/google/apis/apigee_v1/classes.rb', line 3234

def environment
  @environment
end

#filterString

This field contains the filter expression Corresponds to the JSON property filter

Returns:

  • (String)


3239
3240
3241
# File 'lib/google/apis/apigee_v1/classes.rb', line 3239

def filter
  @filter
end

#from_timeString

Legacy field: not used. Contains the from time for the report Corresponds to the JSON property fromTime

Returns:

  • (String)


3244
3245
3246
# File 'lib/google/apis/apigee_v1/classes.rb', line 3244

def from_time
  @from_time
end

#last_modified_atFixnum

Output only. Modified time of this entity as milliseconds since epoch. json key: lastModifiedAt Corresponds to the JSON property lastModifiedAt

Returns:

  • (Fixnum)


3250
3251
3252
# File 'lib/google/apis/apigee_v1/classes.rb', line 3250

def last_modified_at
  @last_modified_at
end

#last_viewed_atFixnum

Output only. Last viewed time of this entity as milliseconds since epoch Corresponds to the JSON property lastViewedAt

Returns:

  • (Fixnum)


3255
3256
3257
# File 'lib/google/apis/apigee_v1/classes.rb', line 3255

def last_viewed_at
  @last_viewed_at
end

#limitString

Legacy field: not used This field contains the limit for the result retrieved Corresponds to the JSON property limit

Returns:

  • (String)


3260
3261
3262
# File 'lib/google/apis/apigee_v1/classes.rb', line 3260

def limit
  @limit
end

#metricsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1CustomReportMetric>

Required. This contains the list of metrics Corresponds to the JSON property metrics



3265
3266
3267
# File 'lib/google/apis/apigee_v1/classes.rb', line 3265

def metrics
  @metrics
end

#nameString

Required. Unique identifier for the report T his is a legacy field used to encode custom report unique id Corresponds to the JSON property name

Returns:

  • (String)


3271
3272
3273
# File 'lib/google/apis/apigee_v1/classes.rb', line 3271

def name
  @name
end

#offsetString

Legacy field: not used. This field contains the offset for the data Corresponds to the JSON property offset

Returns:

  • (String)


3276
3277
3278
# File 'lib/google/apis/apigee_v1/classes.rb', line 3276

def offset
  @offset
end

#organizationString

Output only. Organization name Corresponds to the JSON property organization

Returns:

  • (String)


3281
3282
3283
# File 'lib/google/apis/apigee_v1/classes.rb', line 3281

def organization
  @organization
end

#propertiesArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ReportProperty>

This field contains report properties such as ui metadata etc. Corresponds to the JSON property properties



3286
3287
3288
# File 'lib/google/apis/apigee_v1/classes.rb', line 3286

def properties
  @properties
end

#sort_by_colsArray<String>

Legacy field: not used much. Contains the list of sort by columns Corresponds to the JSON property sortByCols

Returns:

  • (Array<String>)


3291
3292
3293
# File 'lib/google/apis/apigee_v1/classes.rb', line 3291

def sort_by_cols
  @sort_by_cols
end

#sort_orderString

Legacy field: not used much. Contains the sort order for the sort columns Corresponds to the JSON property sortOrder

Returns:

  • (String)


3296
3297
3298
# File 'lib/google/apis/apigee_v1/classes.rb', line 3296

def sort_order
  @sort_order
end

#tagsArray<String>

Legacy field: not used. This field contains a list of tags associated with custom report Corresponds to the JSON property tags

Returns:

  • (Array<String>)


3302
3303
3304
# File 'lib/google/apis/apigee_v1/classes.rb', line 3302

def tags
  @tags
end

#time_unitString

This field contains the time unit of aggregation for the report Corresponds to the JSON property timeUnit

Returns:

  • (String)


3307
3308
3309
# File 'lib/google/apis/apigee_v1/classes.rb', line 3307

def time_unit
  @time_unit
end

#to_timeString

Legacy field: not used. Contains the end time for the report Corresponds to the JSON property toTime

Returns:

  • (String)


3312
3313
3314
# File 'lib/google/apis/apigee_v1/classes.rb', line 3312

def to_time
  @to_time
end

#topkString

Legacy field: not used. This field contains the top k parameter value for restricting the result Corresponds to the JSON property topk

Returns:

  • (String)


3318
3319
3320
# File 'lib/google/apis/apigee_v1/classes.rb', line 3318

def topk
  @topk
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3325
3326
3327
3328
3329
3330
3331
3332
3333
3334
3335
3336
3337
3338
3339
3340
3341
3342
3343
3344
3345
3346
3347
3348
# File 'lib/google/apis/apigee_v1/classes.rb', line 3325

def update!(**args)
  @chart_type = args[:chart_type] if args.key?(:chart_type)
  @comments = args[:comments] if args.key?(:comments)
  @created_at = args[:created_at] if args.key?(:created_at)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @display_name = args[:display_name] if args.key?(:display_name)
  @environment = args[:environment] if args.key?(:environment)
  @filter = args[:filter] if args.key?(:filter)
  @from_time = args[:from_time] if args.key?(:from_time)
  @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at)
  @last_viewed_at = args[:last_viewed_at] if args.key?(:last_viewed_at)
  @limit = args[:limit] if args.key?(:limit)
  @metrics = args[:metrics] if args.key?(:metrics)
  @name = args[:name] if args.key?(:name)
  @offset = args[:offset] if args.key?(:offset)
  @organization = args[:organization] if args.key?(:organization)
  @properties = args[:properties] if args.key?(:properties)
  @sort_by_cols = args[:sort_by_cols] if args.key?(:sort_by_cols)
  @sort_order = args[:sort_order] if args.key?(:sort_order)
  @tags = args[:tags] if args.key?(:tags)
  @time_unit = args[:time_unit] if args.key?(:time_unit)
  @to_time = args[:to_time] if args.key?(:to_time)
  @topk = args[:topk] if args.key?(:topk)
end