Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1CustomReport
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1CustomReport
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Instance Attribute Summary collapse
-
#chart_type ⇒ String
This field contains the chart type for the report Corresponds to the JSON property
chartType. -
#comments ⇒ Array<String>
Legacy field: not used.
-
#created_at ⇒ Fixnum
Output only.
-
#dimensions ⇒ Array<String>
This contains the list of dimensions for the report Corresponds to the JSON property
dimensions. -
#display_name ⇒ String
This is the display name for the report Corresponds to the JSON property
displayName. -
#environment ⇒ String
Output only.
-
#filter ⇒ String
This field contains the filter expression Corresponds to the JSON property
filter. -
#from_time ⇒ String
Legacy field: not used.
-
#last_modified_at ⇒ Fixnum
Output only.
-
#last_viewed_at ⇒ Fixnum
Output only.
-
#limit ⇒ String
Legacy field: not used This field contains the limit for the result retrieved Corresponds to the JSON property
limit. -
#metrics ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1CustomReportMetric>
Required.
-
#name ⇒ String
Required.
-
#offset ⇒ String
Legacy field: not used.
-
#organization ⇒ String
Output only.
-
#properties ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ReportProperty>
This field contains report properties such as ui metadata etc.
-
#sort_by_cols ⇒ Array<String>
Legacy field: not used much.
-
#sort_order ⇒ String
Legacy field: not used much.
-
#tags ⇒ Array<String>
Legacy field: not used.
-
#time_unit ⇒ String
This field contains the time unit of aggregation for the report Corresponds to the JSON property
timeUnit. -
#to_time ⇒ String
Legacy field: not used.
-
#topk ⇒ String
Legacy field: not used.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1CustomReport
constructor
A new instance of GoogleCloudApigeeV1CustomReport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1CustomReport
Returns a new instance of GoogleCloudApigeeV1CustomReport.
3311 3312 3313 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3311 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chart_type ⇒ String
This field contains the chart type for the report
Corresponds to the JSON property chartType
3199 3200 3201 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3199 def chart_type @chart_type end |
#comments ⇒ Array<String>
Legacy field: not used. This field contains a list of comments associated with
custom report
Corresponds to the JSON property comments
3205 3206 3207 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3205 def comments @comments end |
#created_at ⇒ Fixnum
Output only. Unix time when the app was created json key: createdAt
Corresponds to the JSON property createdAt
3210 3211 3212 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3210 def created_at @created_at end |
#dimensions ⇒ Array<String>
This contains the list of dimensions for the report
Corresponds to the JSON property dimensions
3215 3216 3217 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3215 def dimensions @dimensions end |
#display_name ⇒ String
This is the display name for the report
Corresponds to the JSON property displayName
3220 3221 3222 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3220 def display_name @display_name end |
#environment ⇒ String
Output only. Environment name
Corresponds to the JSON property environment
3225 3226 3227 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3225 def environment @environment end |
#filter ⇒ String
This field contains the filter expression
Corresponds to the JSON property filter
3230 3231 3232 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3230 def filter @filter end |
#from_time ⇒ String
Legacy field: not used. Contains the from time for the report
Corresponds to the JSON property fromTime
3235 3236 3237 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3235 def from_time @from_time end |
#last_modified_at ⇒ Fixnum
Output only. Modified time of this entity as milliseconds since epoch. json
key: lastModifiedAt
Corresponds to the JSON property lastModifiedAt
3241 3242 3243 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3241 def last_modified_at @last_modified_at end |
#last_viewed_at ⇒ Fixnum
Output only. Last viewed time of this entity as milliseconds since epoch
Corresponds to the JSON property lastViewedAt
3246 3247 3248 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3246 def last_viewed_at @last_viewed_at end |
#limit ⇒ String
Legacy field: not used This field contains the limit for the result retrieved
Corresponds to the JSON property limit
3251 3252 3253 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3251 def limit @limit end |
#metrics ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1CustomReportMetric>
Required. This contains the list of metrics
Corresponds to the JSON property metrics
3256 3257 3258 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3256 def metrics @metrics end |
#name ⇒ String
Required. Unique identifier for the report T his is a legacy field used to
encode custom report unique id
Corresponds to the JSON property name
3262 3263 3264 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3262 def name @name end |
#offset ⇒ String
Legacy field: not used. This field contains the offset for the data
Corresponds to the JSON property offset
3267 3268 3269 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3267 def offset @offset end |
#organization ⇒ String
Output only. Organization name
Corresponds to the JSON property organization
3272 3273 3274 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3272 def organization @organization end |
#properties ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ReportProperty>
This field contains report properties such as ui metadata etc.
Corresponds to the JSON property properties
3277 3278 3279 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3277 def properties @properties end |
#sort_by_cols ⇒ Array<String>
Legacy field: not used much. Contains the list of sort by columns
Corresponds to the JSON property sortByCols
3282 3283 3284 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3282 def sort_by_cols @sort_by_cols end |
#sort_order ⇒ String
Legacy field: not used much. Contains the sort order for the sort columns
Corresponds to the JSON property sortOrder
3287 3288 3289 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3287 def sort_order @sort_order end |
#tags ⇒ Array<String>
Legacy field: not used. This field contains a list of tags associated with
custom report
Corresponds to the JSON property tags
3293 3294 3295 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3293 def @tags end |
#time_unit ⇒ String
This field contains the time unit of aggregation for the report
Corresponds to the JSON property timeUnit
3298 3299 3300 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3298 def time_unit @time_unit end |
#to_time ⇒ String
Legacy field: not used. Contains the end time for the report
Corresponds to the JSON property toTime
3303 3304 3305 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3303 def to_time @to_time end |
#topk ⇒ String
Legacy field: not used. This field contains the top k parameter value for
restricting the result
Corresponds to the JSON property topk
3309 3310 3311 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3309 def topk @topk end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3316 3317 3318 3319 3320 3321 3322 3323 3324 3325 3326 3327 3328 3329 3330 3331 3332 3333 3334 3335 3336 3337 3338 3339 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3316 def update!(**args) @chart_type = args[:chart_type] if args.key?(:chart_type) @comments = args[:comments] if args.key?(:comments) @created_at = args[:created_at] if args.key?(:created_at) @dimensions = args[:dimensions] if args.key?(:dimensions) @display_name = args[:display_name] if args.key?(:display_name) @environment = args[:environment] if args.key?(:environment) @filter = args[:filter] if args.key?(:filter) @from_time = args[:from_time] if args.key?(:from_time) @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at) @last_viewed_at = args[:last_viewed_at] if args.key?(:last_viewed_at) @limit = args[:limit] if args.key?(:limit) @metrics = args[:metrics] if args.key?(:metrics) @name = args[:name] if args.key?(:name) @offset = args[:offset] if args.key?(:offset) @organization = args[:organization] if args.key?(:organization) @properties = args[:properties] if args.key?(:properties) @sort_by_cols = args[:sort_by_cols] if args.key?(:sort_by_cols) @sort_order = args[:sort_order] if args.key?(:sort_order) @tags = args[:tags] if args.key?(:tags) @time_unit = args[:time_unit] if args.key?(:time_unit) @to_time = args[:to_time] if args.key?(:to_time) @topk = args[:topk] if args.key?(:topk) end |