Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1DataCollector

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Data collector configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1DataCollector

Returns a new instance of GoogleCloudApigeeV1DataCollector.



3399
3400
3401
# File 'lib/google/apis/apigee_v1/classes.rb', line 3399

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#created_atFixnum

Output only. The time at which the data collector was created in milliseconds since the epoch. Corresponds to the JSON property createdAt

Returns:

  • (Fixnum)


3376
3377
3378
# File 'lib/google/apis/apigee_v1/classes.rb', line 3376

def created_at
  @created_at
end

#descriptionString

A description of the data collector. Corresponds to the JSON property description

Returns:

  • (String)


3381
3382
3383
# File 'lib/google/apis/apigee_v1/classes.rb', line 3381

def description
  @description
end

#last_modified_atFixnum

Output only. The time at which the Data Collector was last updated in milliseconds since the epoch. Corresponds to the JSON property lastModifiedAt

Returns:

  • (Fixnum)


3387
3388
3389
# File 'lib/google/apis/apigee_v1/classes.rb', line 3387

def last_modified_at
  @last_modified_at
end

#nameString

ID of the data collector. Must begin with dc_. Corresponds to the JSON property name

Returns:

  • (String)


3392
3393
3394
# File 'lib/google/apis/apigee_v1/classes.rb', line 3392

def name
  @name
end

#typeString

Immutable. The type of data this data collector will collect. Corresponds to the JSON property type

Returns:

  • (String)


3397
3398
3399
# File 'lib/google/apis/apigee_v1/classes.rb', line 3397

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3404
3405
3406
3407
3408
3409
3410
# File 'lib/google/apis/apigee_v1/classes.rb', line 3404

def update!(**args)
  @created_at = args[:created_at] if args.key?(:created_at)
  @description = args[:description] if args.key?(:description)
  @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end