Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Datastore

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

The data store defines the connection to export data repository (Cloud Storage, BigQuery), including the credentials used to access the data repository.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1Datastore

Returns a new instance of GoogleCloudApigeeV1Datastore.



3491
3492
3493
# File 'lib/google/apis/apigee_v1/classes.rb', line 3491

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeFixnum

Output only. Datastore create time, in milliseconds since the epoch of 1970-01- 01T00:00:00Z Corresponds to the JSON property createTime

Returns:

  • (Fixnum)


3457
3458
3459
# File 'lib/google/apis/apigee_v1/classes.rb', line 3457

def create_time
  @create_time
end

#datastore_configGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1DatastoreConfig

Configuration detail for datastore Corresponds to the JSON property datastoreConfig



3462
3463
3464
# File 'lib/google/apis/apigee_v1/classes.rb', line 3462

def datastore_config
  @datastore_config
end

#display_nameString

Required. Display name in UI Corresponds to the JSON property displayName

Returns:

  • (String)


3467
3468
3469
# File 'lib/google/apis/apigee_v1/classes.rb', line 3467

def display_name
  @display_name
end

#last_update_timeFixnum

Output only. Datastore last update time, in milliseconds since the epoch of 1970-01-01T00:00:00Z Corresponds to the JSON property lastUpdateTime

Returns:

  • (Fixnum)


3473
3474
3475
# File 'lib/google/apis/apigee_v1/classes.rb', line 3473

def last_update_time
  @last_update_time
end

#orgString

Output only. Organization that the datastore belongs to Corresponds to the JSON property org

Returns:

  • (String)


3478
3479
3480
# File 'lib/google/apis/apigee_v1/classes.rb', line 3478

def org
  @org
end

#selfString

Output only. Resource link of Datastore. Example: /organizations/org/ analytics/datastores/uuid` Corresponds to the JSON propertyself`

Returns:

  • (String)


3484
3485
3486
# File 'lib/google/apis/apigee_v1/classes.rb', line 3484

def self
  @self
end

#target_typeString

Destination storage type. Supported types gcs or bigquery. Corresponds to the JSON property targetType

Returns:

  • (String)


3489
3490
3491
# File 'lib/google/apis/apigee_v1/classes.rb', line 3489

def target_type
  @target_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3496
3497
3498
3499
3500
3501
3502
3503
3504
# File 'lib/google/apis/apigee_v1/classes.rb', line 3496

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @datastore_config = args[:datastore_config] if args.key?(:datastore_config)
  @display_name = args[:display_name] if args.key?(:display_name)
  @last_update_time = args[:last_update_time] if args.key?(:last_update_time)
  @org = args[:org] if args.key?(:org)
  @self = args[:self] if args.key?(:self)
  @target_type = args[:target_type] if args.key?(:target_type)
end