Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Datastore
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1Datastore
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
The data store defines the connection to export data repository (Cloud Storage, BigQuery), including the credentials used to access the data repository.
Instance Attribute Summary collapse
-
#create_time ⇒ Fixnum
Output only.
-
#datastore_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1DatastoreConfig
Configuration detail for datastore Corresponds to the JSON property
datastoreConfig. -
#display_name ⇒ String
Required.
-
#last_update_time ⇒ Fixnum
Output only.
-
#org ⇒ String
Output only.
-
#self ⇒ String
Output only.
-
#target_type ⇒ String
Destination storage type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1Datastore
constructor
A new instance of GoogleCloudApigeeV1Datastore.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1Datastore
Returns a new instance of GoogleCloudApigeeV1Datastore.
3531 3532 3533 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3531 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ Fixnum
Output only. Datastore create time, in milliseconds since the epoch of 1970-01-
01T00:00:00Z
Corresponds to the JSON property createTime
3497 3498 3499 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3497 def create_time @create_time end |
#datastore_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1DatastoreConfig
Configuration detail for datastore
Corresponds to the JSON property datastoreConfig
3502 3503 3504 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3502 def datastore_config @datastore_config end |
#display_name ⇒ String
Required. Display name in UI
Corresponds to the JSON property displayName
3507 3508 3509 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3507 def display_name @display_name end |
#last_update_time ⇒ Fixnum
Output only. Datastore last update time, in milliseconds since the epoch of
1970-01-01T00:00:00Z
Corresponds to the JSON property lastUpdateTime
3513 3514 3515 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3513 def last_update_time @last_update_time end |
#org ⇒ String
Output only. Organization that the datastore belongs to
Corresponds to the JSON property org
3518 3519 3520 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3518 def org @org end |
#self ⇒ String
Output only. Resource link of Datastore. Example: /organizations/org/
analytics/datastores/uuid`
Corresponds to the JSON propertyself`
3524 3525 3526 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3524 def self @self end |
#target_type ⇒ String
Destination storage type. Supported types gcs or bigquery.
Corresponds to the JSON property targetType
3529 3530 3531 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3529 def target_type @target_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3536 3537 3538 3539 3540 3541 3542 3543 3544 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3536 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @datastore_config = args[:datastore_config] if args.key?(:datastore_config) @display_name = args[:display_name] if args.key?(:display_name) @last_update_time = args[:last_update_time] if args.key?(:last_update_time) @org = args[:org] if args.key?(:org) @self = args[:self] if args.key?(:self) @target_type = args[:target_type] if args.key?(:target_type) end |