Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1DebugSession
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1DebugSession
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Instance Attribute Summary collapse
-
#count ⇒ Fixnum
Optional.
-
#create_time ⇒ String
Output only.
-
#filter ⇒ String
Optional.
-
#name ⇒ String
A unique ID for this DebugSession.
-
#timeout ⇒ Fixnum
Optional.
-
#tracesize ⇒ Fixnum
Optional.
-
#validity ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1DebugSession
constructor
A new instance of GoogleCloudApigeeV1DebugSession.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1DebugSession
Returns a new instance of GoogleCloudApigeeV1DebugSession.
3705 3706 3707 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3705 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Fixnum
Optional. The number of request to be traced. Min = 1, Max = 15, Default = 10.
Corresponds to the JSON property count
3667 3668 3669 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3667 def count @count end |
#create_time ⇒ String
Output only. The first transaction creation timestamp, recorded by UAP.
Corresponds to the JSON property createTime
3672 3673 3674 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3672 def create_time @create_time end |
#filter ⇒ String
Optional. A conditional statement which is evaluated against the request
message to determine if it should be traced. Syntax matches that of on API
Proxy bundle flow Condition.
Corresponds to the JSON property filter
3679 3680 3681 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3679 def filter @filter end |
#name ⇒ String
A unique ID for this DebugSession.
Corresponds to the JSON property name
3684 3685 3686 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3684 def name @name end |
#timeout ⇒ Fixnum
Optional. The time in seconds after which this DebugSession should end. This
value will override the value in query param, if both are provided.
Corresponds to the JSON property timeout
3690 3691 3692 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3690 def timeout @timeout end |
#tracesize ⇒ Fixnum
Optional. The maximum number of bytes captured from the response payload. Min =
0, Max = 5120, Default = 5120.
Corresponds to the JSON property tracesize
3696 3697 3698 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3696 def tracesize @tracesize end |
#validity ⇒ Fixnum
Optional. The length of time, in seconds, that this debug session is valid,
starting from when it's received in the control plane. Min = 1, Max = 15,
Default = 10.
Corresponds to the JSON property validity
3703 3704 3705 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3703 def validity @validity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3710 3711 3712 3713 3714 3715 3716 3717 3718 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3710 def update!(**args) @count = args[:count] if args.key?(:count) @create_time = args[:create_time] if args.key?(:create_time) @filter = args[:filter] if args.key?(:filter) @name = args[:name] if args.key?(:name) @timeout = args[:timeout] if args.key?(:timeout) @tracesize = args[:tracesize] if args.key?(:tracesize) @validity = args[:validity] if args.key?(:validity) end |