Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1DebugSession
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1DebugSession
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Instance Attribute Summary collapse
-
#count ⇒ Fixnum
Optional.
-
#create_time ⇒ String
Output only.
-
#filter ⇒ String
Optional.
-
#name ⇒ String
A unique ID for this DebugSession.
-
#timeout ⇒ Fixnum
Optional.
-
#tracesize ⇒ Fixnum
Optional.
-
#validity ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1DebugSession
constructor
A new instance of GoogleCloudApigeeV1DebugSession.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1DebugSession
Returns a new instance of GoogleCloudApigeeV1DebugSession.
3736 3737 3738 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3736 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Fixnum
Optional. The number of request to be traced. Min = 1, Max = 15, Default = 10.
Corresponds to the JSON property count
3698 3699 3700 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3698 def count @count end |
#create_time ⇒ String
Output only. The first transaction creation timestamp, recorded by UAP.
Corresponds to the JSON property createTime
3703 3704 3705 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3703 def create_time @create_time end |
#filter ⇒ String
Optional. A conditional statement which is evaluated against the request
message to determine if it should be traced. Syntax matches that of on API
Proxy bundle flow Condition.
Corresponds to the JSON property filter
3710 3711 3712 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3710 def filter @filter end |
#name ⇒ String
A unique ID for this DebugSession.
Corresponds to the JSON property name
3715 3716 3717 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3715 def name @name end |
#timeout ⇒ Fixnum
Optional. The time in seconds after which this DebugSession should end. This
value will override the value in query param, if both are provided.
Corresponds to the JSON property timeout
3721 3722 3723 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3721 def timeout @timeout end |
#tracesize ⇒ Fixnum
Optional. The maximum number of bytes captured from the response payload. Min =
0, Max = 5120, Default = 5120.
Corresponds to the JSON property tracesize
3727 3728 3729 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3727 def tracesize @tracesize end |
#validity ⇒ Fixnum
Optional. The length of time, in seconds, that this debug session is valid,
starting from when it's received in the control plane. Min = 1, Max = 15,
Default = 10.
Corresponds to the JSON property validity
3734 3735 3736 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3734 def validity @validity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3741 3742 3743 3744 3745 3746 3747 3748 3749 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3741 def update!(**args) @count = args[:count] if args.key?(:count) @create_time = args[:create_time] if args.key?(:create_time) @filter = args[:filter] if args.key?(:filter) @name = args[:name] if args.key?(:name) @timeout = args[:timeout] if args.key?(:timeout) @tracesize = args[:tracesize] if args.key?(:tracesize) @validity = args[:validity] if args.key?(:validity) end |