Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1DebugSession

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1DebugSession

Returns a new instance of GoogleCloudApigeeV1DebugSession.



3687
3688
3689
# File 'lib/google/apis/apigee_v1/classes.rb', line 3687

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

Optional. The number of request to be traced. Min = 1, Max = 15, Default = 10. Corresponds to the JSON property count

Returns:

  • (Fixnum)


3649
3650
3651
# File 'lib/google/apis/apigee_v1/classes.rb', line 3649

def count
  @count
end

#create_timeString

Output only. The first transaction creation timestamp, recorded by UAP. Corresponds to the JSON property createTime

Returns:

  • (String)


3654
3655
3656
# File 'lib/google/apis/apigee_v1/classes.rb', line 3654

def create_time
  @create_time
end

#filterString

Optional. A conditional statement which is evaluated against the request message to determine if it should be traced. Syntax matches that of on API Proxy bundle flow Condition. Corresponds to the JSON property filter

Returns:

  • (String)


3661
3662
3663
# File 'lib/google/apis/apigee_v1/classes.rb', line 3661

def filter
  @filter
end

#nameString

A unique ID for this DebugSession. Corresponds to the JSON property name

Returns:

  • (String)


3666
3667
3668
# File 'lib/google/apis/apigee_v1/classes.rb', line 3666

def name
  @name
end

#timeoutFixnum

Optional. The time in seconds after which this DebugSession should end. This value will override the value in query param, if both are provided. Corresponds to the JSON property timeout

Returns:

  • (Fixnum)


3672
3673
3674
# File 'lib/google/apis/apigee_v1/classes.rb', line 3672

def timeout
  @timeout
end

#tracesizeFixnum

Optional. The maximum number of bytes captured from the response payload. Min = 0, Max = 5120, Default = 5120. Corresponds to the JSON property tracesize

Returns:

  • (Fixnum)


3678
3679
3680
# File 'lib/google/apis/apigee_v1/classes.rb', line 3678

def tracesize
  @tracesize
end

#validityFixnum

Optional. The length of time, in seconds, that this debug session is valid, starting from when it's received in the control plane. Min = 1, Max = 15, Default = 10. Corresponds to the JSON property validity

Returns:

  • (Fixnum)


3685
3686
3687
# File 'lib/google/apis/apigee_v1/classes.rb', line 3685

def validity
  @validity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3692
3693
3694
3695
3696
3697
3698
3699
3700
# File 'lib/google/apis/apigee_v1/classes.rb', line 3692

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @create_time = args[:create_time] if args.key?(:create_time)
  @filter = args[:filter] if args.key?(:filter)
  @name = args[:name] if args.key?(:name)
  @timeout = args[:timeout] if args.key?(:timeout)
  @tracesize = args[:tracesize] if args.key?(:tracesize)
  @validity = args[:validity] if args.key?(:validity)
end