Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1DebugSessionTransaction
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1DebugSessionTransaction
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
A transaction contains all of the debug information of the entire message flow of an API call processed by the runtime plane. The information is collected and recorded at critical points of the message flow in the runtime apiproxy.
Instance Attribute Summary collapse
-
#completed ⇒ Boolean
(also: #completed?)
Flag indicating whether a transaction is completed or not Corresponds to the JSON property
completed. -
#point ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Point>
List of debug data collected by runtime plane at various defined points in the flow.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1DebugSessionTransaction
constructor
A new instance of GoogleCloudApigeeV1DebugSessionTransaction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1DebugSessionTransaction
Returns a new instance of GoogleCloudApigeeV1DebugSessionTransaction.
3730 3731 3732 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3730 def initialize(**args) update!(**args) end |
Instance Attribute Details
#completed ⇒ Boolean Also known as: completed?
Flag indicating whether a transaction is completed or not
Corresponds to the JSON property completed
3721 3722 3723 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3721 def completed @completed end |
#point ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Point>
List of debug data collected by runtime plane at various defined points in the
flow.
Corresponds to the JSON property point
3728 3729 3730 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3728 def point @point end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3735 3736 3737 3738 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3735 def update!(**args) @completed = args[:completed] if args.key?(:completed) @point = args[:point] if args.key?(:point) end |