Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1DebugSessionTransaction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

A transaction contains all of the debug information of the entire message flow of an API call processed by the runtime plane. The information is collected and recorded at critical points of the message flow in the runtime apiproxy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1DebugSessionTransaction

Returns a new instance of GoogleCloudApigeeV1DebugSessionTransaction.



3770
3771
3772
# File 'lib/google/apis/apigee_v1/classes.rb', line 3770

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completedBoolean Also known as: completed?

Flag indicating whether a transaction is completed or not Corresponds to the JSON property completed

Returns:

  • (Boolean)


3761
3762
3763
# File 'lib/google/apis/apigee_v1/classes.rb', line 3761

def completed
  @completed
end

#pointArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Point>

List of debug data collected by runtime plane at various defined points in the flow. Corresponds to the JSON property point



3768
3769
3770
# File 'lib/google/apis/apigee_v1/classes.rb', line 3768

def point
  @point
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3775
3776
3777
3778
# File 'lib/google/apis/apigee_v1/classes.rb', line 3775

def update!(**args)
  @completed = args[:completed] if args.key?(:completed)
  @point = args[:point] if args.key?(:point)
end