Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Deployment
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1Deployment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Deployment represents a deployment of an API proxy or shared flow.
Instance Attribute Summary collapse
-
#api_proxy ⇒ String
API proxy.
-
#deploy_start_time ⇒ Fixnum
Time the API proxy was marked
deployedin the control plane in millisconds since epoch. -
#environment ⇒ String
Environment.
-
#errors ⇒ Array<Google::Apis::ApigeeV1::GoogleRpcStatus>
Errors reported for this deployment.
-
#instances ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1InstanceDeploymentStatus>
Status reported by each runtime instance.
-
#pods ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1PodStatus>
Status reported by runtime pods.
-
#proxy_deployment_type ⇒ String
Output only.
-
#revision ⇒ String
API proxy revision.
-
#route_conflicts ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeploymentChangeReportRoutingConflict>
Conflicts in the desired state routing configuration.
-
#service_account ⇒ String
The full resource name of Cloud IAM Service Account that this deployment is using, eg,
projects/-/serviceAccounts/email``. -
#state ⇒ String
Current state of the deployment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1Deployment
constructor
A new instance of GoogleCloudApigeeV1Deployment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1Deployment
Returns a new instance of GoogleCloudApigeeV1Deployment.
3877 3878 3879 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3877 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_proxy ⇒ String
API proxy.
Corresponds to the JSON property apiProxy
3810 3811 3812 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3810 def api_proxy @api_proxy end |
#deploy_start_time ⇒ Fixnum
Time the API proxy was marked deployed in the control plane in millisconds
since epoch.
Corresponds to the JSON property deployStartTime
3816 3817 3818 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3816 def deploy_start_time @deploy_start_time end |
#environment ⇒ String
Environment.
Corresponds to the JSON property environment
3821 3822 3823 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3821 def environment @environment end |
#errors ⇒ Array<Google::Apis::ApigeeV1::GoogleRpcStatus>
Errors reported for this deployment. Populated only when state == ERROR. **
Note**: This field is displayed only when viewing deployment status.
Corresponds to the JSON property errors
3827 3828 3829 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3827 def errors @errors end |
#instances ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1InstanceDeploymentStatus>
Status reported by each runtime instance. Note: This field is displayed
only when viewing deployment status.
Corresponds to the JSON property instances
3833 3834 3835 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3833 def instances @instances end |
#pods ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1PodStatus>
Status reported by runtime pods. Note: This field is deprecated.
Runtime versions 1.3 and above report instance level status rather than pod
status.
Corresponds to the JSON property pods
3840 3841 3842 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3840 def pods @pods end |
#proxy_deployment_type ⇒ String
Output only. The type of the deployment (standard or extensible) Deployed
proxy revision will be marked as extensible in following 2 cases. 1. The
deployed proxy revision uses extensible policies. 2. If a environment supports
flowhooks and flow hook is configured.
Corresponds to the JSON property proxyDeploymentType
3848 3849 3850 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3848 def proxy_deployment_type @proxy_deployment_type end |
#revision ⇒ String
API proxy revision.
Corresponds to the JSON property revision
3853 3854 3855 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3853 def revision @revision end |
#route_conflicts ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeploymentChangeReportRoutingConflict>
Conflicts in the desired state routing configuration. The presence of
conflicts does not cause the state to be ERROR, but it will mean that some
of the deployment's base paths are not routed to its environment. If the
conflicts change, the state will transition to PROGRESSING until the latest
configuration is rolled out to all instances. Note: This field is
displayed only when viewing deployment status.
Corresponds to the JSON property routeConflicts
3863 3864 3865 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3863 def route_conflicts @route_conflicts end |
#service_account ⇒ String
The full resource name of Cloud IAM Service Account that this deployment is
using, eg, projects/-/serviceAccounts/email`.
Corresponds to the JSON propertyserviceAccount`
3869 3870 3871 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3869 def service_account @service_account end |
#state ⇒ String
Current state of the deployment. Note: This field is displayed only when
viewing deployment status.
Corresponds to the JSON property state
3875 3876 3877 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3875 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3882 3883 3884 3885 3886 3887 3888 3889 3890 3891 3892 3893 3894 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3882 def update!(**args) @api_proxy = args[:api_proxy] if args.key?(:api_proxy) @deploy_start_time = args[:deploy_start_time] if args.key?(:deploy_start_time) @environment = args[:environment] if args.key?(:environment) @errors = args[:errors] if args.key?(:errors) @instances = args[:instances] if args.key?(:instances) @pods = args[:pods] if args.key?(:pods) @proxy_deployment_type = args[:proxy_deployment_type] if args.key?(:proxy_deployment_type) @revision = args[:revision] if args.key?(:revision) @route_conflicts = args[:route_conflicts] if args.key?(:route_conflicts) @service_account = args[:service_account] if args.key?(:service_account) @state = args[:state] if args.key?(:state) end |