Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Deployment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Deployment represents a deployment of an API proxy or shared flow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1Deployment

Returns a new instance of GoogleCloudApigeeV1Deployment.



3868
3869
3870
# File 'lib/google/apis/apigee_v1/classes.rb', line 3868

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_proxyString

API proxy. Corresponds to the JSON property apiProxy

Returns:

  • (String)


3801
3802
3803
# File 'lib/google/apis/apigee_v1/classes.rb', line 3801

def api_proxy
  @api_proxy
end

#deploy_start_timeFixnum

Time the API proxy was marked deployed in the control plane in millisconds since epoch. Corresponds to the JSON property deployStartTime

Returns:

  • (Fixnum)


3807
3808
3809
# File 'lib/google/apis/apigee_v1/classes.rb', line 3807

def deploy_start_time
  @deploy_start_time
end

#environmentString

Environment. Corresponds to the JSON property environment

Returns:

  • (String)


3812
3813
3814
# File 'lib/google/apis/apigee_v1/classes.rb', line 3812

def environment
  @environment
end

#errorsArray<Google::Apis::ApigeeV1::GoogleRpcStatus>

Errors reported for this deployment. Populated only when state == ERROR. ** Note**: This field is displayed only when viewing deployment status. Corresponds to the JSON property errors



3818
3819
3820
# File 'lib/google/apis/apigee_v1/classes.rb', line 3818

def errors
  @errors
end

#instancesArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1InstanceDeploymentStatus>

Status reported by each runtime instance. Note: This field is displayed only when viewing deployment status. Corresponds to the JSON property instances



3824
3825
3826
# File 'lib/google/apis/apigee_v1/classes.rb', line 3824

def instances
  @instances
end

#podsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1PodStatus>

Status reported by runtime pods. Note: This field is deprecated. Runtime versions 1.3 and above report instance level status rather than pod status. Corresponds to the JSON property pods



3831
3832
3833
# File 'lib/google/apis/apigee_v1/classes.rb', line 3831

def pods
  @pods
end

#proxy_deployment_typeString

Output only. The type of the deployment (standard or extensible) Deployed proxy revision will be marked as extensible in following 2 cases. 1. The deployed proxy revision uses extensible policies. 2. If a environment supports flowhooks and flow hook is configured. Corresponds to the JSON property proxyDeploymentType

Returns:

  • (String)


3839
3840
3841
# File 'lib/google/apis/apigee_v1/classes.rb', line 3839

def proxy_deployment_type
  @proxy_deployment_type
end

#revisionString

API proxy revision. Corresponds to the JSON property revision

Returns:

  • (String)


3844
3845
3846
# File 'lib/google/apis/apigee_v1/classes.rb', line 3844

def revision
  @revision
end

#route_conflictsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeploymentChangeReportRoutingConflict>

Conflicts in the desired state routing configuration. The presence of conflicts does not cause the state to be ERROR, but it will mean that some of the deployment's base paths are not routed to its environment. If the conflicts change, the state will transition to PROGRESSING until the latest configuration is rolled out to all instances. Note: This field is displayed only when viewing deployment status. Corresponds to the JSON property routeConflicts



3854
3855
3856
# File 'lib/google/apis/apigee_v1/classes.rb', line 3854

def route_conflicts
  @route_conflicts
end

#service_accountString

The full resource name of Cloud IAM Service Account that this deployment is using, eg, projects/-/serviceAccounts/email`. Corresponds to the JSON propertyserviceAccount`

Returns:

  • (String)


3860
3861
3862
# File 'lib/google/apis/apigee_v1/classes.rb', line 3860

def 
  @service_account
end

#stateString

Current state of the deployment. Note: This field is displayed only when viewing deployment status. Corresponds to the JSON property state

Returns:

  • (String)


3866
3867
3868
# File 'lib/google/apis/apigee_v1/classes.rb', line 3866

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3873
3874
3875
3876
3877
3878
3879
3880
3881
3882
3883
3884
3885
# File 'lib/google/apis/apigee_v1/classes.rb', line 3873

def update!(**args)
  @api_proxy = args[:api_proxy] if args.key?(:api_proxy)
  @deploy_start_time = args[:deploy_start_time] if args.key?(:deploy_start_time)
  @environment = args[:environment] if args.key?(:environment)
  @errors = args[:errors] if args.key?(:errors)
  @instances = args[:instances] if args.key?(:instances)
  @pods = args[:pods] if args.key?(:pods)
  @proxy_deployment_type = args[:proxy_deployment_type] if args.key?(:proxy_deployment_type)
  @revision = args[:revision] if args.key?(:revision)
  @route_conflicts = args[:route_conflicts] if args.key?(:route_conflicts)
  @service_account = args[:service_account] if args.key?(:service_account)
  @state = args[:state] if args.key?(:state)
end