Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeploymentChangeReport
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeploymentChangeReport
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Response for GenerateDeployChangeReport and GenerateUndeployChangeReport. This report contains any validation failures that would cause the deployment to be rejected, as well changes and conflicts in routing that may occur due to the new deployment. The existence of a routing warning does not necessarily imply that the deployment request is bad, if the desired state of the deployment request is to effect a routing change. The primary purposes of the routing messages are: 1) To inform users of routing changes that may have an effect on traffic currently being routed to other existing deployments. 2) To warn users if some base path in the proxy will not receive traffic due to an existing deployment having already claimed that base path. The presence of routing conflicts/changes will not cause non-dry-run DeployApiProxy/UndeployApiProxy requests to be rejected.
Instance Attribute Summary collapse
-
#routing_changes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeploymentChangeReportRoutingChange>
All routing changes that may result from a deployment request.
-
#routing_conflicts ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeploymentChangeReportRoutingConflict>
All base path conflicts detected for a deployment request.
-
#validation_errors ⇒ Google::Apis::ApigeeV1::GoogleRpcPreconditionFailure
Describes what preconditions have failed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1DeploymentChangeReport
constructor
A new instance of GoogleCloudApigeeV1DeploymentChangeReport.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1DeploymentChangeReport
Returns a new instance of GoogleCloudApigeeV1DeploymentChangeReport.
3929 3930 3931 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3929 def initialize(**args) update!(**args) end |
Instance Attribute Details
#routing_changes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeploymentChangeReportRoutingChange>
All routing changes that may result from a deployment request.
Corresponds to the JSON property routingChanges
3915 3916 3917 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3915 def routing_changes @routing_changes end |
#routing_conflicts ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeploymentChangeReportRoutingConflict>
All base path conflicts detected for a deployment request.
Corresponds to the JSON property routingConflicts
3920 3921 3922 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3920 def routing_conflicts @routing_conflicts end |
#validation_errors ⇒ Google::Apis::ApigeeV1::GoogleRpcPreconditionFailure
Describes what preconditions have failed. For example, if an RPC failed
because it required the Terms of Service to be acknowledged, it could list the
terms of service violation in the PreconditionFailure message.
Corresponds to the JSON property validationErrors
3927 3928 3929 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3927 def validation_errors @validation_errors end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3934 3935 3936 3937 3938 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 3934 def update!(**args) @routing_changes = args[:routing_changes] if args.key?(:routing_changes) @routing_conflicts = args[:routing_conflicts] if args.key?(:routing_conflicts) @validation_errors = args[:validation_errors] if args.key?(:validation_errors) end |