Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeploymentChangeReportRoutingChange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Describes a potential routing change that may occur as a result of some deployment operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1DeploymentChangeReportRoutingChange

Returns a new instance of GoogleCloudApigeeV1DeploymentChangeReportRoutingChange.



3965
3966
3967
# File 'lib/google/apis/apigee_v1/classes.rb', line 3965

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Human-readable description of this routing change. Corresponds to the JSON property description

Returns:

  • (String)


3940
3941
3942
# File 'lib/google/apis/apigee_v1/classes.rb', line 3940

def description
  @description
end

#environment_groupString

Name of the environment group affected by this routing change. Corresponds to the JSON property environmentGroup

Returns:

  • (String)


3945
3946
3947
# File 'lib/google/apis/apigee_v1/classes.rb', line 3945

def environment_group
  @environment_group
end

#from_deploymentGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1DeploymentChangeReportRoutingDeployment

Tuple representing a base path and the deployment containing it. Corresponds to the JSON property fromDeployment



3950
3951
3952
# File 'lib/google/apis/apigee_v1/classes.rb', line 3950

def from_deployment
  @from_deployment
end

#should_sequence_rolloutBoolean Also known as: should_sequence_rollout?

Set to true if using sequenced rollout would make this routing change safer. Note: This does not necessarily imply that automated sequenced rollout mode is supported for the operation. Corresponds to the JSON property shouldSequenceRollout

Returns:

  • (Boolean)


3957
3958
3959
# File 'lib/google/apis/apigee_v1/classes.rb', line 3957

def should_sequence_rollout
  @should_sequence_rollout
end

#to_deploymentGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1DeploymentChangeReportRoutingDeployment

Tuple representing a base path and the deployment containing it. Corresponds to the JSON property toDeployment



3963
3964
3965
# File 'lib/google/apis/apigee_v1/classes.rb', line 3963

def to_deployment
  @to_deployment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3970
3971
3972
3973
3974
3975
3976
# File 'lib/google/apis/apigee_v1/classes.rb', line 3970

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @environment_group = args[:environment_group] if args.key?(:environment_group)
  @from_deployment = args[:from_deployment] if args.key?(:from_deployment)
  @should_sequence_rollout = args[:should_sequence_rollout] if args.key?(:should_sequence_rollout)
  @to_deployment = args[:to_deployment] if args.key?(:to_deployment)
end