Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeploymentChangeReportRoutingConflict

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Describes a routing conflict that may cause a deployment not to receive traffic at some base path.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1DeploymentChangeReportRoutingConflict

Returns a new instance of GoogleCloudApigeeV1DeploymentChangeReportRoutingConflict.



3999
4000
4001
# File 'lib/google/apis/apigee_v1/classes.rb', line 3999

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conflicting_deploymentGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1DeploymentChangeReportRoutingDeployment

Tuple representing a base path and the deployment containing it. Corresponds to the JSON property conflictingDeployment



3987
3988
3989
# File 'lib/google/apis/apigee_v1/classes.rb', line 3987

def conflicting_deployment
  @conflicting_deployment
end

#descriptionString

Human-readable description of this conflict. Corresponds to the JSON property description

Returns:

  • (String)


3992
3993
3994
# File 'lib/google/apis/apigee_v1/classes.rb', line 3992

def description
  @description
end

#environment_groupString

Name of the environment group in which this conflict exists. Corresponds to the JSON property environmentGroup

Returns:

  • (String)


3997
3998
3999
# File 'lib/google/apis/apigee_v1/classes.rb', line 3997

def environment_group
  @environment_group
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4004
4005
4006
4007
4008
# File 'lib/google/apis/apigee_v1/classes.rb', line 4004

def update!(**args)
  @conflicting_deployment = args[:conflicting_deployment] if args.key?(:conflicting_deployment)
  @description = args[:description] if args.key?(:description)
  @environment_group = args[:environment_group] if args.key?(:environment_group)
end