Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeploymentChangeReportRoutingDeployment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Tuple representing a base path and the deployment containing it.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1DeploymentChangeReportRoutingDeployment

Returns a new instance of GoogleCloudApigeeV1DeploymentChangeReportRoutingDeployment.



4035
4036
4037
# File 'lib/google/apis/apigee_v1/classes.rb', line 4035

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_proxyString

Name of the deployed API proxy revision containing the base path. Corresponds to the JSON property apiProxy

Returns:

  • (String)


4018
4019
4020
# File 'lib/google/apis/apigee_v1/classes.rb', line 4018

def api_proxy
  @api_proxy
end

#basepathString

Base path receiving traffic. Corresponds to the JSON property basepath

Returns:

  • (String)


4023
4024
4025
# File 'lib/google/apis/apigee_v1/classes.rb', line 4023

def basepath
  @basepath
end

#environmentString

Name of the environment in which the proxy is deployed. Corresponds to the JSON property environment

Returns:

  • (String)


4028
4029
4030
# File 'lib/google/apis/apigee_v1/classes.rb', line 4028

def environment
  @environment
end

#revisionString

Name of the deployed API proxy revision containing the base path. Corresponds to the JSON property revision

Returns:

  • (String)


4033
4034
4035
# File 'lib/google/apis/apigee_v1/classes.rb', line 4033

def revision
  @revision
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4040
4041
4042
4043
4044
4045
# File 'lib/google/apis/apigee_v1/classes.rb', line 4040

def update!(**args)
  @api_proxy = args[:api_proxy] if args.key?(:api_proxy)
  @basepath = args[:basepath] if args.key?(:basepath)
  @environment = args[:environment] if args.key?(:environment)
  @revision = args[:revision] if args.key?(:revision)
end