Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeploymentConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeploymentConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
NEXT ID: 11
Instance Attribute Summary collapse
-
#attributes ⇒ Hash<String,String>
Additional key-value metadata for the deployment.
-
#base_path ⇒ String
Base path where the application will be hosted.
-
#deployment_groups ⇒ Array<String>
The list of deployment groups in which this proxy should be deployed.
-
#endpoints ⇒ Hash<String,String>
A mapping from basepaths to proxy endpoint names in this proxy.
-
#location ⇒ String
Location of the API proxy bundle as a URI.
-
#name ⇒ String
Name of the API or shared flow revision to be deployed in the following format:
organizations/org/apis/api/revisions/revor `organizations/`org`/ sharedflows/`sharedflow`/revisions/`revCorresponds to the JSON propertyname. -
#proxy_uid ⇒ String
Unique ID of the API proxy revision.
-
#service_account ⇒ String
The service account identity associated with this deployment.
-
#uid ⇒ String
Unique ID.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1DeploymentConfig
constructor
A new instance of GoogleCloudApigeeV1DeploymentConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1DeploymentConfig
Returns a new instance of GoogleCloudApigeeV1DeploymentConfig.
4151 4152 4153 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4151 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributes ⇒ Hash<String,String>
Additional key-value metadata for the deployment.
Corresponds to the JSON property attributes
4104 4105 4106 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4104 def attributes @attributes end |
#base_path ⇒ String
Base path where the application will be hosted. Defaults to "/".
Corresponds to the JSON property basePath
4109 4110 4111 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4109 def base_path @base_path end |
#deployment_groups ⇒ Array<String>
The list of deployment groups in which this proxy should be deployed. Not
currently populated for shared flows.
Corresponds to the JSON property deploymentGroups
4115 4116 4117 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4115 def deployment_groups @deployment_groups end |
#endpoints ⇒ Hash<String,String>
A mapping from basepaths to proxy endpoint names in this proxy. Not populated
for shared flows.
Corresponds to the JSON property endpoints
4121 4122 4123 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4121 def endpoints @endpoints end |
#location ⇒ String
Location of the API proxy bundle as a URI.
Corresponds to the JSON property location
4126 4127 4128 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4126 def location @location end |
#name ⇒ String
Name of the API or shared flow revision to be deployed in the following format:
organizations/org/apis/api/revisions/revor `organizations/`org`/
sharedflows/`sharedflow`/revisions/`rev
Corresponds to the JSON property name
4133 4134 4135 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4133 def name @name end |
#proxy_uid ⇒ String
Unique ID of the API proxy revision.
Corresponds to the JSON property proxyUid
4138 4139 4140 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4138 def proxy_uid @proxy_uid end |
#service_account ⇒ String
The service account identity associated with this deployment. If non-empty,
will be in the following format: projects/-/serviceAccounts/account_email`
Corresponds to the JSON propertyserviceAccount`
4144 4145 4146 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4144 def service_account @service_account end |
#uid ⇒ String
Unique ID. The ID will only change if the deployment is deleted and recreated.
Corresponds to the JSON property uid
4149 4150 4151 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4149 def uid @uid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4156 4157 4158 4159 4160 4161 4162 4163 4164 4165 4166 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4156 def update!(**args) @attributes = args[:attributes] if args.key?(:attributes) @base_path = args[:base_path] if args.key?(:base_path) @deployment_groups = args[:deployment_groups] if args.key?(:deployment_groups) @endpoints = args[:endpoints] if args.key?(:endpoints) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @proxy_uid = args[:proxy_uid] if args.key?(:proxy_uid) @service_account = args[:service_account] if args.key?(:service_account) @uid = args[:uid] if args.key?(:uid) end |