Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeploymentConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeploymentConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
NEXT ID: 11
Instance Attribute Summary collapse
-
#attributes ⇒ Hash<String,String>
Additional key-value metadata for the deployment.
-
#base_path ⇒ String
Base path where the application will be hosted.
-
#deployment_groups ⇒ Array<String>
The list of deployment groups in which this proxy should be deployed.
-
#endpoints ⇒ Hash<String,String>
A mapping from basepaths to proxy endpoint names in this proxy.
-
#location ⇒ String
Location of the API proxy bundle as a URI.
-
#name ⇒ String
Name of the API or shared flow revision to be deployed in the following format:
organizations/org/apis/api/revisions/revor `organizations/`org`/ sharedflows/`sharedflow`/revisions/`revCorresponds to the JSON propertyname. -
#proxy_uid ⇒ String
Unique ID of the API proxy revision.
-
#service_account ⇒ String
The service account identity associated with this deployment.
-
#uid ⇒ String
Unique ID.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1DeploymentConfig
constructor
A new instance of GoogleCloudApigeeV1DeploymentConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1DeploymentConfig
Returns a new instance of GoogleCloudApigeeV1DeploymentConfig.
4102 4103 4104 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4102 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributes ⇒ Hash<String,String>
Additional key-value metadata for the deployment.
Corresponds to the JSON property attributes
4055 4056 4057 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4055 def attributes @attributes end |
#base_path ⇒ String
Base path where the application will be hosted. Defaults to "/".
Corresponds to the JSON property basePath
4060 4061 4062 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4060 def base_path @base_path end |
#deployment_groups ⇒ Array<String>
The list of deployment groups in which this proxy should be deployed. Not
currently populated for shared flows.
Corresponds to the JSON property deploymentGroups
4066 4067 4068 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4066 def deployment_groups @deployment_groups end |
#endpoints ⇒ Hash<String,String>
A mapping from basepaths to proxy endpoint names in this proxy. Not populated
for shared flows.
Corresponds to the JSON property endpoints
4072 4073 4074 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4072 def endpoints @endpoints end |
#location ⇒ String
Location of the API proxy bundle as a URI.
Corresponds to the JSON property location
4077 4078 4079 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4077 def location @location end |
#name ⇒ String
Name of the API or shared flow revision to be deployed in the following format:
organizations/org/apis/api/revisions/revor `organizations/`org`/
sharedflows/`sharedflow`/revisions/`rev
Corresponds to the JSON property name
4084 4085 4086 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4084 def name @name end |
#proxy_uid ⇒ String
Unique ID of the API proxy revision.
Corresponds to the JSON property proxyUid
4089 4090 4091 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4089 def proxy_uid @proxy_uid end |
#service_account ⇒ String
The service account identity associated with this deployment. If non-empty,
will be in the following format: projects/-/serviceAccounts/account_email`
Corresponds to the JSON propertyserviceAccount`
4095 4096 4097 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4095 def service_account @service_account end |
#uid ⇒ String
Unique ID. The ID will only change if the deployment is deleted and recreated.
Corresponds to the JSON property uid
4100 4101 4102 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4100 def uid @uid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4107 4108 4109 4110 4111 4112 4113 4114 4115 4116 4117 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4107 def update!(**args) @attributes = args[:attributes] if args.key?(:attributes) @base_path = args[:base_path] if args.key?(:base_path) @deployment_groups = args[:deployment_groups] if args.key?(:deployment_groups) @endpoints = args[:endpoints] if args.key?(:endpoints) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @proxy_uid = args[:proxy_uid] if args.key?(:proxy_uid) @service_account = args[:service_account] if args.key?(:service_account) @uid = args[:uid] if args.key?(:uid) end |