Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeploymentGroupConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeploymentGroupConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
DeploymentGroupConfig represents a deployment group that should be present in a particular environment.
Instance Attribute Summary collapse
-
#deployment_group_type ⇒ String
Type of the deployment group, which will be either Standard or Extensible.
-
#name ⇒ String
Name of the deployment group in the following format:
organizations/org/ environments/env/deploymentGroups/group``. -
#revision_id ⇒ Fixnum
Revision number which can be used by the runtime to detect if the deployment group has changed between two versions.
-
#uid ⇒ String
Unique ID.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1DeploymentGroupConfig
constructor
A new instance of GoogleCloudApigeeV1DeploymentGroupConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1DeploymentGroupConfig
Returns a new instance of GoogleCloudApigeeV1DeploymentGroupConfig.
4148 4149 4150 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4148 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployment_group_type ⇒ String
Type of the deployment group, which will be either Standard or Extensible.
Corresponds to the JSON property deploymentGroupType
4128 4129 4130 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4128 def deployment_group_type @deployment_group_type end |
#name ⇒ String
Name of the deployment group in the following format: organizations/org/
environments/env/deploymentGroups/group`.
Corresponds to the JSON propertyname`
4134 4135 4136 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4134 def name @name end |
#revision_id ⇒ Fixnum
Revision number which can be used by the runtime to detect if the deployment
group has changed between two versions.
Corresponds to the JSON property revisionId
4140 4141 4142 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4140 def revision_id @revision_id end |
#uid ⇒ String
Unique ID. The ID will only change if the deployment group is deleted and
recreated.
Corresponds to the JSON property uid
4146 4147 4148 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4146 def uid @uid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4153 4154 4155 4156 4157 4158 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4153 def update!(**args) @deployment_group_type = args[:deployment_group_type] if args.key?(:deployment_group_type) @name = args[:name] if args.key?(:name) @revision_id = args[:revision_id] if args.key?(:revision_id) @uid = args[:uid] if args.key?(:uid) end |