Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Developer
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1Developer
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Instance Attribute Summary collapse
-
#access_type ⇒ String
Access type.
-
#app_family ⇒ String
Developer app family.
-
#apps ⇒ Array<String>
List of apps associated with the developer.
-
#attributes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>
Optional.
-
#companies ⇒ Array<String>
List of companies associated with the developer.
-
#created_at ⇒ Fixnum
Output only.
-
#developer_id ⇒ String
ID of the developer.
-
#email ⇒ String
Required.
-
#first_name ⇒ String
Required.
-
#last_modified_at ⇒ Fixnum
Output only.
-
#last_name ⇒ String
Required.
-
#organization_name ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#user_name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1Developer
constructor
A new instance of GoogleCloudApigeeV1Developer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1Developer
Returns a new instance of GoogleCloudApigeeV1Developer.
4290 4291 4292 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4290 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_type ⇒ String
Access type.
Corresponds to the JSON property accessType
4217 4218 4219 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4217 def access_type @access_type end |
#app_family ⇒ String
Developer app family.
Corresponds to the JSON property appFamily
4222 4223 4224 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4222 def app_family @app_family end |
#apps ⇒ Array<String>
List of apps associated with the developer.
Corresponds to the JSON property apps
4227 4228 4229 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4227 def apps @apps end |
#attributes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>
Optional. Developer attributes (name/value pairs). The custom attribute limit
is 18.
Corresponds to the JSON property attributes
4233 4234 4235 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4233 def attributes @attributes end |
#companies ⇒ Array<String>
List of companies associated with the developer.
Corresponds to the JSON property companies
4238 4239 4240 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4238 def companies @companies end |
#created_at ⇒ Fixnum
Output only. Time at which the developer was created in milliseconds since
epoch.
Corresponds to the JSON property createdAt
4244 4245 4246 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4244 def created_at @created_at end |
#developer_id ⇒ String
ID of the developer. Note: IDs are generated internally by Apigee and are
not guaranteed to stay the same over time.
Corresponds to the JSON property developerId
4250 4251 4252 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4250 def developer_id @developer_id end |
#email ⇒ String
Required. Email address of the developer. This value is used to uniquely
identify the developer in Apigee hybrid. Note that the email address has to be
in lowercase only.
Corresponds to the JSON property email
4257 4258 4259 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4257 def email @email end |
#first_name ⇒ String
Required. First name of the developer.
Corresponds to the JSON property firstName
4262 4263 4264 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4262 def first_name @first_name end |
#last_modified_at ⇒ Fixnum
Output only. Time at which the developer was last modified in milliseconds
since epoch.
Corresponds to the JSON property lastModifiedAt
4268 4269 4270 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4268 def last_modified_at @last_modified_at end |
#last_name ⇒ String
Required. Last name of the developer.
Corresponds to the JSON property lastName
4273 4274 4275 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4273 def last_name @last_name end |
#organization_name ⇒ String
Output only. Name of the Apigee organization in which the developer resides.
Corresponds to the JSON property organizationName
4278 4279 4280 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4278 def organization_name @organization_name end |
#status ⇒ String
Output only. Status of the developer. Valid values are active and inactive.
Corresponds to the JSON property status
4283 4284 4285 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4283 def status @status end |
#user_name ⇒ String
Required. User name of the developer. Not used by Apigee hybrid.
Corresponds to the JSON property userName
4288 4289 4290 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4288 def user_name @user_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4295 4296 4297 4298 4299 4300 4301 4302 4303 4304 4305 4306 4307 4308 4309 4310 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4295 def update!(**args) @access_type = args[:access_type] if args.key?(:access_type) @app_family = args[:app_family] if args.key?(:app_family) @apps = args[:apps] if args.key?(:apps) @attributes = args[:attributes] if args.key?(:attributes) @companies = args[:companies] if args.key?(:companies) @created_at = args[:created_at] if args.key?(:created_at) @developer_id = args[:developer_id] if args.key?(:developer_id) @email = args[:email] if args.key?(:email) @first_name = args[:first_name] if args.key?(:first_name) @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at) @last_name = args[:last_name] if args.key?(:last_name) @organization_name = args[:organization_name] if args.key?(:organization_name) @status = args[:status] if args.key?(:status) @user_name = args[:user_name] if args.key?(:user_name) end |