Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Developer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1Developer

Returns a new instance of GoogleCloudApigeeV1Developer.



4241
4242
4243
# File 'lib/google/apis/apigee_v1/classes.rb', line 4241

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_typeString

Access type. Corresponds to the JSON property accessType

Returns:

  • (String)


4168
4169
4170
# File 'lib/google/apis/apigee_v1/classes.rb', line 4168

def access_type
  @access_type
end

#app_familyString

Developer app family. Corresponds to the JSON property appFamily

Returns:

  • (String)


4173
4174
4175
# File 'lib/google/apis/apigee_v1/classes.rb', line 4173

def app_family
  @app_family
end

#appsArray<String>

List of apps associated with the developer. Corresponds to the JSON property apps

Returns:

  • (Array<String>)


4178
4179
4180
# File 'lib/google/apis/apigee_v1/classes.rb', line 4178

def apps
  @apps
end

#attributesArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>

Optional. Developer attributes (name/value pairs). The custom attribute limit is 18. Corresponds to the JSON property attributes



4184
4185
4186
# File 'lib/google/apis/apigee_v1/classes.rb', line 4184

def attributes
  @attributes
end

#companiesArray<String>

List of companies associated with the developer. Corresponds to the JSON property companies

Returns:

  • (Array<String>)


4189
4190
4191
# File 'lib/google/apis/apigee_v1/classes.rb', line 4189

def companies
  @companies
end

#created_atFixnum

Output only. Time at which the developer was created in milliseconds since epoch. Corresponds to the JSON property createdAt

Returns:

  • (Fixnum)


4195
4196
4197
# File 'lib/google/apis/apigee_v1/classes.rb', line 4195

def created_at
  @created_at
end

#developer_idString

ID of the developer. Note: IDs are generated internally by Apigee and are not guaranteed to stay the same over time. Corresponds to the JSON property developerId

Returns:

  • (String)


4201
4202
4203
# File 'lib/google/apis/apigee_v1/classes.rb', line 4201

def developer_id
  @developer_id
end

#emailString

Required. Email address of the developer. This value is used to uniquely identify the developer in Apigee hybrid. Note that the email address has to be in lowercase only. Corresponds to the JSON property email

Returns:

  • (String)


4208
4209
4210
# File 'lib/google/apis/apigee_v1/classes.rb', line 4208

def email
  @email
end

#first_nameString

Required. First name of the developer. Corresponds to the JSON property firstName

Returns:

  • (String)


4213
4214
4215
# File 'lib/google/apis/apigee_v1/classes.rb', line 4213

def first_name
  @first_name
end

#last_modified_atFixnum

Output only. Time at which the developer was last modified in milliseconds since epoch. Corresponds to the JSON property lastModifiedAt

Returns:

  • (Fixnum)


4219
4220
4221
# File 'lib/google/apis/apigee_v1/classes.rb', line 4219

def last_modified_at
  @last_modified_at
end

#last_nameString

Required. Last name of the developer. Corresponds to the JSON property lastName

Returns:

  • (String)


4224
4225
4226
# File 'lib/google/apis/apigee_v1/classes.rb', line 4224

def last_name
  @last_name
end

#organization_nameString

Output only. Name of the Apigee organization in which the developer resides. Corresponds to the JSON property organizationName

Returns:

  • (String)


4229
4230
4231
# File 'lib/google/apis/apigee_v1/classes.rb', line 4229

def organization_name
  @organization_name
end

#statusString

Output only. Status of the developer. Valid values are active and inactive. Corresponds to the JSON property status

Returns:

  • (String)


4234
4235
4236
# File 'lib/google/apis/apigee_v1/classes.rb', line 4234

def status
  @status
end

#user_nameString

Required. User name of the developer. Not used by Apigee hybrid. Corresponds to the JSON property userName

Returns:

  • (String)


4239
4240
4241
# File 'lib/google/apis/apigee_v1/classes.rb', line 4239

def user_name
  @user_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
# File 'lib/google/apis/apigee_v1/classes.rb', line 4246

def update!(**args)
  @access_type = args[:access_type] if args.key?(:access_type)
  @app_family = args[:app_family] if args.key?(:app_family)
  @apps = args[:apps] if args.key?(:apps)
  @attributes = args[:attributes] if args.key?(:attributes)
  @companies = args[:companies] if args.key?(:companies)
  @created_at = args[:created_at] if args.key?(:created_at)
  @developer_id = args[:developer_id] if args.key?(:developer_id)
  @email = args[:email] if args.key?(:email)
  @first_name = args[:first_name] if args.key?(:first_name)
  @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at)
  @last_name = args[:last_name] if args.key?(:last_name)
  @organization_name = args[:organization_name] if args.key?(:organization_name)
  @status = args[:status] if args.key?(:status)
  @user_name = args[:user_name] if args.key?(:user_name)
end