Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Developer
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1Developer
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Instance Attribute Summary collapse
-
#access_type ⇒ String
Access type.
-
#app_family ⇒ String
Developer app family.
-
#apps ⇒ Array<String>
List of apps associated with the developer.
-
#attributes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>
Optional.
-
#companies ⇒ Array<String>
List of companies associated with the developer.
-
#created_at ⇒ Fixnum
Output only.
-
#developer_id ⇒ String
ID of the developer.
-
#email ⇒ String
Required.
-
#first_name ⇒ String
Required.
-
#last_modified_at ⇒ Fixnum
Output only.
-
#last_name ⇒ String
Required.
-
#organization_name ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#user_name ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1Developer
constructor
A new instance of GoogleCloudApigeeV1Developer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1Developer
Returns a new instance of GoogleCloudApigeeV1Developer.
4241 4242 4243 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4241 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_type ⇒ String
Access type.
Corresponds to the JSON property accessType
4168 4169 4170 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4168 def access_type @access_type end |
#app_family ⇒ String
Developer app family.
Corresponds to the JSON property appFamily
4173 4174 4175 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4173 def app_family @app_family end |
#apps ⇒ Array<String>
List of apps associated with the developer.
Corresponds to the JSON property apps
4178 4179 4180 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4178 def apps @apps end |
#attributes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>
Optional. Developer attributes (name/value pairs). The custom attribute limit
is 18.
Corresponds to the JSON property attributes
4184 4185 4186 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4184 def attributes @attributes end |
#companies ⇒ Array<String>
List of companies associated with the developer.
Corresponds to the JSON property companies
4189 4190 4191 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4189 def companies @companies end |
#created_at ⇒ Fixnum
Output only. Time at which the developer was created in milliseconds since
epoch.
Corresponds to the JSON property createdAt
4195 4196 4197 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4195 def created_at @created_at end |
#developer_id ⇒ String
ID of the developer. Note: IDs are generated internally by Apigee and are
not guaranteed to stay the same over time.
Corresponds to the JSON property developerId
4201 4202 4203 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4201 def developer_id @developer_id end |
#email ⇒ String
Required. Email address of the developer. This value is used to uniquely
identify the developer in Apigee hybrid. Note that the email address has to be
in lowercase only.
Corresponds to the JSON property email
4208 4209 4210 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4208 def email @email end |
#first_name ⇒ String
Required. First name of the developer.
Corresponds to the JSON property firstName
4213 4214 4215 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4213 def first_name @first_name end |
#last_modified_at ⇒ Fixnum
Output only. Time at which the developer was last modified in milliseconds
since epoch.
Corresponds to the JSON property lastModifiedAt
4219 4220 4221 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4219 def last_modified_at @last_modified_at end |
#last_name ⇒ String
Required. Last name of the developer.
Corresponds to the JSON property lastName
4224 4225 4226 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4224 def last_name @last_name end |
#organization_name ⇒ String
Output only. Name of the Apigee organization in which the developer resides.
Corresponds to the JSON property organizationName
4229 4230 4231 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4229 def organization_name @organization_name end |
#status ⇒ String
Output only. Status of the developer. Valid values are active and inactive.
Corresponds to the JSON property status
4234 4235 4236 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4234 def status @status end |
#user_name ⇒ String
Required. User name of the developer. Not used by Apigee hybrid.
Corresponds to the JSON property userName
4239 4240 4241 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4239 def user_name @user_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4246 4247 4248 4249 4250 4251 4252 4253 4254 4255 4256 4257 4258 4259 4260 4261 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4246 def update!(**args) @access_type = args[:access_type] if args.key?(:access_type) @app_family = args[:app_family] if args.key?(:app_family) @apps = args[:apps] if args.key?(:apps) @attributes = args[:attributes] if args.key?(:attributes) @companies = args[:companies] if args.key?(:companies) @created_at = args[:created_at] if args.key?(:created_at) @developer_id = args[:developer_id] if args.key?(:developer_id) @email = args[:email] if args.key?(:email) @first_name = args[:first_name] if args.key?(:first_name) @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at) @last_name = args[:last_name] if args.key?(:last_name) @organization_name = args[:organization_name] if args.key?(:organization_name) @status = args[:status] if args.key?(:status) @user_name = args[:user_name] if args.key?(:user_name) end |