Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeveloperApp
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeveloperApp
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Instance Attribute Summary collapse
-
#api_products ⇒ Array<String>
List of API products associated with the developer app.
-
#app_family ⇒ String
Developer app family.
-
#app_id ⇒ String
ID of the developer app.
-
#attributes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>
List of attributes for the developer app.
-
#callback_url ⇒ String
Callback URL used by OAuth 2.0 authorization servers to communicate authorization codes back to developer apps.
-
#created_at ⇒ Fixnum
Output only.
-
#credentials ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Credential>
Output only.
-
#developer_id ⇒ String
ID of the developer.
-
#key_expires_in ⇒ Fixnum
Expiration time, in milliseconds, for the consumer key that is generated for the developer app.
-
#last_modified_at ⇒ Fixnum
Output only.
-
#name ⇒ String
Name of the developer app.
-
#scopes ⇒ Array<String>
Scopes to apply to the developer app.
-
#status ⇒ String
Status of the credential.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1DeveloperApp
constructor
A new instance of GoogleCloudApigeeV1DeveloperApp.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1DeveloperApp
Returns a new instance of GoogleCloudApigeeV1DeveloperApp.
4357 4358 4359 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4357 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_products ⇒ Array<String>
List of API products associated with the developer app.
Corresponds to the JSON property apiProducts
4289 4290 4291 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4289 def api_products @api_products end |
#app_family ⇒ String
Developer app family.
Corresponds to the JSON property appFamily
4294 4295 4296 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4294 def app_family @app_family end |
#app_id ⇒ String
ID of the developer app. This ID is not user specified but is automatically
generated on app creation. appId is a UUID.
Corresponds to the JSON property appId
4300 4301 4302 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4300 def app_id @app_id end |
#attributes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>
List of attributes for the developer app.
Corresponds to the JSON property attributes
4305 4306 4307 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4305 def attributes @attributes end |
#callback_url ⇒ String
Callback URL used by OAuth 2.0 authorization servers to communicate
authorization codes back to developer apps.
Corresponds to the JSON property callbackUrl
4311 4312 4313 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4311 def callback_url @callback_url end |
#created_at ⇒ Fixnum
Output only. Time the developer app was created in milliseconds since epoch.
Corresponds to the JSON property createdAt
4316 4317 4318 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4316 def created_at @created_at end |
#credentials ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Credential>
Output only. Set of credentials for the developer app consisting of the
consumer key/secret pairs associated with the API products.
Corresponds to the JSON property credentials
4322 4323 4324 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4322 def credentials @credentials end |
#developer_id ⇒ String
ID of the developer.
Corresponds to the JSON property developerId
4327 4328 4329 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4327 def developer_id @developer_id end |
#key_expires_in ⇒ Fixnum
Expiration time, in milliseconds, for the consumer key that is generated for
the developer app. If not set or left to the default value of -1, the API
key never expires. The expiration time can't be updated after it is set.
Corresponds to the JSON property keyExpiresIn
4334 4335 4336 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4334 def key_expires_in @key_expires_in end |
#last_modified_at ⇒ Fixnum
Output only. Time the developer app was modified in milliseconds since epoch.
Corresponds to the JSON property lastModifiedAt
4339 4340 4341 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4339 def last_modified_at @last_modified_at end |
#name ⇒ String
Name of the developer app.
Corresponds to the JSON property name
4344 4345 4346 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4344 def name @name end |
#scopes ⇒ Array<String>
Scopes to apply to the developer app. The specified scopes must already exist
for the API product that you associate with the developer app.
Corresponds to the JSON property scopes
4350 4351 4352 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4350 def scopes @scopes end |
#status ⇒ String
Status of the credential. Valid values include approved or revoked.
Corresponds to the JSON property status
4355 4356 4357 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4355 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4362 4363 4364 4365 4366 4367 4368 4369 4370 4371 4372 4373 4374 4375 4376 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4362 def update!(**args) @api_products = args[:api_products] if args.key?(:api_products) @app_family = args[:app_family] if args.key?(:app_family) @app_id = args[:app_id] if args.key?(:app_id) @attributes = args[:attributes] if args.key?(:attributes) @callback_url = args[:callback_url] if args.key?(:callback_url) @created_at = args[:created_at] if args.key?(:created_at) @credentials = args[:credentials] if args.key?(:credentials) @developer_id = args[:developer_id] if args.key?(:developer_id) @key_expires_in = args[:key_expires_in] if args.key?(:key_expires_in) @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at) @name = args[:name] if args.key?(:name) @scopes = args[:scopes] if args.key?(:scopes) @status = args[:status] if args.key?(:status) end |