Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeveloperApp

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1DeveloperApp

Returns a new instance of GoogleCloudApigeeV1DeveloperApp.



4348
4349
4350
# File 'lib/google/apis/apigee_v1/classes.rb', line 4348

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_productsArray<String>

List of API products associated with the developer app. Corresponds to the JSON property apiProducts

Returns:

  • (Array<String>)


4280
4281
4282
# File 'lib/google/apis/apigee_v1/classes.rb', line 4280

def api_products
  @api_products
end

#app_familyString

Developer app family. Corresponds to the JSON property appFamily

Returns:

  • (String)


4285
4286
4287
# File 'lib/google/apis/apigee_v1/classes.rb', line 4285

def app_family
  @app_family
end

#app_idString

ID of the developer app. This ID is not user specified but is automatically generated on app creation. appId is a UUID. Corresponds to the JSON property appId

Returns:

  • (String)


4291
4292
4293
# File 'lib/google/apis/apigee_v1/classes.rb', line 4291

def app_id
  @app_id
end

#attributesArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>

List of attributes for the developer app. Corresponds to the JSON property attributes



4296
4297
4298
# File 'lib/google/apis/apigee_v1/classes.rb', line 4296

def attributes
  @attributes
end

#callback_urlString

Callback URL used by OAuth 2.0 authorization servers to communicate authorization codes back to developer apps. Corresponds to the JSON property callbackUrl

Returns:

  • (String)


4302
4303
4304
# File 'lib/google/apis/apigee_v1/classes.rb', line 4302

def callback_url
  @callback_url
end

#created_atFixnum

Output only. Time the developer app was created in milliseconds since epoch. Corresponds to the JSON property createdAt

Returns:

  • (Fixnum)


4307
4308
4309
# File 'lib/google/apis/apigee_v1/classes.rb', line 4307

def created_at
  @created_at
end

#credentialsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Credential>

Output only. Set of credentials for the developer app consisting of the consumer key/secret pairs associated with the API products. Corresponds to the JSON property credentials



4313
4314
4315
# File 'lib/google/apis/apigee_v1/classes.rb', line 4313

def credentials
  @credentials
end

#developer_idString

ID of the developer. Corresponds to the JSON property developerId

Returns:

  • (String)


4318
4319
4320
# File 'lib/google/apis/apigee_v1/classes.rb', line 4318

def developer_id
  @developer_id
end

#key_expires_inFixnum

Expiration time, in milliseconds, for the consumer key that is generated for the developer app. If not set or left to the default value of -1, the API key never expires. The expiration time can't be updated after it is set. Corresponds to the JSON property keyExpiresIn

Returns:

  • (Fixnum)


4325
4326
4327
# File 'lib/google/apis/apigee_v1/classes.rb', line 4325

def key_expires_in
  @key_expires_in
end

#last_modified_atFixnum

Output only. Time the developer app was modified in milliseconds since epoch. Corresponds to the JSON property lastModifiedAt

Returns:

  • (Fixnum)


4330
4331
4332
# File 'lib/google/apis/apigee_v1/classes.rb', line 4330

def last_modified_at
  @last_modified_at
end

#nameString

Name of the developer app. Corresponds to the JSON property name

Returns:

  • (String)


4335
4336
4337
# File 'lib/google/apis/apigee_v1/classes.rb', line 4335

def name
  @name
end

#scopesArray<String>

Scopes to apply to the developer app. The specified scopes must already exist for the API product that you associate with the developer app. Corresponds to the JSON property scopes

Returns:

  • (Array<String>)


4341
4342
4343
# File 'lib/google/apis/apigee_v1/classes.rb', line 4341

def scopes
  @scopes
end

#statusString

Status of the credential. Valid values include approved or revoked. Corresponds to the JSON property status

Returns:

  • (String)


4346
4347
4348
# File 'lib/google/apis/apigee_v1/classes.rb', line 4346

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4353
4354
4355
4356
4357
4358
4359
4360
4361
4362
4363
4364
4365
4366
4367
# File 'lib/google/apis/apigee_v1/classes.rb', line 4353

def update!(**args)
  @api_products = args[:api_products] if args.key?(:api_products)
  @app_family = args[:app_family] if args.key?(:app_family)
  @app_id = args[:app_id] if args.key?(:app_id)
  @attributes = args[:attributes] if args.key?(:attributes)
  @callback_url = args[:callback_url] if args.key?(:callback_url)
  @created_at = args[:created_at] if args.key?(:created_at)
  @credentials = args[:credentials] if args.key?(:credentials)
  @developer_id = args[:developer_id] if args.key?(:developer_id)
  @key_expires_in = args[:key_expires_in] if args.key?(:key_expires_in)
  @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at)
  @name = args[:name] if args.key?(:name)
  @scopes = args[:scopes] if args.key?(:scopes)
  @status = args[:status] if args.key?(:status)
end