Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeveloperAppKey
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeveloperAppKey
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Instance Attribute Summary collapse
-
#api_products ⇒ Array<Object>
List of API products for which the credential can be used.
-
#attributes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>
List of attributes associated with the credential.
-
#consumer_key ⇒ String
Consumer key.
-
#consumer_secret ⇒ String
Secret key.
-
#expires_at ⇒ Fixnum
Time the developer app expires in milliseconds since epoch.
-
#expires_in_seconds ⇒ Fixnum
Input only.
-
#issued_at ⇒ Fixnum
Time the developer app was created in milliseconds since epoch.
-
#scopes ⇒ Array<String>
Scopes to apply to the app.
-
#status ⇒ String
Status of the credential.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1DeveloperAppKey
constructor
A new instance of GoogleCloudApigeeV1DeveloperAppKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1DeveloperAppKey
Returns a new instance of GoogleCloudApigeeV1DeveloperAppKey.
4434 4435 4436 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4434 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_products ⇒ Array<Object>
List of API products for which the credential can be used. Note: Do not
specify the list of API products when creating a consumer key and secret for a
developer app. Instead, use the UpdateDeveloperAppKey API to make the
association after the consumer key and secret are created.
Corresponds to the JSON property apiProducts
4389 4390 4391 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4389 def api_products @api_products end |
#attributes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>
List of attributes associated with the credential.
Corresponds to the JSON property attributes
4394 4395 4396 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4394 def attributes @attributes end |
#consumer_key ⇒ String
Consumer key.
Corresponds to the JSON property consumerKey
4399 4400 4401 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4399 def consumer_key @consumer_key end |
#consumer_secret ⇒ String
Secret key.
Corresponds to the JSON property consumerSecret
4404 4405 4406 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4404 def consumer_secret @consumer_secret end |
#expires_at ⇒ Fixnum
Time the developer app expires in milliseconds since epoch.
Corresponds to the JSON property expiresAt
4409 4410 4411 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4409 def expires_at @expires_at end |
#expires_in_seconds ⇒ Fixnum
Input only. Expiration time, in seconds, for the consumer key. If not set or
left to the default value of -1, the API key never expires. The expiration
time can't be updated after it is set.
Corresponds to the JSON property expiresInSeconds
4416 4417 4418 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4416 def expires_in_seconds @expires_in_seconds end |
#issued_at ⇒ Fixnum
Time the developer app was created in milliseconds since epoch.
Corresponds to the JSON property issuedAt
4421 4422 4423 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4421 def issued_at @issued_at end |
#scopes ⇒ Array<String>
Scopes to apply to the app. The specified scope names must already be defined
for the API product that you associate with the app.
Corresponds to the JSON property scopes
4427 4428 4429 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4427 def scopes @scopes end |
#status ⇒ String
Status of the credential. Valid values include approved or revoked.
Corresponds to the JSON property status
4432 4433 4434 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4432 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4439 def update!(**args) @api_products = args[:api_products] if args.key?(:api_products) @attributes = args[:attributes] if args.key?(:attributes) @consumer_key = args[:consumer_key] if args.key?(:consumer_key) @consumer_secret = args[:consumer_secret] if args.key?(:consumer_secret) @expires_at = args[:expires_at] if args.key?(:expires_at) @expires_in_seconds = args[:expires_in_seconds] if args.key?(:expires_in_seconds) @issued_at = args[:issued_at] if args.key?(:issued_at) @scopes = args[:scopes] if args.key?(:scopes) @status = args[:status] if args.key?(:status) end |