Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeveloperAppKey

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1DeveloperAppKey

Returns a new instance of GoogleCloudApigeeV1DeveloperAppKey.



4465
4466
4467
# File 'lib/google/apis/apigee_v1/classes.rb', line 4465

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_productsArray<Object>

List of API products for which the credential can be used. Note: Do not specify the list of API products when creating a consumer key and secret for a developer app. Instead, use the UpdateDeveloperAppKey API to make the association after the consumer key and secret are created. Corresponds to the JSON property apiProducts

Returns:

  • (Array<Object>)


4420
4421
4422
# File 'lib/google/apis/apigee_v1/classes.rb', line 4420

def api_products
  @api_products
end

#attributesArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>

List of attributes associated with the credential. Corresponds to the JSON property attributes



4425
4426
4427
# File 'lib/google/apis/apigee_v1/classes.rb', line 4425

def attributes
  @attributes
end

#consumer_keyString

Consumer key. Corresponds to the JSON property consumerKey

Returns:

  • (String)


4430
4431
4432
# File 'lib/google/apis/apigee_v1/classes.rb', line 4430

def consumer_key
  @consumer_key
end

#consumer_secretString

Secret key. Corresponds to the JSON property consumerSecret

Returns:

  • (String)


4435
4436
4437
# File 'lib/google/apis/apigee_v1/classes.rb', line 4435

def consumer_secret
  @consumer_secret
end

#expires_atFixnum

Time the developer app expires in milliseconds since epoch. Corresponds to the JSON property expiresAt

Returns:

  • (Fixnum)


4440
4441
4442
# File 'lib/google/apis/apigee_v1/classes.rb', line 4440

def expires_at
  @expires_at
end

#expires_in_secondsFixnum

Input only. Expiration time, in seconds, for the consumer key. If not set or left to the default value of -1, the API key never expires. The expiration time can't be updated after it is set. Corresponds to the JSON property expiresInSeconds

Returns:

  • (Fixnum)


4447
4448
4449
# File 'lib/google/apis/apigee_v1/classes.rb', line 4447

def expires_in_seconds
  @expires_in_seconds
end

#issued_atFixnum

Time the developer app was created in milliseconds since epoch. Corresponds to the JSON property issuedAt

Returns:

  • (Fixnum)


4452
4453
4454
# File 'lib/google/apis/apigee_v1/classes.rb', line 4452

def issued_at
  @issued_at
end

#scopesArray<String>

Scopes to apply to the app. The specified scope names must already be defined for the API product that you associate with the app. Corresponds to the JSON property scopes

Returns:

  • (Array<String>)


4458
4459
4460
# File 'lib/google/apis/apigee_v1/classes.rb', line 4458

def scopes
  @scopes
end

#statusString

Status of the credential. Valid values include approved or revoked. Corresponds to the JSON property status

Returns:

  • (String)


4463
4464
4465
# File 'lib/google/apis/apigee_v1/classes.rb', line 4463

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4470
4471
4472
4473
4474
4475
4476
4477
4478
4479
4480
# File 'lib/google/apis/apigee_v1/classes.rb', line 4470

def update!(**args)
  @api_products = args[:api_products] if args.key?(:api_products)
  @attributes = args[:attributes] if args.key?(:attributes)
  @consumer_key = args[:consumer_key] if args.key?(:consumer_key)
  @consumer_secret = args[:consumer_secret] if args.key?(:consumer_secret)
  @expires_at = args[:expires_at] if args.key?(:expires_at)
  @expires_in_seconds = args[:expires_in_seconds] if args.key?(:expires_in_seconds)
  @issued_at = args[:issued_at] if args.key?(:issued_at)
  @scopes = args[:scopes] if args.key?(:scopes)
  @status = args[:status] if args.key?(:status)
end