Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeveloperSubscription
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeveloperSubscription
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Structure of a DeveloperSubscription.
Instance Attribute Summary collapse
-
#apiproduct ⇒ String
Name of the API product for which the developer is purchasing a subscription.
-
#created_at ⇒ Fixnum
Output only.
-
#end_time ⇒ Fixnum
Time when the API product subscription ends in milliseconds since epoch.
-
#last_modified_at ⇒ Fixnum
Output only.
-
#name ⇒ String
Output only.
-
#start_time ⇒ Fixnum
Time when the API product subscription starts in milliseconds since epoch.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1DeveloperSubscription
constructor
A new instance of GoogleCloudApigeeV1DeveloperSubscription.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1DeveloperSubscription
Returns a new instance of GoogleCloudApigeeV1DeveloperSubscription.
4535 4536 4537 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4535 def initialize(**args) update!(**args) end |
Instance Attribute Details
#apiproduct ⇒ String
Name of the API product for which the developer is purchasing a subscription.
Corresponds to the JSON property apiproduct
4506 4507 4508 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4506 def apiproduct @apiproduct end |
#created_at ⇒ Fixnum
Output only. Time when the API product subscription was created in
milliseconds since epoch.
Corresponds to the JSON property createdAt
4512 4513 4514 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4512 def created_at @created_at end |
#end_time ⇒ Fixnum
Time when the API product subscription ends in milliseconds since epoch.
Corresponds to the JSON property endTime
4517 4518 4519 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4517 def end_time @end_time end |
#last_modified_at ⇒ Fixnum
Output only. Time when the API product subscription was last modified in
milliseconds since epoch.
Corresponds to the JSON property lastModifiedAt
4523 4524 4525 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4523 def last_modified_at @last_modified_at end |
#name ⇒ String
Output only. Name of the API product subscription.
Corresponds to the JSON property name
4528 4529 4530 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4528 def name @name end |
#start_time ⇒ Fixnum
Time when the API product subscription starts in milliseconds since epoch.
Corresponds to the JSON property startTime
4533 4534 4535 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4533 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4540 4541 4542 4543 4544 4545 4546 4547 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4540 def update!(**args) @apiproduct = args[:apiproduct] if args.key?(:apiproduct) @created_at = args[:created_at] if args.key?(:created_at) @end_time = args[:end_time] if args.key?(:end_time) @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at) @name = args[:name] if args.key?(:name) @start_time = args[:start_time] if args.key?(:start_time) end |