Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1DnsZone
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1DnsZone
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
A DNS zone is a resource under an Apigee organization that is used to create a DNS peering with Apigee's network. DNS peering will let Apigee instances resolve the hostnames created in a peered network.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Required.
-
#domain ⇒ String
Required.
-
#name ⇒ String
Identifier.
-
#peering_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1DnsZonePeeringConfig
Fields for DNS PEERING zone.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1DnsZone
constructor
A new instance of GoogleCloudApigeeV1DnsZone.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1DnsZone
Returns a new instance of GoogleCloudApigeeV1DnsZone.
4690 4691 4692 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4690 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time that this resource was created on the server.
Corresponds to the JSON property createTime
4654 4655 4656 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4654 def create_time @create_time end |
#description ⇒ String
Required. Description of the resource. String of at most 1024 characters
associated with this resource for the user's convenience.
Corresponds to the JSON property description
4660 4661 4662 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4660 def description @description end |
#domain ⇒ String
Required. The domain name for hosts in this private zone, for instance "
example.com.".
Corresponds to the JSON property domain
4666 4667 4668 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4666 def domain @domain end |
#name ⇒ String
Identifier. Unique name for the resource. Defined by the server Format: "
organizations/organization/dnsZones/dns_zone".
Corresponds to the JSON property name
4672 4673 4674 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4672 def name @name end |
#peering_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1DnsZonePeeringConfig
Fields for DNS PEERING zone.
Corresponds to the JSON property peeringConfig
4677 4678 4679 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4677 def peering_config @peering_config end |
#state ⇒ String
Output only. State of the DNS Peering. Values other than ACTIVE mean the
resource is not ready to use.
Corresponds to the JSON property state
4683 4684 4685 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4683 def state @state end |
#update_time ⇒ String
Output only. The time that this resource was updated on the server.
Corresponds to the JSON property updateTime
4688 4689 4690 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4688 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4695 4696 4697 4698 4699 4700 4701 4702 4703 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4695 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @domain = args[:domain] if args.key?(:domain) @name = args[:name] if args.key?(:name) @peering_config = args[:peering_config] if args.key?(:peering_config) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |