Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1DnsZone

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

A DNS zone is a resource under an Apigee organization that is used to create a DNS peering with Apigee's network. DNS peering will let Apigee instances resolve the hostnames created in a peered network.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1DnsZone

Returns a new instance of GoogleCloudApigeeV1DnsZone.



4641
4642
4643
# File 'lib/google/apis/apigee_v1/classes.rb', line 4641

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time that this resource was created on the server. Corresponds to the JSON property createTime

Returns:

  • (String)


4605
4606
4607
# File 'lib/google/apis/apigee_v1/classes.rb', line 4605

def create_time
  @create_time
end

#descriptionString

Required. Description of the resource. String of at most 1024 characters associated with this resource for the user's convenience. Corresponds to the JSON property description

Returns:

  • (String)


4611
4612
4613
# File 'lib/google/apis/apigee_v1/classes.rb', line 4611

def description
  @description
end

#domainString

Required. The domain name for hosts in this private zone, for instance " example.com.". Corresponds to the JSON property domain

Returns:

  • (String)


4617
4618
4619
# File 'lib/google/apis/apigee_v1/classes.rb', line 4617

def domain
  @domain
end

#nameString

Identifier. Unique name for the resource. Defined by the server Format: " organizations/organization/dnsZones/dns_zone". Corresponds to the JSON property name

Returns:

  • (String)


4623
4624
4625
# File 'lib/google/apis/apigee_v1/classes.rb', line 4623

def name
  @name
end

#peering_configGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1DnsZonePeeringConfig

Fields for DNS PEERING zone. Corresponds to the JSON property peeringConfig



4628
4629
4630
# File 'lib/google/apis/apigee_v1/classes.rb', line 4628

def peering_config
  @peering_config
end

#stateString

Output only. State of the DNS Peering. Values other than ACTIVE mean the resource is not ready to use. Corresponds to the JSON property state

Returns:

  • (String)


4634
4635
4636
# File 'lib/google/apis/apigee_v1/classes.rb', line 4634

def state
  @state
end

#update_timeString

Output only. The time that this resource was updated on the server. Corresponds to the JSON property updateTime

Returns:

  • (String)


4639
4640
4641
# File 'lib/google/apis/apigee_v1/classes.rb', line 4639

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4646
4647
4648
4649
4650
4651
4652
4653
4654
# File 'lib/google/apis/apigee_v1/classes.rb', line 4646

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @domain = args[:domain] if args.key?(:domain)
  @name = args[:name] if args.key?(:name)
  @peering_config = args[:peering_config] if args.key?(:peering_config)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end