Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1DnsZonePeeringConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1DnsZonePeeringConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Fields for DNS PEERING zone.
Instance Attribute Summary collapse
-
#target_network_id ⇒ String
Required.
-
#target_project_id ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1DnsZonePeeringConfig
constructor
A new instance of GoogleCloudApigeeV1DnsZonePeeringConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1DnsZonePeeringConfig
Returns a new instance of GoogleCloudApigeeV1DnsZonePeeringConfig.
4682 4683 4684 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4682 def initialize(**args) update!(**args) end |
Instance Attribute Details
#target_network_id ⇒ String
Required. The VPC network where the records for that private DNS zone's
namespace are available. Apigee will be performing DNS peering with this VPC
network.
Corresponds to the JSON property targetNetworkId
4675 4676 4677 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4675 def target_network_id @target_network_id end |
#target_project_id ⇒ String
Required. The ID of the project that contains the producer VPC network.
Corresponds to the JSON property targetProjectId
4680 4681 4682 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4680 def target_project_id @target_project_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4687 4688 4689 4690 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4687 def update!(**args) @target_network_id = args[:target_network_id] if args.key?(:target_network_id) @target_project_id = args[:target_project_id] if args.key?(:target_project_id) end |