Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1DnsZonePeeringConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Fields for DNS PEERING zone.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1DnsZonePeeringConfig

Returns a new instance of GoogleCloudApigeeV1DnsZonePeeringConfig.



4722
4723
4724
# File 'lib/google/apis/apigee_v1/classes.rb', line 4722

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#target_network_idString

Required. The VPC network where the records for that private DNS zone's namespace are available. Apigee will be performing DNS peering with this VPC network. Corresponds to the JSON property targetNetworkId

Returns:

  • (String)


4715
4716
4717
# File 'lib/google/apis/apigee_v1/classes.rb', line 4715

def target_network_id
  @target_network_id
end

#target_project_idString

Required. The ID of the project that contains the producer VPC network. Corresponds to the JSON property targetProjectId

Returns:

  • (String)


4720
4721
4722
# File 'lib/google/apis/apigee_v1/classes.rb', line 4720

def target_project_id
  @target_project_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4727
4728
4729
4730
# File 'lib/google/apis/apigee_v1/classes.rb', line 4727

def update!(**args)
  @target_network_id = args[:target_network_id] if args.key?(:target_network_id)
  @target_project_id = args[:target_project_id] if args.key?(:target_project_id)
end