Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1EndpointAttachment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Apigee endpoint attachment. For more information, see Southbound networking patterns.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1EndpointAttachment

Returns a new instance of GoogleCloudApigeeV1EndpointAttachment.



4773
4774
4775
# File 'lib/google/apis/apigee_v1/classes.rb', line 4773

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_stateString

Output only. State of the endpoint attachment connection to the service attachment. Corresponds to the JSON property connectionState

Returns:

  • (String)


4743
4744
4745
# File 'lib/google/apis/apigee_v1/classes.rb', line 4743

def connection_state
  @connection_state
end

#hostString

Output only. Host that can be used in either the HTTP target endpoint directly or as the host in target server. Corresponds to the JSON property host

Returns:

  • (String)


4749
4750
4751
# File 'lib/google/apis/apigee_v1/classes.rb', line 4749

def host
  @host
end

#locationString

Required. Location of the endpoint attachment. Corresponds to the JSON property location

Returns:

  • (String)


4754
4755
4756
# File 'lib/google/apis/apigee_v1/classes.rb', line 4754

def location
  @location
end

#nameString

Name of the endpoint attachment. Use the following structure in your request: organizations/org/endpointAttachments/endpoint_attachment` Corresponds to the JSON propertyname`

Returns:

  • (String)


4760
4761
4762
# File 'lib/google/apis/apigee_v1/classes.rb', line 4760

def name
  @name
end

#service_attachmentString

Format: projects//regions//serviceAttachments/* Corresponds to the JSON property serviceAttachment

Returns:

  • (String)


4765
4766
4767
# File 'lib/google/apis/apigee_v1/classes.rb', line 4765

def service_attachment
  @service_attachment
end

#stateString

Output only. State of the endpoint attachment. Values other than ACTIVE mean the resource is not ready to use. Corresponds to the JSON property state

Returns:

  • (String)


4771
4772
4773
# File 'lib/google/apis/apigee_v1/classes.rb', line 4771

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4778
4779
4780
4781
4782
4783
4784
4785
# File 'lib/google/apis/apigee_v1/classes.rb', line 4778

def update!(**args)
  @connection_state = args[:connection_state] if args.key?(:connection_state)
  @host = args[:host] if args.key?(:host)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @service_attachment = args[:service_attachment] if args.key?(:service_attachment)
  @state = args[:state] if args.key?(:state)
end