Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1EndpointAttachment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Apigee endpoint attachment. For more information, see Southbound networking patterns.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1EndpointAttachment

Returns a new instance of GoogleCloudApigeeV1EndpointAttachment.



4813
4814
4815
# File 'lib/google/apis/apigee_v1/classes.rb', line 4813

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_stateString

Output only. State of the endpoint attachment connection to the service attachment. Corresponds to the JSON property connectionState

Returns:

  • (String)


4783
4784
4785
# File 'lib/google/apis/apigee_v1/classes.rb', line 4783

def connection_state
  @connection_state
end

#hostString

Output only. Host that can be used in either the HTTP target endpoint directly or as the host in target server. Corresponds to the JSON property host

Returns:

  • (String)


4789
4790
4791
# File 'lib/google/apis/apigee_v1/classes.rb', line 4789

def host
  @host
end

#locationString

Required. Location of the endpoint attachment. Corresponds to the JSON property location

Returns:

  • (String)


4794
4795
4796
# File 'lib/google/apis/apigee_v1/classes.rb', line 4794

def location
  @location
end

#nameString

Name of the endpoint attachment. Use the following structure in your request: organizations/org/endpointAttachments/endpoint_attachment` Corresponds to the JSON propertyname`

Returns:

  • (String)


4800
4801
4802
# File 'lib/google/apis/apigee_v1/classes.rb', line 4800

def name
  @name
end

#service_attachmentString

Format: projects//regions//serviceAttachments/* Corresponds to the JSON property serviceAttachment

Returns:

  • (String)


4805
4806
4807
# File 'lib/google/apis/apigee_v1/classes.rb', line 4805

def service_attachment
  @service_attachment
end

#stateString

Output only. State of the endpoint attachment. Values other than ACTIVE mean the resource is not ready to use. Corresponds to the JSON property state

Returns:

  • (String)


4811
4812
4813
# File 'lib/google/apis/apigee_v1/classes.rb', line 4811

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4818
4819
4820
4821
4822
4823
4824
4825
# File 'lib/google/apis/apigee_v1/classes.rb', line 4818

def update!(**args)
  @connection_state = args[:connection_state] if args.key?(:connection_state)
  @host = args[:host] if args.key?(:host)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @service_attachment = args[:service_attachment] if args.key?(:service_attachment)
  @state = args[:state] if args.key?(:state)
end