Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Environment
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1Environment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Instance Attribute Summary collapse
-
#api_proxy_type ⇒ String
Optional.
-
#client_ip_resolution_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1EnvironmentClientIpResolutionConfig
Configuration for resolving the client ip.
-
#created_at ⇒ Fixnum
Output only.
-
#deployment_type ⇒ String
Optional.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#forward_proxy_uri ⇒ String
Optional.
-
#has_attached_flow_hooks ⇒ Boolean
(also: #has_attached_flow_hooks?)
Corresponds to the JSON property
hasAttachedFlowHooks. -
#last_modified_at ⇒ Fixnum
Output only.
-
#name ⇒ String
Required.
-
#node_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1NodeConfig
NodeConfig for setting the min/max number of nodes associated with the environment.
-
#properties ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1Properties
Message for compatibility with legacy Edge specification for Java Properties object in JSON.
-
#state ⇒ String
Output only.
-
#type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1Environment
constructor
A new instance of GoogleCloudApigeeV1Environment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1Environment
Returns a new instance of GoogleCloudApigeeV1Environment.
4940 4941 4942 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4940 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_proxy_type ⇒ String
Optional. API Proxy type supported by the environment. The type can be set
when creating the Environment and cannot be changed.
Corresponds to the JSON property apiProxyType
4855 4856 4857 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4855 def api_proxy_type @api_proxy_type end |
#client_ip_resolution_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1EnvironmentClientIpResolutionConfig
Configuration for resolving the client ip.
Corresponds to the JSON property clientIpResolutionConfig
4860 4861 4862 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4860 def client_ip_resolution_config @client_ip_resolution_config end |
#created_at ⇒ Fixnum
Output only. Creation time of this environment as milliseconds since epoch.
Corresponds to the JSON property createdAt
4865 4866 4867 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4865 def created_at @created_at end |
#deployment_type ⇒ String
Optional. Deployment type supported by the environment. The deployment type
can be set when creating the environment and cannot be changed. When you
enable archive deployment, you will be prevented from performing a subset
of actions within the environment, including: * Managing the deployment of API
proxy or shared flow revisions * Creating, updating, or deleting resource
files * Creating, updating, or deleting target servers
Corresponds to the JSON property deploymentType
4876 4877 4878 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4876 def deployment_type @deployment_type end |
#description ⇒ String
Optional. Description of the environment.
Corresponds to the JSON property description
4881 4882 4883 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4881 def description @description end |
#display_name ⇒ String
Optional. Display name for this environment.
Corresponds to the JSON property displayName
4886 4887 4888 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4886 def display_name @display_name end |
#forward_proxy_uri ⇒ String
Optional. URI of the forward proxy to be applied to the runtime instances in
this environment. Must be in the format of scheme://hostname:port. Note
that the only supported scheme is "http". The port must be supplied. To remove
a forward proxy setting, update the field to an empty value. Note: At this
time, PUT operations to add forwardProxyUri to an existing environment fail if
the environment has nodeConfig set up. To successfully add the forwardProxyUri
setting in this case, include the NodeConfig details with the request.
Corresponds to the JSON property forwardProxyUri
4897 4898 4899 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4897 def forward_proxy_uri @forward_proxy_uri end |
#has_attached_flow_hooks ⇒ Boolean Also known as: has_attached_flow_hooks?
Corresponds to the JSON property hasAttachedFlowHooks
4902 4903 4904 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4902 def has_attached_flow_hooks @has_attached_flow_hooks end |
#last_modified_at ⇒ Fixnum
Output only. Last modification time of this environment as milliseconds since
epoch.
Corresponds to the JSON property lastModifiedAt
4909 4910 4911 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4909 def last_modified_at @last_modified_at end |
#name ⇒ String
Required. Name of the environment. Values must match the regular expression ^[
.\\pAlnum-_]1,255$
Corresponds to the JSON property name
4915 4916 4917 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4915 def name @name end |
#node_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1NodeConfig
NodeConfig for setting the min/max number of nodes associated with the
environment.
Corresponds to the JSON property nodeConfig
4921 4922 4923 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4921 def node_config @node_config end |
#properties ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1Properties
Message for compatibility with legacy Edge specification for Java Properties
object in JSON.
Corresponds to the JSON property properties
4927 4928 4929 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4927 def properties @properties end |
#state ⇒ String
Output only. State of the environment. Values other than ACTIVE means the
resource is not ready to use.
Corresponds to the JSON property state
4933 4934 4935 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4933 def state @state end |
#type ⇒ String
Optional. EnvironmentType selected for the environment.
Corresponds to the JSON property type
4938 4939 4940 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4938 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4945 4946 4947 4948 4949 4950 4951 4952 4953 4954 4955 4956 4957 4958 4959 4960 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 4945 def update!(**args) @api_proxy_type = args[:api_proxy_type] if args.key?(:api_proxy_type) @client_ip_resolution_config = args[:client_ip_resolution_config] if args.key?(:client_ip_resolution_config) @created_at = args[:created_at] if args.key?(:created_at) @deployment_type = args[:deployment_type] if args.key?(:deployment_type) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @forward_proxy_uri = args[:forward_proxy_uri] if args.key?(:forward_proxy_uri) @has_attached_flow_hooks = args[:has_attached_flow_hooks] if args.key?(:has_attached_flow_hooks) @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at) @name = args[:name] if args.key?(:name) @node_config = args[:node_config] if args.key?(:node_config) @properties = args[:properties] if args.key?(:properties) @state = args[:state] if args.key?(:state) @type = args[:type] if args.key?(:type) end |