Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Environment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1Environment

Returns a new instance of GoogleCloudApigeeV1Environment.



4931
4932
4933
# File 'lib/google/apis/apigee_v1/classes.rb', line 4931

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_proxy_typeString

Optional. API Proxy type supported by the environment. The type can be set when creating the Environment and cannot be changed. Corresponds to the JSON property apiProxyType

Returns:

  • (String)


4846
4847
4848
# File 'lib/google/apis/apigee_v1/classes.rb', line 4846

def api_proxy_type
  @api_proxy_type
end

#client_ip_resolution_configGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1EnvironmentClientIpResolutionConfig

Configuration for resolving the client ip. Corresponds to the JSON property clientIpResolutionConfig



4851
4852
4853
# File 'lib/google/apis/apigee_v1/classes.rb', line 4851

def client_ip_resolution_config
  @client_ip_resolution_config
end

#created_atFixnum

Output only. Creation time of this environment as milliseconds since epoch. Corresponds to the JSON property createdAt

Returns:

  • (Fixnum)


4856
4857
4858
# File 'lib/google/apis/apigee_v1/classes.rb', line 4856

def created_at
  @created_at
end

#deployment_typeString

Optional. Deployment type supported by the environment. The deployment type can be set when creating the environment and cannot be changed. When you enable archive deployment, you will be prevented from performing a subset of actions within the environment, including: * Managing the deployment of API proxy or shared flow revisions * Creating, updating, or deleting resource files * Creating, updating, or deleting target servers Corresponds to the JSON property deploymentType

Returns:

  • (String)


4867
4868
4869
# File 'lib/google/apis/apigee_v1/classes.rb', line 4867

def deployment_type
  @deployment_type
end

#descriptionString

Optional. Description of the environment. Corresponds to the JSON property description

Returns:

  • (String)


4872
4873
4874
# File 'lib/google/apis/apigee_v1/classes.rb', line 4872

def description
  @description
end

#display_nameString

Optional. Display name for this environment. Corresponds to the JSON property displayName

Returns:

  • (String)


4877
4878
4879
# File 'lib/google/apis/apigee_v1/classes.rb', line 4877

def display_name
  @display_name
end

#forward_proxy_uriString

Optional. URI of the forward proxy to be applied to the runtime instances in this environment. Must be in the format of scheme://hostname:port. Note that the only supported scheme is "http". The port must be supplied. To remove a forward proxy setting, update the field to an empty value. Note: At this time, PUT operations to add forwardProxyUri to an existing environment fail if the environment has nodeConfig set up. To successfully add the forwardProxyUri setting in this case, include the NodeConfig details with the request. Corresponds to the JSON property forwardProxyUri

Returns:

  • (String)


4888
4889
4890
# File 'lib/google/apis/apigee_v1/classes.rb', line 4888

def forward_proxy_uri
  @forward_proxy_uri
end

#has_attached_flow_hooksBoolean Also known as: has_attached_flow_hooks?

Corresponds to the JSON property hasAttachedFlowHooks

Returns:

  • (Boolean)


4893
4894
4895
# File 'lib/google/apis/apigee_v1/classes.rb', line 4893

def has_attached_flow_hooks
  @has_attached_flow_hooks
end

#last_modified_atFixnum

Output only. Last modification time of this environment as milliseconds since epoch. Corresponds to the JSON property lastModifiedAt

Returns:

  • (Fixnum)


4900
4901
4902
# File 'lib/google/apis/apigee_v1/classes.rb', line 4900

def last_modified_at
  @last_modified_at
end

#nameString

Required. Name of the environment. Values must match the regular expression ^[ .\\pAlnum-_]1,255$ Corresponds to the JSON property name

Returns:

  • (String)


4906
4907
4908
# File 'lib/google/apis/apigee_v1/classes.rb', line 4906

def name
  @name
end

#node_configGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1NodeConfig

NodeConfig for setting the min/max number of nodes associated with the environment. Corresponds to the JSON property nodeConfig



4912
4913
4914
# File 'lib/google/apis/apigee_v1/classes.rb', line 4912

def node_config
  @node_config
end

#propertiesGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1Properties

Message for compatibility with legacy Edge specification for Java Properties object in JSON. Corresponds to the JSON property properties



4918
4919
4920
# File 'lib/google/apis/apigee_v1/classes.rb', line 4918

def properties
  @properties
end

#stateString

Output only. State of the environment. Values other than ACTIVE means the resource is not ready to use. Corresponds to the JSON property state

Returns:

  • (String)


4924
4925
4926
# File 'lib/google/apis/apigee_v1/classes.rb', line 4924

def state
  @state
end

#typeString

Optional. EnvironmentType selected for the environment. Corresponds to the JSON property type

Returns:

  • (String)


4929
4930
4931
# File 'lib/google/apis/apigee_v1/classes.rb', line 4929

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4936
4937
4938
4939
4940
4941
4942
4943
4944
4945
4946
4947
4948
4949
4950
4951
# File 'lib/google/apis/apigee_v1/classes.rb', line 4936

def update!(**args)
  @api_proxy_type = args[:api_proxy_type] if args.key?(:api_proxy_type)
  @client_ip_resolution_config = args[:client_ip_resolution_config] if args.key?(:client_ip_resolution_config)
  @created_at = args[:created_at] if args.key?(:created_at)
  @deployment_type = args[:deployment_type] if args.key?(:deployment_type)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @forward_proxy_uri = args[:forward_proxy_uri] if args.key?(:forward_proxy_uri)
  @has_attached_flow_hooks = args[:has_attached_flow_hooks] if args.key?(:has_attached_flow_hooks)
  @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at)
  @name = args[:name] if args.key?(:name)
  @node_config = args[:node_config] if args.key?(:node_config)
  @properties = args[:properties] if args.key?(:properties)
  @state = args[:state] if args.key?(:state)
  @type = args[:type] if args.key?(:type)
end