Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1EnvironmentConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1EnvironmentConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Instance Attribute Summary collapse
-
#addons_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeAddonsConfig
RuntimeAddonsConfig defines the runtime configurations for add-ons in an environment.
-
#arc_config_location ⇒ String
The location for the config blob of API Runtime Control, aka Envoy Adapter, for op-based authentication as a URI, e.g.
-
#client_ip_resolution_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1EnvironmentConfigClientIpResolutionConfig
Configuration for resolving the client ip.
-
#create_time ⇒ String
Time that the environment configuration was created.
-
#data_collectors ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1DataCollectorConfig>
List of data collectors used by the deployments in the environment.
-
#debug_mask ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1DebugMask
Debug mask that applies to all deployments in the environment.
-
#deployment_groups ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeploymentGroupConfig>
List of deployment groups in the environment.
-
#deployments ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeploymentConfig>
List of deployments in the environment.
-
#env_scoped_revision_id ⇒ Fixnum
Revision ID for environment-scoped resources (e.g. target servers, keystores) in this config.
-
#feature_flags ⇒ Hash<String,String>
Feature flags inherited from the organization and environment.
-
#flowhooks ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1FlowHookConfig>
List of flow hooks in the environment.
-
#forward_proxy_uri ⇒ String
The forward proxy's url to be used by the runtime.
-
#gateway_config_location ⇒ String
The location for the gateway config blob as a URI, e.g.
-
#keystores ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1KeystoreConfig>
List of keystores in the environment.
-
#name ⇒ String
Name of the environment configuration in the following format:
organizations/org/environments/env/configs/config`Corresponds to the JSON propertyname`. -
#provider ⇒ String
Used by the Control plane to add context information to help detect the source of the document during diagnostics and debugging.
-
#pubsub_topic ⇒ String
Name of the PubSub topic for the environment.
-
#resource_references ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ReferenceConfig>
List of resource references in the environment.
-
#resources ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ResourceConfig>
List of resource versions in the environment.
-
#revision_id ⇒ Fixnum
Revision ID of the environment configuration.
-
#sequence_number ⇒ Fixnum
DEPRECATED: Use revision_id.
-
#targets ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1TargetServerConfig>
List of target servers in the environment.
-
#trace_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceConfig
NEXT ID: 10 RuntimeTraceConfig defines the configurations for distributed trace in an environment.
-
#uid ⇒ String
Unique ID for the environment configuration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1EnvironmentConfig
constructor
A new instance of GoogleCloudApigeeV1EnvironmentConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1EnvironmentConfig
Returns a new instance of GoogleCloudApigeeV1EnvironmentConfig.
5147 5148 5149 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5147 def initialize(**args) update!(**args) end |
Instance Attribute Details
#addons_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeAddonsConfig
RuntimeAddonsConfig defines the runtime configurations for add-ons in an
environment.
Corresponds to the JSON property addonsConfig
5017 5018 5019 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5017 def addons_config @addons_config end |
#arc_config_location ⇒ String
The location for the config blob of API Runtime Control, aka Envoy Adapter,
for op-based authentication as a URI, e.g. a Cloud Storage URI. This is only
used by Envoy-based gateways.
Corresponds to the JSON property arcConfigLocation
5024 5025 5026 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5024 def arc_config_location @arc_config_location end |
#client_ip_resolution_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1EnvironmentConfigClientIpResolutionConfig
Configuration for resolving the client ip.
Corresponds to the JSON property clientIpResolutionConfig
5029 5030 5031 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5029 def client_ip_resolution_config @client_ip_resolution_config end |
#create_time ⇒ String
Time that the environment configuration was created.
Corresponds to the JSON property createTime
5034 5035 5036 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5034 def create_time @create_time end |
#data_collectors ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1DataCollectorConfig>
List of data collectors used by the deployments in the environment.
Corresponds to the JSON property dataCollectors
5039 5040 5041 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5039 def data_collectors @data_collectors end |
#debug_mask ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1DebugMask
Debug mask that applies to all deployments in the environment.
Corresponds to the JSON property debugMask
5044 5045 5046 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5044 def debug_mask @debug_mask end |
#deployment_groups ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeploymentGroupConfig>
List of deployment groups in the environment.
Corresponds to the JSON property deploymentGroups
5049 5050 5051 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5049 def deployment_groups @deployment_groups end |
#deployments ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1DeploymentConfig>
List of deployments in the environment.
Corresponds to the JSON property deployments
5054 5055 5056 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5054 def deployments @deployments end |
#env_scoped_revision_id ⇒ Fixnum
Revision ID for environment-scoped resources (e.g. target servers, keystores)
in this config. This ID will increment any time a resource not scoped to a
deployment group changes.
Corresponds to the JSON property envScopedRevisionId
5061 5062 5063 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5061 def env_scoped_revision_id @env_scoped_revision_id end |
#feature_flags ⇒ Hash<String,String>
Feature flags inherited from the organization and environment.
Corresponds to the JSON property featureFlags
5066 5067 5068 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5066 def feature_flags @feature_flags end |
#flowhooks ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1FlowHookConfig>
List of flow hooks in the environment.
Corresponds to the JSON property flowhooks
5071 5072 5073 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5071 def flowhooks @flowhooks end |
#forward_proxy_uri ⇒ String
The forward proxy's url to be used by the runtime. When set, runtime will send
requests to the target via the given forward proxy. This is only used by
programmable gateways.
Corresponds to the JSON property forwardProxyUri
5078 5079 5080 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5078 def forward_proxy_uri @forward_proxy_uri end |
#gateway_config_location ⇒ String
The location for the gateway config blob as a URI, e.g. a Cloud Storage URI.
This is only used by Envoy-based gateways.
Corresponds to the JSON property gatewayConfigLocation
5084 5085 5086 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5084 def gateway_config_location @gateway_config_location end |
#keystores ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1KeystoreConfig>
List of keystores in the environment.
Corresponds to the JSON property keystores
5089 5090 5091 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5089 def keystores @keystores end |
#name ⇒ String
Name of the environment configuration in the following format: organizations/
org/environments/env/configs/config`
Corresponds to the JSON propertyname`
5095 5096 5097 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5095 def name @name end |
#provider ⇒ String
Used by the Control plane to add context information to help detect the source
of the document during diagnostics and debugging.
Corresponds to the JSON property provider
5101 5102 5103 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5101 def provider @provider end |
#pubsub_topic ⇒ String
Name of the PubSub topic for the environment.
Corresponds to the JSON property pubsubTopic
5106 5107 5108 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5106 def pubsub_topic @pubsub_topic end |
#resource_references ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ReferenceConfig>
List of resource references in the environment.
Corresponds to the JSON property resourceReferences
5111 5112 5113 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5111 def resource_references @resource_references end |
#resources ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ResourceConfig>
List of resource versions in the environment.
Corresponds to the JSON property resources
5116 5117 5118 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5116 def resources @resources end |
#revision_id ⇒ Fixnum
Revision ID of the environment configuration. The higher the value, the more
recently the configuration was deployed.
Corresponds to the JSON property revisionId
5122 5123 5124 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5122 def revision_id @revision_id end |
#sequence_number ⇒ Fixnum
DEPRECATED: Use revision_id.
Corresponds to the JSON property sequenceNumber
5127 5128 5129 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5127 def sequence_number @sequence_number end |
#targets ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1TargetServerConfig>
List of target servers in the environment. Disabled target servers are not
displayed.
Corresponds to the JSON property targets
5133 5134 5135 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5133 def targets @targets end |
#trace_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceConfig
NEXT ID: 10 RuntimeTraceConfig defines the configurations for distributed
trace in an environment.
Corresponds to the JSON property traceConfig
5139 5140 5141 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5139 def trace_config @trace_config end |
#uid ⇒ String
Unique ID for the environment configuration. The ID will only change if the
environment is deleted and recreated.
Corresponds to the JSON property uid
5145 5146 5147 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5145 def uid @uid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5152 5153 5154 5155 5156 5157 5158 5159 5160 5161 5162 5163 5164 5165 5166 5167 5168 5169 5170 5171 5172 5173 5174 5175 5176 5177 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5152 def update!(**args) @addons_config = args[:addons_config] if args.key?(:addons_config) @arc_config_location = args[:arc_config_location] if args.key?(:arc_config_location) @client_ip_resolution_config = args[:client_ip_resolution_config] if args.key?(:client_ip_resolution_config) @create_time = args[:create_time] if args.key?(:create_time) @data_collectors = args[:data_collectors] if args.key?(:data_collectors) @debug_mask = args[:debug_mask] if args.key?(:debug_mask) @deployment_groups = args[:deployment_groups] if args.key?(:deployment_groups) @deployments = args[:deployments] if args.key?(:deployments) @env_scoped_revision_id = args[:env_scoped_revision_id] if args.key?(:env_scoped_revision_id) @feature_flags = args[:feature_flags] if args.key?(:feature_flags) @flowhooks = args[:flowhooks] if args.key?(:flowhooks) @forward_proxy_uri = args[:forward_proxy_uri] if args.key?(:forward_proxy_uri) @gateway_config_location = args[:gateway_config_location] if args.key?(:gateway_config_location) @keystores = args[:keystores] if args.key?(:keystores) @name = args[:name] if args.key?(:name) @provider = args[:provider] if args.key?(:provider) @pubsub_topic = args[:pubsub_topic] if args.key?(:pubsub_topic) @resource_references = args[:resource_references] if args.key?(:resource_references) @resources = args[:resources] if args.key?(:resources) @revision_id = args[:revision_id] if args.key?(:revision_id) @sequence_number = args[:sequence_number] if args.key?(:sequence_number) @targets = args[:targets] if args.key?(:targets) @trace_config = args[:trace_config] if args.key?(:trace_config) @uid = args[:uid] if args.key?(:uid) end |