Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1EnvironmentGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

EnvironmentGroup configuration. An environment group is used to group one or more Apigee environments under a single host name.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1EnvironmentGroup

Returns a new instance of GoogleCloudApigeeV1EnvironmentGroup.



5298
5299
5300
# File 'lib/google/apis/apigee_v1/classes.rb', line 5298

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#created_atFixnum

Output only. The time at which the environment group was created as milliseconds since epoch. Corresponds to the JSON property createdAt

Returns:

  • (Fixnum)


5274
5275
5276
# File 'lib/google/apis/apigee_v1/classes.rb', line 5274

def created_at
  @created_at
end

#hostnamesArray<String>

Required. Host names for this environment group. Corresponds to the JSON property hostnames

Returns:

  • (Array<String>)


5279
5280
5281
# File 'lib/google/apis/apigee_v1/classes.rb', line 5279

def hostnames
  @hostnames
end

#last_modified_atFixnum

Output only. The time at which the environment group was last updated as milliseconds since epoch. Corresponds to the JSON property lastModifiedAt

Returns:

  • (Fixnum)


5285
5286
5287
# File 'lib/google/apis/apigee_v1/classes.rb', line 5285

def last_modified_at
  @last_modified_at
end

#nameString

ID of the environment group. Corresponds to the JSON property name

Returns:

  • (String)


5290
5291
5292
# File 'lib/google/apis/apigee_v1/classes.rb', line 5290

def name
  @name
end

#stateString

Output only. State of the environment group. Values other than ACTIVE means the resource is not ready to use. Corresponds to the JSON property state

Returns:

  • (String)


5296
5297
5298
# File 'lib/google/apis/apigee_v1/classes.rb', line 5296

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5303
5304
5305
5306
5307
5308
5309
# File 'lib/google/apis/apigee_v1/classes.rb', line 5303

def update!(**args)
  @created_at = args[:created_at] if args.key?(:created_at)
  @hostnames = args[:hostnames] if args.key?(:hostnames)
  @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
end