Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1EnvironmentGroup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

EnvironmentGroup configuration. An environment group is used to group one or more Apigee environments under a single host name.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1EnvironmentGroup

Returns a new instance of GoogleCloudApigeeV1EnvironmentGroup.



5249
5250
5251
# File 'lib/google/apis/apigee_v1/classes.rb', line 5249

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#created_atFixnum

Output only. The time at which the environment group was created as milliseconds since epoch. Corresponds to the JSON property createdAt

Returns:

  • (Fixnum)


5225
5226
5227
# File 'lib/google/apis/apigee_v1/classes.rb', line 5225

def created_at
  @created_at
end

#hostnamesArray<String>

Required. Host names for this environment group. Corresponds to the JSON property hostnames

Returns:

  • (Array<String>)


5230
5231
5232
# File 'lib/google/apis/apigee_v1/classes.rb', line 5230

def hostnames
  @hostnames
end

#last_modified_atFixnum

Output only. The time at which the environment group was last updated as milliseconds since epoch. Corresponds to the JSON property lastModifiedAt

Returns:

  • (Fixnum)


5236
5237
5238
# File 'lib/google/apis/apigee_v1/classes.rb', line 5236

def last_modified_at
  @last_modified_at
end

#nameString

ID of the environment group. Corresponds to the JSON property name

Returns:

  • (String)


5241
5242
5243
# File 'lib/google/apis/apigee_v1/classes.rb', line 5241

def name
  @name
end

#stateString

Output only. State of the environment group. Values other than ACTIVE means the resource is not ready to use. Corresponds to the JSON property state

Returns:

  • (String)


5247
5248
5249
# File 'lib/google/apis/apigee_v1/classes.rb', line 5247

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5254
5255
5256
5257
5258
5259
5260
# File 'lib/google/apis/apigee_v1/classes.rb', line 5254

def update!(**args)
  @created_at = args[:created_at] if args.key?(:created_at)
  @hostnames = args[:hostnames] if args.key?(:hostnames)
  @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
end