Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1EnvironmentGroupConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

EnvironmentGroupConfig is a revisioned snapshot of an EnvironmentGroup and its associated routing rules.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1EnvironmentGroupConfig

Returns a new instance of GoogleCloudApigeeV1EnvironmentGroupConfig.



5397
5398
5399
# File 'lib/google/apis/apigee_v1/classes.rb', line 5397

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endpoint_chaining_rulesArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1EndpointChainingRule>

A list of proxies in each deployment group for proxy chaining calls. Corresponds to the JSON property endpointChainingRules



5359
5360
5361
# File 'lib/google/apis/apigee_v1/classes.rb', line 5359

def endpoint_chaining_rules
  @endpoint_chaining_rules
end

#hostnamesArray<String>

Host names for the environment group. Corresponds to the JSON property hostnames

Returns:

  • (Array<String>)


5364
5365
5366
# File 'lib/google/apis/apigee_v1/classes.rb', line 5364

def hostnames
  @hostnames
end

#locationString

When this message appears in the top-level IngressConfig, this field will be populated in lieu of the inlined routing_rules and hostnames fields. Some URL for downloading the full EnvironmentGroupConfig for this group. Corresponds to the JSON property location

Returns:

  • (String)


5371
5372
5373
# File 'lib/google/apis/apigee_v1/classes.rb', line 5371

def location
  @location
end

#nameString

Name of the environment group in the following format: organizations/org/ envgroups/envgroup`. Corresponds to the JSON propertyname`

Returns:

  • (String)


5377
5378
5379
# File 'lib/google/apis/apigee_v1/classes.rb', line 5377

def name
  @name
end

#revision_idFixnum

Revision id that defines the ordering of the EnvironmentGroupConfig resource. The higher the revision, the more recently the configuration was deployed. Corresponds to the JSON property revisionId

Returns:

  • (Fixnum)


5383
5384
5385
# File 'lib/google/apis/apigee_v1/classes.rb', line 5383

def revision_id
  @revision_id
end

#routing_rulesArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1RoutingRule>

Ordered list of routing rules defining how traffic to this environment group's hostnames should be routed to different environments. Corresponds to the JSON property routingRules



5389
5390
5391
# File 'lib/google/apis/apigee_v1/classes.rb', line 5389

def routing_rules
  @routing_rules
end

#uidString

A unique id for the environment group config that will only change if the environment group is deleted and recreated. Corresponds to the JSON property uid

Returns:

  • (String)


5395
5396
5397
# File 'lib/google/apis/apigee_v1/classes.rb', line 5395

def uid
  @uid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5402
5403
5404
5405
5406
5407
5408
5409
5410
# File 'lib/google/apis/apigee_v1/classes.rb', line 5402

def update!(**args)
  @endpoint_chaining_rules = args[:endpoint_chaining_rules] if args.key?(:endpoint_chaining_rules)
  @hostnames = args[:hostnames] if args.key?(:hostnames)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @revision_id = args[:revision_id] if args.key?(:revision_id)
  @routing_rules = args[:routing_rules] if args.key?(:routing_rules)
  @uid = args[:uid] if args.key?(:uid)
end