Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1EnvironmentGroupConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1EnvironmentGroupConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
EnvironmentGroupConfig is a revisioned snapshot of an EnvironmentGroup and its associated routing rules.
Instance Attribute Summary collapse
-
#endpoint_chaining_rules ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1EndpointChainingRule>
A list of proxies in each deployment group for proxy chaining calls.
-
#hostnames ⇒ Array<String>
Host names for the environment group.
-
#location ⇒ String
When this message appears in the top-level IngressConfig, this field will be populated in lieu of the inlined routing_rules and hostnames fields.
-
#name ⇒ String
Name of the environment group in the following format:
organizations/org/ envgroups/envgroup``. -
#revision_id ⇒ Fixnum
Revision id that defines the ordering of the EnvironmentGroupConfig resource.
-
#routing_rules ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1RoutingRule>
Ordered list of routing rules defining how traffic to this environment group's hostnames should be routed to different environments.
-
#uid ⇒ String
A unique id for the environment group config that will only change if the environment group is deleted and recreated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1EnvironmentGroupConfig
constructor
A new instance of GoogleCloudApigeeV1EnvironmentGroupConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1EnvironmentGroupConfig
Returns a new instance of GoogleCloudApigeeV1EnvironmentGroupConfig.
5348 5349 5350 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5348 def initialize(**args) update!(**args) end |
Instance Attribute Details
#endpoint_chaining_rules ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1EndpointChainingRule>
A list of proxies in each deployment group for proxy chaining calls.
Corresponds to the JSON property endpointChainingRules
5310 5311 5312 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5310 def endpoint_chaining_rules @endpoint_chaining_rules end |
#hostnames ⇒ Array<String>
Host names for the environment group.
Corresponds to the JSON property hostnames
5315 5316 5317 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5315 def hostnames @hostnames end |
#location ⇒ String
When this message appears in the top-level IngressConfig, this field will be
populated in lieu of the inlined routing_rules and hostnames fields. Some URL
for downloading the full EnvironmentGroupConfig for this group.
Corresponds to the JSON property location
5322 5323 5324 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5322 def location @location end |
#name ⇒ String
Name of the environment group in the following format: organizations/org/
envgroups/envgroup`.
Corresponds to the JSON propertyname`
5328 5329 5330 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5328 def name @name end |
#revision_id ⇒ Fixnum
Revision id that defines the ordering of the EnvironmentGroupConfig resource.
The higher the revision, the more recently the configuration was deployed.
Corresponds to the JSON property revisionId
5334 5335 5336 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5334 def revision_id @revision_id end |
#routing_rules ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1RoutingRule>
Ordered list of routing rules defining how traffic to this environment group's
hostnames should be routed to different environments.
Corresponds to the JSON property routingRules
5340 5341 5342 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5340 def routing_rules @routing_rules end |
#uid ⇒ String
A unique id for the environment group config that will only change if the
environment group is deleted and recreated.
Corresponds to the JSON property uid
5346 5347 5348 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5346 def uid @uid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5353 5354 5355 5356 5357 5358 5359 5360 5361 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5353 def update!(**args) @endpoint_chaining_rules = args[:endpoint_chaining_rules] if args.key?(:endpoint_chaining_rules) @hostnames = args[:hostnames] if args.key?(:hostnames) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @revision_id = args[:revision_id] if args.key?(:revision_id) @routing_rules = args[:routing_rules] if args.key?(:routing_rules) @uid = args[:uid] if args.key?(:uid) end |