Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Export

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Details of an export job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1Export

Returns a new instance of GoogleCloudApigeeV1Export.



5443
5444
5445
# File 'lib/google/apis/apigee_v1/classes.rb', line 5443

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createdString

Output only. Time the export job was created. Corresponds to the JSON property created

Returns:

  • (String)


5396
5397
5398
# File 'lib/google/apis/apigee_v1/classes.rb', line 5396

def created
  @created
end

#datastore_nameString

Name of the datastore that is the destination of the export job [datastore] Corresponds to the JSON property datastoreName

Returns:

  • (String)


5401
5402
5403
# File 'lib/google/apis/apigee_v1/classes.rb', line 5401

def datastore_name
  @datastore_name
end

#descriptionString

Description of the export job. Corresponds to the JSON property description

Returns:

  • (String)


5406
5407
5408
# File 'lib/google/apis/apigee_v1/classes.rb', line 5406

def description
  @description
end

#errorString

Output only. Error is set when export fails Corresponds to the JSON property error

Returns:

  • (String)


5411
5412
5413
# File 'lib/google/apis/apigee_v1/classes.rb', line 5411

def error
  @error
end

#execution_timeString

Output only. Execution time for this export job. If the job is still in progress, it will be set to the amount of time that has elapsed sincecreated, in seconds. Else, it will set to (updated - created), in seconds. Corresponds to the JSON property executionTime

Returns:

  • (String)


5418
5419
5420
# File 'lib/google/apis/apigee_v1/classes.rb', line 5418

def execution_time
  @execution_time
end

#nameString

Display name of the export job. Corresponds to the JSON property name

Returns:

  • (String)


5423
5424
5425
# File 'lib/google/apis/apigee_v1/classes.rb', line 5423

def name
  @name
end

#selfString

Output only. Self link of the export job. A URI that can be used to retrieve the status of an export job. Example: /organizations/myorg/environments/myenv/ analytics/exports/9cfc0d85-0f30-46d6-ae6f-318d0cb961bd Corresponds to the JSON property self

Returns:

  • (String)


5430
5431
5432
# File 'lib/google/apis/apigee_v1/classes.rb', line 5430

def self
  @self
end

#stateString

Output only. Status of the export job. Valid values include enqueued, running, completed, and failed. Corresponds to the JSON property state

Returns:

  • (String)


5436
5437
5438
# File 'lib/google/apis/apigee_v1/classes.rb', line 5436

def state
  @state
end

#updatedString

Output only. Time the export job was last updated. Corresponds to the JSON property updated

Returns:

  • (String)


5441
5442
5443
# File 'lib/google/apis/apigee_v1/classes.rb', line 5441

def updated
  @updated
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5448
5449
5450
5451
5452
5453
5454
5455
5456
5457
5458
# File 'lib/google/apis/apigee_v1/classes.rb', line 5448

def update!(**args)
  @created = args[:created] if args.key?(:created)
  @datastore_name = args[:datastore_name] if args.key?(:datastore_name)
  @description = args[:description] if args.key?(:description)
  @error = args[:error] if args.key?(:error)
  @execution_time = args[:execution_time] if args.key?(:execution_time)
  @name = args[:name] if args.key?(:name)
  @self = args[:self] if args.key?(:self)
  @state = args[:state] if args.key?(:state)
  @updated = args[:updated] if args.key?(:updated)
end