Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Export
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1Export
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Details of an export job.
Instance Attribute Summary collapse
-
#created ⇒ String
Output only.
-
#datastore_name ⇒ String
Name of the datastore that is the destination of the export job [datastore] Corresponds to the JSON property
datastoreName. -
#description ⇒ String
Description of the export job.
-
#error ⇒ String
Output only.
-
#execution_time ⇒ String
Output only.
-
#name ⇒ String
Display name of the export job.
-
#self ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#updated ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1Export
constructor
A new instance of GoogleCloudApigeeV1Export.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1Export
Returns a new instance of GoogleCloudApigeeV1Export.
5443 5444 5445 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5443 def initialize(**args) update!(**args) end |
Instance Attribute Details
#created ⇒ String
Output only. Time the export job was created.
Corresponds to the JSON property created
5396 5397 5398 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5396 def created @created end |
#datastore_name ⇒ String
Name of the datastore that is the destination of the export job [datastore]
Corresponds to the JSON property datastoreName
5401 5402 5403 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5401 def datastore_name @datastore_name end |
#description ⇒ String
Description of the export job.
Corresponds to the JSON property description
5406 5407 5408 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5406 def description @description end |
#error ⇒ String
Output only. Error is set when export fails
Corresponds to the JSON property error
5411 5412 5413 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5411 def error @error end |
#execution_time ⇒ String
Output only. Execution time for this export job. If the job is still in
progress, it will be set to the amount of time that has elapsed sincecreated,
in seconds. Else, it will set to (updated - created), in seconds.
Corresponds to the JSON property executionTime
5418 5419 5420 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5418 def execution_time @execution_time end |
#name ⇒ String
Display name of the export job.
Corresponds to the JSON property name
5423 5424 5425 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5423 def name @name end |
#self ⇒ String
Output only. Self link of the export job. A URI that can be used to retrieve
the status of an export job. Example: /organizations/myorg/environments/myenv/
analytics/exports/9cfc0d85-0f30-46d6-ae6f-318d0cb961bd
Corresponds to the JSON property self
5430 5431 5432 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5430 def self @self end |
#state ⇒ String
Output only. Status of the export job. Valid values include enqueued,
running, completed, and failed.
Corresponds to the JSON property state
5436 5437 5438 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5436 def state @state end |
#updated ⇒ String
Output only. Time the export job was last updated.
Corresponds to the JSON property updated
5441 5442 5443 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5441 def updated @updated end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5448 5449 5450 5451 5452 5453 5454 5455 5456 5457 5458 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5448 def update!(**args) @created = args[:created] if args.key?(:created) @datastore_name = args[:datastore_name] if args.key?(:datastore_name) @description = args[:description] if args.key?(:description) @error = args[:error] if args.key?(:error) @execution_time = args[:execution_time] if args.key?(:execution_time) @name = args[:name] if args.key?(:name) @self = args[:self] if args.key?(:self) @state = args[:state] if args.key?(:state) @updated = args[:updated] if args.key?(:updated) end |