Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Export

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Details of an export job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1Export

Returns a new instance of GoogleCloudApigeeV1Export.



5493
5494
5495
# File 'lib/google/apis/apigee_v1/classes.rb', line 5493

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createdString

Output only. Time the export job was created. Corresponds to the JSON property created

Returns:

  • (String)


5446
5447
5448
# File 'lib/google/apis/apigee_v1/classes.rb', line 5446

def created
  @created
end

#datastore_nameString

Name of the datastore that is the destination of the export job [datastore] Corresponds to the JSON property datastoreName

Returns:

  • (String)


5451
5452
5453
# File 'lib/google/apis/apigee_v1/classes.rb', line 5451

def datastore_name
  @datastore_name
end

#descriptionString

Description of the export job. Corresponds to the JSON property description

Returns:

  • (String)


5456
5457
5458
# File 'lib/google/apis/apigee_v1/classes.rb', line 5456

def description
  @description
end

#errorString

Output only. Error is set when export fails Corresponds to the JSON property error

Returns:

  • (String)


5461
5462
5463
# File 'lib/google/apis/apigee_v1/classes.rb', line 5461

def error
  @error
end

#execution_timeString

Output only. Execution time for this export job. If the job is still in progress, it will be set to the amount of time that has elapsed sincecreated, in seconds. Else, it will set to (updated - created), in seconds. Corresponds to the JSON property executionTime

Returns:

  • (String)


5468
5469
5470
# File 'lib/google/apis/apigee_v1/classes.rb', line 5468

def execution_time
  @execution_time
end

#nameString

Display name of the export job. Corresponds to the JSON property name

Returns:

  • (String)


5473
5474
5475
# File 'lib/google/apis/apigee_v1/classes.rb', line 5473

def name
  @name
end

#selfString

Output only. Self link of the export job. A URI that can be used to retrieve the status of an export job. Example: /organizations/myorg/environments/myenv/ analytics/exports/9cfc0d85-0f30-46d6-ae6f-318d0cb961bd Corresponds to the JSON property self

Returns:

  • (String)


5480
5481
5482
# File 'lib/google/apis/apigee_v1/classes.rb', line 5480

def self
  @self
end

#stateString

Output only. Status of the export job. Valid values include enqueued, running, completed, and failed. Corresponds to the JSON property state

Returns:

  • (String)


5486
5487
5488
# File 'lib/google/apis/apigee_v1/classes.rb', line 5486

def state
  @state
end

#updatedString

Output only. Time the export job was last updated. Corresponds to the JSON property updated

Returns:

  • (String)


5491
5492
5493
# File 'lib/google/apis/apigee_v1/classes.rb', line 5491

def updated
  @updated
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5498
5499
5500
5501
5502
5503
5504
5505
5506
5507
5508
# File 'lib/google/apis/apigee_v1/classes.rb', line 5498

def update!(**args)
  @created = args[:created] if args.key?(:created)
  @datastore_name = args[:datastore_name] if args.key?(:datastore_name)
  @description = args[:description] if args.key?(:description)
  @error = args[:error] if args.key?(:error)
  @execution_time = args[:execution_time] if args.key?(:execution_time)
  @name = args[:name] if args.key?(:name)
  @self = args[:self] if args.key?(:self)
  @state = args[:state] if args.key?(:state)
  @updated = args[:updated] if args.key?(:updated)
end