Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Export
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1Export
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Details of an export job.
Instance Attribute Summary collapse
-
#created ⇒ String
Output only.
-
#datastore_name ⇒ String
Name of the datastore that is the destination of the export job [datastore] Corresponds to the JSON property
datastoreName. -
#description ⇒ String
Description of the export job.
-
#error ⇒ String
Output only.
-
#execution_time ⇒ String
Output only.
-
#name ⇒ String
Display name of the export job.
-
#self ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#updated ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1Export
constructor
A new instance of GoogleCloudApigeeV1Export.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1Export
Returns a new instance of GoogleCloudApigeeV1Export.
5493 5494 5495 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5493 def initialize(**args) update!(**args) end |
Instance Attribute Details
#created ⇒ String
Output only. Time the export job was created.
Corresponds to the JSON property created
5446 5447 5448 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5446 def created @created end |
#datastore_name ⇒ String
Name of the datastore that is the destination of the export job [datastore]
Corresponds to the JSON property datastoreName
5451 5452 5453 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5451 def datastore_name @datastore_name end |
#description ⇒ String
Description of the export job.
Corresponds to the JSON property description
5456 5457 5458 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5456 def description @description end |
#error ⇒ String
Output only. Error is set when export fails
Corresponds to the JSON property error
5461 5462 5463 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5461 def error @error end |
#execution_time ⇒ String
Output only. Execution time for this export job. If the job is still in
progress, it will be set to the amount of time that has elapsed sincecreated,
in seconds. Else, it will set to (updated - created), in seconds.
Corresponds to the JSON property executionTime
5468 5469 5470 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5468 def execution_time @execution_time end |
#name ⇒ String
Display name of the export job.
Corresponds to the JSON property name
5473 5474 5475 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5473 def name @name end |
#self ⇒ String
Output only. Self link of the export job. A URI that can be used to retrieve
the status of an export job. Example: /organizations/myorg/environments/myenv/
analytics/exports/9cfc0d85-0f30-46d6-ae6f-318d0cb961bd
Corresponds to the JSON property self
5480 5481 5482 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5480 def self @self end |
#state ⇒ String
Output only. Status of the export job. Valid values include enqueued,
running, completed, and failed.
Corresponds to the JSON property state
5486 5487 5488 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5486 def state @state end |
#updated ⇒ String
Output only. Time the export job was last updated.
Corresponds to the JSON property updated
5491 5492 5493 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5491 def updated @updated end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5498 5499 5500 5501 5502 5503 5504 5505 5506 5507 5508 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5498 def update!(**args) @created = args[:created] if args.key?(:created) @datastore_name = args[:datastore_name] if args.key?(:datastore_name) @description = args[:description] if args.key?(:description) @error = args[:error] if args.key?(:error) @execution_time = args[:execution_time] if args.key?(:execution_time) @name = args[:name] if args.key?(:name) @self = args[:self] if args.key?(:self) @state = args[:state] if args.key?(:state) @updated = args[:updated] if args.key?(:updated) end |