Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1FlowHook
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1FlowHook
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Instance Attribute Summary collapse
-
#continue_on_error ⇒ Boolean
(also: #continue_on_error?)
Optional.
-
#description ⇒ String
Description of the flow hook.
-
#flow_hook_point ⇒ String
Output only.
-
#shared_flow ⇒ String
Shared flow attached to this flow hook, or empty if there is none attached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1FlowHook
constructor
A new instance of GoogleCloudApigeeV1FlowHook.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1FlowHook
Returns a new instance of GoogleCloudApigeeV1FlowHook.
5544 5545 5546 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5544 def initialize(**args) update!(**args) end |
Instance Attribute Details
#continue_on_error ⇒ Boolean Also known as: continue_on_error?
Optional. Flag that specifies whether execution should continue if the flow
hook throws an exception. Set to true to continue execution. Set to false
to stop execution if the flow hook throws an exception. Defaults to true.
Corresponds to the JSON property continueOnError
5524 5525 5526 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5524 def continue_on_error @continue_on_error end |
#description ⇒ String
Description of the flow hook.
Corresponds to the JSON property description
5530 5531 5532 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5530 def description @description end |
#flow_hook_point ⇒ String
Output only. Where in the API call flow the flow hook is invoked. Must be one
of PreProxyFlowHook, PostProxyFlowHook, PreTargetFlowHook, or
PostTargetFlowHook.
Corresponds to the JSON property flowHookPoint
5537 5538 5539 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5537 def flow_hook_point @flow_hook_point end |
#shared_flow ⇒ String
Shared flow attached to this flow hook, or empty if there is none attached.
Corresponds to the JSON property sharedFlow
5542 5543 5544 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5542 def shared_flow @shared_flow end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5549 5550 5551 5552 5553 5554 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5549 def update!(**args) @continue_on_error = args[:continue_on_error] if args.key?(:continue_on_error) @description = args[:description] if args.key?(:description) @flow_hook_point = args[:flow_hook_point] if args.key?(:flow_hook_point) @shared_flow = args[:shared_flow] if args.key?(:shared_flow) end |