Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1FlowHookConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1FlowHookConfig

Returns a new instance of GoogleCloudApigeeV1FlowHookConfig.



5582
5583
5584
# File 'lib/google/apis/apigee_v1/classes.rb', line 5582

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#continue_on_errorBoolean Also known as: continue_on_error?

Flag that specifies whether the flow should abort after an error in the flow hook. Defaults to true (continue on error). Corresponds to the JSON property continueOnError

Returns:

  • (Boolean)


5565
5566
5567
# File 'lib/google/apis/apigee_v1/classes.rb', line 5565

def continue_on_error
  @continue_on_error
end

#nameString

Name of the flow hook in the following format: organizations/org/ environments/env/flowhooks/point`. Validpointvalues include: PreProxyFlowHook,PostProxyFlowHook,PreTargetFlowHook, and PostTargetFlowHook Corresponds to the JSON propertyname`

Returns:

  • (String)


5574
5575
5576
# File 'lib/google/apis/apigee_v1/classes.rb', line 5574

def name
  @name
end

#shared_flow_nameString

Name of the shared flow to invoke in the following format: organizations/org /sharedflows/sharedflow` Corresponds to the JSON propertysharedFlowName`

Returns:

  • (String)


5580
5581
5582
# File 'lib/google/apis/apigee_v1/classes.rb', line 5580

def shared_flow_name
  @shared_flow_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5587
5588
5589
5590
5591
# File 'lib/google/apis/apigee_v1/classes.rb', line 5587

def update!(**args)
  @continue_on_error = args[:continue_on_error] if args.key?(:continue_on_error)
  @name = args[:name] if args.key?(:name)
  @shared_flow_name = args[:shared_flow_name] if args.key?(:shared_flow_name)
end