Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1GraphQlOperation
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1GraphQlOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Represents the pairing of GraphQL operation types and the GraphQL operation name.
Instance Attribute Summary collapse
-
#operation ⇒ String
GraphQL operation name.
-
#operation_types ⇒ Array<String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1GraphQlOperation
constructor
A new instance of GoogleCloudApigeeV1GraphQlOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1GraphQlOperation
Returns a new instance of GoogleCloudApigeeV1GraphQlOperation.
5751 5752 5753 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5751 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operation ⇒ String
GraphQL operation name. The name and operation type will be used to apply
quotas. If no name is specified, the quota will be applied to all GraphQL
operations irrespective of their operation names in the payload.
Corresponds to the JSON property operation
5743 5744 5745 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5743 def operation @operation end |
#operation_types ⇒ Array<String>
Required. GraphQL operation types. Valid values include query or mutation.
Note: Apigee does not currently support subscription types.
Corresponds to the JSON property operationTypes
5749 5750 5751 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5749 def operation_types @operation_types end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5756 5757 5758 5759 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5756 def update!(**args) @operation = args[:operation] if args.key?(:operation) @operation_types = args[:operation_types] if args.key?(:operation_types) end |