Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1GraphQlOperationConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1GraphQlOperationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Binds the resources in a proxy or remote service with the GraphQL operation and its associated quota enforcement.
Instance Attribute Summary collapse
-
#api_source ⇒ String
Required.
-
#attributes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>
Custom attributes associated with the operation.
-
#operations ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1GraphQlOperation>
Required.
-
#quota ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1Quota
Quota contains the essential parameters needed that can be applied on the resources, methods, API source combination associated with this API product.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1GraphQlOperationConfig
constructor
A new instance of GoogleCloudApigeeV1GraphQlOperationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1GraphQlOperationConfig
Returns a new instance of GoogleCloudApigeeV1GraphQlOperationConfig.
5795 5796 5797 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5795 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_source ⇒ String
Required. Name of the API proxy endpoint or remote service with which the
GraphQL operation and quota are associated.
Corresponds to the JSON property apiSource
5771 5772 5773 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5771 def api_source @api_source end |
#attributes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>
Custom attributes associated with the operation.
Corresponds to the JSON property attributes
5776 5777 5778 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5776 def attributes @attributes end |
#operations ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1GraphQlOperation>
Required. List of GraphQL name/operation type pairs for the proxy or remote
service to which quota will be applied. If only operation types are specified,
the quota will be applied to all GraphQL requests irrespective of the GraphQL
name. Note: Currently, you can specify only a single GraphQLOperation.
Specifying more than one will cause the operation to fail.
Corresponds to the JSON property operations
5785 5786 5787 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5785 def operations @operations end |
#quota ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1Quota
Quota contains the essential parameters needed that can be applied on the
resources, methods, API source combination associated with this API product.
While Quota is optional, setting it prevents requests from exceeding the
provisioned parameters.
Corresponds to the JSON property quota
5793 5794 5795 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5793 def quota @quota end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5800 5801 5802 5803 5804 5805 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 5800 def update!(**args) @api_source = args[:api_source] if args.key?(:api_source) @attributes = args[:attributes] if args.key?(:attributes) @operations = args[:operations] if args.key?(:operations) @quota = args[:quota] if args.key?(:quota) end |