Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1IngressConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1IngressConfig

Returns a new instance of GoogleCloudApigeeV1IngressConfig.



5974
5975
5976
# File 'lib/google/apis/apigee_v1/classes.rb', line 5974

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#environment_groupsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1EnvironmentGroupConfig>

List of environment groups in the organization. Corresponds to the JSON property environmentGroups



5949
5950
5951
# File 'lib/google/apis/apigee_v1/classes.rb', line 5949

def environment_groups
  @environment_groups
end

#nameString

Name of the resource in the following format: organizations/org/ deployedIngressConfig. Corresponds to the JSON property name

Returns:

  • (String)


5955
5956
5957
# File 'lib/google/apis/apigee_v1/classes.rb', line 5955

def name
  @name
end

#revision_create_timeString

Time at which the IngressConfig revision was created. Corresponds to the JSON property revisionCreateTime

Returns:

  • (String)


5960
5961
5962
# File 'lib/google/apis/apigee_v1/classes.rb', line 5960

def revision_create_time
  @revision_create_time
end

#revision_idFixnum

Revision id that defines the ordering on IngressConfig resources. The higher the revision, the more recently the configuration was deployed. Corresponds to the JSON property revisionId

Returns:

  • (Fixnum)


5966
5967
5968
# File 'lib/google/apis/apigee_v1/classes.rb', line 5966

def revision_id
  @revision_id
end

#uidString

A unique id for the ingress config that will only change if the organization is deleted and recreated. Corresponds to the JSON property uid

Returns:

  • (String)


5972
5973
5974
# File 'lib/google/apis/apigee_v1/classes.rb', line 5972

def uid
  @uid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5979
5980
5981
5982
5983
5984
5985
# File 'lib/google/apis/apigee_v1/classes.rb', line 5979

def update!(**args)
  @environment_groups = args[:environment_groups] if args.key?(:environment_groups)
  @name = args[:name] if args.key?(:name)
  @revision_create_time = args[:revision_create_time] if args.key?(:revision_create_time)
  @revision_id = args[:revision_id] if args.key?(:revision_id)
  @uid = args[:uid] if args.key?(:uid)
end