Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Instance
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1Instance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Apigee runtime instance.
Instance Attribute Summary collapse
-
#access_logging_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1AccessLoggingConfig
Access logging configuration enables customers to ship the access logs from the tenant projects to their own project's cloud logging.
-
#consumer_accept_list ⇒ Array<String>
Optional.
-
#created_at ⇒ Fixnum
Output only.
-
#description ⇒ String
Optional.
-
#disk_encryption_key_name ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#host ⇒ String
Output only.
-
#ip_range ⇒ String
Optional.
-
#is_version_locked ⇒ Boolean
(also: #is_version_locked?)
Output only.
-
#last_modified_at ⇒ Fixnum
Output only.
-
#location ⇒ String
Required.
-
#maintenance_update_policy ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1MaintenanceUpdatePolicy
MaintenanceUpdatePolicy specifies the preferred window to perform maintenance on the instance (day of the week and time of day).
-
#name ⇒ String
Required.
-
#peering_cidr_range ⇒ String
Optional.
-
#port ⇒ String
Output only.
-
#runtime_version ⇒ String
Output only.
-
#scheduled_maintenance ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ScheduledMaintenance
Scheduled maintenance information for an instance.
-
#service_attachment ⇒ String
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1Instance
constructor
A new instance of GoogleCloudApigeeV1Instance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1Instance
Returns a new instance of GoogleCloudApigeeV1Instance.
6135 6136 6137 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6135 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_logging_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1AccessLoggingConfig
Access logging configuration enables customers to ship the access logs from
the tenant projects to their own project's cloud logging. The feature is at
the instance level ad disabled by default. It can be enabled during
CreateInstance or UpdateInstance.
Corresponds to the JSON property accessLoggingConfig
6015 6016 6017 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6015 def access_logging_config @access_logging_config end |
#consumer_accept_list ⇒ Array<String>
Optional. Customer accept list represents the list of projects (id/number) on
customer side that can privately connect to the service attachment. It is an
optional field which the customers can provide during the instance creation.
By default, the customer project associated with the Apigee organization will
be included to the list.
Corresponds to the JSON property consumerAcceptList
6024 6025 6026 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6024 def consumer_accept_list @consumer_accept_list end |
#created_at ⇒ Fixnum
Output only. Time the instance was created in milliseconds since epoch.
Corresponds to the JSON property createdAt
6029 6030 6031 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6029 def created_at @created_at end |
#description ⇒ String
Optional. Description of the instance.
Corresponds to the JSON property description
6034 6035 6036 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6034 def description @description end |
#disk_encryption_key_name ⇒ String
Optional. Customer Managed Encryption Key (CMEK) used for disk and volume
encryption. If not specified, a Google-Managed encryption key will be used.
Use the following format: projects/([^/]+)/locations/([^/]+)/keyRings/([^/]+)/
cryptoKeys/([^/]+)
Corresponds to the JSON property diskEncryptionKeyName
6042 6043 6044 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6042 def disk_encryption_key_name @disk_encryption_key_name end |
#display_name ⇒ String
Optional. Display name for the instance.
Corresponds to the JSON property displayName
6047 6048 6049 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6047 def display_name @display_name end |
#host ⇒ String
Output only. Internal hostname or IP address of the Apigee endpoint used by
clients to connect to the service.
Corresponds to the JSON property host
6053 6054 6055 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6053 def host @host end |
#ip_range ⇒ String
Optional. Comma-separated list of CIDR blocks of length 22 and/or 28 used to
create the Apigee instance. Providing CIDR ranges is optional. You can provide
just /22 or /28 or both (or neither). Ranges you provide should be freely
available as part of a larger named range you have allocated to the Service
Networking peering. If this parameter is not provided, Apigee automatically
requests an available /22 and /28 CIDR block from Service Networking. Use the /
22 CIDR block for configuring your firewall needs to allow traffic from Apigee.
Input formats: a.b.c.d/22 or e.f.g.h/28 or a.b.c.d/22,e.f.g.h/28
Corresponds to the JSON property ipRange
6065 6066 6067 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6065 def ip_range @ip_range end |
#is_version_locked ⇒ Boolean Also known as: is_version_locked?
Output only. Indicates whether the instance is version locked. If true, the
instance will not be updated by automated runtime rollouts. This is only
supported for Apigee X instances.
Corresponds to the JSON property isVersionLocked
6072 6073 6074 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6072 def is_version_locked @is_version_locked end |
#last_modified_at ⇒ Fixnum
Output only. Time the instance was last modified in milliseconds since epoch.
Corresponds to the JSON property lastModifiedAt
6078 6079 6080 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6078 def last_modified_at @last_modified_at end |
#location ⇒ String
Required. Compute Engine location where the instance resides.
Corresponds to the JSON property location
6083 6084 6085 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6083 def location @location end |
#maintenance_update_policy ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1MaintenanceUpdatePolicy
MaintenanceUpdatePolicy specifies the preferred window to perform maintenance
on the instance (day of the week and time of day).
Corresponds to the JSON property maintenanceUpdatePolicy
6089 6090 6091 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6089 def maintenance_update_policy @maintenance_update_policy end |
#name ⇒ String
Required. Resource ID of the instance. Values must match the regular
expression ^a-z0,30[a-z\d]$.
Corresponds to the JSON property name
6095 6096 6097 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6095 def name @name end |
#peering_cidr_range ⇒ String
Optional. Size of the CIDR block range that will be reserved by the instance.
PAID organizations support SLASH_16 to SLASH_20 and defaults to SLASH_16.
Evaluation organizations support only SLASH_23.
Corresponds to the JSON property peeringCidrRange
6102 6103 6104 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6102 def peering_cidr_range @peering_cidr_range end |
#port ⇒ String
Output only. Port number of the exposed Apigee endpoint.
Corresponds to the JSON property port
6107 6108 6109 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6107 def port @port end |
#runtime_version ⇒ String
Output only. Version of the runtime system running in the instance. The
runtime system is the set of components that serve the API Proxy traffic in
your Environments.
Corresponds to the JSON property runtimeVersion
6114 6115 6116 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6114 def runtime_version @runtime_version end |
#scheduled_maintenance ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ScheduledMaintenance
Scheduled maintenance information for an instance.
Corresponds to the JSON property scheduledMaintenance
6119 6120 6121 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6119 def scheduled_maintenance @scheduled_maintenance end |
#service_attachment ⇒ String
Output only. Resource name of the service attachment created for the instance
in the format: projects/*/regions/*/serviceAttachments/* Apigee customers
can privately forward traffic to this service attachment using the PSC
endpoints.
Corresponds to the JSON property serviceAttachment
6127 6128 6129 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6127 def @service_attachment end |
#state ⇒ String
Output only. State of the instance. Values other than ACTIVE means the
resource is not ready to use.
Corresponds to the JSON property state
6133 6134 6135 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6133 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6140 6141 6142 6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 6154 6155 6156 6157 6158 6159 6160 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6140 def update!(**args) @access_logging_config = args[:access_logging_config] if args.key?(:access_logging_config) @consumer_accept_list = args[:consumer_accept_list] if args.key?(:consumer_accept_list) @created_at = args[:created_at] if args.key?(:created_at) @description = args[:description] if args.key?(:description) @disk_encryption_key_name = args[:disk_encryption_key_name] if args.key?(:disk_encryption_key_name) @display_name = args[:display_name] if args.key?(:display_name) @host = args[:host] if args.key?(:host) @ip_range = args[:ip_range] if args.key?(:ip_range) @is_version_locked = args[:is_version_locked] if args.key?(:is_version_locked) @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at) @location = args[:location] if args.key?(:location) @maintenance_update_policy = args[:maintenance_update_policy] if args.key?(:maintenance_update_policy) @name = args[:name] if args.key?(:name) @peering_cidr_range = args[:peering_cidr_range] if args.key?(:peering_cidr_range) @port = args[:port] if args.key?(:port) @runtime_version = args[:runtime_version] if args.key?(:runtime_version) @scheduled_maintenance = args[:scheduled_maintenance] if args.key?(:scheduled_maintenance) @service_attachment = args[:service_attachment] if args.key?(:service_attachment) @state = args[:state] if args.key?(:state) end |