Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Instance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Apigee runtime instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1Instance

Returns a new instance of GoogleCloudApigeeV1Instance.



6126
6127
6128
# File 'lib/google/apis/apigee_v1/classes.rb', line 6126

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_logging_configGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1AccessLoggingConfig

Access logging configuration enables customers to ship the access logs from the tenant projects to their own project's cloud logging. The feature is at the instance level ad disabled by default. It can be enabled during CreateInstance or UpdateInstance. Corresponds to the JSON property accessLoggingConfig



6006
6007
6008
# File 'lib/google/apis/apigee_v1/classes.rb', line 6006

def access_logging_config
  @access_logging_config
end

#consumer_accept_listArray<String>

Optional. Customer accept list represents the list of projects (id/number) on customer side that can privately connect to the service attachment. It is an optional field which the customers can provide during the instance creation. By default, the customer project associated with the Apigee organization will be included to the list. Corresponds to the JSON property consumerAcceptList

Returns:

  • (Array<String>)


6015
6016
6017
# File 'lib/google/apis/apigee_v1/classes.rb', line 6015

def consumer_accept_list
  @consumer_accept_list
end

#created_atFixnum

Output only. Time the instance was created in milliseconds since epoch. Corresponds to the JSON property createdAt

Returns:

  • (Fixnum)


6020
6021
6022
# File 'lib/google/apis/apigee_v1/classes.rb', line 6020

def created_at
  @created_at
end

#descriptionString

Optional. Description of the instance. Corresponds to the JSON property description

Returns:

  • (String)


6025
6026
6027
# File 'lib/google/apis/apigee_v1/classes.rb', line 6025

def description
  @description
end

#disk_encryption_key_nameString

Optional. Customer Managed Encryption Key (CMEK) used for disk and volume encryption. If not specified, a Google-Managed encryption key will be used. Use the following format: projects/([^/]+)/locations/([^/]+)/keyRings/([^/]+)/ cryptoKeys/([^/]+) Corresponds to the JSON property diskEncryptionKeyName

Returns:

  • (String)


6033
6034
6035
# File 'lib/google/apis/apigee_v1/classes.rb', line 6033

def disk_encryption_key_name
  @disk_encryption_key_name
end

#display_nameString

Optional. Display name for the instance. Corresponds to the JSON property displayName

Returns:

  • (String)


6038
6039
6040
# File 'lib/google/apis/apigee_v1/classes.rb', line 6038

def display_name
  @display_name
end

#hostString

Output only. Internal hostname or IP address of the Apigee endpoint used by clients to connect to the service. Corresponds to the JSON property host

Returns:

  • (String)


6044
6045
6046
# File 'lib/google/apis/apigee_v1/classes.rb', line 6044

def host
  @host
end

#ip_rangeString

Optional. Comma-separated list of CIDR blocks of length 22 and/or 28 used to create the Apigee instance. Providing CIDR ranges is optional. You can provide just /22 or /28 or both (or neither). Ranges you provide should be freely available as part of a larger named range you have allocated to the Service Networking peering. If this parameter is not provided, Apigee automatically requests an available /22 and /28 CIDR block from Service Networking. Use the / 22 CIDR block for configuring your firewall needs to allow traffic from Apigee. Input formats: a.b.c.d/22 or e.f.g.h/28 or a.b.c.d/22,e.f.g.h/28 Corresponds to the JSON property ipRange

Returns:

  • (String)


6056
6057
6058
# File 'lib/google/apis/apigee_v1/classes.rb', line 6056

def ip_range
  @ip_range
end

#is_version_lockedBoolean Also known as: is_version_locked?

Output only. Indicates whether the instance is version locked. If true, the instance will not be updated by automated runtime rollouts. This is only supported for Apigee X instances. Corresponds to the JSON property isVersionLocked

Returns:

  • (Boolean)


6063
6064
6065
# File 'lib/google/apis/apigee_v1/classes.rb', line 6063

def is_version_locked
  @is_version_locked
end

#last_modified_atFixnum

Output only. Time the instance was last modified in milliseconds since epoch. Corresponds to the JSON property lastModifiedAt

Returns:

  • (Fixnum)


6069
6070
6071
# File 'lib/google/apis/apigee_v1/classes.rb', line 6069

def last_modified_at
  @last_modified_at
end

#locationString

Required. Compute Engine location where the instance resides. Corresponds to the JSON property location

Returns:

  • (String)


6074
6075
6076
# File 'lib/google/apis/apigee_v1/classes.rb', line 6074

def location
  @location
end

#maintenance_update_policyGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1MaintenanceUpdatePolicy

MaintenanceUpdatePolicy specifies the preferred window to perform maintenance on the instance (day of the week and time of day). Corresponds to the JSON property maintenanceUpdatePolicy



6080
6081
6082
# File 'lib/google/apis/apigee_v1/classes.rb', line 6080

def maintenance_update_policy
  @maintenance_update_policy
end

#nameString

Required. Resource ID of the instance. Values must match the regular expression ^a-z0,30[a-z\d]$. Corresponds to the JSON property name

Returns:

  • (String)


6086
6087
6088
# File 'lib/google/apis/apigee_v1/classes.rb', line 6086

def name
  @name
end

#peering_cidr_rangeString

Optional. Size of the CIDR block range that will be reserved by the instance. PAID organizations support SLASH_16 to SLASH_20 and defaults to SLASH_16. Evaluation organizations support only SLASH_23. Corresponds to the JSON property peeringCidrRange

Returns:

  • (String)


6093
6094
6095
# File 'lib/google/apis/apigee_v1/classes.rb', line 6093

def peering_cidr_range
  @peering_cidr_range
end

#portString

Output only. Port number of the exposed Apigee endpoint. Corresponds to the JSON property port

Returns:

  • (String)


6098
6099
6100
# File 'lib/google/apis/apigee_v1/classes.rb', line 6098

def port
  @port
end

#runtime_versionString

Output only. Version of the runtime system running in the instance. The runtime system is the set of components that serve the API Proxy traffic in your Environments. Corresponds to the JSON property runtimeVersion

Returns:

  • (String)


6105
6106
6107
# File 'lib/google/apis/apigee_v1/classes.rb', line 6105

def runtime_version
  @runtime_version
end

#scheduled_maintenanceGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1ScheduledMaintenance

Scheduled maintenance information for an instance. Corresponds to the JSON property scheduledMaintenance



6110
6111
6112
# File 'lib/google/apis/apigee_v1/classes.rb', line 6110

def scheduled_maintenance
  @scheduled_maintenance
end

#service_attachmentString

Output only. Resource name of the service attachment created for the instance in the format: projects/*/regions/*/serviceAttachments/* Apigee customers can privately forward traffic to this service attachment using the PSC endpoints. Corresponds to the JSON property serviceAttachment

Returns:

  • (String)


6118
6119
6120
# File 'lib/google/apis/apigee_v1/classes.rb', line 6118

def service_attachment
  @service_attachment
end

#stateString

Output only. State of the instance. Values other than ACTIVE means the resource is not ready to use. Corresponds to the JSON property state

Returns:

  • (String)


6124
6125
6126
# File 'lib/google/apis/apigee_v1/classes.rb', line 6124

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6131
6132
6133
6134
6135
6136
6137
6138
6139
6140
6141
6142
6143
6144
6145
6146
6147
6148
6149
6150
6151
# File 'lib/google/apis/apigee_v1/classes.rb', line 6131

def update!(**args)
  @access_logging_config = args[:access_logging_config] if args.key?(:access_logging_config)
  @consumer_accept_list = args[:consumer_accept_list] if args.key?(:consumer_accept_list)
  @created_at = args[:created_at] if args.key?(:created_at)
  @description = args[:description] if args.key?(:description)
  @disk_encryption_key_name = args[:disk_encryption_key_name] if args.key?(:disk_encryption_key_name)
  @display_name = args[:display_name] if args.key?(:display_name)
  @host = args[:host] if args.key?(:host)
  @ip_range = args[:ip_range] if args.key?(:ip_range)
  @is_version_locked = args[:is_version_locked] if args.key?(:is_version_locked)
  @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at)
  @location = args[:location] if args.key?(:location)
  @maintenance_update_policy = args[:maintenance_update_policy] if args.key?(:maintenance_update_policy)
  @name = args[:name] if args.key?(:name)
  @peering_cidr_range = args[:peering_cidr_range] if args.key?(:peering_cidr_range)
  @port = args[:port] if args.key?(:port)
  @runtime_version = args[:runtime_version] if args.key?(:runtime_version)
  @scheduled_maintenance = args[:scheduled_maintenance] if args.key?(:scheduled_maintenance)
  @service_attachment = args[:service_attachment] if args.key?(:service_attachment)
  @state = args[:state] if args.key?(:state)
end