Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1InstanceAttachment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

InstanceAttachment represents the installation of an environment onto an instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1InstanceAttachment

Returns a new instance of GoogleCloudApigeeV1InstanceAttachment.



6165
6166
6167
# File 'lib/google/apis/apigee_v1/classes.rb', line 6165

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#created_atFixnum

Output only. Time the attachment was created in milliseconds since epoch. Corresponds to the JSON property createdAt

Returns:

  • (Fixnum)


6153
6154
6155
# File 'lib/google/apis/apigee_v1/classes.rb', line 6153

def created_at
  @created_at
end

#environmentString

ID of the attached environment. Corresponds to the JSON property environment

Returns:

  • (String)


6158
6159
6160
# File 'lib/google/apis/apigee_v1/classes.rb', line 6158

def environment
  @environment
end

#nameString

Output only. ID of the attachment. Corresponds to the JSON property name

Returns:

  • (String)


6163
6164
6165
# File 'lib/google/apis/apigee_v1/classes.rb', line 6163

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6170
6171
6172
6173
6174
# File 'lib/google/apis/apigee_v1/classes.rb', line 6170

def update!(**args)
  @created_at = args[:created_at] if args.key?(:created_at)
  @environment = args[:environment] if args.key?(:environment)
  @name = args[:name] if args.key?(:name)
end