Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1InstanceAttachment
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1InstanceAttachment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
InstanceAttachment represents the installation of an environment onto an instance.
Instance Attribute Summary collapse
-
#created_at ⇒ Fixnum
Output only.
-
#environment ⇒ String
ID of the attached environment.
-
#name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1InstanceAttachment
constructor
A new instance of GoogleCloudApigeeV1InstanceAttachment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1InstanceAttachment
Returns a new instance of GoogleCloudApigeeV1InstanceAttachment.
6166 6167 6168 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6166 def initialize(**args) update!(**args) end |
Instance Attribute Details
#created_at ⇒ Fixnum
Output only. Time the attachment was created in milliseconds since epoch.
Corresponds to the JSON property createdAt
6154 6155 6156 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6154 def created_at @created_at end |
#environment ⇒ String
ID of the attached environment.
Corresponds to the JSON property environment
6159 6160 6161 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6159 def environment @environment end |
#name ⇒ String
Output only. ID of the attachment.
Corresponds to the JSON property name
6164 6165 6166 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6164 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6171 6172 6173 6174 6175 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6171 def update!(**args) @created_at = args[:created_at] if args.key?(:created_at) @environment = args[:environment] if args.key?(:environment) @name = args[:name] if args.key?(:name) end |