Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1KeyValueMap

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Collection of key/value string pairs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1KeyValueMap

Returns a new instance of GoogleCloudApigeeV1KeyValueMap.



6371
6372
6373
# File 'lib/google/apis/apigee_v1/classes.rb', line 6371

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#encryptedBoolean Also known as: encrypted?

Required. Flag that specifies whether entry values will be encrypted. This field is retained for backward compatibility and the value of encrypted will always be true. Apigee X and hybrid do not support unencrypted key value maps. Corresponds to the JSON property encrypted

Returns:

  • (Boolean)


6356
6357
6358
# File 'lib/google/apis/apigee_v1/classes.rb', line 6356

def encrypted
  @encrypted
end

#masked_valuesBoolean Also known as: masked_values?

Optional. Flag that specifies whether entry values will be masked when returned. Corresponds to the JSON property maskedValues

Returns:

  • (Boolean)


6363
6364
6365
# File 'lib/google/apis/apigee_v1/classes.rb', line 6363

def masked_values
  @masked_values
end

#nameString

Required. ID of the key value map. Corresponds to the JSON property name

Returns:

  • (String)


6369
6370
6371
# File 'lib/google/apis/apigee_v1/classes.rb', line 6369

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6376
6377
6378
6379
6380
# File 'lib/google/apis/apigee_v1/classes.rb', line 6376

def update!(**args)
  @encrypted = args[:encrypted] if args.key?(:encrypted)
  @masked_values = args[:masked_values] if args.key?(:masked_values)
  @name = args[:name] if args.key?(:name)
end