Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ListApiDebugSessionsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1ListApiDebugSessionsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Response for ListApiDebugSessions.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Page token that you can include in a ListApiDebugSessionsRequest to retrieve the next page.
-
#sessions ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiDebugSession>
Session info that includes debug session ID, environment ID, api proxy revision ID and the first transaction creation timestamp.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1ListApiDebugSessionsResponse
constructor
A new instance of GoogleCloudApigeeV1ListApiDebugSessionsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1ListApiDebugSessionsResponse
Returns a new instance of GoogleCloudApigeeV1ListApiDebugSessionsResponse.
6494 6495 6496 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6494 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Page token that you can include in a ListApiDebugSessionsRequest to retrieve
the next page. If omitted, no subsequent pages exist.
Corresponds to the JSON property nextPageToken
6486 6487 6488 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6486 def next_page_token @next_page_token end |
#sessions ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ApiDebugSession>
Session info that includes debug session ID, environment ID, api proxy
revision ID and the first transaction creation timestamp.
Corresponds to the JSON property sessions
6492 6493 6494 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6492 def sessions @sessions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6499 6500 6501 6502 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 6499 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @sessions = args[:sessions] if args.key?(:sessions) end |