Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ListSecurityIncidentsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Response for ListSecurityIncidents.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1ListSecurityIncidentsResponse

Returns a new instance of GoogleCloudApigeeV1ListSecurityIncidentsResponse.



7334
7335
7336
# File 'lib/google/apis/apigee_v1/classes.rb', line 7334

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7327
7328
7329
# File 'lib/google/apis/apigee_v1/classes.rb', line 7327

def next_page_token
  @next_page_token
end

#security_incidentsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityIncident>

List of security incidents in the organization Corresponds to the JSON property securityIncidents



7332
7333
7334
# File 'lib/google/apis/apigee_v1/classes.rb', line 7332

def security_incidents
  @security_incidents
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7339
7340
7341
7342
# File 'lib/google/apis/apigee_v1/classes.rb', line 7339

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @security_incidents = args[:security_incidents] if args.key?(:security_incidents)
end