Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ListSecurityProfilesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Response for ListSecurityProfiles.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1ListSecurityProfilesResponse

Returns a new instance of GoogleCloudApigeeV1ListSecurityProfilesResponse.



7423
7424
7425
# File 'lib/google/apis/apigee_v1/classes.rb', line 7423

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token that can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7414
7415
7416
# File 'lib/google/apis/apigee_v1/classes.rb', line 7414

def next_page_token
  @next_page_token
end

#security_profilesArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityProfile>

List of security profiles in the organization. The profiles may be attached or unattached to any environment. This will return latest revision of each profile. Corresponds to the JSON property securityProfiles



7421
7422
7423
# File 'lib/google/apis/apigee_v1/classes.rb', line 7421

def security_profiles
  @security_profiles
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7428
7429
7430
7431
# File 'lib/google/apis/apigee_v1/classes.rb', line 7428

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @security_profiles = args[:security_profiles] if args.key?(:security_profiles)
end