Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ListSecurityReportsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

The response for SecurityReports.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1ListSecurityReportsResponse

Returns a new instance of GoogleCloudApigeeV1ListSecurityReportsResponse.



7468
7469
7470
# File 'lib/google/apis/apigee_v1/classes.rb', line 7468

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

If the number of security reports exceeded the page size requested, the token can be used to fetch the next page in a subsequent call. If the response is the last page and there are no more reports to return this field is left empty. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7461
7462
7463
# File 'lib/google/apis/apigee_v1/classes.rb', line 7461

def next_page_token
  @next_page_token
end

#security_reportsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityReport>

The security reports belong to requested resource name. Corresponds to the JSON property securityReports



7466
7467
7468
# File 'lib/google/apis/apigee_v1/classes.rb', line 7466

def security_reports
  @security_reports
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7473
7474
7475
7476
# File 'lib/google/apis/apigee_v1/classes.rb', line 7473

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @security_reports = args[:security_reports] if args.key?(:security_reports)
end