Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1LlmOperationConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1LlmOperationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Binds the resources in an API proxy or remote service with the allowed REST methods and associated quota enforcement.
Instance Attribute Summary collapse
-
#api_source ⇒ String
Required.
-
#attributes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>
Optional.
-
#llm_operations ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1LlmOperation>
Required.
-
#llm_token_quota ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1LlmTokenQuota
LLM Token Quota contains the essential parameters needed that can be applied on the resources, methods, models, API source combination associated with this API product.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1LlmOperationConfig
constructor
A new instance of GoogleCloudApigeeV1LlmOperationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1LlmOperationConfig
Returns a new instance of GoogleCloudApigeeV1LlmOperationConfig.
7616 7617 7618 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7616 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_source ⇒ String
Required. Name of the API proxy or remote service with which the resources,
methods, and quota are associated.
Corresponds to the JSON property apiSource
7593 7594 7595 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7593 def api_source @api_source end |
#attributes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>
Optional. Custom attributes associated with the operation.
Corresponds to the JSON property attributes
7598 7599 7600 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7598 def attributes @attributes end |
#llm_operations ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1LlmOperation>
Required. List of resource/method/model for the API proxy to which quota will
applied. Note: Currently, you can specify only a single resource/method/
model mapping. The call will fail if more than one resource/method/model
mappings are provided.
Corresponds to the JSON property llmOperations
7606 7607 7608 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7606 def llm_operations @llm_operations end |
#llm_token_quota ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1LlmTokenQuota
LLM Token Quota contains the essential parameters needed that can be applied
on the resources, methods, models, API source combination associated with this
API product. While LLM Token Quota is optional, setting it prevents requests
from exceeding the provisioned parameters.
Corresponds to the JSON property llmTokenQuota
7614 7615 7616 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7614 def llm_token_quota @llm_token_quota end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7621 7622 7623 7624 7625 7626 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7621 def update!(**args) @api_source = args[:api_source] if args.key?(:api_source) @attributes = args[:attributes] if args.key?(:attributes) @llm_operations = args[:llm_operations] if args.key?(:llm_operations) @llm_token_quota = args[:llm_token_quota] if args.key?(:llm_token_quota) end |