Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1LlmOperationConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1LlmOperationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Binds the resources in an API proxy or remote service with the allowed REST methods and associated quota enforcement.
Instance Attribute Summary collapse
-
#api_source ⇒ String
Required.
-
#attributes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>
Optional.
-
#llm_operations ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1LlmOperation>
Required.
-
#llm_token_quota ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1LlmTokenQuota
LLM Token Quota contains the essential parameters needed that can be applied on the resources, methods, models, API source combination associated with this API product.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1LlmOperationConfig
constructor
A new instance of GoogleCloudApigeeV1LlmOperationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1LlmOperationConfig
Returns a new instance of GoogleCloudApigeeV1LlmOperationConfig.
7617 7618 7619 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7617 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_source ⇒ String
Required. Name of the API proxy or remote service with which the resources,
methods, and quota are associated.
Corresponds to the JSON property apiSource
7594 7595 7596 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7594 def api_source @api_source end |
#attributes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>
Optional. Custom attributes associated with the operation.
Corresponds to the JSON property attributes
7599 7600 7601 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7599 def attributes @attributes end |
#llm_operations ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1LlmOperation>
Required. List of resource/method/model for the API proxy to which quota will
applied. Note: Currently, you can specify only a single resource/method/
model mapping. The call will fail if more than one resource/method/model
mappings are provided.
Corresponds to the JSON property llmOperations
7607 7608 7609 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7607 def llm_operations @llm_operations end |
#llm_token_quota ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1LlmTokenQuota
LLM Token Quota contains the essential parameters needed that can be applied
on the resources, methods, models, API source combination associated with this
API product. While LLM Token Quota is optional, setting it prevents requests
from exceeding the provisioned parameters.
Corresponds to the JSON property llmTokenQuota
7615 7616 7617 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7615 def llm_token_quota @llm_token_quota end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7622 7623 7624 7625 7626 7627 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7622 def update!(**args) @api_source = args[:api_source] if args.key?(:api_source) @attributes = args[:attributes] if args.key?(:attributes) @llm_operations = args[:llm_operations] if args.key?(:llm_operations) @llm_token_quota = args[:llm_token_quota] if args.key?(:llm_token_quota) end |