Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1LlmTokenQuota
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1LlmTokenQuota
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
LLM Token Quota contains the essential parameters needed that can be applied on the resources, methods, models, API source combination associated with this API product. While LLM Token Quota is optional, setting it prevents requests from exceeding the provisioned parameters.
Instance Attribute Summary collapse
-
#interval ⇒ String
Required.
-
#limit ⇒ String
Required.
-
#time_unit ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1LlmTokenQuota
constructor
A new instance of GoogleCloudApigeeV1LlmTokenQuota.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1LlmTokenQuota
Returns a new instance of GoogleCloudApigeeV1LlmTokenQuota.
7675 7676 7677 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7675 def initialize(**args) update!(**args) end |
Instance Attribute Details
#interval ⇒ String
Required. Time interval over which the number of request messages is
calculated.
Corresponds to the JSON property interval
7660 7661 7662 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7660 def interval @interval end |
#limit ⇒ String
Required. Upper limit of LLM tokens allowed for the time interval and time
unit specified. Requests exceeding this limit will be rejected.
Corresponds to the JSON property limit
7666 7667 7668 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7666 def limit @limit end |
#time_unit ⇒ String
Optional. Time unit defined for the interval. Valid values include minute,
hour, day, or month. If limit and interval are valid, the default
value is hour; otherwise, the default is null.
Corresponds to the JSON property timeUnit
7673 7674 7675 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7673 def time_unit @time_unit end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7680 7681 7682 7683 7684 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7680 def update!(**args) @interval = args[:interval] if args.key?(:interval) @limit = args[:limit] if args.key?(:limit) @time_unit = args[:time_unit] if args.key?(:time_unit) end |