Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1MaintenanceUpdatePolicyMaintenanceWindow
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1MaintenanceUpdatePolicyMaintenanceWindow
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
MaintenanceWindow specifies the preferred day of the week and time of day to perform maintenance.
Instance Attribute Summary collapse
-
#day ⇒ String
Required.
-
#start_time ⇒ Google::Apis::ApigeeV1::GoogleTypeTimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1MaintenanceUpdatePolicyMaintenanceWindow
constructor
A new instance of GoogleCloudApigeeV1MaintenanceUpdatePolicyMaintenanceWindow.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1MaintenanceUpdatePolicyMaintenanceWindow
Returns a new instance of GoogleCloudApigeeV1MaintenanceUpdatePolicyMaintenanceWindow.
7731 7732 7733 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7731 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day ⇒ String
Required. Preferred day of the week for maintenance, e.g. MONDAY, TUESDAY, etc.
Corresponds to the JSON property day
7722 7723 7724 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7722 def day @day end |
#start_time ⇒ Google::Apis::ApigeeV1::GoogleTypeTimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property startTime
7729 7730 7731 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7729 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7736 7737 7738 7739 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7736 def update!(**args) @day = args[:day] if args.key?(:day) @start_time = args[:start_time] if args.key?(:start_time) end |