Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1MetricAggregation
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1MetricAggregation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
The optionally aggregated metric to query with its ordering.
Instance Attribute Summary collapse
-
#aggregation ⇒ String
Aggregation function associated with the metric.
-
#name ⇒ String
Name of the metric Corresponds to the JSON property
name. -
#order ⇒ String
Ordering for this aggregation in the result.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1MetricAggregation
constructor
A new instance of GoogleCloudApigeeV1MetricAggregation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1MetricAggregation
Returns a new instance of GoogleCloudApigeeV1MetricAggregation.
7836 7837 7838 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7836 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aggregation ⇒ String
Aggregation function associated with the metric.
Corresponds to the JSON property aggregation
7823 7824 7825 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7823 def aggregation @aggregation end |
#name ⇒ String
Name of the metric
Corresponds to the JSON property name
7828 7829 7830 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7828 def name @name end |
#order ⇒ String
Ordering for this aggregation in the result. For time series this is ignored
since the ordering of points depends only on the timestamp, not the values.
Corresponds to the JSON property order
7834 7835 7836 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7834 def order @order end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7841 7842 7843 7844 7845 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7841 def update!(**args) @aggregation = args[:aggregation] if args.key?(:aggregation) @name = args[:name] if args.key?(:name) @order = args[:order] if args.key?(:order) end |