Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1MetricAggregation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

The optionally aggregated metric to query with its ordering.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1MetricAggregation

Returns a new instance of GoogleCloudApigeeV1MetricAggregation.



7827
7828
7829
# File 'lib/google/apis/apigee_v1/classes.rb', line 7827

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregationString

Aggregation function associated with the metric. Corresponds to the JSON property aggregation

Returns:

  • (String)


7814
7815
7816
# File 'lib/google/apis/apigee_v1/classes.rb', line 7814

def aggregation
  @aggregation
end

#nameString

Name of the metric Corresponds to the JSON property name

Returns:

  • (String)


7819
7820
7821
# File 'lib/google/apis/apigee_v1/classes.rb', line 7819

def name
  @name
end

#orderString

Ordering for this aggregation in the result. For time series this is ignored since the ordering of points depends only on the timestamp, not the values. Corresponds to the JSON property order

Returns:

  • (String)


7825
7826
7827
# File 'lib/google/apis/apigee_v1/classes.rb', line 7825

def order
  @order
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7832
7833
7834
7835
7836
# File 'lib/google/apis/apigee_v1/classes.rb', line 7832

def update!(**args)
  @aggregation = args[:aggregation] if args.key?(:aggregation)
  @name = args[:name] if args.key?(:name)
  @order = args[:order] if args.key?(:order)
end