Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1MetricAggregation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

The optionally aggregated metric to query with its ordering.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1MetricAggregation

Returns a new instance of GoogleCloudApigeeV1MetricAggregation.



7868
7869
7870
# File 'lib/google/apis/apigee_v1/classes.rb', line 7868

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregationString

Aggregation function associated with the metric. Corresponds to the JSON property aggregation

Returns:

  • (String)


7855
7856
7857
# File 'lib/google/apis/apigee_v1/classes.rb', line 7855

def aggregation
  @aggregation
end

#nameString

Name of the metric Corresponds to the JSON property name

Returns:

  • (String)


7860
7861
7862
# File 'lib/google/apis/apigee_v1/classes.rb', line 7860

def name
  @name
end

#orderString

Ordering for this aggregation in the result. For time series this is ignored since the ordering of points depends only on the timestamp, not the values. Corresponds to the JSON property order

Returns:

  • (String)


7866
7867
7868
# File 'lib/google/apis/apigee_v1/classes.rb', line 7866

def order
  @order
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7873
7874
7875
7876
7877
# File 'lib/google/apis/apigee_v1/classes.rb', line 7873

def update!(**args)
  @aggregation = args[:aggregation] if args.key?(:aggregation)
  @name = args[:name] if args.key?(:name)
  @order = args[:order] if args.key?(:order)
end