Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1MoveApiProxyRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Moves an API Proxy to a different Space.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1MoveApiProxyRequest

Returns a new instance of GoogleCloudApigeeV1MoveApiProxyRequest.



7881
7882
7883
# File 'lib/google/apis/apigee_v1/classes.rb', line 7881

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#spaceString

Optional. Resource ID of the space to move the proxy to. If unspecified, the proxy will be moved to the organization level. Corresponds to the JSON property space

Returns:

  • (String)


7879
7880
7881
# File 'lib/google/apis/apigee_v1/classes.rb', line 7879

def space
  @space
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7886
7887
7888
# File 'lib/google/apis/apigee_v1/classes.rb', line 7886

def update!(**args)
  @space = args[:space] if args.key?(:space)
end