Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1MoveSharedFlowRequest
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1MoveSharedFlowRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Moves a Shared Flow to a different space.
Instance Attribute Summary collapse
-
#space ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1MoveSharedFlowRequest
constructor
A new instance of GoogleCloudApigeeV1MoveSharedFlowRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1MoveSharedFlowRequest
Returns a new instance of GoogleCloudApigeeV1MoveSharedFlowRequest.
7950 7951 7952 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7950 def initialize(**args) update!(**args) end |
Instance Attribute Details
#space ⇒ String
Optional. Resource ID of the space to move the shared flow to. If unspecified,
the shared flow will be moved to the organization level.
Corresponds to the JSON property space
7948 7949 7950 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7948 def space @space end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7955 7956 7957 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7955 def update!(**args) @space = args[:space] if args.key?(:space) end |