Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1MoveSharedFlowRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Moves a Shared Flow to a different space.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1MoveSharedFlowRequest

Returns a new instance of GoogleCloudApigeeV1MoveSharedFlowRequest.



7901
7902
7903
# File 'lib/google/apis/apigee_v1/classes.rb', line 7901

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#spaceString

Optional. Resource ID of the space to move the shared flow to. If unspecified, the shared flow will be moved to the organization level. Corresponds to the JSON property space

Returns:

  • (String)


7899
7900
7901
# File 'lib/google/apis/apigee_v1/classes.rb', line 7899

def space
  @space
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7906
7907
7908
# File 'lib/google/apis/apigee_v1/classes.rb', line 7906

def update!(**args)
  @space = args[:space] if args.key?(:space)
end