Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1NodeConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1NodeConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
NodeConfig for setting the min/max number of nodes associated with the environment.
Instance Attribute Summary collapse
-
#current_aggregate_node_count ⇒ Fixnum
Output only.
-
#max_node_count ⇒ Fixnum
Optional.
-
#min_node_count ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1NodeConfig
constructor
A new instance of GoogleCloudApigeeV1NodeConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1NodeConfig
Returns a new instance of GoogleCloudApigeeV1NodeConfig.
7978 7979 7980 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7978 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_aggregate_node_count ⇒ Fixnum
Output only. The current total number of gateway nodes that each environment
currently has across all instances.
Corresponds to the JSON property currentAggregateNodeCount
7960 7961 7962 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7960 def current_aggregate_node_count @current_aggregate_node_count end |
#max_node_count ⇒ Fixnum
Optional. The maximum total number of gateway nodes that the is reserved for
all instances that has the specified environment. If not specified, the
default is determined by the recommended maximum number of nodes for that
gateway.
Corresponds to the JSON property maxNodeCount
7968 7969 7970 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7968 def max_node_count @max_node_count end |
#min_node_count ⇒ Fixnum
Optional. The minimum total number of gateway nodes that the is reserved for
all instances that has the specified environment. If not specified, the
default is determined by the recommended minimum number of nodes for that
gateway.
Corresponds to the JSON property minNodeCount
7976 7977 7978 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7976 def min_node_count @min_node_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7983 7984 7985 7986 7987 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 7983 def update!(**args) @current_aggregate_node_count = args[:current_aggregate_node_count] if args.key?(:current_aggregate_node_count) @max_node_count = args[:max_node_count] if args.key?(:max_node_count) @min_node_count = args[:min_node_count] if args.key?(:min_node_count) end |