Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1NodeConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

NodeConfig for setting the min/max number of nodes associated with the environment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1NodeConfig

Returns a new instance of GoogleCloudApigeeV1NodeConfig.



7969
7970
7971
# File 'lib/google/apis/apigee_v1/classes.rb', line 7969

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_aggregate_node_countFixnum

Output only. The current total number of gateway nodes that each environment currently has across all instances. Corresponds to the JSON property currentAggregateNodeCount

Returns:

  • (Fixnum)


7951
7952
7953
# File 'lib/google/apis/apigee_v1/classes.rb', line 7951

def current_aggregate_node_count
  @current_aggregate_node_count
end

#max_node_countFixnum

Optional. The maximum total number of gateway nodes that the is reserved for all instances that has the specified environment. If not specified, the default is determined by the recommended maximum number of nodes for that gateway. Corresponds to the JSON property maxNodeCount

Returns:

  • (Fixnum)


7959
7960
7961
# File 'lib/google/apis/apigee_v1/classes.rb', line 7959

def max_node_count
  @max_node_count
end

#min_node_countFixnum

Optional. The minimum total number of gateway nodes that the is reserved for all instances that has the specified environment. If not specified, the default is determined by the recommended minimum number of nodes for that gateway. Corresponds to the JSON property minNodeCount

Returns:

  • (Fixnum)


7967
7968
7969
# File 'lib/google/apis/apigee_v1/classes.rb', line 7967

def min_node_count
  @min_node_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7974
7975
7976
7977
7978
# File 'lib/google/apis/apigee_v1/classes.rb', line 7974

def update!(**args)
  @current_aggregate_node_count = args[:current_aggregate_node_count] if args.key?(:current_aggregate_node_count)
  @max_node_count = args[:max_node_count] if args.key?(:max_node_count)
  @min_node_count = args[:min_node_count] if args.key?(:min_node_count)
end