Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1NodeConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1NodeConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
NodeConfig for setting the min/max number of nodes associated with the environment.
Instance Attribute Summary collapse
-
#current_aggregate_node_count ⇒ Fixnum
Output only.
-
#max_node_count ⇒ Fixnum
Optional.
-
#min_node_count ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1NodeConfig
constructor
A new instance of GoogleCloudApigeeV1NodeConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1NodeConfig
Returns a new instance of GoogleCloudApigeeV1NodeConfig.
8019 8020 8021 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8019 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_aggregate_node_count ⇒ Fixnum
Output only. The current total number of gateway nodes that each environment
currently has across all instances.
Corresponds to the JSON property currentAggregateNodeCount
8001 8002 8003 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8001 def current_aggregate_node_count @current_aggregate_node_count end |
#max_node_count ⇒ Fixnum
Optional. The maximum total number of gateway nodes that the is reserved for
all instances that has the specified environment. If not specified, the
default is determined by the recommended maximum number of nodes for that
gateway.
Corresponds to the JSON property maxNodeCount
8009 8010 8011 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8009 def max_node_count @max_node_count end |
#min_node_count ⇒ Fixnum
Optional. The minimum total number of gateway nodes that the is reserved for
all instances that has the specified environment. If not specified, the
default is determined by the recommended minimum number of nodes for that
gateway.
Corresponds to the JSON property minNodeCount
8017 8018 8019 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8017 def min_node_count @min_node_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8024 8025 8026 8027 8028 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8024 def update!(**args) @current_aggregate_node_count = args[:current_aggregate_node_count] if args.key?(:current_aggregate_node_count) @max_node_count = args[:max_node_count] if args.key?(:max_node_count) @min_node_count = args[:min_node_count] if args.key?(:min_node_count) end |