Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1OperationConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1OperationConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Binds the resources in an API proxy or remote service with the allowed REST methods and associated quota enforcement.
Instance Attribute Summary collapse
-
#api_source ⇒ String
Required.
-
#attributes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>
Custom attributes associated with the operation.
-
#operations ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Operation>
List of resource/method pairs for the API proxy or remote service to which quota will applied.
-
#quota ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1Quota
Quota contains the essential parameters needed that can be applied on the resources, methods, API source combination associated with this API product.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1OperationConfig
constructor
A new instance of GoogleCloudApigeeV1OperationConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1OperationConfig
Returns a new instance of GoogleCloudApigeeV1OperationConfig.
8074 8075 8076 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8074 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_source ⇒ String
Required. Name of the API proxy or remote service with which the resources,
methods, and quota are associated.
Corresponds to the JSON property apiSource
8051 8052 8053 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8051 def api_source @api_source end |
#attributes ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Attribute>
Custom attributes associated with the operation.
Corresponds to the JSON property attributes
8056 8057 8058 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8056 def attributes @attributes end |
#operations ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Operation>
List of resource/method pairs for the API proxy or remote service to which
quota will applied. Note: Currently, you can specify only a single
resource/method pair. The call will fail if more than one resource/method pair
is provided.
Corresponds to the JSON property operations
8064 8065 8066 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8064 def operations @operations end |
#quota ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1Quota
Quota contains the essential parameters needed that can be applied on the
resources, methods, API source combination associated with this API product.
While Quota is optional, setting it prevents requests from exceeding the
provisioned parameters.
Corresponds to the JSON property quota
8072 8073 8074 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8072 def quota @quota end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8079 8080 8081 8082 8083 8084 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8079 def update!(**args) @api_source = args[:api_source] if args.key?(:api_source) @attributes = args[:attributes] if args.key?(:attributes) @operations = args[:operations] if args.key?(:operations) @quota = args[:quota] if args.key?(:quota) end |