Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Organization
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1Organization
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Instance Attribute Summary collapse
-
#addons_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1AddonsConfig
Add-on configurations for the Apigee organization.
-
#analytics_region ⇒ String
Required.
-
#api_consumer_data_encryption_key_name ⇒ String
Optional.
-
#api_consumer_data_location ⇒ String
Optional.
-
#apigee_project_id ⇒ String
Output only.
-
#attributes ⇒ Array<String>
Not used by Apigee.
-
#authorized_network ⇒ String
Optional.
-
#billing_type ⇒ String
Optional.
-
#ca_certificate ⇒ String
Output only.
-
#ca_certificates ⇒ Array<String>
Output only.
-
#control_plane_encryption_key_name ⇒ String
Optional.
-
#created_at ⇒ Fixnum
Output only.
-
#customer_name ⇒ String
Not used by Apigee.
-
#description ⇒ String
Optional.
-
#disable_vpc_peering ⇒ Boolean
(also: #disable_vpc_peering?)
Optional.
-
#display_name ⇒ String
Optional.
-
#environments ⇒ Array<String>
Output only.
-
#expires_at ⇒ Fixnum
Output only.
-
#last_modified_at ⇒ Fixnum
Output only.
-
#name ⇒ String
Output only.
-
#network_egress_restricted ⇒ Boolean
(also: #network_egress_restricted?)
Optional.
-
#portal_disabled ⇒ Boolean
(also: #portal_disabled?)
Optional.
-
#project_id ⇒ String
Output only.
-
#properties ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1Properties
Message for compatibility with legacy Edge specification for Java Properties object in JSON.
-
#runtime_database_encryption_key_name ⇒ String
Optional.
-
#runtime_type ⇒ String
Required.
-
#state ⇒ String
Output only.
-
#subscription_plan ⇒ String
Output only.
-
#subscription_type ⇒ String
Output only.
-
#type ⇒ String
Not used by Apigee.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1Organization
constructor
A new instance of GoogleCloudApigeeV1Organization.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1Organization
Returns a new instance of GoogleCloudApigeeV1Organization.
8500 8501 8502 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8500 def initialize(**args) update!(**args) end |
Instance Attribute Details
#addons_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1AddonsConfig
Add-on configurations for the Apigee organization.
Corresponds to the JSON property addonsConfig
8284 8285 8286 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8284 def addons_config @addons_config end |
#analytics_region ⇒ String
Required. DEPRECATED: This field will eventually be deprecated and replaced
with a differently-named field. Primary Google Cloud region for analytics data
storage. For valid values, see Create an Apigee organization.
Corresponds to the JSON property analyticsRegion
8292 8293 8294 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8292 def analytics_region @analytics_region end |
#api_consumer_data_encryption_key_name ⇒ String
Optional. Cloud KMS key name used for encrypting API consumer data. If not
specified or BillingType is EVALUATION, a Google-Managed
encryption key will be used. Format: projects/*/locations/*/keyRings/*/
cryptoKeys/*
Corresponds to the JSON property apiConsumerDataEncryptionKeyName
8300 8301 8302 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8300 def api_consumer_data_encryption_key_name @api_consumer_data_encryption_key_name end |
#api_consumer_data_location ⇒ String
Optional. This field is needed only for customers using non-default data
residency regions. Apigee stores some control plane data only in single region.
This field determines which single region Apigee should use. For example: "us-
west1" when control plane is in US or "europe-west2" when control plane is in
EU.
Corresponds to the JSON property apiConsumerDataLocation
8309 8310 8311 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8309 def api_consumer_data_location @api_consumer_data_location end |
#apigee_project_id ⇒ String
Output only. Apigee Project ID associated with the organization. Use this
project to allowlist Apigee in the Service Attachment when using private
service connect with Apigee.
Corresponds to the JSON property apigeeProjectId
8316 8317 8318 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8316 def apigee_project_id @apigee_project_id end |
#attributes ⇒ Array<String>
Not used by Apigee.
Corresponds to the JSON property attributes
8321 8322 8323 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8321 def attributes @attributes end |
#authorized_network ⇒ String
Optional. Compute Engine network used for Service Networking to be peered with
Apigee runtime instances. See Getting started with the Service Networking API. Valid only when RuntimeType is set to CLOUD
. The value must be set before the creation of a runtime instance and can be
updated only when there are no runtime instances. For example: default. When
changing authorizedNetwork, you must reconfigure VPC peering. After VPC
peering with previous network is deleted, run the following command: gcloud
services vpc-peerings delete --network=NETWORK, where NETWORK is the name
of the previous network. This will delete the previous Service Networking.
Otherwise, you will get the following error: The resource 'projects/...-tp'
is already linked to another shared VPC host 'projects/...-tp. Apigee also
supports shared VPC (that is, the host network project is not the same as the
one that is peering with Apigee). See Shared VPC overview. To use a shared VPC network, use the
following format: projects/host-project-id/region/networks/network-name`
. For example:projects/my-sharedvpc-host/global/networks/mynetwork**Note:**
Not supported for Apigee hybrid.
Corresponds to the JSON propertyauthorizedNetwork`
8344 8345 8346 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8344 def @authorized_network end |
#billing_type ⇒ String
Optional. Billing type of the Apigee organization. See Apigee pricing.
Corresponds to the JSON property billingType
8350 8351 8352 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8350 def billing_type @billing_type end |
#ca_certificate ⇒ String
Output only. Deprecated: Use ca_certificates instead. Base64-encoded public
certificate for the root CA of the Apigee organization. Valid only when
RuntimeType is CLOUD.
Corresponds to the JSON property caCertificate
NOTE: Values are automatically base64 encoded/decoded in the client library.
8358 8359 8360 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8358 def ca_certificate @ca_certificate end |
#ca_certificates ⇒ Array<String>
Output only. Base64-encoded public certificates for the root CA of the Apigee
organization. Valid only when RuntimeType is CLOUD. Multiple
certificates are used to support certificate rotation.
Corresponds to the JSON property caCertificates
8365 8366 8367 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8365 def ca_certificates @ca_certificates end |
#control_plane_encryption_key_name ⇒ String
Optional. Cloud KMS key name used for encrypting control plane data that is
stored in a multi region. Only used for the data residency region "US" or "EU".
If not specified or BillingType is EVALUATION, a Google-
Managed encryption key will be used. Format: projects/*/locations/*/keyRings/*
/cryptoKeys/*
Corresponds to the JSON property controlPlaneEncryptionKeyName
8374 8375 8376 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8374 def control_plane_encryption_key_name @control_plane_encryption_key_name end |
#created_at ⇒ Fixnum
Output only. Time that the Apigee organization was created in milliseconds
since epoch.
Corresponds to the JSON property createdAt
8380 8381 8382 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8380 def created_at @created_at end |
#customer_name ⇒ String
Not used by Apigee.
Corresponds to the JSON property customerName
8385 8386 8387 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8385 def customer_name @customer_name end |
#description ⇒ String
Optional. Description of the Apigee organization.
Corresponds to the JSON property description
8390 8391 8392 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8390 def description @description end |
#disable_vpc_peering ⇒ Boolean Also known as: disable_vpc_peering?
Optional. Flag that specifies whether the VPC Peering through Private Google
Access should be disabled between the consumer network and Apigee. Valid only
when RuntimeType is set to CLOUD. Required if an authorizedNetwork on the
consumer project is not provided, in which case the flag should be set to true.
The value must be set before the creation of any Apigee runtime instance and
can be updated only when there are no runtime instances. Note: Apigee will
be deprecating the vpc peering model that requires you to provide '
authorizedNetwork', by making the non-peering model as the default way of
provisioning Apigee organization in future. So, this will be a temporary flag
to enable the transition. Not supported for Apigee hybrid.
Corresponds to the JSON property disableVpcPeering
8404 8405 8406 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8404 def disable_vpc_peering @disable_vpc_peering end |
#display_name ⇒ String
Optional. Display name for the Apigee organization. Unused, but reserved for
future use.
Corresponds to the JSON property displayName
8411 8412 8413 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8411 def display_name @display_name end |
#environments ⇒ Array<String>
Output only. List of environments in the Apigee organization.
Corresponds to the JSON property environments
8416 8417 8418 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8416 def environments @environments end |
#expires_at ⇒ Fixnum
Output only. Time that the Apigee organization is scheduled for deletion.
Corresponds to the JSON property expiresAt
8421 8422 8423 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8421 def expires_at @expires_at end |
#last_modified_at ⇒ Fixnum
Output only. Time that the Apigee organization was last modified in
milliseconds since epoch.
Corresponds to the JSON property lastModifiedAt
8427 8428 8429 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8427 def last_modified_at @last_modified_at end |
#name ⇒ String
Output only. Name of the Apigee organization.
Corresponds to the JSON property name
8432 8433 8434 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8432 def name @name end |
#network_egress_restricted ⇒ Boolean Also known as: network_egress_restricted?
Optional. Flag that specifies if internet egress is restricted for VPC Service
Controls. Valid only when runtime_type is CLOUD and disable_vpc_peering is
true.
Corresponds to the JSON property networkEgressRestricted
8439 8440 8441 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8439 def network_egress_restricted @network_egress_restricted end |
#portal_disabled ⇒ Boolean Also known as: portal_disabled?
Optional. Configuration for the Portals settings.
Corresponds to the JSON property portalDisabled
8445 8446 8447 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8445 def portal_disabled @portal_disabled end |
#project_id ⇒ String
Output only. Project ID associated with the Apigee organization.
Corresponds to the JSON property projectId
8451 8452 8453 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8451 def project_id @project_id end |
#properties ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1Properties
Message for compatibility with legacy Edge specification for Java Properties
object in JSON.
Corresponds to the JSON property properties
8457 8458 8459 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8457 def properties @properties end |
#runtime_database_encryption_key_name ⇒ String
Optional. Cloud KMS key name used for encrypting the data that is stored and
replicated across runtime instances. Update is not allowed after the
organization is created. If not specified or RuntimeType is
TRIAL, a Google-Managed encryption key will be used. For example: "projects/
foo/locations/us/keyRings/bar/cryptoKeys/baz". Note: Not supported for
Apigee hybrid.
Corresponds to the JSON property runtimeDatabaseEncryptionKeyName
8467 8468 8469 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8467 def runtime_database_encryption_key_name @runtime_database_encryption_key_name end |
#runtime_type ⇒ String
Required. Runtime type of the Apigee organization based on the Apigee
subscription purchased.
Corresponds to the JSON property runtimeType
8473 8474 8475 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8473 def runtime_type @runtime_type end |
#state ⇒ String
Output only. State of the organization. Values other than ACTIVE means the
resource is not ready to use.
Corresponds to the JSON property state
8479 8480 8481 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8479 def state @state end |
#subscription_plan ⇒ String
Output only. Subscription plan that the customer has purchased. Output only.
Corresponds to the JSON property subscriptionPlan
8484 8485 8486 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8484 def subscription_plan @subscription_plan end |
#subscription_type ⇒ String
Output only. DEPRECATED: This will eventually be replaced by BillingType.
Subscription type of the Apigee organization. Valid values include trial (free,
limited, and for evaluation purposes only) or paid (full subscription has
been purchased). See Apigee pricing
.
Corresponds to the JSON property subscriptionType
8493 8494 8495 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8493 def subscription_type @subscription_type end |
#type ⇒ String
Not used by Apigee.
Corresponds to the JSON property type
8498 8499 8500 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8498 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8505 8506 8507 8508 8509 8510 8511 8512 8513 8514 8515 8516 8517 8518 8519 8520 8521 8522 8523 8524 8525 8526 8527 8528 8529 8530 8531 8532 8533 8534 8535 8536 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8505 def update!(**args) @addons_config = args[:addons_config] if args.key?(:addons_config) @analytics_region = args[:analytics_region] if args.key?(:analytics_region) @api_consumer_data_encryption_key_name = args[:api_consumer_data_encryption_key_name] if args.key?(:api_consumer_data_encryption_key_name) @api_consumer_data_location = args[:api_consumer_data_location] if args.key?(:api_consumer_data_location) @apigee_project_id = args[:apigee_project_id] if args.key?(:apigee_project_id) @attributes = args[:attributes] if args.key?(:attributes) @authorized_network = args[:authorized_network] if args.key?(:authorized_network) @billing_type = args[:billing_type] if args.key?(:billing_type) @ca_certificate = args[:ca_certificate] if args.key?(:ca_certificate) @ca_certificates = args[:ca_certificates] if args.key?(:ca_certificates) @control_plane_encryption_key_name = args[:control_plane_encryption_key_name] if args.key?(:control_plane_encryption_key_name) @created_at = args[:created_at] if args.key?(:created_at) @customer_name = args[:customer_name] if args.key?(:customer_name) @description = args[:description] if args.key?(:description) @disable_vpc_peering = args[:disable_vpc_peering] if args.key?(:disable_vpc_peering) @display_name = args[:display_name] if args.key?(:display_name) @environments = args[:environments] if args.key?(:environments) @expires_at = args[:expires_at] if args.key?(:expires_at) @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at) @name = args[:name] if args.key?(:name) @network_egress_restricted = args[:network_egress_restricted] if args.key?(:network_egress_restricted) @portal_disabled = args[:portal_disabled] if args.key?(:portal_disabled) @project_id = args[:project_id] if args.key?(:project_id) @properties = args[:properties] if args.key?(:properties) @runtime_database_encryption_key_name = args[:runtime_database_encryption_key_name] if args.key?(:runtime_database_encryption_key_name) @runtime_type = args[:runtime_type] if args.key?(:runtime_type) @state = args[:state] if args.key?(:state) @subscription_plan = args[:subscription_plan] if args.key?(:subscription_plan) @subscription_type = args[:subscription_type] if args.key?(:subscription_type) @type = args[:type] if args.key?(:type) end |