Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1OrganizationProjectMapping
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1OrganizationProjectMapping
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Instance Attribute Summary collapse
-
#location ⇒ String
Output only.
-
#organization ⇒ String
Name of the Apigee organization.
-
#project_id ⇒ String
Google Cloud project associated with the Apigee organization Corresponds to the JSON property
projectId. -
#project_ids ⇒ Array<String>
DEPRECATED: Use
project_id.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1OrganizationProjectMapping
constructor
A new instance of GoogleCloudApigeeV1OrganizationProjectMapping.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1OrganizationProjectMapping
Returns a new instance of GoogleCloudApigeeV1OrganizationProjectMapping.
8565 8566 8567 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8565 def initialize(**args) update!(**args) end |
Instance Attribute Details
#location ⇒ String
Output only. The Google Cloud region where control plane data is located. For
more information, see https://cloud.google.com/about/locations/.
Corresponds to the JSON property location
8547 8548 8549 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8547 def location @location end |
#organization ⇒ String
Name of the Apigee organization.
Corresponds to the JSON property organization
8552 8553 8554 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8552 def organization @organization end |
#project_id ⇒ String
Google Cloud project associated with the Apigee organization
Corresponds to the JSON property projectId
8557 8558 8559 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8557 def project_id @project_id end |
#project_ids ⇒ Array<String>
DEPRECATED: Use project_id. An Apigee Organization is mapped to a single
project.
Corresponds to the JSON property projectIds
8563 8564 8565 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8563 def project_ids @project_ids end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8570 8571 8572 8573 8574 8575 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8570 def update!(**args) @location = args[:location] if args.key?(:location) @organization = args[:organization] if args.key?(:organization) @project_id = args[:project_id] if args.key?(:project_id) @project_ids = args[:project_ids] if args.key?(:project_ids) end |