Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1PayloadOperation
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1PayloadOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Represents a single operation identifier extracted from the request payload.
Instance Attribute Summary collapse
-
#operation ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1PayloadOperation
constructor
A new instance of GoogleCloudApigeeV1PayloadOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1PayloadOperation
Returns a new instance of GoogleCloudApigeeV1PayloadOperation.
8606 8607 8608 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8606 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operation ⇒ String
Required. The operation name extracted from the request payload at runtime by
the ParsePayload policy. For example, for MCP protocol requests, this could be
"tools/list" or "tools/call/get_weather". Wildcards are not supported.
Corresponds to the JSON property operation
8604 8605 8606 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8604 def operation @operation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8611 8612 8613 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8611 def update!(**args) @operation = args[:operation] if args.key?(:operation) end |