Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1PodStatus
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1PodStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Instance Attribute Summary collapse
-
#app_version ⇒ String
Version of the application running in the pod.
-
#deployment_status ⇒ String
Status of the deployment.
-
#deployment_status_time ⇒ Fixnum
Time the deployment status was reported in milliseconds since epoch.
-
#deployment_time ⇒ Fixnum
Time the proxy was deployed in milliseconds since epoch.
-
#pod_name ⇒ String
Name of the pod which is reporting the status.
-
#pod_status ⇒ String
Overall status of the pod (not this specific deployment).
-
#pod_status_time ⇒ Fixnum
Time the pod status was reported in milliseconds since epoch.
-
#status_code ⇒ String
Code associated with the deployment status.
-
#status_code_details ⇒ String
Human-readable message associated with the status code.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1PodStatus
constructor
A new instance of GoogleCloudApigeeV1PodStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1PodStatus
Returns a new instance of GoogleCloudApigeeV1PodStatus.
8734 8735 8736 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8734 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_version ⇒ String
Version of the application running in the pod.
Corresponds to the JSON property appVersion
8689 8690 8691 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8689 def app_version @app_version end |
#deployment_status ⇒ String
Status of the deployment. Valid values include: - deployed: Successful. -
error : Failed. - pending : Pod has not yet reported on the deployment.
Corresponds to the JSON property deploymentStatus
8695 8696 8697 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8695 def deployment_status @deployment_status end |
#deployment_status_time ⇒ Fixnum
Time the deployment status was reported in milliseconds since epoch.
Corresponds to the JSON property deploymentStatusTime
8700 8701 8702 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8700 def deployment_status_time @deployment_status_time end |
#deployment_time ⇒ Fixnum
Time the proxy was deployed in milliseconds since epoch.
Corresponds to the JSON property deploymentTime
8705 8706 8707 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8705 def deployment_time @deployment_time end |
#pod_name ⇒ String
Name of the pod which is reporting the status.
Corresponds to the JSON property podName
8710 8711 8712 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8710 def pod_name @pod_name end |
#pod_status ⇒ String
Overall status of the pod (not this specific deployment). Valid values include:
active: Up to date. -stale: Recently out of date. Pods that have not reported status in a long time are excluded from the output. Corresponds to the JSON propertypodStatus
8717 8718 8719 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8717 def pod_status @pod_status end |
#pod_status_time ⇒ Fixnum
Time the pod status was reported in milliseconds since epoch.
Corresponds to the JSON property podStatusTime
8722 8723 8724 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8722 def pod_status_time @pod_status_time end |
#status_code ⇒ String
Code associated with the deployment status.
Corresponds to the JSON property statusCode
8727 8728 8729 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8727 def status_code @status_code end |
#status_code_details ⇒ String
Human-readable message associated with the status code.
Corresponds to the JSON property statusCodeDetails
8732 8733 8734 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8732 def status_code_details @status_code_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8739 8740 8741 8742 8743 8744 8745 8746 8747 8748 8749 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8739 def update!(**args) @app_version = args[:app_version] if args.key?(:app_version) @deployment_status = args[:deployment_status] if args.key?(:deployment_status) @deployment_status_time = args[:deployment_status_time] if args.key?(:deployment_status_time) @deployment_time = args[:deployment_time] if args.key?(:deployment_time) @pod_name = args[:pod_name] if args.key?(:pod_name) @pod_status = args[:pod_status] if args.key?(:pod_status) @pod_status_time = args[:pod_status_time] if args.key?(:pod_status_time) @status_code = args[:status_code] if args.key?(:status_code) @status_code_details = args[:status_code_details] if args.key?(:status_code_details) end |