Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1PodStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1PodStatus

Returns a new instance of GoogleCloudApigeeV1PodStatus.



8679
8680
8681
# File 'lib/google/apis/apigee_v1/classes.rb', line 8679

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_versionString

Version of the application running in the pod. Corresponds to the JSON property appVersion

Returns:

  • (String)


8634
8635
8636
# File 'lib/google/apis/apigee_v1/classes.rb', line 8634

def app_version
  @app_version
end

#deployment_statusString

Status of the deployment. Valid values include: - deployed: Successful. - error : Failed. - pending : Pod has not yet reported on the deployment. Corresponds to the JSON property deploymentStatus

Returns:

  • (String)


8640
8641
8642
# File 'lib/google/apis/apigee_v1/classes.rb', line 8640

def deployment_status
  @deployment_status
end

#deployment_status_timeFixnum

Time the deployment status was reported in milliseconds since epoch. Corresponds to the JSON property deploymentStatusTime

Returns:

  • (Fixnum)


8645
8646
8647
# File 'lib/google/apis/apigee_v1/classes.rb', line 8645

def deployment_status_time
  @deployment_status_time
end

#deployment_timeFixnum

Time the proxy was deployed in milliseconds since epoch. Corresponds to the JSON property deploymentTime

Returns:

  • (Fixnum)


8650
8651
8652
# File 'lib/google/apis/apigee_v1/classes.rb', line 8650

def deployment_time
  @deployment_time
end

#pod_nameString

Name of the pod which is reporting the status. Corresponds to the JSON property podName

Returns:

  • (String)


8655
8656
8657
# File 'lib/google/apis/apigee_v1/classes.rb', line 8655

def pod_name
  @pod_name
end

#pod_statusString

Overall status of the pod (not this specific deployment). Valid values include:

  • active: Up to date. - stale : Recently out of date. Pods that have not reported status in a long time are excluded from the output. Corresponds to the JSON property podStatus

Returns:

  • (String)


8662
8663
8664
# File 'lib/google/apis/apigee_v1/classes.rb', line 8662

def pod_status
  @pod_status
end

#pod_status_timeFixnum

Time the pod status was reported in milliseconds since epoch. Corresponds to the JSON property podStatusTime

Returns:

  • (Fixnum)


8667
8668
8669
# File 'lib/google/apis/apigee_v1/classes.rb', line 8667

def pod_status_time
  @pod_status_time
end

#status_codeString

Code associated with the deployment status. Corresponds to the JSON property statusCode

Returns:

  • (String)


8672
8673
8674
# File 'lib/google/apis/apigee_v1/classes.rb', line 8672

def status_code
  @status_code
end

#status_code_detailsString

Human-readable message associated with the status code. Corresponds to the JSON property statusCodeDetails

Returns:

  • (String)


8677
8678
8679
# File 'lib/google/apis/apigee_v1/classes.rb', line 8677

def status_code_details
  @status_code_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8684
8685
8686
8687
8688
8689
8690
8691
8692
8693
8694
# File 'lib/google/apis/apigee_v1/classes.rb', line 8684

def update!(**args)
  @app_version = args[:app_version] if args.key?(:app_version)
  @deployment_status = args[:deployment_status] if args.key?(:deployment_status)
  @deployment_status_time = args[:deployment_status_time] if args.key?(:deployment_status_time)
  @deployment_time = args[:deployment_time] if args.key?(:deployment_time)
  @pod_name = args[:pod_name] if args.key?(:pod_name)
  @pod_status = args[:pod_status] if args.key?(:pod_status)
  @pod_status_time = args[:pod_status_time] if args.key?(:pod_status_time)
  @status_code = args[:status_code] if args.key?(:status_code)
  @status_code_details = args[:status_code_details] if args.key?(:status_code_details)
end