Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigAbuse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Checks for abuse, which includes any requests sent to the API for purposes other than what it is intended for, such as high volumes of requests, data scraping, and abuse related to authorization.

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1ProfileConfigAbuse

Returns a new instance of GoogleCloudApigeeV1ProfileConfigAbuse.



8756
8757
8758
# File 'lib/google/apis/apigee_v1/classes.rb', line 8756

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8761
8762
# File 'lib/google/apis/apigee_v1/classes.rb', line 8761

def update!(**args)
end