Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigAbuse
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigAbuse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Checks for abuse, which includes any requests sent to the API for purposes other than what it is intended for, such as high volumes of requests, data scraping, and abuse related to authorization.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1ProfileConfigAbuse
constructor
A new instance of GoogleCloudApigeeV1ProfileConfigAbuse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1ProfileConfigAbuse
Returns a new instance of GoogleCloudApigeeV1ProfileConfigAbuse.
8707 8708 8709 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8707 def initialize(**args) update!(**args) end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8712 8713 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8712 def update!(**args) end |