Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigCategory

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Advanced API Security provides security profile that scores the following categories.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1ProfileConfigCategory

Returns a new instance of GoogleCloudApigeeV1ProfileConfigCategory.



8791
8792
8793
# File 'lib/google/apis/apigee_v1/classes.rb', line 8791

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#abuseGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigAbuse

Checks for abuse, which includes any requests sent to the API for purposes other than what it is intended for, such as high volumes of requests, data scraping, and abuse related to authorization. Corresponds to the JSON property abuse



8761
8762
8763
# File 'lib/google/apis/apigee_v1/classes.rb', line 8761

def abuse
  @abuse
end

#authorizationGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigAuthorization

By default, following policies will be included: - JWS - JWT - OAuth - BasicAuth - APIKey Corresponds to the JSON property authorization



8767
8768
8769
# File 'lib/google/apis/apigee_v1/classes.rb', line 8767

def authorization
  @authorization
end

#corsGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigCors

Checks to see if you have CORS policy in place. Corresponds to the JSON property cors



8772
8773
8774
# File 'lib/google/apis/apigee_v1/classes.rb', line 8772

def cors
  @cors
end

#mediationGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigMediation

By default, following policies will be included: - OASValidation - SOAPMessageValidation Corresponds to the JSON property mediation



8778
8779
8780
# File 'lib/google/apis/apigee_v1/classes.rb', line 8778

def mediation
  @mediation
end

#mtlsGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigMtls

Checks to see if you have configured mTLS for the target server. Corresponds to the JSON property mtls



8783
8784
8785
# File 'lib/google/apis/apigee_v1/classes.rb', line 8783

def mtls
  @mtls
end

#threatGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigThreat

By default, following policies will be included: - XMLThreatProtection - JSONThreatProtection Corresponds to the JSON property threat



8789
8790
8791
# File 'lib/google/apis/apigee_v1/classes.rb', line 8789

def threat
  @threat
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8796
8797
8798
8799
8800
8801
8802
8803
# File 'lib/google/apis/apigee_v1/classes.rb', line 8796

def update!(**args)
  @abuse = args[:abuse] if args.key?(:abuse)
  @authorization = args[:authorization] if args.key?(:authorization)
  @cors = args[:cors] if args.key?(:cors)
  @mediation = args[:mediation] if args.key?(:mediation)
  @mtls = args[:mtls] if args.key?(:mtls)
  @threat = args[:threat] if args.key?(:threat)
end