Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigCategory

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Advanced API Security provides security profile that scores the following categories.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1ProfileConfigCategory

Returns a new instance of GoogleCloudApigeeV1ProfileConfigCategory.



8782
8783
8784
# File 'lib/google/apis/apigee_v1/classes.rb', line 8782

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#abuseGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigAbuse

Checks for abuse, which includes any requests sent to the API for purposes other than what it is intended for, such as high volumes of requests, data scraping, and abuse related to authorization. Corresponds to the JSON property abuse



8752
8753
8754
# File 'lib/google/apis/apigee_v1/classes.rb', line 8752

def abuse
  @abuse
end

#authorizationGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigAuthorization

By default, following policies will be included: - JWS - JWT - OAuth - BasicAuth - APIKey Corresponds to the JSON property authorization



8758
8759
8760
# File 'lib/google/apis/apigee_v1/classes.rb', line 8758

def authorization
  @authorization
end

#corsGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigCors

Checks to see if you have CORS policy in place. Corresponds to the JSON property cors



8763
8764
8765
# File 'lib/google/apis/apigee_v1/classes.rb', line 8763

def cors
  @cors
end

#mediationGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigMediation

By default, following policies will be included: - OASValidation - SOAPMessageValidation Corresponds to the JSON property mediation



8769
8770
8771
# File 'lib/google/apis/apigee_v1/classes.rb', line 8769

def mediation
  @mediation
end

#mtlsGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigMtls

Checks to see if you have configured mTLS for the target server. Corresponds to the JSON property mtls



8774
8775
8776
# File 'lib/google/apis/apigee_v1/classes.rb', line 8774

def mtls
  @mtls
end

#threatGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigThreat

By default, following policies will be included: - XMLThreatProtection - JSONThreatProtection Corresponds to the JSON property threat



8780
8781
8782
# File 'lib/google/apis/apigee_v1/classes.rb', line 8780

def threat
  @threat
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8787
8788
8789
8790
8791
8792
8793
8794
# File 'lib/google/apis/apigee_v1/classes.rb', line 8787

def update!(**args)
  @abuse = args[:abuse] if args.key?(:abuse)
  @authorization = args[:authorization] if args.key?(:authorization)
  @cors = args[:cors] if args.key?(:cors)
  @mediation = args[:mediation] if args.key?(:mediation)
  @mtls = args[:mtls] if args.key?(:mtls)
  @threat = args[:threat] if args.key?(:threat)
end