Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigCategory
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigCategory
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Advanced API Security provides security profile that scores the following categories.
Instance Attribute Summary collapse
-
#abuse ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigAbuse
Checks for abuse, which includes any requests sent to the API for purposes other than what it is intended for, such as high volumes of requests, data scraping, and abuse related to authorization.
-
#authorization ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigAuthorization
By default, following policies will be included: - JWS - JWT - OAuth - BasicAuth - APIKey Corresponds to the JSON property
authorization. -
#cors ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigCors
Checks to see if you have CORS policy in place.
-
#mediation ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigMediation
By default, following policies will be included: - OASValidation - SOAPMessageValidation Corresponds to the JSON property
mediation. -
#mtls ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigMtls
Checks to see if you have configured mTLS for the target server.
-
#threat ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigThreat
By default, following policies will be included: - XMLThreatProtection - JSONThreatProtection Corresponds to the JSON property
threat.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1ProfileConfigCategory
constructor
A new instance of GoogleCloudApigeeV1ProfileConfigCategory.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1ProfileConfigCategory
Returns a new instance of GoogleCloudApigeeV1ProfileConfigCategory.
8832 8833 8834 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8832 def initialize(**args) update!(**args) end |
Instance Attribute Details
#abuse ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigAbuse
Checks for abuse, which includes any requests sent to the API for purposes
other than what it is intended for, such as high volumes of requests, data
scraping, and abuse related to authorization.
Corresponds to the JSON property abuse
8802 8803 8804 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8802 def abuse @abuse end |
#authorization ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigAuthorization
By default, following policies will be included: - JWS - JWT - OAuth -
BasicAuth - APIKey
Corresponds to the JSON property authorization
8808 8809 8810 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8808 def @authorization end |
#cors ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigCors
Checks to see if you have CORS policy in place.
Corresponds to the JSON property cors
8813 8814 8815 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8813 def cors @cors end |
#mediation ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigMediation
By default, following policies will be included: - OASValidation -
SOAPMessageValidation
Corresponds to the JSON property mediation
8819 8820 8821 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8819 def mediation @mediation end |
#mtls ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigMtls
Checks to see if you have configured mTLS for the target server.
Corresponds to the JSON property mtls
8824 8825 8826 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8824 def mtls @mtls end |
#threat ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigThreat
By default, following policies will be included: - XMLThreatProtection -
JSONThreatProtection
Corresponds to the JSON property threat
8830 8831 8832 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8830 def threat @threat end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8837 8838 8839 8840 8841 8842 8843 8844 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8837 def update!(**args) @abuse = args[:abuse] if args.key?(:abuse) @authorization = args[:authorization] if args.key?(:authorization) @cors = args[:cors] if args.key?(:cors) @mediation = args[:mediation] if args.key?(:mediation) @mtls = args[:mtls] if args.key?(:mtls) @threat = args[:threat] if args.key?(:threat) end |