Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigCategory
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigCategory
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Advanced API Security provides security profile that scores the following categories.
Instance Attribute Summary collapse
-
#abuse ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigAbuse
Checks for abuse, which includes any requests sent to the API for purposes other than what it is intended for, such as high volumes of requests, data scraping, and abuse related to authorization.
-
#authorization ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigAuthorization
By default, following policies will be included: - JWS - JWT - OAuth - BasicAuth - APIKey Corresponds to the JSON property
authorization. -
#cors ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigCors
Checks to see if you have CORS policy in place.
-
#mediation ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigMediation
By default, following policies will be included: - OASValidation - SOAPMessageValidation Corresponds to the JSON property
mediation. -
#mtls ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigMtls
Checks to see if you have configured mTLS for the target server.
-
#threat ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigThreat
By default, following policies will be included: - XMLThreatProtection - JSONThreatProtection Corresponds to the JSON property
threat.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1ProfileConfigCategory
constructor
A new instance of GoogleCloudApigeeV1ProfileConfigCategory.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1ProfileConfigCategory
Returns a new instance of GoogleCloudApigeeV1ProfileConfigCategory.
8783 8784 8785 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8783 def initialize(**args) update!(**args) end |
Instance Attribute Details
#abuse ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigAbuse
Checks for abuse, which includes any requests sent to the API for purposes
other than what it is intended for, such as high volumes of requests, data
scraping, and abuse related to authorization.
Corresponds to the JSON property abuse
8753 8754 8755 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8753 def abuse @abuse end |
#authorization ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigAuthorization
By default, following policies will be included: - JWS - JWT - OAuth -
BasicAuth - APIKey
Corresponds to the JSON property authorization
8759 8760 8761 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8759 def @authorization end |
#cors ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigCors
Checks to see if you have CORS policy in place.
Corresponds to the JSON property cors
8764 8765 8766 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8764 def cors @cors end |
#mediation ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigMediation
By default, following policies will be included: - OASValidation -
SOAPMessageValidation
Corresponds to the JSON property mediation
8770 8771 8772 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8770 def mediation @mediation end |
#mtls ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigMtls
Checks to see if you have configured mTLS for the target server.
Corresponds to the JSON property mtls
8775 8776 8777 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8775 def mtls @mtls end |
#threat ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfigThreat
By default, following policies will be included: - XMLThreatProtection -
JSONThreatProtection
Corresponds to the JSON property threat
8781 8782 8783 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8781 def threat @threat end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8788 8789 8790 8791 8792 8793 8794 8795 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 8788 def update!(**args) @abuse = args[:abuse] if args.key?(:abuse) @authorization = args[:authorization] if args.key?(:authorization) @cors = args[:cors] if args.key?(:cors) @mediation = args[:mediation] if args.key?(:mediation) @mtls = args[:mtls] if args.key?(:mtls) @threat = args[:threat] if args.key?(:threat) end |