Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Properties

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Message for compatibility with legacy Edge specification for Java Properties object in JSON.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1Properties

Returns a new instance of GoogleCloudApigeeV1Properties.



8849
8850
8851
# File 'lib/google/apis/apigee_v1/classes.rb', line 8849

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#propertyArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1Property>

List of all properties in the object Corresponds to the JSON property property



8847
8848
8849
# File 'lib/google/apis/apigee_v1/classes.rb', line 8847

def property
  @property
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8854
8855
8856
# File 'lib/google/apis/apigee_v1/classes.rb', line 8854

def update!(**args)
  @property = args[:property] if args.key?(:property)
end