Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Query

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1Query

Returns a new instance of GoogleCloudApigeeV1Query.



9023
9024
9025
# File 'lib/google/apis/apigee_v1/classes.rb', line 9023

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#csv_delimiterString

Delimiter used in the CSV file, if outputFormat is set to csv. Defaults to the , (comma) character. Supported delimiter characters include comma (,), pipe (|), and tab (\t). Corresponds to the JSON property csvDelimiter

Returns:

  • (String)


8952
8953
8954
# File 'lib/google/apis/apigee_v1/classes.rb', line 8952

def csv_delimiter
  @csv_delimiter
end

#dimensionsArray<String>

A list of dimensions. https://docs.apigee.com/api-platform/analytics/analytics- reference#dimensions Corresponds to the JSON property dimensions

Returns:

  • (Array<String>)


8958
8959
8960
# File 'lib/google/apis/apigee_v1/classes.rb', line 8958

def dimensions
  @dimensions
end

#envgroup_hostnameString

Hostname needs to be specified if query intends to run at host level. This field is only allowed when query is submitted by CreateHostAsyncQuery where analytics data will be grouped by organization and hostname. Corresponds to the JSON property envgroupHostname

Returns:

  • (String)


8965
8966
8967
# File 'lib/google/apis/apigee_v1/classes.rb', line 8965

def envgroup_hostname
  @envgroup_hostname
end

#filterString

Boolean expression that can be used to filter data. Filter expressions can be combined using AND/OR terms and should be fully parenthesized to avoid ambiguity. See Analytics metrics, dimensions, and filters reference https:// docs.apigee.com/api-platform/analytics/analytics-reference for more information on the fields available to filter on. For more information on the tokens that you use to build filter expressions, see Filter expression syntax. https://docs.apigee.com/api-platform/analytics/asynch-reports-api#filter- expression-syntax Corresponds to the JSON property filter

Returns:

  • (String)


8977
8978
8979
# File 'lib/google/apis/apigee_v1/classes.rb', line 8977

def filter
  @filter
end

#group_by_time_unitString

Time unit used to group the result set. Valid values include: second, minute, hour, day, week, or month. If a query includes groupByTimeUnit, then the result is an aggregation based on the specified time unit and the resultant timestamp does not include milliseconds precision. If a query omits groupByTimeUnit, then the resultant timestamp includes milliseconds precision. Corresponds to the JSON property groupByTimeUnit

Returns:

  • (String)


8986
8987
8988
# File 'lib/google/apis/apigee_v1/classes.rb', line 8986

def group_by_time_unit
  @group_by_time_unit
end

#limitFixnum

Maximum number of rows that can be returned in the result. Corresponds to the JSON property limit

Returns:

  • (Fixnum)


8991
8992
8993
# File 'lib/google/apis/apigee_v1/classes.rb', line 8991

def limit
  @limit
end

#metricsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1QueryMetric>

A list of Metrics. Corresponds to the JSON property metrics



8996
8997
8998
# File 'lib/google/apis/apigee_v1/classes.rb', line 8996

def metrics
  @metrics
end

#nameString

Asynchronous Query Name. Corresponds to the JSON property name

Returns:

  • (String)


9001
9002
9003
# File 'lib/google/apis/apigee_v1/classes.rb', line 9001

def name
  @name
end

#output_formatString

Valid values include: csv or json. Defaults to json. Note: Configure the delimiter for CSV output using the csvDelimiter property. Corresponds to the JSON property outputFormat

Returns:

  • (String)


9007
9008
9009
# File 'lib/google/apis/apigee_v1/classes.rb', line 9007

def output_format
  @output_format
end

#report_definition_idString

Asynchronous Report ID. Corresponds to the JSON property reportDefinitionId

Returns:

  • (String)


9012
9013
9014
# File 'lib/google/apis/apigee_v1/classes.rb', line 9012

def report_definition_id
  @report_definition_id
end

#time_rangeObject

Required. Time range for the query. Can use the following predefined strings to specify the time range: last60minutes last24hours last7days Or, specify the timeRange as a structure describing start and end timestamps in the ISO format: yyyy-mm-ddThh:mm:ssZ. Example: "timeRange": "start": "2018- 07-29T00:13:00Z", "end": "2018-08-01T00:18:00Z" Corresponds to the JSON property timeRange

Returns:

  • (Object)


9021
9022
9023
# File 'lib/google/apis/apigee_v1/classes.rb', line 9021

def time_range
  @time_range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9028
9029
9030
9031
9032
9033
9034
9035
9036
9037
9038
9039
9040
# File 'lib/google/apis/apigee_v1/classes.rb', line 9028

def update!(**args)
  @csv_delimiter = args[:csv_delimiter] if args.key?(:csv_delimiter)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @envgroup_hostname = args[:envgroup_hostname] if args.key?(:envgroup_hostname)
  @filter = args[:filter] if args.key?(:filter)
  @group_by_time_unit = args[:group_by_time_unit] if args.key?(:group_by_time_unit)
  @limit = args[:limit] if args.key?(:limit)
  @metrics = args[:metrics] if args.key?(:metrics)
  @name = args[:name] if args.key?(:name)
  @output_format = args[:output_format] if args.key?(:output_format)
  @report_definition_id = args[:report_definition_id] if args.key?(:report_definition_id)
  @time_range = args[:time_range] if args.key?(:time_range)
end