Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1QueryMetric
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1QueryMetric
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
More info about Metric: https://docs.apigee.com/api-platform/analytics/ analytics-reference#metrics
Instance Attribute Summary collapse
-
#alias ⇒ String
Alias for the metric.
-
#function ⇒ String
Aggregation function: avg, min, max, or sum.
-
#name ⇒ String
Required.
-
#operator ⇒ String
One of
+,-,/,%,*. -
#value ⇒ String
Operand value should be provided when operator is set.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1QueryMetric
constructor
A new instance of GoogleCloudApigeeV1QueryMetric.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1QueryMetric
Returns a new instance of GoogleCloudApigeeV1QueryMetric.
9228 9229 9230 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9228 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alias ⇒ String
Alias for the metric. Alias will be used to replace metric name in query
results.
Corresponds to the JSON property alias
9206 9207 9208 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9206 def alias @alias end |
#function ⇒ String
Aggregation function: avg, min, max, or sum.
Corresponds to the JSON property function
9211 9212 9213 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9211 def function @function end |
#name ⇒ String
Required. Metric name.
Corresponds to the JSON property name
9216 9217 9218 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9216 def name @name end |
#operator ⇒ String
One of +, -, /, %, *.
Corresponds to the JSON property operator
9221 9222 9223 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9221 def operator @operator end |
#value ⇒ String
Operand value should be provided when operator is set.
Corresponds to the JSON property value
9226 9227 9228 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9226 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9233 9234 9235 9236 9237 9238 9239 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9233 def update!(**args) @alias = args[:alias] if args.key?(:alias) @function = args[:function] if args.key?(:function) @name = args[:name] if args.key?(:name) @operator = args[:operator] if args.key?(:operator) @value = args[:value] if args.key?(:value) end |