Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1QueryMetric
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1QueryMetric
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
More info about Metric: https://docs.apigee.com/api-platform/analytics/ analytics-reference#metrics
Instance Attribute Summary collapse
-
#alias ⇒ String
Alias for the metric.
-
#function ⇒ String
Aggregation function: avg, min, max, or sum.
-
#name ⇒ String
Required.
-
#operator ⇒ String
One of
+,-,/,%,*. -
#value ⇒ String
Operand value should be provided when operator is set.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1QueryMetric
constructor
A new instance of GoogleCloudApigeeV1QueryMetric.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1QueryMetric
Returns a new instance of GoogleCloudApigeeV1QueryMetric.
9173 9174 9175 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9173 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alias ⇒ String
Alias for the metric. Alias will be used to replace metric name in query
results.
Corresponds to the JSON property alias
9151 9152 9153 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9151 def alias @alias end |
#function ⇒ String
Aggregation function: avg, min, max, or sum.
Corresponds to the JSON property function
9156 9157 9158 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9156 def function @function end |
#name ⇒ String
Required. Metric name.
Corresponds to the JSON property name
9161 9162 9163 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9161 def name @name end |
#operator ⇒ String
One of +, -, /, %, *.
Corresponds to the JSON property operator
9166 9167 9168 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9166 def operator @operator end |
#value ⇒ String
Operand value should be provided when operator is set.
Corresponds to the JSON property value
9171 9172 9173 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9171 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9178 9179 9180 9181 9182 9183 9184 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9178 def update!(**args) @alias = args[:alias] if args.key?(:alias) @function = args[:function] if args.key?(:function) @name = args[:name] if args.key?(:name) @operator = args[:operator] if args.key?(:operator) @value = args[:value] if args.key?(:value) end |