Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1QueryMetric

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

More info about Metric: https://docs.apigee.com/api-platform/analytics/ analytics-reference#metrics

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1QueryMetric

Returns a new instance of GoogleCloudApigeeV1QueryMetric.



9124
9125
9126
# File 'lib/google/apis/apigee_v1/classes.rb', line 9124

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aliasString

Alias for the metric. Alias will be used to replace metric name in query results. Corresponds to the JSON property alias

Returns:

  • (String)


9102
9103
9104
# File 'lib/google/apis/apigee_v1/classes.rb', line 9102

def alias
  @alias
end

#functionString

Aggregation function: avg, min, max, or sum. Corresponds to the JSON property function

Returns:

  • (String)


9107
9108
9109
# File 'lib/google/apis/apigee_v1/classes.rb', line 9107

def function
  @function
end

#nameString

Required. Metric name. Corresponds to the JSON property name

Returns:

  • (String)


9112
9113
9114
# File 'lib/google/apis/apigee_v1/classes.rb', line 9112

def name
  @name
end

#operatorString

One of +, -, /, %, *. Corresponds to the JSON property operator

Returns:

  • (String)


9117
9118
9119
# File 'lib/google/apis/apigee_v1/classes.rb', line 9117

def operator
  @operator
end

#valueString

Operand value should be provided when operator is set. Corresponds to the JSON property value

Returns:

  • (String)


9122
9123
9124
# File 'lib/google/apis/apigee_v1/classes.rb', line 9122

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9129
9130
9131
9132
9133
9134
9135
# File 'lib/google/apis/apigee_v1/classes.rb', line 9129

def update!(**args)
  @alias = args[:alias] if args.key?(:alias)
  @function = args[:function] if args.key?(:function)
  @name = args[:name] if args.key?(:name)
  @operator = args[:operator] if args.key?(:operator)
  @value = args[:value] if args.key?(:value)
end