Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1QueryTabularStatsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1QueryTabularStatsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Request payload representing the query to be run for fetching security statistics as rows.
Instance Attribute Summary collapse
-
#dimensions ⇒ Array<String>
Required.
-
#filter ⇒ String
Filter further on specific dimension values.
-
#metrics ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1MetricAggregation>
Required.
-
#page_size ⇒ Fixnum
Page size represents the number of rows.
-
#page_token ⇒ String
Identifies a sequence of rows.
-
#time_range ⇒ Google::Apis::ApigeeV1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1QueryTabularStatsRequest
constructor
A new instance of GoogleCloudApigeeV1QueryTabularStatsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1QueryTabularStatsRequest
Returns a new instance of GoogleCloudApigeeV1QueryTabularStatsRequest.
9178 9179 9180 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9178 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dimensions ⇒ Array<String>
Required. List of dimension names to group the aggregations by.
Corresponds to the JSON property dimensions
9145 9146 9147 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9145 def dimensions @dimensions end |
#filter ⇒ String
Filter further on specific dimension values. Follows the same grammar as
custom report's filter expressions. Example, apiproxy eq 'foobar'. https://
cloud.google.com/apigee/docs/api-platform/analytics/analytics-reference#
filters
Corresponds to the JSON property filter
9153 9154 9155 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9153 def filter @filter end |
#metrics ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1MetricAggregation>
Required. List of metrics and their aggregations.
Corresponds to the JSON property metrics
9158 9159 9160 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9158 def metrics @metrics end |
#page_size ⇒ Fixnum
Page size represents the number of rows.
Corresponds to the JSON property pageSize
9163 9164 9165 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9163 def page_size @page_size end |
#page_token ⇒ String
Identifies a sequence of rows.
Corresponds to the JSON property pageToken
9168 9169 9170 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9168 def page_token @page_token end |
#time_range ⇒ Google::Apis::ApigeeV1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive). The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time). When
both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property timeRange
9176 9177 9178 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9176 def time_range @time_range end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9183 9184 9185 9186 9187 9188 9189 9190 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9183 def update!(**args) @dimensions = args[:dimensions] if args.key?(:dimensions) @filter = args[:filter] if args.key?(:filter) @metrics = args[:metrics] if args.key?(:metrics) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @time_range = args[:time_range] if args.key?(:time_range) end |