Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1QueryTabularStatsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Request payload representing the query to be run for fetching security statistics as rows.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1QueryTabularStatsRequest

Returns a new instance of GoogleCloudApigeeV1QueryTabularStatsRequest.



9179
9180
9181
# File 'lib/google/apis/apigee_v1/classes.rb', line 9179

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimensionsArray<String>

Required. List of dimension names to group the aggregations by. Corresponds to the JSON property dimensions

Returns:

  • (Array<String>)


9146
9147
9148
# File 'lib/google/apis/apigee_v1/classes.rb', line 9146

def dimensions
  @dimensions
end

#filterString

Filter further on specific dimension values. Follows the same grammar as custom report's filter expressions. Example, apiproxy eq 'foobar'. https:// cloud.google.com/apigee/docs/api-platform/analytics/analytics-reference# filters Corresponds to the JSON property filter

Returns:

  • (String)


9154
9155
9156
# File 'lib/google/apis/apigee_v1/classes.rb', line 9154

def filter
  @filter
end

#metricsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1MetricAggregation>

Required. List of metrics and their aggregations. Corresponds to the JSON property metrics



9159
9160
9161
# File 'lib/google/apis/apigee_v1/classes.rb', line 9159

def metrics
  @metrics
end

#page_sizeFixnum

Page size represents the number of rows. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


9164
9165
9166
# File 'lib/google/apis/apigee_v1/classes.rb', line 9164

def page_size
  @page_size
end

#page_tokenString

Identifies a sequence of rows. Corresponds to the JSON property pageToken

Returns:

  • (String)


9169
9170
9171
# File 'lib/google/apis/apigee_v1/classes.rb', line 9169

def page_token
  @page_token
end

#time_rangeGoogle::Apis::ApigeeV1::GoogleTypeInterval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property timeRange



9177
9178
9179
# File 'lib/google/apis/apigee_v1/classes.rb', line 9177

def time_range
  @time_range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9184
9185
9186
9187
9188
9189
9190
9191
# File 'lib/google/apis/apigee_v1/classes.rb', line 9184

def update!(**args)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @filter = args[:filter] if args.key?(:filter)
  @metrics = args[:metrics] if args.key?(:metrics)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @time_range = args[:time_range] if args.key?(:time_range)
end