Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1QueryTimeSeriesStatsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1QueryTimeSeriesStatsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
QueryTimeSeriesStatsRequest represents a query that returns a collection of time series sequences grouped by their values.
Instance Attribute Summary collapse
-
#dimensions ⇒ Array<String>
List of dimension names to group the aggregations by.
-
#filter ⇒ String
Filter further on specific dimension values.
-
#metrics ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1MetricAggregation>
Required.
-
#page_size ⇒ Fixnum
Page size represents the number of time series sequences, one per unique set of dimensions and their values.
-
#page_token ⇒ String
Page token stands for a specific collection of time series sequences.
-
#time_range ⇒ Google::Apis::ApigeeV1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
-
#timestamp_order ⇒ String
Order the sequences in increasing or decreasing order of timestamps.
-
#window_size ⇒ String
Time buckets to group the stats by.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1QueryTimeSeriesStatsRequest
constructor
A new instance of GoogleCloudApigeeV1QueryTimeSeriesStatsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1QueryTimeSeriesStatsRequest
Returns a new instance of GoogleCloudApigeeV1QueryTimeSeriesStatsRequest.
9387 9388 9389 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9387 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dimensions ⇒ Array<String>
List of dimension names to group the aggregations by. If no dimensions are
passed, a single trend line representing the requested metric aggregations
grouped by environment is returned.
Corresponds to the JSON property dimensions
9342 9343 9344 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9342 def dimensions @dimensions end |
#filter ⇒ String
Filter further on specific dimension values. Follows the same grammar as
custom report's filter expressions. Example, apiproxy eq 'foobar'. https://
cloud.google.com/apigee/docs/api-platform/analytics/analytics-reference#
filters
Corresponds to the JSON property filter
9350 9351 9352 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9350 def filter @filter end |
#metrics ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1MetricAggregation>
Required. List of metrics and their aggregations.
Corresponds to the JSON property metrics
9355 9356 9357 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9355 def metrics @metrics end |
#page_size ⇒ Fixnum
Page size represents the number of time series sequences, one per unique set
of dimensions and their values.
Corresponds to the JSON property pageSize
9361 9362 9363 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9361 def page_size @page_size end |
#page_token ⇒ String
Page token stands for a specific collection of time series sequences.
Corresponds to the JSON property pageToken
9366 9367 9368 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9366 def page_token @page_token end |
#time_range ⇒ Google::Apis::ApigeeV1::GoogleTypeInterval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive). The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time). When
both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property timeRange
9374 9375 9376 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9374 def time_range @time_range end |
#timestamp_order ⇒ String
Order the sequences in increasing or decreasing order of timestamps. Default
is descending order of timestamps (latest first).
Corresponds to the JSON property timestampOrder
9380 9381 9382 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9380 def @timestamp_order end |
#window_size ⇒ String
Time buckets to group the stats by.
Corresponds to the JSON property windowSize
9385 9386 9387 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9385 def window_size @window_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9392 9393 9394 9395 9396 9397 9398 9399 9400 9401 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9392 def update!(**args) @dimensions = args[:dimensions] if args.key?(:dimensions) @filter = args[:filter] if args.key?(:filter) @metrics = args[:metrics] if args.key?(:metrics) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @time_range = args[:time_range] if args.key?(:time_range) @timestamp_order = args[:timestamp_order] if args.key?(:timestamp_order) @window_size = args[:window_size] if args.key?(:window_size) end |