Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1QueryTimeSeriesStatsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

QueryTimeSeriesStatsRequest represents a query that returns a collection of time series sequences grouped by their values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1QueryTimeSeriesStatsRequest

Returns a new instance of GoogleCloudApigeeV1QueryTimeSeriesStatsRequest.



9283
9284
9285
# File 'lib/google/apis/apigee_v1/classes.rb', line 9283

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimensionsArray<String>

List of dimension names to group the aggregations by. If no dimensions are passed, a single trend line representing the requested metric aggregations grouped by environment is returned. Corresponds to the JSON property dimensions

Returns:

  • (Array<String>)


9238
9239
9240
# File 'lib/google/apis/apigee_v1/classes.rb', line 9238

def dimensions
  @dimensions
end

#filterString

Filter further on specific dimension values. Follows the same grammar as custom report's filter expressions. Example, apiproxy eq 'foobar'. https:// cloud.google.com/apigee/docs/api-platform/analytics/analytics-reference# filters Corresponds to the JSON property filter

Returns:

  • (String)


9246
9247
9248
# File 'lib/google/apis/apigee_v1/classes.rb', line 9246

def filter
  @filter
end

#metricsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1MetricAggregation>

Required. List of metrics and their aggregations. Corresponds to the JSON property metrics



9251
9252
9253
# File 'lib/google/apis/apigee_v1/classes.rb', line 9251

def metrics
  @metrics
end

#page_sizeFixnum

Page size represents the number of time series sequences, one per unique set of dimensions and their values. Corresponds to the JSON property pageSize

Returns:

  • (Fixnum)


9257
9258
9259
# File 'lib/google/apis/apigee_v1/classes.rb', line 9257

def page_size
  @page_size
end

#page_tokenString

Page token stands for a specific collection of time series sequences. Corresponds to the JSON property pageToken

Returns:

  • (String)


9262
9263
9264
# File 'lib/google/apis/apigee_v1/classes.rb', line 9262

def page_token
  @page_token
end

#time_rangeGoogle::Apis::ApigeeV1::GoogleTypeInterval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property timeRange



9270
9271
9272
# File 'lib/google/apis/apigee_v1/classes.rb', line 9270

def time_range
  @time_range
end

#timestamp_orderString

Order the sequences in increasing or decreasing order of timestamps. Default is descending order of timestamps (latest first). Corresponds to the JSON property timestampOrder

Returns:

  • (String)


9276
9277
9278
# File 'lib/google/apis/apigee_v1/classes.rb', line 9276

def timestamp_order
  @timestamp_order
end

#window_sizeString

Time buckets to group the stats by. Corresponds to the JSON property windowSize

Returns:

  • (String)


9281
9282
9283
# File 'lib/google/apis/apigee_v1/classes.rb', line 9281

def window_size
  @window_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9288
9289
9290
9291
9292
9293
9294
9295
9296
9297
# File 'lib/google/apis/apigee_v1/classes.rb', line 9288

def update!(**args)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @filter = args[:filter] if args.key?(:filter)
  @metrics = args[:metrics] if args.key?(:metrics)
  @page_size = args[:page_size] if args.key?(:page_size)
  @page_token = args[:page_token] if args.key?(:page_token)
  @time_range = args[:time_range] if args.key?(:time_range)
  @timestamp_order = args[:timestamp_order] if args.key?(:timestamp_order)
  @window_size = args[:window_size] if args.key?(:window_size)
end