Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1QueryTimeSeriesStatsResponse
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1QueryTimeSeriesStatsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Represents security stats result as a collection of time series sequences.
Instance Attribute Summary collapse
-
#columns ⇒ Array<String>
Column names corresponding to the same order as the inner values in the stats field.
-
#next_page_token ⇒ String
Next page token.
-
#values ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1QueryTimeSeriesStatsResponseSequence>
Results of the query returned as a JSON array.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1QueryTimeSeriesStatsResponse
constructor
A new instance of GoogleCloudApigeeV1QueryTimeSeriesStatsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1QueryTimeSeriesStatsResponse
Returns a new instance of GoogleCloudApigeeV1QueryTimeSeriesStatsResponse.
9320 9321 9322 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9320 def initialize(**args) update!(**args) end |
Instance Attribute Details
#columns ⇒ Array<String>
Column names corresponding to the same order as the inner values in the stats
field.
Corresponds to the JSON property columns
9308 9309 9310 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9308 def columns @columns end |
#next_page_token ⇒ String
Next page token.
Corresponds to the JSON property nextPageToken
9313 9314 9315 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9313 def next_page_token @next_page_token end |
#values ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1QueryTimeSeriesStatsResponseSequence>
Results of the query returned as a JSON array.
Corresponds to the JSON property values
9318 9319 9320 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9318 def values @values end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9325 9326 9327 9328 9329 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9325 def update!(**args) @columns = args[:columns] if args.key?(:columns) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @values = args[:values] if args.key?(:values) end |