Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1QueryTimeSeriesStatsResponseSequence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

A sequence of time series.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1QueryTimeSeriesStatsResponseSequence

Returns a new instance of GoogleCloudApigeeV1QueryTimeSeriesStatsResponseSequence.



9355
9356
9357
# File 'lib/google/apis/apigee_v1/classes.rb', line 9355

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimensionsHash<String,String>

Map of dimensions and their values that uniquely identifies a time series sequence. Corresponds to the JSON property dimensions

Returns:

  • (Hash<String,String>)


9348
9349
9350
# File 'lib/google/apis/apigee_v1/classes.rb', line 9348

def dimensions
  @dimensions
end

#pointsArray<Array<Object>>

List of points. First value of each inner list is a timestamp. Corresponds to the JSON property points

Returns:

  • (Array<Array<Object>>)


9353
9354
9355
# File 'lib/google/apis/apigee_v1/classes.rb', line 9353

def points
  @points
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9360
9361
9362
9363
# File 'lib/google/apis/apigee_v1/classes.rb', line 9360

def update!(**args)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @points = args[:points] if args.key?(:points)
end