Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Quota
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1Quota
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Quota contains the essential parameters needed that can be applied on the resources, methods, API source combination associated with this API product. While Quota is optional, setting it prevents requests from exceeding the provisioned parameters.
Instance Attribute Summary collapse
-
#interval ⇒ String
Required.
-
#limit ⇒ String
Required.
-
#time_unit ⇒ String
Time unit defined for the
interval.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1Quota
constructor
A new instance of GoogleCloudApigeeV1Quota.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1Quota
Returns a new instance of GoogleCloudApigeeV1Quota.
9392 9393 9394 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9392 def initialize(**args) update!(**args) end |
Instance Attribute Details
#interval ⇒ String
Required. Time interval over which the number of request messages is
calculated.
Corresponds to the JSON property interval
9377 9378 9379 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9377 def interval @interval end |
#limit ⇒ String
Required. Upper limit allowed for the time interval and time unit specified.
Requests exceeding this limit will be rejected.
Corresponds to the JSON property limit
9383 9384 9385 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9383 def limit @limit end |
#time_unit ⇒ String
Time unit defined for the interval. Valid values include minute, hour,
day, or month. If limit and interval are valid, the default value is
hour; otherwise, the default is null.
Corresponds to the JSON property timeUnit
9390 9391 9392 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9390 def time_unit @time_unit end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9397 9398 9399 9400 9401 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9397 def update!(**args) @interval = args[:interval] if args.key?(:interval) @limit = args[:limit] if args.key?(:limit) @time_unit = args[:time_unit] if args.key?(:time_unit) end |