Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Quota
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1Quota
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Quota contains the essential parameters needed that can be applied on the resources, methods, API source combination associated with this API product. While Quota is optional, setting it prevents requests from exceeding the provisioned parameters.
Instance Attribute Summary collapse
-
#interval ⇒ String
Required.
-
#limit ⇒ String
Required.
-
#time_unit ⇒ String
Time unit defined for the
interval.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1Quota
constructor
A new instance of GoogleCloudApigeeV1Quota.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1Quota
Returns a new instance of GoogleCloudApigeeV1Quota.
9384 9385 9386 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9384 def initialize(**args) update!(**args) end |
Instance Attribute Details
#interval ⇒ String
Required. Time interval over which the number of request messages is
calculated.
Corresponds to the JSON property interval
9369 9370 9371 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9369 def interval @interval end |
#limit ⇒ String
Required. Upper limit allowed for the time interval and time unit specified.
Requests exceeding this limit will be rejected.
Corresponds to the JSON property limit
9375 9376 9377 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9375 def limit @limit end |
#time_unit ⇒ String
Time unit defined for the interval. Valid values include minute, hour,
day, or month. If limit and interval are valid, the default value is
hour; otherwise, the default is null.
Corresponds to the JSON property timeUnit
9382 9383 9384 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9382 def time_unit @time_unit end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9389 9390 9391 9392 9393 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9389 def update!(**args) @interval = args[:interval] if args.key?(:interval) @limit = args[:limit] if args.key?(:limit) @time_unit = args[:time_unit] if args.key?(:time_unit) end |