Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1RateRange
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1RateRange
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
API call volume range and the fees charged when the total number of API calls is within the range.
Instance Attribute Summary collapse
-
#end ⇒ Fixnum
Ending value of the range.
-
#fee ⇒ Google::Apis::ApigeeV1::GoogleTypeMoney
Represents an amount of money with its currency type.
-
#start ⇒ Fixnum
Starting value of the range.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1RateRange
constructor
A new instance of GoogleCloudApigeeV1RateRange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1RateRange
Returns a new instance of GoogleCloudApigeeV1RateRange.
9558 9559 9560 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9558 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end ⇒ Fixnum
Ending value of the range. Set to 0 or null for the last range of values.
Corresponds to the JSON property end
9545 9546 9547 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9545 def end @end end |
#fee ⇒ Google::Apis::ApigeeV1::GoogleTypeMoney
Represents an amount of money with its currency type.
Corresponds to the JSON property fee
9550 9551 9552 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9550 def fee @fee end |
#start ⇒ Fixnum
Starting value of the range. Set to 0 or null for the initial range of
values.
Corresponds to the JSON property start
9556 9557 9558 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9556 def start @start end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9563 9564 9565 9566 9567 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9563 def update!(**args) @end = args[:end] if args.key?(:end) @fee = args[:fee] if args.key?(:fee) @start = args[:start] if args.key?(:start) end |