Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ResourceStatus
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1ResourceStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
The status of a resource loaded in the runtime.
Instance Attribute Summary collapse
-
#resource ⇒ String
The resource name.
-
#revisions ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1RevisionStatus>
Revisions of the resource currently deployed in the instance.
-
#total_replicas ⇒ Fixnum
The total number of replicas that should have this resource.
-
#uid ⇒ String
The uid of the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1ResourceStatus
constructor
A new instance of GoogleCloudApigeeV1ResourceStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1ResourceStatus
Returns a new instance of GoogleCloudApigeeV1ResourceStatus.
9811 9812 9813 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9811 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource ⇒ String
The resource name. Currently only two resources are supported:
EnvironmentGroup - organizations/org/envgroups/envgroup EnvironmentConfig -
organizations/org/environments/environment/deployedConfig
Corresponds to the JSON property resource
9792 9793 9794 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9792 def resource @resource end |
#revisions ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1RevisionStatus>
Revisions of the resource currently deployed in the instance.
Corresponds to the JSON property revisions
9797 9798 9799 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9797 def revisions @revisions end |
#total_replicas ⇒ Fixnum
The total number of replicas that should have this resource.
Corresponds to the JSON property totalReplicas
9802 9803 9804 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9802 def total_replicas @total_replicas end |
#uid ⇒ String
The uid of the resource. In the unexpected case that the instance has multiple
uids for the same name, they should be reported under separate
ResourceStatuses.
Corresponds to the JSON property uid
9809 9810 9811 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9809 def uid @uid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9816 9817 9818 9819 9820 9821 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9816 def update!(**args) @resource = args[:resource] if args.key?(:resource) @revisions = args[:revisions] if args.key?(:revisions) @total_replicas = args[:total_replicas] if args.key?(:total_replicas) @uid = args[:uid] if args.key?(:uid) end |