Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1RevenueShareRange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

API call volume range and the percentage of revenue to share with the developer when the total number of API calls is within the range.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1RevenueShareRange

Returns a new instance of GoogleCloudApigeeV1RevenueShareRange.



9989
9990
9991
# File 'lib/google/apis/apigee_v1/classes.rb', line 9989

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endFixnum

Ending value of the range. Set to 0 or null for the last range of values. Corresponds to the JSON property end

Returns:

  • (Fixnum)


9973
9974
9975
# File 'lib/google/apis/apigee_v1/classes.rb', line 9973

def end
  @end
end

#share_percentageFloat

Percentage of the revenue to be shared with the developer. For example, to share 21 percent of the total revenue with the developer, set this value to 21. Specify a decimal number with a maximum of two digits following the decimal point. Corresponds to the JSON property sharePercentage

Returns:

  • (Float)


9981
9982
9983
# File 'lib/google/apis/apigee_v1/classes.rb', line 9981

def share_percentage
  @share_percentage
end

#startFixnum

Starting value of the range. Set to 0 or null for the initial range of values. Corresponds to the JSON property start

Returns:

  • (Fixnum)


9987
9988
9989
# File 'lib/google/apis/apigee_v1/classes.rb', line 9987

def start
  @start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9994
9995
9996
9997
9998
# File 'lib/google/apis/apigee_v1/classes.rb', line 9994

def update!(**args)
  @end = args[:end] if args.key?(:end)
  @share_percentage = args[:share_percentage] if args.key?(:share_percentage)
  @start = args[:start] if args.key?(:start)
end