Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1RevisionStatus
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1RevisionStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
The status of a specific resource revision.
Instance Attribute Summary collapse
-
#errors ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1UpdateError>
Errors reported when attempting to load this revision.
-
#json_spec ⇒ String
The json content of the resource revision.
-
#replicas ⇒ Fixnum
The number of replicas that have successfully loaded this revision.
-
#revision_id ⇒ String
The revision of the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1RevisionStatus
constructor
A new instance of GoogleCloudApigeeV1RevisionStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1RevisionStatus
Returns a new instance of GoogleCloudApigeeV1RevisionStatus.
10081 10082 10083 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10081 def initialize(**args) update!(**args) end |
Instance Attribute Details
#errors ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1UpdateError>
Errors reported when attempting to load this revision.
Corresponds to the JSON property errors
10063 10064 10065 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10063 def errors @errors end |
#json_spec ⇒ String
The json content of the resource revision. Large specs should be sent
individually via the spec field to avoid hitting request size limits.
Corresponds to the JSON property jsonSpec
10069 10070 10071 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10069 def json_spec @json_spec end |
#replicas ⇒ Fixnum
The number of replicas that have successfully loaded this revision.
Corresponds to the JSON property replicas
10074 10075 10076 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10074 def replicas @replicas end |
#revision_id ⇒ String
The revision of the resource.
Corresponds to the JSON property revisionId
10079 10080 10081 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10079 def revision_id @revision_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10086 10087 10088 10089 10090 10091 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10086 def update!(**args) @errors = args[:errors] if args.key?(:errors) @json_spec = args[:json_spec] if args.key?(:json_spec) @replicas = args[:replicas] if args.key?(:replicas) @revision_id = args[:revision_id] if args.key?(:revision_id) end |