Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1RevisionStatus
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1RevisionStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
The status of a specific resource revision.
Instance Attribute Summary collapse
-
#errors ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1UpdateError>
Errors reported when attempting to load this revision.
-
#json_spec ⇒ String
The json content of the resource revision.
-
#replicas ⇒ Fixnum
The number of replicas that have successfully loaded this revision.
-
#revision_id ⇒ String
The revision of the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1RevisionStatus
constructor
A new instance of GoogleCloudApigeeV1RevisionStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1RevisionStatus
Returns a new instance of GoogleCloudApigeeV1RevisionStatus.
10026 10027 10028 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10026 def initialize(**args) update!(**args) end |
Instance Attribute Details
#errors ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1UpdateError>
Errors reported when attempting to load this revision.
Corresponds to the JSON property errors
10008 10009 10010 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10008 def errors @errors end |
#json_spec ⇒ String
The json content of the resource revision. Large specs should be sent
individually via the spec field to avoid hitting request size limits.
Corresponds to the JSON property jsonSpec
10014 10015 10016 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10014 def json_spec @json_spec end |
#replicas ⇒ Fixnum
The number of replicas that have successfully loaded this revision.
Corresponds to the JSON property replicas
10019 10020 10021 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10019 def replicas @replicas end |
#revision_id ⇒ String
The revision of the resource.
Corresponds to the JSON property revisionId
10024 10025 10026 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10024 def revision_id @revision_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10031 10032 10033 10034 10035 10036 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10031 def update!(**args) @errors = args[:errors] if args.key?(:errors) @json_spec = args[:json_spec] if args.key?(:json_spec) @replicas = args[:replicas] if args.key?(:replicas) @revision_id = args[:revision_id] if args.key?(:revision_id) end |