Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1RevisionStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

The status of a specific resource revision.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1RevisionStatus

Returns a new instance of GoogleCloudApigeeV1RevisionStatus.



9977
9978
9979
# File 'lib/google/apis/apigee_v1/classes.rb', line 9977

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1UpdateError>

Errors reported when attempting to load this revision. Corresponds to the JSON property errors



9959
9960
9961
# File 'lib/google/apis/apigee_v1/classes.rb', line 9959

def errors
  @errors
end

#json_specString

The json content of the resource revision. Large specs should be sent individually via the spec field to avoid hitting request size limits. Corresponds to the JSON property jsonSpec

Returns:

  • (String)


9965
9966
9967
# File 'lib/google/apis/apigee_v1/classes.rb', line 9965

def json_spec
  @json_spec
end

#replicasFixnum

The number of replicas that have successfully loaded this revision. Corresponds to the JSON property replicas

Returns:

  • (Fixnum)


9970
9971
9972
# File 'lib/google/apis/apigee_v1/classes.rb', line 9970

def replicas
  @replicas
end

#revision_idString

The revision of the resource. Corresponds to the JSON property revisionId

Returns:

  • (String)


9975
9976
9977
# File 'lib/google/apis/apigee_v1/classes.rb', line 9975

def revision_id
  @revision_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9982
9983
9984
9985
9986
9987
# File 'lib/google/apis/apigee_v1/classes.rb', line 9982

def update!(**args)
  @errors = args[:errors] if args.key?(:errors)
  @json_spec = args[:json_spec] if args.key?(:json_spec)
  @replicas = args[:replicas] if args.key?(:replicas)
  @revision_id = args[:revision_id] if args.key?(:revision_id)
end