Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1RevisionStatus
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1RevisionStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
The status of a specific resource revision.
Instance Attribute Summary collapse
-
#errors ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1UpdateError>
Errors reported when attempting to load this revision.
-
#json_spec ⇒ String
The json content of the resource revision.
-
#replicas ⇒ Fixnum
The number of replicas that have successfully loaded this revision.
-
#revision_id ⇒ String
The revision of the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1RevisionStatus
constructor
A new instance of GoogleCloudApigeeV1RevisionStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1RevisionStatus
Returns a new instance of GoogleCloudApigeeV1RevisionStatus.
9977 9978 9979 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9977 def initialize(**args) update!(**args) end |
Instance Attribute Details
#errors ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1UpdateError>
Errors reported when attempting to load this revision.
Corresponds to the JSON property errors
9959 9960 9961 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9959 def errors @errors end |
#json_spec ⇒ String
The json content of the resource revision. Large specs should be sent
individually via the spec field to avoid hitting request size limits.
Corresponds to the JSON property jsonSpec
9965 9966 9967 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9965 def json_spec @json_spec end |
#replicas ⇒ Fixnum
The number of replicas that have successfully loaded this revision.
Corresponds to the JSON property replicas
9970 9971 9972 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9970 def replicas @replicas end |
#revision_id ⇒ String
The revision of the resource.
Corresponds to the JSON property revisionId
9975 9976 9977 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9975 def revision_id @revision_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9982 9983 9984 9985 9986 9987 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 9982 def update!(**args) @errors = args[:errors] if args.key?(:errors) @json_spec = args[:json_spec] if args.key?(:json_spec) @replicas = args[:replicas] if args.key?(:replicas) @revision_id = args[:revision_id] if args.key?(:revision_id) end |