Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1RoutingRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1RoutingRule

Returns a new instance of GoogleCloudApigeeV1RoutingRule.



10044
10045
10046
# File 'lib/google/apis/apigee_v1/classes.rb', line 10044

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#basepathString

URI path prefix used to route to the specified environment. May contain one or more wildcards. For example, path segments consisting of a single * character will match any string. Corresponds to the JSON property basepath

Returns:

  • (String)


9998
9999
10000
# File 'lib/google/apis/apigee_v1/classes.rb', line 9998

def basepath
  @basepath
end

#deployment_groupString

Name of a deployment group in an environment bound to the environment group in the following format: organizations/org/environment/env/deploymentGroups/ group`Only one of environment or deployment_group will be set. Corresponds to the JSON propertydeploymentGroup`

Returns:

  • (String)


10005
10006
10007
# File 'lib/google/apis/apigee_v1/classes.rb', line 10005

def deployment_group
  @deployment_group
end

#env_group_revisionFixnum

The env group config revision_id when this rule was added or last updated. This value is set when the rule is created and will only update if the the environment_id changes. It is used to determine if the runtime is up to date with respect to this rule. This field is omitted from the IngressConfig unless the GetDeployedIngressConfig API is called with view=FULL. Corresponds to the JSON property envGroupRevision

Returns:

  • (Fixnum)


10014
10015
10016
# File 'lib/google/apis/apigee_v1/classes.rb', line 10014

def env_group_revision
  @env_group_revision
end

#environmentString

Name of an environment bound to the environment group in the following format: organizations/org/environments/env`. Only one of environment or deployment_group will be set. Corresponds to the JSON propertyenvironment`

Returns:

  • (String)


10021
10022
10023
# File 'lib/google/apis/apigee_v1/classes.rb', line 10021

def environment
  @environment
end

#other_targetsArray<String>

Conflicting targets, which will be resource names specifying either deployment groups or environments. Corresponds to the JSON property otherTargets

Returns:

  • (Array<String>)


10027
10028
10029
# File 'lib/google/apis/apigee_v1/classes.rb', line 10027

def other_targets
  @other_targets
end

#receiverString

The resource name of the proxy revision that is receiving this basepath in the following format: organizations/org/apis/api/revisions/rev`. This field is omitted from the IngressConfig unless the GetDeployedIngressConfig API is called with view=FULL. Corresponds to the JSON propertyreceiver`

Returns:

  • (String)


10035
10036
10037
# File 'lib/google/apis/apigee_v1/classes.rb', line 10035

def receiver
  @receiver
end

#update_timeString

The unix timestamp when this rule was updated. This is updated whenever env_group_revision is updated. This field is omitted from the IngressConfig unless the GetDeployedIngressConfig API is called with view=FULL. Corresponds to the JSON property updateTime

Returns:

  • (String)


10042
10043
10044
# File 'lib/google/apis/apigee_v1/classes.rb', line 10042

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10049
10050
10051
10052
10053
10054
10055
10056
10057
# File 'lib/google/apis/apigee_v1/classes.rb', line 10049

def update!(**args)
  @basepath = args[:basepath] if args.key?(:basepath)
  @deployment_group = args[:deployment_group] if args.key?(:deployment_group)
  @env_group_revision = args[:env_group_revision] if args.key?(:env_group_revision)
  @environment = args[:environment] if args.key?(:environment)
  @other_targets = args[:other_targets] if args.key?(:other_targets)
  @receiver = args[:receiver] if args.key?(:receiver)
  @update_time = args[:update_time] if args.key?(:update_time)
end