Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeAddonsConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeAddonsConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
RuntimeAddonsConfig defines the runtime configurations for add-ons in an environment.
Instance Attribute Summary collapse
-
#analytics_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeAnalyticsConfig
Runtime configuration for the Analytics add-on.
-
#api_security_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeApiSecurityConfig
Runtime configuration for the API Security add-on.
-
#name ⇒ String
Name of the addons config in the format:
organizations/org/environments/env/addonsConfigCorresponds to the JSON propertyname. -
#revision_id ⇒ String
Revision number used by the runtime to detect config changes.
-
#uid ⇒ String
UID is to detect if config is recreated after deletion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1RuntimeAddonsConfig
constructor
A new instance of GoogleCloudApigeeV1RuntimeAddonsConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1RuntimeAddonsConfig
Returns a new instance of GoogleCloudApigeeV1RuntimeAddonsConfig.
10143 10144 10145 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10143 def initialize(**args) update!(**args) end |
Instance Attribute Details
#analytics_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeAnalyticsConfig
Runtime configuration for the Analytics add-on.
Corresponds to the JSON property analyticsConfig
10118 10119 10120 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10118 def analytics_config @analytics_config end |
#api_security_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeApiSecurityConfig
Runtime configuration for the API Security add-on.
Corresponds to the JSON property apiSecurityConfig
10123 10124 10125 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10123 def api_security_config @api_security_config end |
#name ⇒ String
Name of the addons config in the format: organizations/org/environments/
env/addonsConfig
Corresponds to the JSON property name
10129 10130 10131 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10129 def name @name end |
#revision_id ⇒ String
Revision number used by the runtime to detect config changes.
Corresponds to the JSON property revisionId
10134 10135 10136 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10134 def revision_id @revision_id end |
#uid ⇒ String
UID is to detect if config is recreated after deletion. The add-on config will
only be deleted when the environment itself gets deleted, thus it will always
be the same as the UID of EnvironmentConfig.
Corresponds to the JSON property uid
10141 10142 10143 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10141 def uid @uid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10148 10149 10150 10151 10152 10153 10154 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10148 def update!(**args) @analytics_config = args[:analytics_config] if args.key?(:analytics_config) @api_security_config = args[:api_security_config] if args.key?(:api_security_config) @name = args[:name] if args.key?(:name) @revision_id = args[:revision_id] if args.key?(:revision_id) @uid = args[:uid] if args.key?(:uid) end |