Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeAddonsConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

RuntimeAddonsConfig defines the runtime configurations for add-ons in an environment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1RuntimeAddonsConfig

Returns a new instance of GoogleCloudApigeeV1RuntimeAddonsConfig.



10094
10095
10096
# File 'lib/google/apis/apigee_v1/classes.rb', line 10094

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analytics_configGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeAnalyticsConfig

Runtime configuration for the Analytics add-on. Corresponds to the JSON property analyticsConfig



10069
10070
10071
# File 'lib/google/apis/apigee_v1/classes.rb', line 10069

def analytics_config
  @analytics_config
end

#api_security_configGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeApiSecurityConfig

Runtime configuration for the API Security add-on. Corresponds to the JSON property apiSecurityConfig



10074
10075
10076
# File 'lib/google/apis/apigee_v1/classes.rb', line 10074

def api_security_config
  @api_security_config
end

#nameString

Name of the addons config in the format: organizations/org/environments/ env/addonsConfig Corresponds to the JSON property name

Returns:

  • (String)


10080
10081
10082
# File 'lib/google/apis/apigee_v1/classes.rb', line 10080

def name
  @name
end

#revision_idString

Revision number used by the runtime to detect config changes. Corresponds to the JSON property revisionId

Returns:

  • (String)


10085
10086
10087
# File 'lib/google/apis/apigee_v1/classes.rb', line 10085

def revision_id
  @revision_id
end

#uidString

UID is to detect if config is recreated after deletion. The add-on config will only be deleted when the environment itself gets deleted, thus it will always be the same as the UID of EnvironmentConfig. Corresponds to the JSON property uid

Returns:

  • (String)


10092
10093
10094
# File 'lib/google/apis/apigee_v1/classes.rb', line 10092

def uid
  @uid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10099
10100
10101
10102
10103
10104
10105
# File 'lib/google/apis/apigee_v1/classes.rb', line 10099

def update!(**args)
  @analytics_config = args[:analytics_config] if args.key?(:analytics_config)
  @api_security_config = args[:api_security_config] if args.key?(:api_security_config)
  @name = args[:name] if args.key?(:name)
  @revision_id = args[:revision_id] if args.key?(:revision_id)
  @uid = args[:uid] if args.key?(:uid)
end