Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Runtime configuration for the organization. Response for GetRuntimeConfig.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1RuntimeConfig

Returns a new instance of GoogleCloudApigeeV1RuntimeConfig.



10184
10185
10186
# File 'lib/google/apis/apigee_v1/classes.rb', line 10184

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#analytics_bucketString

Cloud Storage bucket used for uploading Analytics records. Corresponds to the JSON property analyticsBucket

Returns:

  • (String)


10161
10162
10163
# File 'lib/google/apis/apigee_v1/classes.rb', line 10161

def analytics_bucket
  @analytics_bucket
end

#nameString

Name of the resource in the following format: organizations/org/ runtimeConfig. Corresponds to the JSON property name

Returns:

  • (String)


10167
10168
10169
# File 'lib/google/apis/apigee_v1/classes.rb', line 10167

def name
  @name
end

#tenant_project_idString

Output only. Tenant project ID associated with the Apigee organization. The tenant project is used to host Google-managed resources that are dedicated to this Apigee organization. Clients have limited access to resources within the tenant project used to support Apigee runtime instances. Access to the tenant project is managed using SetSyncAuthorization. It can be empty if the tenant project hasn't been created yet. Corresponds to the JSON property tenantProjectId

Returns:

  • (String)


10177
10178
10179
# File 'lib/google/apis/apigee_v1/classes.rb', line 10177

def tenant_project_id
  @tenant_project_id
end

#trace_bucketString

Cloud Storage bucket used for uploading Trace records. Corresponds to the JSON property traceBucket

Returns:

  • (String)


10182
10183
10184
# File 'lib/google/apis/apigee_v1/classes.rb', line 10182

def trace_bucket
  @trace_bucket
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10189
10190
10191
10192
10193
10194
# File 'lib/google/apis/apigee_v1/classes.rb', line 10189

def update!(**args)
  @analytics_bucket = args[:analytics_bucket] if args.key?(:analytics_bucket)
  @name = args[:name] if args.key?(:name)
  @tenant_project_id = args[:tenant_project_id] if args.key?(:tenant_project_id)
  @trace_bucket = args[:trace_bucket] if args.key?(:trace_bucket)
end