Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
NEXT ID: 13 RuntimeTraceConfig defines the configurations for distributed trace in an environment.
Instance Attribute Summary collapse
-
#endpoint ⇒ String
Endpoint of the exporter.
-
#exporter ⇒ String
Exporter that is used to view the distributed trace captured using OpenCensus.
-
#m_tls_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceConfigOtelMtlsConfig
Runtime-side view of
TraceConfig.OtelMtlsConfigfor the outbound OTel Collector mTLS connection. -
#name ⇒ String
Name of the trace config in the following format:
organizations/org/ environment/env/traceConfigCorresponds to the JSON propertyname. -
#open_telemetry_protocol_enabled ⇒ Boolean
(also: #open_telemetry_protocol_enabled?)
Optional.
-
#otel_collector_security_scheme ⇒ String
Optional.
-
#overrides ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceConfigOverride>
List of trace configuration overrides for spicific API proxies.
-
#revision_create_time ⇒ String
The timestamp that the revision was created or updated.
-
#revision_id ⇒ String
Revision number which can be used by the runtime to detect if the trace config has changed between two versions.
-
#sampling_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceSamplingConfig
NEXT ID: 3 RuntimeTraceSamplingConfig represents the detail settings of distributed tracing.
-
#span_semantics ⇒ String
Optional.
-
#trace_protocol ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1RuntimeTraceConfig
constructor
A new instance of GoogleCloudApigeeV1RuntimeTraceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1RuntimeTraceConfig
Returns a new instance of GoogleCloudApigeeV1RuntimeTraceConfig.
10464 10465 10466 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10464 def initialize(**args) update!(**args) end |
Instance Attribute Details
#endpoint ⇒ String
Endpoint of the exporter.
Corresponds to the JSON property endpoint
10381 10382 10383 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10381 def endpoint @endpoint end |
#exporter ⇒ String
Exporter that is used to view the distributed trace captured using OpenCensus.
An exporter sends traces to any backend that is capable of consuming them.
Recorded spans can be exported by registered exporters.
Corresponds to the JSON property exporter
10388 10389 10390 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10388 def exporter @exporter end |
#m_tls_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceConfigOtelMtlsConfig
Runtime-side view of TraceConfig.OtelMtlsConfig for the outbound OTel
Collector mTLS connection. Shape mirrors TlsInfoConfig (in this same file,
above) exactly. The oneof discriminates between a direct keystore reference
and a ref://-indirected reference; both are surfaced on the wire without
flattening. The referenced keystore must also appear in EnvironmentConfig.
keystores[] so the underlying alias bytes are available at runtime.
Referential integrity is enforced at trace-config update time: any PATCH that
references a keystore not already present is rejected in the same transaction
that would persist the update, and keystore/alias/reference deletion is
blocked while a trace-config references it.
Corresponds to the JSON property mTlsConfig
10402 10403 10404 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10402 def m_tls_config @m_tls_config end |
#name ⇒ String
Name of the trace config in the following format: organizations/org/
environment/env/traceConfig
Corresponds to the JSON property name
10408 10409 10410 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10408 def name @name end |
#open_telemetry_protocol_enabled ⇒ Boolean Also known as: open_telemetry_protocol_enabled?
Optional. If true, the runtime uses OpenTelemetry Protocol (OTLP) to send
trace data. Configuration Requirements (if open_telemetry_protocol_enabled
is true): - Allowed Exporters: CLOUD_TRACE or OPEN_TELEMETRY_COLLECTOR.
- If
ExporterisOPEN_TELEMETRY_COLLECTOR: -endpointrefers to a valid OTLP collector URL. - IfExporterisCLOUD_TRACE: -endpointrefers to a valid project ID Deprecated: Use trace_protocol instead. Corresponds to the JSON propertyopenTelemetryProtocolEnabled
10418 10419 10420 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10418 def open_telemetry_protocol_enabled @open_telemetry_protocol_enabled end |
#otel_collector_security_scheme ⇒ String
Optional. Security scheme for the outbound connection to the customer-owned
OpenTelemetry Collector. Only meaningful when exporter is
OPEN_TELEMETRY_COLLECTOR. Runtime consumers unaware of a value should treat
it as OTEL_COLLECTOR_SECURITY_SCHEME_UNSPECIFIED (== NONE).
Corresponds to the JSON property otelCollectorSecurityScheme
10427 10428 10429 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10427 def otel_collector_security_scheme @otel_collector_security_scheme end |
#overrides ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceConfigOverride>
List of trace configuration overrides for spicific API proxies.
Corresponds to the JSON property overrides
10432 10433 10434 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10432 def overrides @overrides end |
#revision_create_time ⇒ String
The timestamp that the revision was created or updated.
Corresponds to the JSON property revisionCreateTime
10437 10438 10439 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10437 def revision_create_time @revision_create_time end |
#revision_id ⇒ String
Revision number which can be used by the runtime to detect if the trace config
has changed between two versions.
Corresponds to the JSON property revisionId
10443 10444 10445 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10443 def revision_id @revision_id end |
#sampling_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceSamplingConfig
NEXT ID: 3 RuntimeTraceSamplingConfig represents the detail settings of
distributed tracing. Only the fields that are defined in the distributed trace
configuration can be overridden using the distribute trace configuration
override APIs.
Corresponds to the JSON property samplingConfig
10451 10452 10453 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10451 def sampling_config @sampling_config end |
#span_semantics ⇒ String
Optional. The span semantics to use. Configuration Requirements (if
span_semantics is OTEL): - trace_protocol must be OTLP.
Corresponds to the JSON property spanSemantics
10457 10458 10459 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10457 def span_semantics @span_semantics end |
#trace_protocol ⇒ String
Optional. The trace protocol to use.
Corresponds to the JSON property traceProtocol
10462 10463 10464 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10462 def trace_protocol @trace_protocol end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10469 10470 10471 10472 10473 10474 10475 10476 10477 10478 10479 10480 10481 10482 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10469 def update!(**args) @endpoint = args[:endpoint] if args.key?(:endpoint) @exporter = args[:exporter] if args.key?(:exporter) @m_tls_config = args[:m_tls_config] if args.key?(:m_tls_config) @name = args[:name] if args.key?(:name) @open_telemetry_protocol_enabled = args[:open_telemetry_protocol_enabled] if args.key?(:open_telemetry_protocol_enabled) @otel_collector_security_scheme = args[:otel_collector_security_scheme] if args.key?(:otel_collector_security_scheme) @overrides = args[:overrides] if args.key?(:overrides) @revision_create_time = args[:revision_create_time] if args.key?(:revision_create_time) @revision_id = args[:revision_id] if args.key?(:revision_id) @sampling_config = args[:sampling_config] if args.key?(:sampling_config) @span_semantics = args[:span_semantics] if args.key?(:span_semantics) @trace_protocol = args[:trace_protocol] if args.key?(:trace_protocol) end |