Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

NEXT ID: 10 RuntimeTraceConfig defines the configurations for distributed trace in an environment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1RuntimeTraceConfig

Returns a new instance of GoogleCloudApigeeV1RuntimeTraceConfig.



10365
10366
10367
# File 'lib/google/apis/apigee_v1/classes.rb', line 10365

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endpointString

Endpoint of the exporter. Corresponds to the JSON property endpoint

Returns:

  • (String)


10310
10311
10312
# File 'lib/google/apis/apigee_v1/classes.rb', line 10310

def endpoint
  @endpoint
end

#exporterString

Exporter that is used to view the distributed trace captured using OpenCensus. An exporter sends traces to any backend that is capable of consuming them. Recorded spans can be exported by registered exporters. Corresponds to the JSON property exporter

Returns:

  • (String)


10317
10318
10319
# File 'lib/google/apis/apigee_v1/classes.rb', line 10317

def exporter
  @exporter
end

#nameString

Name of the trace config in the following format: organizations/org/ environment/env/traceConfig Corresponds to the JSON property name

Returns:

  • (String)


10323
10324
10325
# File 'lib/google/apis/apigee_v1/classes.rb', line 10323

def name
  @name
end

#open_telemetry_protocol_enabledBoolean Also known as: open_telemetry_protocol_enabled?

Optional. If true, the runtime uses OpenTelemetry Protocol (OTLP) to send trace data. Configuration Requirements (if open_telemetry_protocol_enabled is true): - Allowed Exporters: CLOUD_TRACE or OPEN_TELEMETRY_COLLECTOR.

  • If Exporter is OPEN_TELEMETRY_COLLECTOR: - endpoint refers to a valid OTLP collector URL. - If Exporter is CLOUD_TRACE: - endpoint refers to a valid project ID Deprecated: Use trace_protocol instead. Corresponds to the JSON property openTelemetryProtocolEnabled

Returns:

  • (Boolean)


10333
10334
10335
# File 'lib/google/apis/apigee_v1/classes.rb', line 10333

def open_telemetry_protocol_enabled
  @open_telemetry_protocol_enabled
end

#overridesArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceConfigOverride>

List of trace configuration overrides for spicific API proxies. Corresponds to the JSON property overrides



10339
10340
10341
# File 'lib/google/apis/apigee_v1/classes.rb', line 10339

def overrides
  @overrides
end

#revision_create_timeString

The timestamp that the revision was created or updated. Corresponds to the JSON property revisionCreateTime

Returns:

  • (String)


10344
10345
10346
# File 'lib/google/apis/apigee_v1/classes.rb', line 10344

def revision_create_time
  @revision_create_time
end

#revision_idString

Revision number which can be used by the runtime to detect if the trace config has changed between two versions. Corresponds to the JSON property revisionId

Returns:

  • (String)


10350
10351
10352
# File 'lib/google/apis/apigee_v1/classes.rb', line 10350

def revision_id
  @revision_id
end

#sampling_configGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceSamplingConfig

NEXT ID: 3 RuntimeTraceSamplingConfig represents the detail settings of distributed tracing. Only the fields that are defined in the distributed trace configuration can be overridden using the distribute trace configuration override APIs. Corresponds to the JSON property samplingConfig



10358
10359
10360
# File 'lib/google/apis/apigee_v1/classes.rb', line 10358

def sampling_config
  @sampling_config
end

#trace_protocolString

Optional. The trace protocol to use. Corresponds to the JSON property traceProtocol

Returns:

  • (String)


10363
10364
10365
# File 'lib/google/apis/apigee_v1/classes.rb', line 10363

def trace_protocol
  @trace_protocol
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10370
10371
10372
10373
10374
10375
10376
10377
10378
10379
10380
# File 'lib/google/apis/apigee_v1/classes.rb', line 10370

def update!(**args)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @exporter = args[:exporter] if args.key?(:exporter)
  @name = args[:name] if args.key?(:name)
  @open_telemetry_protocol_enabled = args[:open_telemetry_protocol_enabled] if args.key?(:open_telemetry_protocol_enabled)
  @overrides = args[:overrides] if args.key?(:overrides)
  @revision_create_time = args[:revision_create_time] if args.key?(:revision_create_time)
  @revision_id = args[:revision_id] if args.key?(:revision_id)
  @sampling_config = args[:sampling_config] if args.key?(:sampling_config)
  @trace_protocol = args[:trace_protocol] if args.key?(:trace_protocol)
end