Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
NEXT ID: 10 RuntimeTraceConfig defines the configurations for distributed trace in an environment.
Instance Attribute Summary collapse
-
#endpoint ⇒ String
Endpoint of the exporter.
-
#exporter ⇒ String
Exporter that is used to view the distributed trace captured using OpenCensus.
-
#name ⇒ String
Name of the trace config in the following format:
organizations/org/ environment/env/traceConfigCorresponds to the JSON propertyname. -
#open_telemetry_protocol_enabled ⇒ Boolean
(also: #open_telemetry_protocol_enabled?)
Optional.
-
#overrides ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceConfigOverride>
List of trace configuration overrides for spicific API proxies.
-
#revision_create_time ⇒ String
The timestamp that the revision was created or updated.
-
#revision_id ⇒ String
Revision number which can be used by the runtime to detect if the trace config has changed between two versions.
-
#sampling_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceSamplingConfig
NEXT ID: 3 RuntimeTraceSamplingConfig represents the detail settings of distributed tracing.
-
#trace_protocol ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1RuntimeTraceConfig
constructor
A new instance of GoogleCloudApigeeV1RuntimeTraceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1RuntimeTraceConfig
Returns a new instance of GoogleCloudApigeeV1RuntimeTraceConfig.
10260 10261 10262 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10260 def initialize(**args) update!(**args) end |
Instance Attribute Details
#endpoint ⇒ String
Endpoint of the exporter.
Corresponds to the JSON property endpoint
10205 10206 10207 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10205 def endpoint @endpoint end |
#exporter ⇒ String
Exporter that is used to view the distributed trace captured using OpenCensus.
An exporter sends traces to any backend that is capable of consuming them.
Recorded spans can be exported by registered exporters.
Corresponds to the JSON property exporter
10212 10213 10214 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10212 def exporter @exporter end |
#name ⇒ String
Name of the trace config in the following format: organizations/org/
environment/env/traceConfig
Corresponds to the JSON property name
10218 10219 10220 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10218 def name @name end |
#open_telemetry_protocol_enabled ⇒ Boolean Also known as: open_telemetry_protocol_enabled?
Optional. If true, the runtime uses OpenTelemetry Protocol (OTLP) to send
trace data. Configuration Requirements (if open_telemetry_protocol_enabled
is true): - Allowed Exporters: CLOUD_TRACE or OPEN_TELEMETRY_COLLECTOR.
- If
ExporterisOPEN_TELEMETRY_COLLECTOR: -endpointrefers to a valid OTLP collector URL. - IfExporterisCLOUD_TRACE: -endpointrefers to a valid project ID Deprecated: Use trace_protocol instead. Corresponds to the JSON propertyopenTelemetryProtocolEnabled
10228 10229 10230 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10228 def open_telemetry_protocol_enabled @open_telemetry_protocol_enabled end |
#overrides ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceConfigOverride>
List of trace configuration overrides for spicific API proxies.
Corresponds to the JSON property overrides
10234 10235 10236 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10234 def overrides @overrides end |
#revision_create_time ⇒ String
The timestamp that the revision was created or updated.
Corresponds to the JSON property revisionCreateTime
10239 10240 10241 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10239 def revision_create_time @revision_create_time end |
#revision_id ⇒ String
Revision number which can be used by the runtime to detect if the trace config
has changed between two versions.
Corresponds to the JSON property revisionId
10245 10246 10247 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10245 def revision_id @revision_id end |
#sampling_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceSamplingConfig
NEXT ID: 3 RuntimeTraceSamplingConfig represents the detail settings of
distributed tracing. Only the fields that are defined in the distributed trace
configuration can be overridden using the distribute trace configuration
override APIs.
Corresponds to the JSON property samplingConfig
10253 10254 10255 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10253 def sampling_config @sampling_config end |
#trace_protocol ⇒ String
Optional. The trace protocol to use.
Corresponds to the JSON property traceProtocol
10258 10259 10260 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10258 def trace_protocol @trace_protocol end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10265 10266 10267 10268 10269 10270 10271 10272 10273 10274 10275 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10265 def update!(**args) @endpoint = args[:endpoint] if args.key?(:endpoint) @exporter = args[:exporter] if args.key?(:exporter) @name = args[:name] if args.key?(:name) @open_telemetry_protocol_enabled = args[:open_telemetry_protocol_enabled] if args.key?(:open_telemetry_protocol_enabled) @overrides = args[:overrides] if args.key?(:overrides) @revision_create_time = args[:revision_create_time] if args.key?(:revision_create_time) @revision_id = args[:revision_id] if args.key?(:revision_id) @sampling_config = args[:sampling_config] if args.key?(:sampling_config) @trace_protocol = args[:trace_protocol] if args.key?(:trace_protocol) end |