Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

NEXT ID: 9 RuntimeTraceConfig defines the configurations for distributed trace in an environment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1RuntimeTraceConfig

Returns a new instance of GoogleCloudApigeeV1RuntimeTraceConfig.



10305
10306
10307
# File 'lib/google/apis/apigee_v1/classes.rb', line 10305

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endpointString

Endpoint of the exporter. Corresponds to the JSON property endpoint

Returns:

  • (String)


10255
10256
10257
# File 'lib/google/apis/apigee_v1/classes.rb', line 10255

def endpoint
  @endpoint
end

#exporterString

Exporter that is used to view the distributed trace captured using OpenCensus. An exporter sends traces to any backend that is capable of consuming them. Recorded spans can be exported by registered exporters. Corresponds to the JSON property exporter

Returns:

  • (String)


10262
10263
10264
# File 'lib/google/apis/apigee_v1/classes.rb', line 10262

def exporter
  @exporter
end

#nameString

Name of the trace config in the following format: organizations/org/ environment/env/traceConfig Corresponds to the JSON property name

Returns:

  • (String)


10268
10269
10270
# File 'lib/google/apis/apigee_v1/classes.rb', line 10268

def name
  @name
end

#open_telemetry_protocol_enabledBoolean Also known as: open_telemetry_protocol_enabled?

If true, the runtime uses OpenTelemetry Protocol (OTLP) to send trace data. Configuration Requirements (if open_telemetry_protocol_enabled is true): - Allowed Exporters: CLOUD_TRACE or OPEN_TELEMETRY_COLLECTOR. - If Exporter is OPEN_TELEMETRY_COLLECTOR: - endpoint refers to a valid OTLP collector URL. - If Exporter is CLOUD_TRACE: - endpoint refers to a valid project ID Corresponds to the JSON property openTelemetryProtocolEnabled

Returns:

  • (Boolean)


10278
10279
10280
# File 'lib/google/apis/apigee_v1/classes.rb', line 10278

def open_telemetry_protocol_enabled
  @open_telemetry_protocol_enabled
end

#overridesArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceConfigOverride>

List of trace configuration overrides for spicific API proxies. Corresponds to the JSON property overrides



10284
10285
10286
# File 'lib/google/apis/apigee_v1/classes.rb', line 10284

def overrides
  @overrides
end

#revision_create_timeString

The timestamp that the revision was created or updated. Corresponds to the JSON property revisionCreateTime

Returns:

  • (String)


10289
10290
10291
# File 'lib/google/apis/apigee_v1/classes.rb', line 10289

def revision_create_time
  @revision_create_time
end

#revision_idString

Revision number which can be used by the runtime to detect if the trace config has changed between two versions. Corresponds to the JSON property revisionId

Returns:

  • (String)


10295
10296
10297
# File 'lib/google/apis/apigee_v1/classes.rb', line 10295

def revision_id
  @revision_id
end

#sampling_configGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceSamplingConfig

NEXT ID: 3 RuntimeTraceSamplingConfig represents the detail settings of distributed tracing. Only the fields that are defined in the distributed trace configuration can be overridden using the distribute trace configuration override APIs. Corresponds to the JSON property samplingConfig



10303
10304
10305
# File 'lib/google/apis/apigee_v1/classes.rb', line 10303

def sampling_config
  @sampling_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10310
10311
10312
10313
10314
10315
10316
10317
10318
10319
# File 'lib/google/apis/apigee_v1/classes.rb', line 10310

def update!(**args)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @exporter = args[:exporter] if args.key?(:exporter)
  @name = args[:name] if args.key?(:name)
  @open_telemetry_protocol_enabled = args[:open_telemetry_protocol_enabled] if args.key?(:open_telemetry_protocol_enabled)
  @overrides = args[:overrides] if args.key?(:overrides)
  @revision_create_time = args[:revision_create_time] if args.key?(:revision_create_time)
  @revision_id = args[:revision_id] if args.key?(:revision_id)
  @sampling_config = args[:sampling_config] if args.key?(:sampling_config)
end