Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceConfigOverride

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

NEXT ID: 10 Trace configuration override for a specific API proxy in an environment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1RuntimeTraceConfigOverride

Returns a new instance of GoogleCloudApigeeV1RuntimeTraceConfigOverride.



10454
10455
10456
# File 'lib/google/apis/apigee_v1/classes.rb', line 10454

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_proxyString

Name of the API proxy that will have its trace configuration overridden following format: organizations/org/apis/api` Corresponds to the JSON propertyapiProxy`

Returns:

  • (String)


10399
10400
10401
# File 'lib/google/apis/apigee_v1/classes.rb', line 10399

def api_proxy
  @api_proxy
end

#nameString

Name of the trace config override in the following format: organizations/org /environment/env/traceConfig/overrides/override` Corresponds to the JSON propertyname`

Returns:

  • (String)


10405
10406
10407
# File 'lib/google/apis/apigee_v1/classes.rb', line 10405

def name
  @name
end

#open_telemetry_protocol_enabledBoolean Also known as: open_telemetry_protocol_enabled?

Optional. If true, the runtime uses OpenTelemetry Protocol (OTLP) to send trace data. Configuration Requirements (if open_telemetry_protocol_enabled is true): - Allowed Exporters: CLOUD_TRACE or OPEN_TELEMETRY_COLLECTOR.

  • If Exporter is OPEN_TELEMETRY_COLLECTOR: - endpoint refers to a valid OTLP collector URL. - If Exporter is CLOUD_TRACE: - endpoint refers to a valid project ID Deprecated: Use trace_protocol instead. Corresponds to the JSON property openTelemetryProtocolEnabled

Returns:

  • (Boolean)


10415
10416
10417
# File 'lib/google/apis/apigee_v1/classes.rb', line 10415

def open_telemetry_protocol_enabled
  @open_telemetry_protocol_enabled
end

#revision_create_timeString

The timestamp that the revision was created or updated. Corresponds to the JSON property revisionCreateTime

Returns:

  • (String)


10421
10422
10423
# File 'lib/google/apis/apigee_v1/classes.rb', line 10421

def revision_create_time
  @revision_create_time
end

#revision_idString

Revision number which can be used by the runtime to detect if the trace config override has changed between two versions. Corresponds to the JSON property revisionId

Returns:

  • (String)


10427
10428
10429
# File 'lib/google/apis/apigee_v1/classes.rb', line 10427

def revision_id
  @revision_id
end

#sampling_configGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceSamplingConfig

NEXT ID: 3 RuntimeTraceSamplingConfig represents the detail settings of distributed tracing. Only the fields that are defined in the distributed trace configuration can be overridden using the distribute trace configuration override APIs. Corresponds to the JSON property samplingConfig



10435
10436
10437
# File 'lib/google/apis/apigee_v1/classes.rb', line 10435

def sampling_config
  @sampling_config
end

#span_semanticsString

Optional. The span semantics to use. Configuration Requirements (if span_semantics is OTEL): - trace_protocol must be OTLP. Corresponds to the JSON property spanSemantics

Returns:

  • (String)


10441
10442
10443
# File 'lib/google/apis/apigee_v1/classes.rb', line 10441

def span_semantics
  @span_semantics
end

#trace_protocolString

Optional. The trace protocol to use. Corresponds to the JSON property traceProtocol

Returns:

  • (String)


10446
10447
10448
# File 'lib/google/apis/apigee_v1/classes.rb', line 10446

def trace_protocol
  @trace_protocol
end

#uidString

Unique ID for the configuration override. The ID will only change if the override is deleted and recreated. Corresponds to name's "override" field. Corresponds to the JSON property uid

Returns:

  • (String)


10452
10453
10454
# File 'lib/google/apis/apigee_v1/classes.rb', line 10452

def uid
  @uid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
# File 'lib/google/apis/apigee_v1/classes.rb', line 10459

def update!(**args)
  @api_proxy = args[:api_proxy] if args.key?(:api_proxy)
  @name = args[:name] if args.key?(:name)
  @open_telemetry_protocol_enabled = args[:open_telemetry_protocol_enabled] if args.key?(:open_telemetry_protocol_enabled)
  @revision_create_time = args[:revision_create_time] if args.key?(:revision_create_time)
  @revision_id = args[:revision_id] if args.key?(:revision_id)
  @sampling_config = args[:sampling_config] if args.key?(:sampling_config)
  @span_semantics = args[:span_semantics] if args.key?(:span_semantics)
  @trace_protocol = args[:trace_protocol] if args.key?(:trace_protocol)
  @uid = args[:uid] if args.key?(:uid)
end