Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceConfigOverride
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceConfigOverride
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
NEXT ID: 9 Trace configuration override for a specific API proxy in an environment.
Instance Attribute Summary collapse
-
#api_proxy ⇒ String
Name of the API proxy that will have its trace configuration overridden following format:
organizations/org/apis/api`Corresponds to the JSON propertyapiProxy`. -
#name ⇒ String
Name of the trace config override in the following format:
organizations/org/environment/env/traceConfig/overrides/override`Corresponds to the JSON propertyname`. -
#open_telemetry_protocol_enabled ⇒ Boolean
(also: #open_telemetry_protocol_enabled?)
Optional.
-
#revision_create_time ⇒ String
The timestamp that the revision was created or updated.
-
#revision_id ⇒ String
Revision number which can be used by the runtime to detect if the trace config override has changed between two versions.
-
#sampling_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceSamplingConfig
NEXT ID: 3 RuntimeTraceSamplingConfig represents the detail settings of distributed tracing.
-
#trace_protocol ⇒ String
Optional.
-
#uid ⇒ String
Unique ID for the configuration override.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1RuntimeTraceConfigOverride
constructor
A new instance of GoogleCloudApigeeV1RuntimeTraceConfigOverride.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1RuntimeTraceConfigOverride
Returns a new instance of GoogleCloudApigeeV1RuntimeTraceConfigOverride.
10336 10337 10338 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10336 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_proxy ⇒ String
Name of the API proxy that will have its trace configuration overridden
following format: organizations/org/apis/api`
Corresponds to the JSON propertyapiProxy`
10287 10288 10289 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10287 def api_proxy @api_proxy end |
#name ⇒ String
Name of the trace config override in the following format: organizations/org
/environment/env/traceConfig/overrides/override`
Corresponds to the JSON propertyname`
10293 10294 10295 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10293 def name @name end |
#open_telemetry_protocol_enabled ⇒ Boolean Also known as: open_telemetry_protocol_enabled?
Optional. If true, the runtime uses OpenTelemetry Protocol (OTLP) to send
trace data. Configuration Requirements (if open_telemetry_protocol_enabled
is true): - Allowed Exporters: CLOUD_TRACE or OPEN_TELEMETRY_COLLECTOR.
- If
ExporterisOPEN_TELEMETRY_COLLECTOR: -endpointrefers to a valid OTLP collector URL. - IfExporterisCLOUD_TRACE: -endpointrefers to a valid project ID Deprecated: Use trace_protocol instead. Corresponds to the JSON propertyopenTelemetryProtocolEnabled
10303 10304 10305 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10303 def open_telemetry_protocol_enabled @open_telemetry_protocol_enabled end |
#revision_create_time ⇒ String
The timestamp that the revision was created or updated.
Corresponds to the JSON property revisionCreateTime
10309 10310 10311 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10309 def revision_create_time @revision_create_time end |
#revision_id ⇒ String
Revision number which can be used by the runtime to detect if the trace config
override has changed between two versions.
Corresponds to the JSON property revisionId
10315 10316 10317 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10315 def revision_id @revision_id end |
#sampling_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceSamplingConfig
NEXT ID: 3 RuntimeTraceSamplingConfig represents the detail settings of
distributed tracing. Only the fields that are defined in the distributed trace
configuration can be overridden using the distribute trace configuration
override APIs.
Corresponds to the JSON property samplingConfig
10323 10324 10325 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10323 def sampling_config @sampling_config end |
#trace_protocol ⇒ String
Optional. The trace protocol to use.
Corresponds to the JSON property traceProtocol
10328 10329 10330 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10328 def trace_protocol @trace_protocol end |
#uid ⇒ String
Unique ID for the configuration override. The ID will only change if the
override is deleted and recreated. Corresponds to name's "override" field.
Corresponds to the JSON property uid
10334 10335 10336 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10334 def uid @uid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10341 10342 10343 10344 10345 10346 10347 10348 10349 10350 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10341 def update!(**args) @api_proxy = args[:api_proxy] if args.key?(:api_proxy) @name = args[:name] if args.key?(:name) @open_telemetry_protocol_enabled = args[:open_telemetry_protocol_enabled] if args.key?(:open_telemetry_protocol_enabled) @revision_create_time = args[:revision_create_time] if args.key?(:revision_create_time) @revision_id = args[:revision_id] if args.key?(:revision_id) @sampling_config = args[:sampling_config] if args.key?(:sampling_config) @trace_protocol = args[:trace_protocol] if args.key?(:trace_protocol) @uid = args[:uid] if args.key?(:uid) end |