Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceConfigOverride

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

NEXT ID: 8 Trace configuration override for a specific API proxy in an environment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1RuntimeTraceConfigOverride

Returns a new instance of GoogleCloudApigeeV1RuntimeTraceConfigOverride.



10375
10376
10377
# File 'lib/google/apis/apigee_v1/classes.rb', line 10375

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_proxyString

Name of the API proxy that will have its trace configuration overridden following format: organizations/org/apis/api` Corresponds to the JSON propertyapiProxy`

Returns:

  • (String)


10331
10332
10333
# File 'lib/google/apis/apigee_v1/classes.rb', line 10331

def api_proxy
  @api_proxy
end

#nameString

Name of the trace config override in the following format: organizations/org /environment/env/traceConfig/overrides/override` Corresponds to the JSON propertyname`

Returns:

  • (String)


10337
10338
10339
# File 'lib/google/apis/apigee_v1/classes.rb', line 10337

def name
  @name
end

#open_telemetry_protocol_enabledBoolean Also known as: open_telemetry_protocol_enabled?

If true, the runtime uses OpenTelemetry Protocol (OTLP) to send trace data. Configuration Requirements (if open_telemetry_protocol_enabled is true): - Allowed Exporters: CLOUD_TRACE or OPEN_TELEMETRY_COLLECTOR. - If Exporter is OPEN_TELEMETRY_COLLECTOR: - endpoint refers to a valid OTLP collector URL. - If Exporter is CLOUD_TRACE: - endpoint refers to a valid project ID Corresponds to the JSON property openTelemetryProtocolEnabled

Returns:

  • (Boolean)


10347
10348
10349
# File 'lib/google/apis/apigee_v1/classes.rb', line 10347

def open_telemetry_protocol_enabled
  @open_telemetry_protocol_enabled
end

#revision_create_timeString

The timestamp that the revision was created or updated. Corresponds to the JSON property revisionCreateTime

Returns:

  • (String)


10353
10354
10355
# File 'lib/google/apis/apigee_v1/classes.rb', line 10353

def revision_create_time
  @revision_create_time
end

#revision_idString

Revision number which can be used by the runtime to detect if the trace config override has changed between two versions. Corresponds to the JSON property revisionId

Returns:

  • (String)


10359
10360
10361
# File 'lib/google/apis/apigee_v1/classes.rb', line 10359

def revision_id
  @revision_id
end

#sampling_configGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceSamplingConfig

NEXT ID: 3 RuntimeTraceSamplingConfig represents the detail settings of distributed tracing. Only the fields that are defined in the distributed trace configuration can be overridden using the distribute trace configuration override APIs. Corresponds to the JSON property samplingConfig



10367
10368
10369
# File 'lib/google/apis/apigee_v1/classes.rb', line 10367

def sampling_config
  @sampling_config
end

#uidString

Unique ID for the configuration override. The ID will only change if the override is deleted and recreated. Corresponds to name's "override" field. Corresponds to the JSON property uid

Returns:

  • (String)


10373
10374
10375
# File 'lib/google/apis/apigee_v1/classes.rb', line 10373

def uid
  @uid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10380
10381
10382
10383
10384
10385
10386
10387
10388
# File 'lib/google/apis/apigee_v1/classes.rb', line 10380

def update!(**args)
  @api_proxy = args[:api_proxy] if args.key?(:api_proxy)
  @name = args[:name] if args.key?(:name)
  @open_telemetry_protocol_enabled = args[:open_telemetry_protocol_enabled] if args.key?(:open_telemetry_protocol_enabled)
  @revision_create_time = args[:revision_create_time] if args.key?(:revision_create_time)
  @revision_id = args[:revision_id] if args.key?(:revision_id)
  @sampling_config = args[:sampling_config] if args.key?(:sampling_config)
  @uid = args[:uid] if args.key?(:uid)
end