Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceConfigOverride
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceConfigOverride
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
NEXT ID: 7 Trace configuration override for a specific API proxy in an environment.
Instance Attribute Summary collapse
-
#api_proxy ⇒ String
Name of the API proxy that will have its trace configuration overridden following format:
organizations/org/apis/api`Corresponds to the JSON propertyapiProxy`. -
#name ⇒ String
Name of the trace config override in the following format:
organizations/org/environment/env/traceConfig/overrides/override`Corresponds to the JSON propertyname`. -
#revision_create_time ⇒ String
The timestamp that the revision was created or updated.
-
#revision_id ⇒ String
Revision number which can be used by the runtime to detect if the trace config override has changed between two versions.
-
#sampling_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceSamplingConfig
NEXT ID: 3 RuntimeTraceSamplingConfig represents the detail settings of distributed tracing.
-
#uid ⇒ String
Unique ID for the configuration override.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1RuntimeTraceConfigOverride
constructor
A new instance of GoogleCloudApigeeV1RuntimeTraceConfigOverride.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1RuntimeTraceConfigOverride
Returns a new instance of GoogleCloudApigeeV1RuntimeTraceConfigOverride.
10303 10304 10305 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10303 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_proxy ⇒ String
Name of the API proxy that will have its trace configuration overridden
following format: organizations/org/apis/api`
Corresponds to the JSON propertyapiProxy`
10270 10271 10272 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10270 def api_proxy @api_proxy end |
#name ⇒ String
Name of the trace config override in the following format: organizations/org
/environment/env/traceConfig/overrides/override`
Corresponds to the JSON propertyname`
10276 10277 10278 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10276 def name @name end |
#revision_create_time ⇒ String
The timestamp that the revision was created or updated.
Corresponds to the JSON property revisionCreateTime
10281 10282 10283 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10281 def revision_create_time @revision_create_time end |
#revision_id ⇒ String
Revision number which can be used by the runtime to detect if the trace config
override has changed between two versions.
Corresponds to the JSON property revisionId
10287 10288 10289 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10287 def revision_id @revision_id end |
#sampling_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceSamplingConfig
NEXT ID: 3 RuntimeTraceSamplingConfig represents the detail settings of
distributed tracing. Only the fields that are defined in the distributed trace
configuration can be overridden using the distribute trace configuration
override APIs.
Corresponds to the JSON property samplingConfig
10295 10296 10297 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10295 def sampling_config @sampling_config end |
#uid ⇒ String
Unique ID for the configuration override. The ID will only change if the
override is deleted and recreated. Corresponds to name's "override" field.
Corresponds to the JSON property uid
10301 10302 10303 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10301 def uid @uid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10308 10309 10310 10311 10312 10313 10314 10315 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10308 def update!(**args) @api_proxy = args[:api_proxy] if args.key?(:api_proxy) @name = args[:name] if args.key?(:name) @revision_create_time = args[:revision_create_time] if args.key?(:revision_create_time) @revision_id = args[:revision_id] if args.key?(:revision_id) @sampling_config = args[:sampling_config] if args.key?(:sampling_config) @uid = args[:uid] if args.key?(:uid) end |