Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceSamplingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

NEXT ID: 3 RuntimeTraceSamplingConfig represents the detail settings of distributed tracing. Only the fields that are defined in the distributed trace configuration can be overridden using the distribute trace configuration override APIs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1RuntimeTraceSamplingConfig

Returns a new instance of GoogleCloudApigeeV1RuntimeTraceSamplingConfig.



10476
10477
10478
# File 'lib/google/apis/apigee_v1/classes.rb', line 10476

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#samplerString

Sampler of distributed tracing. OFF is the default value. Corresponds to the JSON property sampler

Returns:

  • (String)


10468
10469
10470
# File 'lib/google/apis/apigee_v1/classes.rb', line 10468

def sampler
  @sampler
end

#sampling_rateFloat

Field sampling rate. This value is only applicable when using the PROBABILITY sampler. The supported values are > 0 and <= 0.5. Corresponds to the JSON property samplingRate

Returns:

  • (Float)


10474
10475
10476
# File 'lib/google/apis/apigee_v1/classes.rb', line 10474

def sampling_rate
  @sampling_rate
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10481
10482
10483
10484
# File 'lib/google/apis/apigee_v1/classes.rb', line 10481

def update!(**args)
  @sampler = args[:sampler] if args.key?(:sampler)
  @sampling_rate = args[:sampling_rate] if args.key?(:sampling_rate)
end