Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceSamplingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

NEXT ID: 3 RuntimeTraceSamplingConfig represents the detail settings of distributed tracing. Only the fields that are defined in the distributed trace configuration can be overridden using the distribute trace configuration override APIs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1RuntimeTraceSamplingConfig

Returns a new instance of GoogleCloudApigeeV1RuntimeTraceSamplingConfig.



10380
10381
10382
# File 'lib/google/apis/apigee_v1/classes.rb', line 10380

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#samplerString

Sampler of distributed tracing. OFF is the default value. Corresponds to the JSON property sampler

Returns:

  • (String)


10372
10373
10374
# File 'lib/google/apis/apigee_v1/classes.rb', line 10372

def sampler
  @sampler
end

#sampling_rateFloat

Field sampling rate. This value is only applicable when using the PROBABILITY sampler. The supported values are > 0 and <= 0.5. Corresponds to the JSON property samplingRate

Returns:

  • (Float)


10378
10379
10380
# File 'lib/google/apis/apigee_v1/classes.rb', line 10378

def sampling_rate
  @sampling_rate
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10385
10386
10387
10388
# File 'lib/google/apis/apigee_v1/classes.rb', line 10385

def update!(**args)
  @sampler = args[:sampler] if args.key?(:sampler)
  @sampling_rate = args[:sampling_rate] if args.key?(:sampling_rate)
end