Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceSamplingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

NEXT ID: 3 RuntimeTraceSamplingConfig represents the detail settings of distributed tracing. Only the fields that are defined in the distributed trace configuration can be overridden using the distribute trace configuration override APIs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1RuntimeTraceSamplingConfig

Returns a new instance of GoogleCloudApigeeV1RuntimeTraceSamplingConfig.



10371
10372
10373
# File 'lib/google/apis/apigee_v1/classes.rb', line 10371

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#samplerString

Sampler of distributed tracing. OFF is the default value. Corresponds to the JSON property sampler

Returns:

  • (String)


10363
10364
10365
# File 'lib/google/apis/apigee_v1/classes.rb', line 10363

def sampler
  @sampler
end

#sampling_rateFloat

Field sampling rate. This value is only applicable when using the PROBABILITY sampler. The supported values are > 0 and <= 0.5. Corresponds to the JSON property samplingRate

Returns:

  • (Float)


10369
10370
10371
# File 'lib/google/apis/apigee_v1/classes.rb', line 10369

def sampling_rate
  @sampling_rate
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10376
10377
10378
10379
# File 'lib/google/apis/apigee_v1/classes.rb', line 10376

def update!(**args)
  @sampler = args[:sampler] if args.key?(:sampler)
  @sampling_rate = args[:sampling_rate] if args.key?(:sampling_rate)
end