Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceSamplingConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1RuntimeTraceSamplingConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
NEXT ID: 3 RuntimeTraceSamplingConfig represents the detail settings of distributed tracing. Only the fields that are defined in the distributed trace configuration can be overridden using the distribute trace configuration override APIs.
Instance Attribute Summary collapse
-
#sampler ⇒ String
Sampler of distributed tracing.
-
#sampling_rate ⇒ Float
Field sampling rate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1RuntimeTraceSamplingConfig
constructor
A new instance of GoogleCloudApigeeV1RuntimeTraceSamplingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1RuntimeTraceSamplingConfig
Returns a new instance of GoogleCloudApigeeV1RuntimeTraceSamplingConfig.
10409 10410 10411 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10409 def initialize(**args) update!(**args) end |
Instance Attribute Details
#sampler ⇒ String
Sampler of distributed tracing. OFF is the default value.
Corresponds to the JSON property sampler
10401 10402 10403 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10401 def sampler @sampler end |
#sampling_rate ⇒ Float
Field sampling rate. This value is only applicable when using the PROBABILITY
sampler. The supported values are > 0 and <= 0.5.
Corresponds to the JSON property samplingRate
10407 10408 10409 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10407 def sampling_rate @sampling_rate end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10414 10415 10416 10417 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10414 def update!(**args) @sampler = args[:sampler] if args.key?(:sampler) @sampling_rate = args[:sampling_rate] if args.key?(:sampling_rate) end |