Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Schema

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Response for Schema call

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1Schema

Returns a new instance of GoogleCloudApigeeV1Schema.



10422
10423
10424
# File 'lib/google/apis/apigee_v1/classes.rb', line 10422

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimensionsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SchemaSchemaElement>

List of schema fields grouped as dimensions. Corresponds to the JSON property dimensions



10408
10409
10410
# File 'lib/google/apis/apigee_v1/classes.rb', line 10408

def dimensions
  @dimensions
end

#metaArray<String>

Additional metadata associated with schema. This is a legacy field and usually consists of an empty array of strings. Corresponds to the JSON property meta

Returns:

  • (Array<String>)


10414
10415
10416
# File 'lib/google/apis/apigee_v1/classes.rb', line 10414

def meta
  @meta
end

#metricsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SchemaSchemaElement>

List of schema fields grouped as dimensions that can be used with an aggregate function such as sum, avg, min, and max. Corresponds to the JSON property metrics



10420
10421
10422
# File 'lib/google/apis/apigee_v1/classes.rb', line 10420

def metrics
  @metrics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10427
10428
10429
10430
10431
# File 'lib/google/apis/apigee_v1/classes.rb', line 10427

def update!(**args)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @meta = args[:meta] if args.key?(:meta)
  @metrics = args[:metrics] if args.key?(:metrics)
end