Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SchemaSchemaProperty

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Properties for the schema field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SchemaSchemaProperty

Returns a new instance of GoogleCloudApigeeV1SchemaSchemaProperty.



10480
10481
10482
# File 'lib/google/apis/apigee_v1/classes.rb', line 10480

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Time the field was created in RFC3339 string form. For example: 2016-02-26T10: 23:09.592Z. Corresponds to the JSON property createTime

Returns:

  • (String)


10467
10468
10469
# File 'lib/google/apis/apigee_v1/classes.rb', line 10467

def create_time
  @create_time
end

#customString

Flag that specifies whether the field is standard in the dataset or a custom field created by the customer. true indicates that it is a custom field. Corresponds to the JSON property custom

Returns:

  • (String)


10473
10474
10475
# File 'lib/google/apis/apigee_v1/classes.rb', line 10473

def custom
  @custom
end

#typeString

Data type of the field. Corresponds to the JSON property type

Returns:

  • (String)


10478
10479
10480
# File 'lib/google/apis/apigee_v1/classes.rb', line 10478

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10485
10486
10487
10488
10489
# File 'lib/google/apis/apigee_v1/classes.rb', line 10485

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @custom = args[:custom] if args.key?(:custom)
  @type = args[:type] if args.key?(:type)
end