Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SchemaSchemaProperty
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1SchemaSchemaProperty
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Properties for the schema field.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Time the field was created in RFC3339 string form.
-
#custom ⇒ String
Flag that specifies whether the field is standard in the dataset or a custom field created by the customer.
-
#type ⇒ String
Data type of the field.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1SchemaSchemaProperty
constructor
A new instance of GoogleCloudApigeeV1SchemaSchemaProperty.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1SchemaSchemaProperty
Returns a new instance of GoogleCloudApigeeV1SchemaSchemaProperty.
10445 10446 10447 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10445 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Time the field was created in RFC3339 string form. For example: 2016-02-26T10:
23:09.592Z.
Corresponds to the JSON property createTime
10432 10433 10434 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10432 def create_time @create_time end |
#custom ⇒ String
Flag that specifies whether the field is standard in the dataset or a custom
field created by the customer. true indicates that it is a custom field.
Corresponds to the JSON property custom
10438 10439 10440 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10438 def custom @custom end |
#type ⇒ String
Data type of the field.
Corresponds to the JSON property type
10443 10444 10445 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10443 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10450 10451 10452 10453 10454 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10450 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @custom = args[:custom] if args.key?(:custom) @type = args[:type] if args.key?(:type) end |