Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Score

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Represents Security Score.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1Score

Returns a new instance of GoogleCloudApigeeV1Score.



10619
10620
10621
# File 'lib/google/apis/apigee_v1/classes.rb', line 10619

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#componentGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponent

Component is an individual security element that is scored. Corresponds to the JSON property component



10604
10605
10606
# File 'lib/google/apis/apigee_v1/classes.rb', line 10604

def component
  @component
end

#subcomponentsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponent>

List of all the drilldown score components. Corresponds to the JSON property subcomponents



10609
10610
10611
# File 'lib/google/apis/apigee_v1/classes.rb', line 10609

def subcomponents
  @subcomponents
end

#time_rangeGoogle::Apis::ApigeeV1::GoogleTypeInterval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property timeRange



10617
10618
10619
# File 'lib/google/apis/apigee_v1/classes.rb', line 10617

def time_range
  @time_range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10624
10625
10626
10627
10628
# File 'lib/google/apis/apigee_v1/classes.rb', line 10624

def update!(**args)
  @component = args[:component] if args.key?(:component)
  @subcomponents = args[:subcomponents] if args.key?(:subcomponents)
  @time_range = args[:time_range] if args.key?(:time_range)
end