Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1Score

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Represents Security Score.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1Score

Returns a new instance of GoogleCloudApigeeV1Score.



10514
10515
10516
# File 'lib/google/apis/apigee_v1/classes.rb', line 10514

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#componentGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponent

Component is an individual security element that is scored. Corresponds to the JSON property component



10499
10500
10501
# File 'lib/google/apis/apigee_v1/classes.rb', line 10499

def component
  @component
end

#subcomponentsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponent>

List of all the drilldown score components. Corresponds to the JSON property subcomponents



10504
10505
10506
# File 'lib/google/apis/apigee_v1/classes.rb', line 10504

def subcomponents
  @subcomponents
end

#time_rangeGoogle::Apis::ApigeeV1::GoogleTypeInterval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property timeRange



10512
10513
10514
# File 'lib/google/apis/apigee_v1/classes.rb', line 10512

def time_range
  @time_range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10519
10520
10521
10522
10523
# File 'lib/google/apis/apigee_v1/classes.rb', line 10519

def update!(**args)
  @component = args[:component] if args.key?(:component)
  @subcomponents = args[:subcomponents] if args.key?(:subcomponents)
  @time_range = args[:time_range] if args.key?(:time_range)
end