Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Component is an individual security element that is scored.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1ScoreComponent

Returns a new instance of GoogleCloudApigeeV1ScoreComponent.



10562
10563
10564
# File 'lib/google/apis/apigee_v1/classes.rb', line 10562

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#calculate_timeString

Time when score was calculated. Corresponds to the JSON property calculateTime

Returns:

  • (String)


10533
10534
10535
# File 'lib/google/apis/apigee_v1/classes.rb', line 10533

def calculate_time
  @calculate_time
end

#data_capture_timeString

Time in the requested time period when data was last captured to compute the score. Corresponds to the JSON property dataCaptureTime

Returns:

  • (String)


10539
10540
10541
# File 'lib/google/apis/apigee_v1/classes.rb', line 10539

def data_capture_time
  @data_capture_time
end

#drilldown_pathsArray<String>

List of paths for next components. Corresponds to the JSON property drilldownPaths

Returns:

  • (Array<String>)


10544
10545
10546
# File 'lib/google/apis/apigee_v1/classes.rb', line 10544

def drilldown_paths
  @drilldown_paths
end

#recommendationsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponentRecommendation>

List of recommendations to improve API security. Corresponds to the JSON property recommendations



10549
10550
10551
# File 'lib/google/apis/apigee_v1/classes.rb', line 10549

def recommendations
  @recommendations
end

#scoreFixnum

Score for the component. Corresponds to the JSON property score

Returns:

  • (Fixnum)


10554
10555
10556
# File 'lib/google/apis/apigee_v1/classes.rb', line 10554

def score
  @score
end

#score_pathString

Path of the component. Example: /org@myorg/envgroup@myenvgroup/proxies/proxy@ myproxy Corresponds to the JSON property scorePath

Returns:

  • (String)


10560
10561
10562
# File 'lib/google/apis/apigee_v1/classes.rb', line 10560

def score_path
  @score_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10567
10568
10569
10570
10571
10572
10573
10574
# File 'lib/google/apis/apigee_v1/classes.rb', line 10567

def update!(**args)
  @calculate_time = args[:calculate_time] if args.key?(:calculate_time)
  @data_capture_time = args[:data_capture_time] if args.key?(:data_capture_time)
  @drilldown_paths = args[:drilldown_paths] if args.key?(:drilldown_paths)
  @recommendations = args[:recommendations] if args.key?(:recommendations)
  @score = args[:score] if args.key?(:score)
  @score_path = args[:score_path] if args.key?(:score_path)
end