Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Component is an individual security element that is scored.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1ScoreComponent

Returns a new instance of GoogleCloudApigeeV1ScoreComponent.



10527
10528
10529
# File 'lib/google/apis/apigee_v1/classes.rb', line 10527

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#calculate_timeString

Time when score was calculated. Corresponds to the JSON property calculateTime

Returns:

  • (String)


10498
10499
10500
# File 'lib/google/apis/apigee_v1/classes.rb', line 10498

def calculate_time
  @calculate_time
end

#data_capture_timeString

Time in the requested time period when data was last captured to compute the score. Corresponds to the JSON property dataCaptureTime

Returns:

  • (String)


10504
10505
10506
# File 'lib/google/apis/apigee_v1/classes.rb', line 10504

def data_capture_time
  @data_capture_time
end

#drilldown_pathsArray<String>

List of paths for next components. Corresponds to the JSON property drilldownPaths

Returns:

  • (Array<String>)


10509
10510
10511
# File 'lib/google/apis/apigee_v1/classes.rb', line 10509

def drilldown_paths
  @drilldown_paths
end

#recommendationsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponentRecommendation>

List of recommendations to improve API security. Corresponds to the JSON property recommendations



10514
10515
10516
# File 'lib/google/apis/apigee_v1/classes.rb', line 10514

def recommendations
  @recommendations
end

#scoreFixnum

Score for the component. Corresponds to the JSON property score

Returns:

  • (Fixnum)


10519
10520
10521
# File 'lib/google/apis/apigee_v1/classes.rb', line 10519

def score
  @score
end

#score_pathString

Path of the component. Example: /org@myorg/envgroup@myenvgroup/proxies/proxy@ myproxy Corresponds to the JSON property scorePath

Returns:

  • (String)


10525
10526
10527
# File 'lib/google/apis/apigee_v1/classes.rb', line 10525

def score_path
  @score_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10532
10533
10534
10535
10536
10537
10538
10539
# File 'lib/google/apis/apigee_v1/classes.rb', line 10532

def update!(**args)
  @calculate_time = args[:calculate_time] if args.key?(:calculate_time)
  @data_capture_time = args[:data_capture_time] if args.key?(:data_capture_time)
  @drilldown_paths = args[:drilldown_paths] if args.key?(:drilldown_paths)
  @recommendations = args[:recommendations] if args.key?(:recommendations)
  @score = args[:score] if args.key?(:score)
  @score_path = args[:score_path] if args.key?(:score_path)
end