Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponent
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponent
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Component is an individual security element that is scored.
Instance Attribute Summary collapse
-
#calculate_time ⇒ String
Time when score was calculated.
-
#data_capture_time ⇒ String
Time in the requested time period when data was last captured to compute the score.
-
#drilldown_paths ⇒ Array<String>
List of paths for next components.
-
#recommendations ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponentRecommendation>
List of recommendations to improve API security.
-
#score ⇒ Fixnum
Score for the component.
-
#score_path ⇒ String
Path of the component.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1ScoreComponent
constructor
A new instance of GoogleCloudApigeeV1ScoreComponent.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1ScoreComponent
Returns a new instance of GoogleCloudApigeeV1ScoreComponent.
10527 10528 10529 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10527 def initialize(**args) update!(**args) end |
Instance Attribute Details
#calculate_time ⇒ String
Time when score was calculated.
Corresponds to the JSON property calculateTime
10498 10499 10500 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10498 def calculate_time @calculate_time end |
#data_capture_time ⇒ String
Time in the requested time period when data was last captured to compute the
score.
Corresponds to the JSON property dataCaptureTime
10504 10505 10506 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10504 def data_capture_time @data_capture_time end |
#drilldown_paths ⇒ Array<String>
List of paths for next components.
Corresponds to the JSON property drilldownPaths
10509 10510 10511 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10509 def drilldown_paths @drilldown_paths end |
#recommendations ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponentRecommendation>
List of recommendations to improve API security.
Corresponds to the JSON property recommendations
10514 10515 10516 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10514 def recommendations @recommendations end |
#score ⇒ Fixnum
Score for the component.
Corresponds to the JSON property score
10519 10520 10521 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10519 def score @score end |
#score_path ⇒ String
Path of the component. Example: /org@myorg/envgroup@myenvgroup/proxies/proxy@
myproxy
Corresponds to the JSON property scorePath
10525 10526 10527 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10525 def score_path @score_path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10532 10533 10534 10535 10536 10537 10538 10539 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10532 def update!(**args) @calculate_time = args[:calculate_time] if args.key?(:calculate_time) @data_capture_time = args[:data_capture_time] if args.key?(:data_capture_time) @drilldown_paths = args[:drilldown_paths] if args.key?(:drilldown_paths) @recommendations = args[:recommendations] if args.key?(:recommendations) @score = args[:score] if args.key?(:score) @score_path = args[:score_path] if args.key?(:score_path) end |