Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponentRecommendation
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponentRecommendation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Recommendation based on security concerns and score.
Instance Attribute Summary collapse
-
#actions ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponentRecommendationAction>
Actions for the recommendation to improve the security score.
-
#description ⇒ String
Description of the recommendation.
-
#impact ⇒ Fixnum
Potential impact of this recommendation on the overall score.
-
#title ⇒ String
Title represents recommendation title.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1ScoreComponentRecommendation
constructor
A new instance of GoogleCloudApigeeV1ScoreComponentRecommendation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1ScoreComponentRecommendation
Returns a new instance of GoogleCloudApigeeV1ScoreComponentRecommendation.
10867 10868 10869 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10867 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actions ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponentRecommendationAction>
Actions for the recommendation to improve the security score.
Corresponds to the JSON property actions
10849 10850 10851 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10849 def actions @actions end |
#description ⇒ String
Description of the recommendation.
Corresponds to the JSON property description
10854 10855 10856 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10854 def description @description end |
#impact ⇒ Fixnum
Potential impact of this recommendation on the overall score. This denotes how
important this recommendation is to improve the score.
Corresponds to the JSON property impact
10860 10861 10862 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10860 def impact @impact end |
#title ⇒ String
Title represents recommendation title.
Corresponds to the JSON property title
10865 10866 10867 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10865 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10872 10873 10874 10875 10876 10877 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10872 def update!(**args) @actions = args[:actions] if args.key?(:actions) @description = args[:description] if args.key?(:description) @impact = args[:impact] if args.key?(:impact) @title = args[:title] if args.key?(:title) end |