Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponentRecommendation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Recommendation based on security concerns and score.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1ScoreComponentRecommendation

Returns a new instance of GoogleCloudApigeeV1ScoreComponentRecommendation.



10707
10708
10709
# File 'lib/google/apis/apigee_v1/classes.rb', line 10707

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponentRecommendationAction>

Actions for the recommendation to improve the security score. Corresponds to the JSON property actions



10689
10690
10691
# File 'lib/google/apis/apigee_v1/classes.rb', line 10689

def actions
  @actions
end

#descriptionString

Description of the recommendation. Corresponds to the JSON property description

Returns:

  • (String)


10694
10695
10696
# File 'lib/google/apis/apigee_v1/classes.rb', line 10694

def description
  @description
end

#impactFixnum

Potential impact of this recommendation on the overall score. This denotes how important this recommendation is to improve the score. Corresponds to the JSON property impact

Returns:

  • (Fixnum)


10700
10701
10702
# File 'lib/google/apis/apigee_v1/classes.rb', line 10700

def impact
  @impact
end

#titleString

Title represents recommendation title. Corresponds to the JSON property title

Returns:

  • (String)


10705
10706
10707
# File 'lib/google/apis/apigee_v1/classes.rb', line 10705

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10712
10713
10714
10715
10716
10717
# File 'lib/google/apis/apigee_v1/classes.rb', line 10712

def update!(**args)
  @actions = args[:actions] if args.key?(:actions)
  @description = args[:description] if args.key?(:description)
  @impact = args[:impact] if args.key?(:impact)
  @title = args[:title] if args.key?(:title)
end