Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponentRecommendation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Recommendation based on security concerns and score.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1ScoreComponentRecommendation

Returns a new instance of GoogleCloudApigeeV1ScoreComponentRecommendation.



10611
10612
10613
# File 'lib/google/apis/apigee_v1/classes.rb', line 10611

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponentRecommendationAction>

Actions for the recommendation to improve the security score. Corresponds to the JSON property actions



10593
10594
10595
# File 'lib/google/apis/apigee_v1/classes.rb', line 10593

def actions
  @actions
end

#descriptionString

Description of the recommendation. Corresponds to the JSON property description

Returns:

  • (String)


10598
10599
10600
# File 'lib/google/apis/apigee_v1/classes.rb', line 10598

def description
  @description
end

#impactFixnum

Potential impact of this recommendation on the overall score. This denotes how important this recommendation is to improve the score. Corresponds to the JSON property impact

Returns:

  • (Fixnum)


10604
10605
10606
# File 'lib/google/apis/apigee_v1/classes.rb', line 10604

def impact
  @impact
end

#titleString

Title represents recommendation title. Corresponds to the JSON property title

Returns:

  • (String)


10609
10610
10611
# File 'lib/google/apis/apigee_v1/classes.rb', line 10609

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10616
10617
10618
10619
10620
10621
# File 'lib/google/apis/apigee_v1/classes.rb', line 10616

def update!(**args)
  @actions = args[:actions] if args.key?(:actions)
  @description = args[:description] if args.key?(:description)
  @impact = args[:impact] if args.key?(:impact)
  @title = args[:title] if args.key?(:title)
end