Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponentRecommendation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Recommendation based on security concerns and score.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1ScoreComponentRecommendation

Returns a new instance of GoogleCloudApigeeV1ScoreComponentRecommendation.



10567
10568
10569
# File 'lib/google/apis/apigee_v1/classes.rb', line 10567

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1ScoreComponentRecommendationAction>

Actions for the recommendation to improve the security score. Corresponds to the JSON property actions



10549
10550
10551
# File 'lib/google/apis/apigee_v1/classes.rb', line 10549

def actions
  @actions
end

#descriptionString

Description of the recommendation. Corresponds to the JSON property description

Returns:

  • (String)


10554
10555
10556
# File 'lib/google/apis/apigee_v1/classes.rb', line 10554

def description
  @description
end

#impactFixnum

Potential impact of this recommendation on the overall score. This denotes how important this recommendation is to improve the score. Corresponds to the JSON property impact

Returns:

  • (Fixnum)


10560
10561
10562
# File 'lib/google/apis/apigee_v1/classes.rb', line 10560

def impact
  @impact
end

#titleString

Title represents recommendation title. Corresponds to the JSON property title

Returns:

  • (String)


10565
10566
10567
# File 'lib/google/apis/apigee_v1/classes.rb', line 10565

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10572
10573
10574
10575
10576
10577
# File 'lib/google/apis/apigee_v1/classes.rb', line 10572

def update!(**args)
  @actions = args[:actions] if args.key?(:actions)
  @description = args[:description] if args.key?(:description)
  @impact = args[:impact] if args.key?(:impact)
  @title = args[:title] if args.key?(:title)
end