Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAction

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

A SecurityAction is rule that can be enforced at an environment level. The result is one of: - A denied API call - An explicitly allowed API call - A flagged API call (HTTP headers added before the target receives it) At least one condition is required to create a SecurityAction.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityAction

Returns a new instance of GoogleCloudApigeeV1SecurityAction.



10849
10850
10851
# File 'lib/google/apis/apigee_v1/classes.rb', line 10849

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityActionAllow

Message that should be set in case of an Allow Action. This does not have any fields. Corresponds to the JSON property allow



10775
10776
10777
# File 'lib/google/apis/apigee_v1/classes.rb', line 10775

def allow
  @allow
end

#api_proxiesArray<String>

Optional. If unset, this would apply to all proxies in the environment. If set, this action is enforced only if at least one proxy in the repeated list is deployed at the time of enforcement. If set, several restrictions are enforced on SecurityActions. There can be at most 100 enabled actions with proxies set in an env. Several other restrictions apply on conditions and are detailed later. Corresponds to the JSON property apiProxies

Returns:

  • (Array<String>)


10785
10786
10787
# File 'lib/google/apis/apigee_v1/classes.rb', line 10785

def api_proxies
  @api_proxies
end

#condition_configGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityActionConditionConfig

The following are a list of conditions. A valid SecurityAction must contain at least one condition. Within a condition, each element is ORed. Across conditions elements are ANDed. For example if a SecurityAction has the following: ip_address_ranges: ["ip1", "ip2"] and bot_reasons: ["Flooder", " Robot Abuser"] then this is interpreted as: enforce the action if the incoming request has ((ip_address_ranges = "ip1" OR ip_address_ranges = "ip2") AND ( bot_reasons="Flooder" OR bot_reasons="Robot Abuser")). Conditions other than ip_address_ranges and bot_reasons cannot be ANDed. Corresponds to the JSON property conditionConfig



10797
10798
10799
# File 'lib/google/apis/apigee_v1/classes.rb', line 10797

def condition_config
  @condition_config
end

#create_timeString

Output only. The create time for this SecurityAction. Corresponds to the JSON property createTime

Returns:

  • (String)


10802
10803
10804
# File 'lib/google/apis/apigee_v1/classes.rb', line 10802

def create_time
  @create_time
end

#denyGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityActionDeny

Message that should be set in case of a Deny Action. Corresponds to the JSON property deny



10807
10808
10809
# File 'lib/google/apis/apigee_v1/classes.rb', line 10807

def deny
  @deny
end

#descriptionString

Optional. An optional user provided description of the SecurityAction. Corresponds to the JSON property description

Returns:

  • (String)


10812
10813
10814
# File 'lib/google/apis/apigee_v1/classes.rb', line 10812

def description
  @description
end

#expire_timeString

The expiration for this SecurityAction. Corresponds to the JSON property expireTime

Returns:

  • (String)


10817
10818
10819
# File 'lib/google/apis/apigee_v1/classes.rb', line 10817

def expire_time
  @expire_time
end

#flagGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityActionFlag

The message that should be set in the case of a Flag action. Corresponds to the JSON property flag



10822
10823
10824
# File 'lib/google/apis/apigee_v1/classes.rb', line 10822

def flag
  @flag
end

#nameString

Immutable. This field is ignored during creation as per AIP-133. Please set the security_action_id field in the CreateSecurityActionRequest when creating a new SecurityAction. Format: organizations/org/environments/env/ securityActions/security_action Corresponds to the JSON property name

Returns:

  • (String)


10830
10831
10832
# File 'lib/google/apis/apigee_v1/classes.rb', line 10830

def name
  @name
end

#stateString

Required. Only an ENABLED SecurityAction is enforced. An ENABLED SecurityAction past its expiration time will not be enforced. Corresponds to the JSON property state

Returns:

  • (String)


10836
10837
10838
# File 'lib/google/apis/apigee_v1/classes.rb', line 10836

def state
  @state
end

#ttlString

Input only. The TTL for this SecurityAction. Corresponds to the JSON property ttl

Returns:

  • (String)


10841
10842
10843
# File 'lib/google/apis/apigee_v1/classes.rb', line 10841

def ttl
  @ttl
end

#update_timeString

Output only. The update time for this SecurityAction. This reflects when this SecurityAction changed states. Corresponds to the JSON property updateTime

Returns:

  • (String)


10847
10848
10849
# File 'lib/google/apis/apigee_v1/classes.rb', line 10847

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10854
10855
10856
10857
10858
10859
10860
10861
10862
10863
10864
10865
10866
10867
# File 'lib/google/apis/apigee_v1/classes.rb', line 10854

def update!(**args)
  @allow = args[:allow] if args.key?(:allow)
  @api_proxies = args[:api_proxies] if args.key?(:api_proxies)
  @condition_config = args[:condition_config] if args.key?(:condition_config)
  @create_time = args[:create_time] if args.key?(:create_time)
  @deny = args[:deny] if args.key?(:deny)
  @description = args[:description] if args.key?(:description)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @flag = args[:flag] if args.key?(:flag)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @ttl = args[:ttl] if args.key?(:ttl)
  @update_time = args[:update_time] if args.key?(:update_time)
end