Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityActionFlag

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

The message that should be set in the case of a Flag action.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityActionFlag

Returns a new instance of GoogleCloudApigeeV1SecurityActionFlag.



10913
10914
10915
# File 'lib/google/apis/apigee_v1/classes.rb', line 10913

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#headersArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityActionHttpHeader>

Optional. A list of HTTP headers to be sent to the target in case of a FLAG SecurityAction. Limit 5 headers per SecurityAction. At least one is mandatory. Corresponds to the JSON property headers



10911
10912
10913
# File 'lib/google/apis/apigee_v1/classes.rb', line 10911

def headers
  @headers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10918
10919
10920
# File 'lib/google/apis/apigee_v1/classes.rb', line 10918

def update!(**args)
  @headers = args[:headers] if args.key?(:headers)
end