Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityActionHttpHeader
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityActionHttpHeader
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
An HTTP header.
Instance Attribute Summary collapse
-
#name ⇒ String
The header name to be sent to the target.
-
#value ⇒ String
The header value to be sent to the target.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityActionHttpHeader
constructor
A new instance of GoogleCloudApigeeV1SecurityActionHttpHeader.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityActionHttpHeader
Returns a new instance of GoogleCloudApigeeV1SecurityActionHttpHeader.
10966 10967 10968 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10966 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
The header name to be sent to the target.
Corresponds to the JSON property name
10959 10960 10961 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10959 def name @name end |
#value ⇒ String
The header value to be sent to the target.
Corresponds to the JSON property value
10964 10965 10966 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10964 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10971 10972 10973 10974 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10971 def update!(**args) @name = args[:name] if args.key?(:name) @value = args[:value] if args.key?(:value) end |