Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityActionHttpHeader

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

An HTTP header.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityActionHttpHeader

Returns a new instance of GoogleCloudApigeeV1SecurityActionHttpHeader.



10893
10894
10895
# File 'lib/google/apis/apigee_v1/classes.rb', line 10893

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The header name to be sent to the target. Corresponds to the JSON property name

Returns:

  • (String)


10886
10887
10888
# File 'lib/google/apis/apigee_v1/classes.rb', line 10886

def name
  @name
end

#valueString

The header value to be sent to the target. Corresponds to the JSON property value

Returns:

  • (String)


10891
10892
10893
# File 'lib/google/apis/apigee_v1/classes.rb', line 10891

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10898
10899
10900
10901
# File 'lib/google/apis/apigee_v1/classes.rb', line 10898

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @value = args[:value] if args.key?(:value)
end