Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityActionsConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

SecurityActionsConfig reflects the current state of the SecurityActions feature. This is a singleton resource: https://google.aip.dev/156

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityActionsConfig

Returns a new instance of GoogleCloudApigeeV1SecurityActionsConfig.



11083
11084
11085
# File 'lib/google/apis/apigee_v1/classes.rb', line 11083

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

The flag that controls whether this feature is enabled. This is unset by default. When this flag is false, even if individual rules are enabled, no SecurityActions will be enforced. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


11068
11069
11070
# File 'lib/google/apis/apigee_v1/classes.rb', line 11068

def enabled
  @enabled
end

#nameString

This is a singleton resource, the name will always be set by SecurityActions and any user input will be ignored. The name is always: organizations/org/ environments/env/security_actions_config Corresponds to the JSON property name

Returns:

  • (String)


11076
11077
11078
# File 'lib/google/apis/apigee_v1/classes.rb', line 11076

def name
  @name
end

#update_timeString

Output only. The update time for configuration. Corresponds to the JSON property updateTime

Returns:

  • (String)


11081
11082
11083
# File 'lib/google/apis/apigee_v1/classes.rb', line 11081

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11088
11089
11090
11091
11092
# File 'lib/google/apis/apigee_v1/classes.rb', line 11088

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end