Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityActionsConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityActionsConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
SecurityActionsConfig reflects the current state of the SecurityActions feature. This is a singleton resource: https://google.aip.dev/156
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
The flag that controls whether this feature is enabled.
-
#name ⇒ String
This is a singleton resource, the name will always be set by SecurityActions and any user input will be ignored.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityActionsConfig
constructor
A new instance of GoogleCloudApigeeV1SecurityActionsConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityActionsConfig
Returns a new instance of GoogleCloudApigeeV1SecurityActionsConfig.
11069 11070 11071 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11069 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
The flag that controls whether this feature is enabled. This is unset by
default. When this flag is false, even if individual rules are enabled, no
SecurityActions will be enforced.
Corresponds to the JSON property enabled
11054 11055 11056 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11054 def enabled @enabled end |
#name ⇒ String
This is a singleton resource, the name will always be set by SecurityActions
and any user input will be ignored. The name is always: organizations/org/
environments/env/security_actions_config
Corresponds to the JSON property name
11062 11063 11064 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11062 def name @name end |
#update_time ⇒ String
Output only. The update time for configuration.
Corresponds to the JSON property updateTime
11067 11068 11069 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11067 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11074 11075 11076 11077 11078 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11074 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |