Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityActionsConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

SecurityActionsConfig reflects the current state of the SecurityActions feature. This is a singleton resource: https://google.aip.dev/156

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityActionsConfig

Returns a new instance of GoogleCloudApigeeV1SecurityActionsConfig.



10973
10974
10975
# File 'lib/google/apis/apigee_v1/classes.rb', line 10973

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

The flag that controls whether this feature is enabled. This is unset by default. When this flag is false, even if individual rules are enabled, no SecurityActions will be enforced. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


10958
10959
10960
# File 'lib/google/apis/apigee_v1/classes.rb', line 10958

def enabled
  @enabled
end

#nameString

This is a singleton resource, the name will always be set by SecurityActions and any user input will be ignored. The name is always: organizations/org/ environments/env/security_actions_config Corresponds to the JSON property name

Returns:

  • (String)


10966
10967
10968
# File 'lib/google/apis/apigee_v1/classes.rb', line 10966

def name
  @name
end

#update_timeString

Output only. The update time for configuration. Corresponds to the JSON property updateTime

Returns:

  • (String)


10971
10972
10973
# File 'lib/google/apis/apigee_v1/classes.rb', line 10971

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10978
10979
10980
10981
10982
# File 'lib/google/apis/apigee_v1/classes.rb', line 10978

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end