Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityActionsConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityActionsConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
SecurityActionsConfig reflects the current state of the SecurityActions feature. This is a singleton resource: https://google.aip.dev/156
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
The flag that controls whether this feature is enabled.
-
#name ⇒ String
This is a singleton resource, the name will always be set by SecurityActions and any user input will be ignored.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityActionsConfig
constructor
A new instance of GoogleCloudApigeeV1SecurityActionsConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityActionsConfig
Returns a new instance of GoogleCloudApigeeV1SecurityActionsConfig.
10964 10965 10966 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10964 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
The flag that controls whether this feature is enabled. This is unset by
default. When this flag is false, even if individual rules are enabled, no
SecurityActions will be enforced.
Corresponds to the JSON property enabled
10949 10950 10951 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10949 def enabled @enabled end |
#name ⇒ String
This is a singleton resource, the name will always be set by SecurityActions
and any user input will be ignored. The name is always: organizations/org/
environments/env/security_actions_config
Corresponds to the JSON property name
10957 10958 10959 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10957 def name @name end |
#update_time ⇒ String
Output only. The update time for configuration.
Corresponds to the JSON property updateTime
10962 10963 10964 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10962 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10969 10970 10971 10972 10973 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10969 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |