Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityActionsConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

SecurityActionsConfig reflects the current state of the SecurityActions feature. This is a singleton resource: https://google.aip.dev/156

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityActionsConfig

Returns a new instance of GoogleCloudApigeeV1SecurityActionsConfig.



11002
11003
11004
# File 'lib/google/apis/apigee_v1/classes.rb', line 11002

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

The flag that controls whether this feature is enabled. This is unset by default. When this flag is false, even if individual rules are enabled, no SecurityActions will be enforced. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


10987
10988
10989
# File 'lib/google/apis/apigee_v1/classes.rb', line 10987

def enabled
  @enabled
end

#nameString

This is a singleton resource, the name will always be set by SecurityActions and any user input will be ignored. The name is always: organizations/org/ environments/env/security_actions_config Corresponds to the JSON property name

Returns:

  • (String)


10995
10996
10997
# File 'lib/google/apis/apigee_v1/classes.rb', line 10995

def name
  @name
end

#update_timeString

Output only. The update time for configuration. Corresponds to the JSON property updateTime

Returns:

  • (String)


11000
11001
11002
# File 'lib/google/apis/apigee_v1/classes.rb', line 11000

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11007
11008
11009
11010
11011
# File 'lib/google/apis/apigee_v1/classes.rb', line 11007

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end