Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

The security assessment result for one resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityAssessmentResult

Returns a new instance of GoogleCloudApigeeV1SecurityAssessmentResult.



11111
11112
11113
# File 'lib/google/apis/apigee_v1/classes.rb', line 11111

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

The time of the assessment of this resource. This could lag behind assessment_time due to caching within the backend. Corresponds to the JSON property createTime

Returns:

  • (String)


11089
11090
11091
# File 'lib/google/apis/apigee_v1/classes.rb', line 11089

def create_time
  @create_time
end

#errorGoogle::Apis::ApigeeV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



11099
11100
11101
# File 'lib/google/apis/apigee_v1/classes.rb', line 11099

def error
  @error
end

#resourceGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultResource

Resource for which we are computing security assessment. Corresponds to the JSON property resource



11104
11105
11106
# File 'lib/google/apis/apigee_v1/classes.rb', line 11104

def resource
  @resource
end

#scoring_resultGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultScoringResult

The result of the assessment. Corresponds to the JSON property scoringResult



11109
11110
11111
# File 'lib/google/apis/apigee_v1/classes.rb', line 11109

def scoring_result
  @scoring_result
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11116
11117
11118
11119
11120
11121
# File 'lib/google/apis/apigee_v1/classes.rb', line 11116

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @error = args[:error] if args.key?(:error)
  @resource = args[:resource] if args.key?(:resource)
  @scoring_result = args[:scoring_result] if args.key?(:scoring_result)
end