Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResult
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
The security assessment result for one resource.
Instance Attribute Summary collapse
-
#create_time ⇒ String
The time of the assessment of this resource.
-
#error ⇒ Google::Apis::ApigeeV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#resource ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultResource
Resource for which we are computing security assessment.
-
#scoring_result ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultScoringResult
The result of the assessment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityAssessmentResult
constructor
A new instance of GoogleCloudApigeeV1SecurityAssessmentResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityAssessmentResult
Returns a new instance of GoogleCloudApigeeV1SecurityAssessmentResult.
11006 11007 11008 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11006 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
The time of the assessment of this resource. This could lag behind
assessment_time due to caching within the backend.
Corresponds to the JSON property createTime
10984 10985 10986 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10984 def create_time @create_time end |
#error ⇒ Google::Apis::ApigeeV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
10994 10995 10996 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10994 def error @error end |
#resource ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultResource
Resource for which we are computing security assessment.
Corresponds to the JSON property resource
10999 11000 11001 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10999 def resource @resource end |
#scoring_result ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultScoringResult
The result of the assessment.
Corresponds to the JSON property scoringResult
11004 11005 11006 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11004 def scoring_result @scoring_result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11011 11012 11013 11014 11015 11016 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11011 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @error = args[:error] if args.key?(:error) @resource = args[:resource] if args.key?(:resource) @scoring_result = args[:scoring_result] if args.key?(:scoring_result) end |