Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

The security assessment result for one resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityAssessmentResult

Returns a new instance of GoogleCloudApigeeV1SecurityAssessmentResult.



10971
10972
10973
# File 'lib/google/apis/apigee_v1/classes.rb', line 10971

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

The time of the assessment of this resource. This could lag behind assessment_time due to caching within the backend. Corresponds to the JSON property createTime

Returns:

  • (String)


10949
10950
10951
# File 'lib/google/apis/apigee_v1/classes.rb', line 10949

def create_time
  @create_time
end

#errorGoogle::Apis::ApigeeV1::GoogleRpcStatus

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



10959
10960
10961
# File 'lib/google/apis/apigee_v1/classes.rb', line 10959

def error
  @error
end

#resourceGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultResource

Resource for which we are computing security assessment. Corresponds to the JSON property resource



10964
10965
10966
# File 'lib/google/apis/apigee_v1/classes.rb', line 10964

def resource
  @resource
end

#scoring_resultGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultScoringResult

The result of the assessment. Corresponds to the JSON property scoringResult



10969
10970
10971
# File 'lib/google/apis/apigee_v1/classes.rb', line 10969

def scoring_result
  @scoring_result
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10976
10977
10978
10979
10980
10981
# File 'lib/google/apis/apigee_v1/classes.rb', line 10976

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @error = args[:error] if args.key?(:error)
  @resource = args[:resource] if args.key?(:resource)
  @scoring_result = args[:scoring_result] if args.key?(:scoring_result)
end