Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultResource
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Resource for which we are computing security assessment.
Instance Attribute Summary collapse
-
#api_hub_deployment_details ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultResourceApiHubDeploymentDetails
Additional details if the resource is an API Hub deployment.
-
#api_hub_gateway_type ⇒ String
Optional.
-
#name ⇒ String
Required.
-
#resource_revision_id ⇒ String
The revision id for the resource.
-
#type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityAssessmentResultResource
constructor
A new instance of GoogleCloudApigeeV1SecurityAssessmentResultResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityAssessmentResultResource
Returns a new instance of GoogleCloudApigeeV1SecurityAssessmentResultResource.
11155 11156 11157 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11155 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_hub_deployment_details ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultResourceApiHubDeploymentDetails
Additional details if the resource is an API Hub deployment.
Corresponds to the JSON property apiHubDeploymentDetails
11131 11132 11133 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11131 def api_hub_deployment_details @api_hub_deployment_details end |
#api_hub_gateway_type ⇒ String
Optional.
Corresponds to the JSON property apiHubGatewayType
11136 11137 11138 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11136 def api_hub_gateway_type @api_hub_gateway_type end |
#name ⇒ String
Required. Name of this resource. For an Apigee API Proxy, this should be the
id of the API proxy. For an API Hub Deployment, this should be the id of the
deployment.
Corresponds to the JSON property name
11143 11144 11145 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11143 def name @name end |
#resource_revision_id ⇒ String
The revision id for the resource. In case of Apigee, this is proxy revision id.
Corresponds to the JSON property resourceRevisionId
11148 11149 11150 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11148 def resource_revision_id @resource_revision_id end |
#type ⇒ String
Required. Type of this resource.
Corresponds to the JSON property type
11153 11154 11155 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11153 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11160 11161 11162 11163 11164 11165 11166 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11160 def update!(**args) @api_hub_deployment_details = args[:api_hub_deployment_details] if args.key?(:api_hub_deployment_details) @api_hub_gateway_type = args[:api_hub_gateway_type] if args.key?(:api_hub_gateway_type) @name = args[:name] if args.key?(:name) @resource_revision_id = args[:resource_revision_id] if args.key?(:resource_revision_id) @type = args[:type] if args.key?(:type) end |