Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Resource for which we are computing security assessment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityAssessmentResultResource

Returns a new instance of GoogleCloudApigeeV1SecurityAssessmentResultResource.



11059
11060
11061
# File 'lib/google/apis/apigee_v1/classes.rb', line 11059

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_hub_deployment_detailsGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultResourceApiHubDeploymentDetails

Additional details if the resource is an API Hub deployment. Corresponds to the JSON property apiHubDeploymentDetails



11035
11036
11037
# File 'lib/google/apis/apigee_v1/classes.rb', line 11035

def api_hub_deployment_details
  @api_hub_deployment_details
end

#api_hub_gateway_typeString

Optional. Corresponds to the JSON property apiHubGatewayType

Returns:

  • (String)


11040
11041
11042
# File 'lib/google/apis/apigee_v1/classes.rb', line 11040

def api_hub_gateway_type
  @api_hub_gateway_type
end

#nameString

Required. Name of this resource. For an Apigee API Proxy, this should be the id of the API proxy. For an API Hub Deployment, this should be the id of the deployment. Corresponds to the JSON property name

Returns:

  • (String)


11047
11048
11049
# File 'lib/google/apis/apigee_v1/classes.rb', line 11047

def name
  @name
end

#resource_revision_idString

The revision id for the resource. In case of Apigee, this is proxy revision id. Corresponds to the JSON property resourceRevisionId

Returns:

  • (String)


11052
11053
11054
# File 'lib/google/apis/apigee_v1/classes.rb', line 11052

def resource_revision_id
  @resource_revision_id
end

#typeString

Required. Type of this resource. Corresponds to the JSON property type

Returns:

  • (String)


11057
11058
11059
# File 'lib/google/apis/apigee_v1/classes.rb', line 11057

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11064
11065
11066
11067
11068
11069
11070
# File 'lib/google/apis/apigee_v1/classes.rb', line 11064

def update!(**args)
  @api_hub_deployment_details = args[:api_hub_deployment_details] if args.key?(:api_hub_deployment_details)
  @api_hub_gateway_type = args[:api_hub_gateway_type] if args.key?(:api_hub_gateway_type)
  @name = args[:name] if args.key?(:name)
  @resource_revision_id = args[:resource_revision_id] if args.key?(:resource_revision_id)
  @type = args[:type] if args.key?(:type)
end