Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Resource for which we are computing security assessment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityAssessmentResultResource

Returns a new instance of GoogleCloudApigeeV1SecurityAssessmentResultResource.



11050
11051
11052
# File 'lib/google/apis/apigee_v1/classes.rb', line 11050

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_hub_deployment_detailsGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultResourceApiHubDeploymentDetails

Additional details if the resource is an API Hub deployment. Corresponds to the JSON property apiHubDeploymentDetails



11026
11027
11028
# File 'lib/google/apis/apigee_v1/classes.rb', line 11026

def api_hub_deployment_details
  @api_hub_deployment_details
end

#api_hub_gateway_typeString

Optional. Corresponds to the JSON property apiHubGatewayType

Returns:

  • (String)


11031
11032
11033
# File 'lib/google/apis/apigee_v1/classes.rb', line 11031

def api_hub_gateway_type
  @api_hub_gateway_type
end

#nameString

Required. Name of this resource. For an Apigee API Proxy, this should be the id of the API proxy. For an API Hub Deployment, this should be the id of the deployment. Corresponds to the JSON property name

Returns:

  • (String)


11038
11039
11040
# File 'lib/google/apis/apigee_v1/classes.rb', line 11038

def name
  @name
end

#resource_revision_idString

The revision id for the resource. In case of Apigee, this is proxy revision id. Corresponds to the JSON property resourceRevisionId

Returns:

  • (String)


11043
11044
11045
# File 'lib/google/apis/apigee_v1/classes.rb', line 11043

def resource_revision_id
  @resource_revision_id
end

#typeString

Required. Type of this resource. Corresponds to the JSON property type

Returns:

  • (String)


11048
11049
11050
# File 'lib/google/apis/apigee_v1/classes.rb', line 11048

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11055
11056
11057
11058
11059
11060
11061
# File 'lib/google/apis/apigee_v1/classes.rb', line 11055

def update!(**args)
  @api_hub_deployment_details = args[:api_hub_deployment_details] if args.key?(:api_hub_deployment_details)
  @api_hub_gateway_type = args[:api_hub_gateway_type] if args.key?(:api_hub_gateway_type)
  @name = args[:name] if args.key?(:name)
  @resource_revision_id = args[:resource_revision_id] if args.key?(:resource_revision_id)
  @type = args[:type] if args.key?(:type)
end