Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultResource
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Resource for which we are computing security assessment.
Instance Attribute Summary collapse
-
#api_hub_deployment_details ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultResourceApiHubDeploymentDetails
Additional details if the resource is an API Hub deployment.
-
#name ⇒ String
Required.
-
#resource_revision_id ⇒ String
The revision id for the resource.
-
#type ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityAssessmentResultResource
constructor
A new instance of GoogleCloudApigeeV1SecurityAssessmentResultResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityAssessmentResultResource
Returns a new instance of GoogleCloudApigeeV1SecurityAssessmentResultResource.
11010 11011 11012 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11010 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_hub_deployment_details ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultResourceApiHubDeploymentDetails
Additional details if the resource is an API Hub deployment.
Corresponds to the JSON property apiHubDeploymentDetails
10991 10992 10993 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10991 def api_hub_deployment_details @api_hub_deployment_details end |
#name ⇒ String
Required. Name of this resource. For an Apigee API Proxy, this should be the
id of the API proxy. For an API Hub Deployment, this should be the id of the
deployment.
Corresponds to the JSON property name
10998 10999 11000 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 10998 def name @name end |
#resource_revision_id ⇒ String
The revision id for the resource. In case of Apigee, this is proxy revision id.
Corresponds to the JSON property resourceRevisionId
11003 11004 11005 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11003 def resource_revision_id @resource_revision_id end |
#type ⇒ String
Required. Type of this resource.
Corresponds to the JSON property type
11008 11009 11010 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11008 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11015 11016 11017 11018 11019 11020 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11015 def update!(**args) @api_hub_deployment_details = args[:api_hub_deployment_details] if args.key?(:api_hub_deployment_details) @name = args[:name] if args.key?(:name) @resource_revision_id = args[:resource_revision_id] if args.key?(:resource_revision_id) @type = args[:type] if args.key?(:type) end |