Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultScoringResult
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultScoringResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
The result of the assessment.
Instance Attribute Summary collapse
-
#assessment_recommendations ⇒ Hash<String,Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultScoringResultAssessmentRecommendation>
The recommendations of the assessment.
-
#data_update_time ⇒ String
The time when resource data was last fetched for this resource.
-
#failed_assessment_per_weight ⇒ Hash<String,Fixnum>
The number of failed assessments grouped by its weight.
-
#score ⇒ Fixnum
The security score of the assessment.
-
#severity ⇒ String
Corresponds to the JSON property
severity.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityAssessmentResultScoringResult
constructor
A new instance of GoogleCloudApigeeV1SecurityAssessmentResultScoringResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityAssessmentResultScoringResult
Returns a new instance of GoogleCloudApigeeV1SecurityAssessmentResultScoringResult.
11260 11261 11262 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11260 def initialize(**args) update!(**args) end |
Instance Attribute Details
#assessment_recommendations ⇒ Hash<String,Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultScoringResultAssessmentRecommendation>
The recommendations of the assessment. The key is the "name" of the assessment
(not display_name), and the value are the recommendations.
Corresponds to the JSON property assessmentRecommendations
11235 11236 11237 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11235 def assessment_recommendations @assessment_recommendations end |
#data_update_time ⇒ String
The time when resource data was last fetched for this resource. This time may
be different than when the resource was actually updated due to lag in data
collection.
Corresponds to the JSON property dataUpdateTime
11242 11243 11244 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11242 def data_update_time @data_update_time end |
#failed_assessment_per_weight ⇒ Hash<String,Fixnum>
The number of failed assessments grouped by its weight. Keys are one of the
following: "MAJOR", "MODERATE", "MINOR".
Corresponds to the JSON property failedAssessmentPerWeight
11248 11249 11250 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11248 def failed_assessment_per_weight @failed_assessment_per_weight end |
#score ⇒ Fixnum
The security score of the assessment.
Corresponds to the JSON property score
11253 11254 11255 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11253 def score @score end |
#severity ⇒ String
Corresponds to the JSON property severity
11258 11259 11260 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11258 def severity @severity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11265 11266 11267 11268 11269 11270 11271 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11265 def update!(**args) @assessment_recommendations = args[:assessment_recommendations] if args.key?(:assessment_recommendations) @data_update_time = args[:data_update_time] if args.key?(:data_update_time) @failed_assessment_per_weight = args[:failed_assessment_per_weight] if args.key?(:failed_assessment_per_weight) @score = args[:score] if args.key?(:score) @severity = args[:severity] if args.key?(:severity) end |