Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultScoringResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

The result of the assessment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityAssessmentResultScoringResult

Returns a new instance of GoogleCloudApigeeV1SecurityAssessmentResultScoringResult.



11246
11247
11248
# File 'lib/google/apis/apigee_v1/classes.rb', line 11246

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assessment_recommendationsHash<String,Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultScoringResultAssessmentRecommendation>

The recommendations of the assessment. The key is the "name" of the assessment (not display_name), and the value are the recommendations. Corresponds to the JSON property assessmentRecommendations



11221
11222
11223
# File 'lib/google/apis/apigee_v1/classes.rb', line 11221

def assessment_recommendations
  @assessment_recommendations
end

#data_update_timeString

The time when resource data was last fetched for this resource. This time may be different than when the resource was actually updated due to lag in data collection. Corresponds to the JSON property dataUpdateTime

Returns:

  • (String)


11228
11229
11230
# File 'lib/google/apis/apigee_v1/classes.rb', line 11228

def data_update_time
  @data_update_time
end

#failed_assessment_per_weightHash<String,Fixnum>

The number of failed assessments grouped by its weight. Keys are one of the following: "MAJOR", "MODERATE", "MINOR". Corresponds to the JSON property failedAssessmentPerWeight

Returns:

  • (Hash<String,Fixnum>)


11234
11235
11236
# File 'lib/google/apis/apigee_v1/classes.rb', line 11234

def failed_assessment_per_weight
  @failed_assessment_per_weight
end

#scoreFixnum

The security score of the assessment. Corresponds to the JSON property score

Returns:

  • (Fixnum)


11239
11240
11241
# File 'lib/google/apis/apigee_v1/classes.rb', line 11239

def score
  @score
end

#severityString

Corresponds to the JSON property severity

Returns:

  • (String)


11244
11245
11246
# File 'lib/google/apis/apigee_v1/classes.rb', line 11244

def severity
  @severity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11251
11252
11253
11254
11255
11256
11257
# File 'lib/google/apis/apigee_v1/classes.rb', line 11251

def update!(**args)
  @assessment_recommendations = args[:assessment_recommendations] if args.key?(:assessment_recommendations)
  @data_update_time = args[:data_update_time] if args.key?(:data_update_time)
  @failed_assessment_per_weight = args[:failed_assessment_per_weight] if args.key?(:failed_assessment_per_weight)
  @score = args[:score] if args.key?(:score)
  @severity = args[:severity] if args.key?(:severity)
end