Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultScoringResultAssessmentRecommendation
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultScoringResultAssessmentRecommendation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
The message format of a recommendation from the assessment.
Instance Attribute Summary collapse
-
#display_name ⇒ String
The display name of the assessment.
-
#recommendations ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultScoringResultAssessmentRecommendationRecommendation>
The recommended steps of the assessment.
-
#score_impact ⇒ Fixnum
Score impact indicates the impact on the overall score if the assessment were to pass.
-
#verdict ⇒ String
Verdict indicates the assessment result.
-
#weight ⇒ String
The weight of the assessment which was set in the profile.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityAssessmentResultScoringResultAssessmentRecommendation
constructor
A new instance of GoogleCloudApigeeV1SecurityAssessmentResultScoringResultAssessmentRecommendation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityAssessmentResultScoringResultAssessmentRecommendation
Returns a new instance of GoogleCloudApigeeV1SecurityAssessmentResultScoringResultAssessmentRecommendation.
11223 11224 11225 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11223 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
The display name of the assessment.
Corresponds to the JSON property displayName
11200 11201 11202 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11200 def display_name @display_name end |
#recommendations ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityAssessmentResultScoringResultAssessmentRecommendationRecommendation>
The recommended steps of the assessment.
Corresponds to the JSON property recommendations
11205 11206 11207 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11205 def recommendations @recommendations end |
#score_impact ⇒ Fixnum
Score impact indicates the impact on the overall score if the assessment were
to pass.
Corresponds to the JSON property scoreImpact
11211 11212 11213 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11211 def score_impact @score_impact end |
#verdict ⇒ String
Verdict indicates the assessment result.
Corresponds to the JSON property verdict
11216 11217 11218 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11216 def verdict @verdict end |
#weight ⇒ String
The weight of the assessment which was set in the profile.
Corresponds to the JSON property weight
11221 11222 11223 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11221 def weight @weight end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11228 11229 11230 11231 11232 11233 11234 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11228 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @recommendations = args[:recommendations] if args.key?(:recommendations) @score_impact = args[:score_impact] if args.key?(:score_impact) @verdict = args[:verdict] if args.key?(:verdict) @weight = args[:weight] if args.key?(:weight) end |