Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityFeedback
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityFeedback
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Represents a feedback report from an Advanced API Security customer.
Instance Attribute Summary collapse
-
#comment ⇒ String
Optional.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#feedback_contexts ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityFeedbackFeedbackContext>
Required.
-
#feedback_type ⇒ String
Required.
-
#name ⇒ String
Output only.
-
#reason ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityFeedback
constructor
A new instance of GoogleCloudApigeeV1SecurityFeedback.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityFeedback
Returns a new instance of GoogleCloudApigeeV1SecurityFeedback.
11400 11401 11402 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11400 def initialize(**args) update!(**args) end |
Instance Attribute Details
#comment ⇒ String
Optional. Optional text the user can provide for additional, unstructured
context.
Corresponds to the JSON property comment
11362 11363 11364 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11362 def comment @comment end |
#create_time ⇒ String
Output only. The time when this specific feedback id was created.
Corresponds to the JSON property createTime
11367 11368 11369 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11367 def create_time @create_time end |
#display_name ⇒ String
Optional. The display name of the feedback.
Corresponds to the JSON property displayName
11372 11373 11374 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11372 def display_name @display_name end |
#feedback_contexts ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityFeedbackFeedbackContext>
Required. One or more attribute/value pairs for constraining the feedback.
Corresponds to the JSON property feedbackContexts
11377 11378 11379 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11377 def feedback_contexts @feedback_contexts end |
#feedback_type ⇒ String
Required. The type of feedback being submitted.
Corresponds to the JSON property feedbackType
11382 11383 11384 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11382 def feedback_type @feedback_type end |
#name ⇒ String
Output only. Identifier. The feedback name is intended to be a system-
generated uuid.
Corresponds to the JSON property name
11388 11389 11390 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11388 def name @name end |
#reason ⇒ String
Optional. The reason for the feedback.
Corresponds to the JSON property reason
11393 11394 11395 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11393 def reason @reason end |
#update_time ⇒ String
Output only. The time when this specific feedback id was updated.
Corresponds to the JSON property updateTime
11398 11399 11400 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11398 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11405 11406 11407 11408 11409 11410 11411 11412 11413 11414 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11405 def update!(**args) @comment = args[:comment] if args.key?(:comment) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @feedback_contexts = args[:feedback_contexts] if args.key?(:feedback_contexts) @feedback_type = args[:feedback_type] if args.key?(:feedback_type) @name = args[:name] if args.key?(:name) @reason = args[:reason] if args.key?(:reason) @update_time = args[:update_time] if args.key?(:update_time) end |