Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityFeedback

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Represents a feedback report from an Advanced API Security customer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityFeedback

Returns a new instance of GoogleCloudApigeeV1SecurityFeedback.



11333
11334
11335
# File 'lib/google/apis/apigee_v1/classes.rb', line 11333

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commentString

Optional. Optional text the user can provide for additional, unstructured context. Corresponds to the JSON property comment

Returns:

  • (String)


11295
11296
11297
# File 'lib/google/apis/apigee_v1/classes.rb', line 11295

def comment
  @comment
end

#create_timeString

Output only. The time when this specific feedback id was created. Corresponds to the JSON property createTime

Returns:

  • (String)


11300
11301
11302
# File 'lib/google/apis/apigee_v1/classes.rb', line 11300

def create_time
  @create_time
end

#display_nameString

Optional. The display name of the feedback. Corresponds to the JSON property displayName

Returns:

  • (String)


11305
11306
11307
# File 'lib/google/apis/apigee_v1/classes.rb', line 11305

def display_name
  @display_name
end

#feedback_contextsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityFeedbackFeedbackContext>

Required. One or more attribute/value pairs for constraining the feedback. Corresponds to the JSON property feedbackContexts



11310
11311
11312
# File 'lib/google/apis/apigee_v1/classes.rb', line 11310

def feedback_contexts
  @feedback_contexts
end

#feedback_typeString

Required. The type of feedback being submitted. Corresponds to the JSON property feedbackType

Returns:

  • (String)


11315
11316
11317
# File 'lib/google/apis/apigee_v1/classes.rb', line 11315

def feedback_type
  @feedback_type
end

#nameString

Output only. Identifier. The feedback name is intended to be a system- generated uuid. Corresponds to the JSON property name

Returns:

  • (String)


11321
11322
11323
# File 'lib/google/apis/apigee_v1/classes.rb', line 11321

def name
  @name
end

#reasonString

Optional. The reason for the feedback. Corresponds to the JSON property reason

Returns:

  • (String)


11326
11327
11328
# File 'lib/google/apis/apigee_v1/classes.rb', line 11326

def reason
  @reason
end

#update_timeString

Output only. The time when this specific feedback id was updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


11331
11332
11333
# File 'lib/google/apis/apigee_v1/classes.rb', line 11331

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11338
11339
11340
11341
11342
11343
11344
11345
11346
11347
# File 'lib/google/apis/apigee_v1/classes.rb', line 11338

def update!(**args)
  @comment = args[:comment] if args.key?(:comment)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @feedback_contexts = args[:feedback_contexts] if args.key?(:feedback_contexts)
  @feedback_type = args[:feedback_type] if args.key?(:feedback_type)
  @name = args[:name] if args.key?(:name)
  @reason = args[:reason] if args.key?(:reason)
  @update_time = args[:update_time] if args.key?(:update_time)
end