Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityFeedback
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityFeedback
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Represents a feedback report from an Advanced API Security customer.
Instance Attribute Summary collapse
-
#comment ⇒ String
Optional.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#feedback_contexts ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityFeedbackFeedbackContext>
Required.
-
#feedback_type ⇒ String
Required.
-
#name ⇒ String
Output only.
-
#reason ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityFeedback
constructor
A new instance of GoogleCloudApigeeV1SecurityFeedback.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityFeedback
Returns a new instance of GoogleCloudApigeeV1SecurityFeedback.
11254 11255 11256 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11254 def initialize(**args) update!(**args) end |
Instance Attribute Details
#comment ⇒ String
Optional. Optional text the user can provide for additional, unstructured
context.
Corresponds to the JSON property comment
11216 11217 11218 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11216 def comment @comment end |
#create_time ⇒ String
Output only. The time when this specific feedback id was created.
Corresponds to the JSON property createTime
11221 11222 11223 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11221 def create_time @create_time end |
#display_name ⇒ String
Optional. The display name of the feedback.
Corresponds to the JSON property displayName
11226 11227 11228 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11226 def display_name @display_name end |
#feedback_contexts ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityFeedbackFeedbackContext>
Required. One or more attribute/value pairs for constraining the feedback.
Corresponds to the JSON property feedbackContexts
11231 11232 11233 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11231 def feedback_contexts @feedback_contexts end |
#feedback_type ⇒ String
Required. The type of feedback being submitted.
Corresponds to the JSON property feedbackType
11236 11237 11238 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11236 def feedback_type @feedback_type end |
#name ⇒ String
Output only. Identifier. The feedback name is intended to be a system-
generated uuid.
Corresponds to the JSON property name
11242 11243 11244 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11242 def name @name end |
#reason ⇒ String
Optional. The reason for the feedback.
Corresponds to the JSON property reason
11247 11248 11249 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11247 def reason @reason end |
#update_time ⇒ String
Output only. The time when this specific feedback id was updated.
Corresponds to the JSON property updateTime
11252 11253 11254 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11252 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11259 11260 11261 11262 11263 11264 11265 11266 11267 11268 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11259 def update!(**args) @comment = args[:comment] if args.key?(:comment) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @feedback_contexts = args[:feedback_contexts] if args.key?(:feedback_contexts) @feedback_type = args[:feedback_type] if args.key?(:feedback_type) @name = args[:name] if args.key?(:name) @reason = args[:reason] if args.key?(:reason) @update_time = args[:update_time] if args.key?(:update_time) end |