Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityIncident
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityIncident
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Represents an SecurityIncident resource.
Instance Attribute Summary collapse
-
#detection_types ⇒ Array<String>
Output only.
-
#display_name ⇒ String
Optional.
-
#first_detected_time ⇒ String
Output only.
-
#last_detected_time ⇒ String
Output only.
-
#last_observability_change_time ⇒ String
Output only.
-
#name ⇒ String
Immutable.
-
#observability ⇒ String
Optional.
-
#risk_level ⇒ String
Output only.
-
#traffic_count ⇒ Fixnum
Total traffic detected as part of the incident.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityIncident
constructor
A new instance of GoogleCloudApigeeV1SecurityIncident.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityIncident
Returns a new instance of GoogleCloudApigeeV1SecurityIncident.
11400 11401 11402 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11400 def initialize(**args) update!(**args) end |
Instance Attribute Details
#detection_types ⇒ Array<String>
Output only. Detection types which are part of the incident. Examples: Flooder,
OAuth Abuser, Static Content Scraper, Anomaly Detection.
Corresponds to the JSON property detectionTypes
11354 11355 11356 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11354 def detection_types @detection_types end |
#display_name ⇒ String
Optional. Display name of the security incident.
Corresponds to the JSON property displayName
11359 11360 11361 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11359 def display_name @display_name end |
#first_detected_time ⇒ String
Output only. The time when events associated with the incident were first
detected.
Corresponds to the JSON property firstDetectedTime
11365 11366 11367 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11365 def first_detected_time @first_detected_time end |
#last_detected_time ⇒ String
Output only. The time when events associated with the incident were last
detected.
Corresponds to the JSON property lastDetectedTime
11371 11372 11373 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11371 def last_detected_time @last_detected_time end |
#last_observability_change_time ⇒ String
Output only. The time when the incident observability was last changed.
Corresponds to the JSON property lastObservabilityChangeTime
11376 11377 11378 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11376 def last_observability_change_time @last_observability_change_time end |
#name ⇒ String
Immutable. Name of the security incident resource. Format: organizations/org/
environments/environment/securityIncidents/incident Example: organizations/
apigee-org/environments/dev/securityIncidents/1234-5678-9101-1111
Corresponds to the JSON property name
11383 11384 11385 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11383 def name @name end |
#observability ⇒ String
Optional. Indicates if the user archived this incident.
Corresponds to the JSON property observability
11388 11389 11390 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11388 def observability @observability end |
#risk_level ⇒ String
Output only. Risk level of the incident.
Corresponds to the JSON property riskLevel
11393 11394 11395 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11393 def risk_level @risk_level end |
#traffic_count ⇒ Fixnum
Total traffic detected as part of the incident.
Corresponds to the JSON property trafficCount
11398 11399 11400 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11398 def traffic_count @traffic_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11405 11406 11407 11408 11409 11410 11411 11412 11413 11414 11415 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11405 def update!(**args) @detection_types = args[:detection_types] if args.key?(:detection_types) @display_name = args[:display_name] if args.key?(:display_name) @first_detected_time = args[:first_detected_time] if args.key?(:first_detected_time) @last_detected_time = args[:last_detected_time] if args.key?(:last_detected_time) @last_observability_change_time = args[:last_observability_change_time] if args.key?(:last_observability_change_time) @name = args[:name] if args.key?(:name) @observability = args[:observability] if args.key?(:observability) @risk_level = args[:risk_level] if args.key?(:risk_level) @traffic_count = args[:traffic_count] if args.key?(:traffic_count) end |