Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityIncident

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Represents an SecurityIncident resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityIncident

Returns a new instance of GoogleCloudApigeeV1SecurityIncident.



11429
11430
11431
# File 'lib/google/apis/apigee_v1/classes.rb', line 11429

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detection_typesArray<String>

Output only. Detection types which are part of the incident. Examples: Flooder, OAuth Abuser, Static Content Scraper, Anomaly Detection. Corresponds to the JSON property detectionTypes

Returns:

  • (Array<String>)


11383
11384
11385
# File 'lib/google/apis/apigee_v1/classes.rb', line 11383

def detection_types
  @detection_types
end

#display_nameString

Optional. Display name of the security incident. Corresponds to the JSON property displayName

Returns:

  • (String)


11388
11389
11390
# File 'lib/google/apis/apigee_v1/classes.rb', line 11388

def display_name
  @display_name
end

#first_detected_timeString

Output only. The time when events associated with the incident were first detected. Corresponds to the JSON property firstDetectedTime

Returns:

  • (String)


11394
11395
11396
# File 'lib/google/apis/apigee_v1/classes.rb', line 11394

def first_detected_time
  @first_detected_time
end

#last_detected_timeString

Output only. The time when events associated with the incident were last detected. Corresponds to the JSON property lastDetectedTime

Returns:

  • (String)


11400
11401
11402
# File 'lib/google/apis/apigee_v1/classes.rb', line 11400

def last_detected_time
  @last_detected_time
end

#last_observability_change_timeString

Output only. The time when the incident observability was last changed. Corresponds to the JSON property lastObservabilityChangeTime

Returns:

  • (String)


11405
11406
11407
# File 'lib/google/apis/apigee_v1/classes.rb', line 11405

def last_observability_change_time
  @last_observability_change_time
end

#nameString

Immutable. Name of the security incident resource. Format: organizations/org/ environments/environment/securityIncidents/incident Example: organizations/ apigee-org/environments/dev/securityIncidents/1234-5678-9101-1111 Corresponds to the JSON property name

Returns:

  • (String)


11412
11413
11414
# File 'lib/google/apis/apigee_v1/classes.rb', line 11412

def name
  @name
end

#observabilityString

Optional. Indicates if the user archived this incident. Corresponds to the JSON property observability

Returns:

  • (String)


11417
11418
11419
# File 'lib/google/apis/apigee_v1/classes.rb', line 11417

def observability
  @observability
end

#risk_levelString

Output only. Risk level of the incident. Corresponds to the JSON property riskLevel

Returns:

  • (String)


11422
11423
11424
# File 'lib/google/apis/apigee_v1/classes.rb', line 11422

def risk_level
  @risk_level
end

#traffic_countFixnum

Total traffic detected as part of the incident. Corresponds to the JSON property trafficCount

Returns:

  • (Fixnum)


11427
11428
11429
# File 'lib/google/apis/apigee_v1/classes.rb', line 11427

def traffic_count
  @traffic_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11434
11435
11436
11437
11438
11439
11440
11441
11442
11443
11444
# File 'lib/google/apis/apigee_v1/classes.rb', line 11434

def update!(**args)
  @detection_types = args[:detection_types] if args.key?(:detection_types)
  @display_name = args[:display_name] if args.key?(:display_name)
  @first_detected_time = args[:first_detected_time] if args.key?(:first_detected_time)
  @last_detected_time = args[:last_detected_time] if args.key?(:last_detected_time)
  @last_observability_change_time = args[:last_observability_change_time] if args.key?(:last_observability_change_time)
  @name = args[:name] if args.key?(:name)
  @observability = args[:observability] if args.key?(:observability)
  @risk_level = args[:risk_level] if args.key?(:risk_level)
  @traffic_count = args[:traffic_count] if args.key?(:traffic_count)
end