Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityMonitoringCondition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Security monitoring condition for risk assessment version 2.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityMonitoringCondition

Returns a new instance of GoogleCloudApigeeV1SecurityMonitoringCondition.



11580
11581
11582
# File 'lib/google/apis/apigee_v1/classes.rb', line 11580

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_hub_gatewayString

Optional. The API Hub gateway monitored by the security monitoring condition. This should only be set if risk_assessment_type is API_HUB. Format: projects/ project/locations/location/plugins/plugin/instances/instance` Corresponds to the JSON propertyapiHubGateway`

Returns:

  • (String)


11523
11524
11525
# File 'lib/google/apis/apigee_v1/classes.rb', line 11523

def api_hub_gateway
  @api_hub_gateway
end

#create_timeString

Output only. The time of the security monitoring condition creation. Corresponds to the JSON property createTime

Returns:

  • (String)


11528
11529
11530
# File 'lib/google/apis/apigee_v1/classes.rb', line 11528

def create_time
  @create_time
end

#includeGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequestResourceArray

Message for the array of resources. For Apigee, the proxies are resources. Corresponds to the JSON property include



11533
11534
11535
# File 'lib/google/apis/apigee_v1/classes.rb', line 11533

def include
  @include
end

#include_all_resourcesGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequestIncludeAll

Message for include_all_resources option. Corresponds to the JSON property includeAllResources



11538
11539
11540
# File 'lib/google/apis/apigee_v1/classes.rb', line 11538

def include_all_resources
  @include_all_resources
end

#nameString

Identifier. Name of the security monitoring condition resource. Format: organizations/org/securityMonitoringConditions/ security_monitoring_condition Corresponds to the JSON property name

Returns:

  • (String)


11545
11546
11547
# File 'lib/google/apis/apigee_v1/classes.rb', line 11545

def name
  @name
end

#profileString

Required. ID of security profile of the security monitoring condition. Corresponds to the JSON property profile

Returns:

  • (String)


11550
11551
11552
# File 'lib/google/apis/apigee_v1/classes.rb', line 11550

def profile
  @profile
end

#risk_assessment_typeString

Optional. The risk assessment type of the security monitoring condition. Defaults to ADVANCED_API_SECURITY. Corresponds to the JSON property riskAssessmentType

Returns:

  • (String)


11556
11557
11558
# File 'lib/google/apis/apigee_v1/classes.rb', line 11556

def risk_assessment_type
  @risk_assessment_type
end

#scopeString

Optional. Scope of the security monitoring condition. When RiskAssessmentType is APIGEE, the scope should be set to the environment of the resources. When RiskAssessmentType is API_HUB, the scope should not be set. Corresponds to the JSON property scope

Returns:

  • (String)


11563
11564
11565
# File 'lib/google/apis/apigee_v1/classes.rb', line 11563

def scope
  @scope
end

#total_deployed_resourcesFixnum

Output only. Total number of deployed resources within scope. Corresponds to the JSON property totalDeployedResources

Returns:

  • (Fixnum)


11568
11569
11570
# File 'lib/google/apis/apigee_v1/classes.rb', line 11568

def total_deployed_resources
  @total_deployed_resources
end

#total_monitored_resourcesFixnum

Output only. Total number of monitored resources within this condition. Corresponds to the JSON property totalMonitoredResources

Returns:

  • (Fixnum)


11573
11574
11575
# File 'lib/google/apis/apigee_v1/classes.rb', line 11573

def total_monitored_resources
  @total_monitored_resources
end

#update_timeString

Output only. The time of the security monitoring condition update. Corresponds to the JSON property updateTime

Returns:

  • (String)


11578
11579
11580
# File 'lib/google/apis/apigee_v1/classes.rb', line 11578

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11585
11586
11587
11588
11589
11590
11591
11592
11593
11594
11595
11596
11597
# File 'lib/google/apis/apigee_v1/classes.rb', line 11585

def update!(**args)
  @api_hub_gateway = args[:api_hub_gateway] if args.key?(:api_hub_gateway)
  @create_time = args[:create_time] if args.key?(:create_time)
  @include = args[:include] if args.key?(:include)
  @include_all_resources = args[:include_all_resources] if args.key?(:include_all_resources)
  @name = args[:name] if args.key?(:name)
  @profile = args[:profile] if args.key?(:profile)
  @risk_assessment_type = args[:risk_assessment_type] if args.key?(:risk_assessment_type)
  @scope = args[:scope] if args.key?(:scope)
  @total_deployed_resources = args[:total_deployed_resources] if args.key?(:total_deployed_resources)
  @total_monitored_resources = args[:total_monitored_resources] if args.key?(:total_monitored_resources)
  @update_time = args[:update_time] if args.key?(:update_time)
end