Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityMonitoringCondition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Security monitoring condition for risk assessment version 2.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityMonitoringCondition

Returns a new instance of GoogleCloudApigeeV1SecurityMonitoringCondition.



11513
11514
11515
# File 'lib/google/apis/apigee_v1/classes.rb', line 11513

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_hub_gatewayString

Optional. The API Hub gateway monitored by the security monitoring condition. This should only be set if risk_assessment_type is API_HUB. Format: projects/ project/locations/location/plugins/plugin/instances/instance` Corresponds to the JSON propertyapiHubGateway`

Returns:

  • (String)


11456
11457
11458
# File 'lib/google/apis/apigee_v1/classes.rb', line 11456

def api_hub_gateway
  @api_hub_gateway
end

#create_timeString

Output only. The time of the security monitoring condition creation. Corresponds to the JSON property createTime

Returns:

  • (String)


11461
11462
11463
# File 'lib/google/apis/apigee_v1/classes.rb', line 11461

def create_time
  @create_time
end

#includeGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequestResourceArray

Message for the array of resources. For Apigee, the proxies are resources. Corresponds to the JSON property include



11466
11467
11468
# File 'lib/google/apis/apigee_v1/classes.rb', line 11466

def include
  @include
end

#include_all_resourcesGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequestIncludeAll

Message for include_all_resources option. Corresponds to the JSON property includeAllResources



11471
11472
11473
# File 'lib/google/apis/apigee_v1/classes.rb', line 11471

def include_all_resources
  @include_all_resources
end

#nameString

Identifier. Name of the security monitoring condition resource. Format: organizations/org/securityMonitoringConditions/ security_monitoring_condition Corresponds to the JSON property name

Returns:

  • (String)


11478
11479
11480
# File 'lib/google/apis/apigee_v1/classes.rb', line 11478

def name
  @name
end

#profileString

Required. ID of security profile of the security monitoring condition. Corresponds to the JSON property profile

Returns:

  • (String)


11483
11484
11485
# File 'lib/google/apis/apigee_v1/classes.rb', line 11483

def profile
  @profile
end

#risk_assessment_typeString

Optional. The risk assessment type of the security monitoring condition. Defaults to ADVANCED_API_SECURITY. Corresponds to the JSON property riskAssessmentType

Returns:

  • (String)


11489
11490
11491
# File 'lib/google/apis/apigee_v1/classes.rb', line 11489

def risk_assessment_type
  @risk_assessment_type
end

#scopeString

Optional. Scope of the security monitoring condition. When RiskAssessmentType is APIGEE, the scope should be set to the environment of the resources. When RiskAssessmentType is API_HUB, the scope should not be set. Corresponds to the JSON property scope

Returns:

  • (String)


11496
11497
11498
# File 'lib/google/apis/apigee_v1/classes.rb', line 11496

def scope
  @scope
end

#total_deployed_resourcesFixnum

Output only. Total number of deployed resources within scope. Corresponds to the JSON property totalDeployedResources

Returns:

  • (Fixnum)


11501
11502
11503
# File 'lib/google/apis/apigee_v1/classes.rb', line 11501

def total_deployed_resources
  @total_deployed_resources
end

#total_monitored_resourcesFixnum

Output only. Total number of monitored resources within this condition. Corresponds to the JSON property totalMonitoredResources

Returns:

  • (Fixnum)


11506
11507
11508
# File 'lib/google/apis/apigee_v1/classes.rb', line 11506

def total_monitored_resources
  @total_monitored_resources
end

#update_timeString

Output only. The time of the security monitoring condition update. Corresponds to the JSON property updateTime

Returns:

  • (String)


11511
11512
11513
# File 'lib/google/apis/apigee_v1/classes.rb', line 11511

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11518
11519
11520
11521
11522
11523
11524
11525
11526
11527
11528
11529
11530
# File 'lib/google/apis/apigee_v1/classes.rb', line 11518

def update!(**args)
  @api_hub_gateway = args[:api_hub_gateway] if args.key?(:api_hub_gateway)
  @create_time = args[:create_time] if args.key?(:create_time)
  @include = args[:include] if args.key?(:include)
  @include_all_resources = args[:include_all_resources] if args.key?(:include_all_resources)
  @name = args[:name] if args.key?(:name)
  @profile = args[:profile] if args.key?(:profile)
  @risk_assessment_type = args[:risk_assessment_type] if args.key?(:risk_assessment_type)
  @scope = args[:scope] if args.key?(:scope)
  @total_deployed_resources = args[:total_deployed_resources] if args.key?(:total_deployed_resources)
  @total_monitored_resources = args[:total_monitored_resources] if args.key?(:total_monitored_resources)
  @update_time = args[:update_time] if args.key?(:update_time)
end