Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityMonitoringCondition

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Security monitoring condition for risk assessment version 2.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityMonitoringCondition

Returns a new instance of GoogleCloudApigeeV1SecurityMonitoringCondition.



11420
11421
11422
# File 'lib/google/apis/apigee_v1/classes.rb', line 11420

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The time of the security monitoring condition creation. Corresponds to the JSON property createTime

Returns:

  • (String)


11375
11376
11377
# File 'lib/google/apis/apigee_v1/classes.rb', line 11375

def create_time
  @create_time
end

#includeGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequestResourceArray

Message for the array of resources. For Apigee, the proxies are resources. Corresponds to the JSON property include



11380
11381
11382
# File 'lib/google/apis/apigee_v1/classes.rb', line 11380

def include
  @include
end

#include_all_resourcesGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1BatchComputeSecurityAssessmentResultsRequestIncludeAll

Message for include_all_resources option. Corresponds to the JSON property includeAllResources



11385
11386
11387
# File 'lib/google/apis/apigee_v1/classes.rb', line 11385

def include_all_resources
  @include_all_resources
end

#nameString

Identifier. Name of the security monitoring condition resource. Format: organizations/org/securityMonitoringConditions/ security_monitoring_condition Corresponds to the JSON property name

Returns:

  • (String)


11392
11393
11394
# File 'lib/google/apis/apigee_v1/classes.rb', line 11392

def name
  @name
end

#profileString

Required. ID of security profile of the security monitoring condition. Corresponds to the JSON property profile

Returns:

  • (String)


11397
11398
11399
# File 'lib/google/apis/apigee_v1/classes.rb', line 11397

def profile
  @profile
end

#scopeString

Optional. Scope of the security monitoring condition. For Apigee, the environment is the scope of the resources. Corresponds to the JSON property scope

Returns:

  • (String)


11403
11404
11405
# File 'lib/google/apis/apigee_v1/classes.rb', line 11403

def scope
  @scope
end

#total_deployed_resourcesFixnum

Output only. Total number of deployed resources within scope. Corresponds to the JSON property totalDeployedResources

Returns:

  • (Fixnum)


11408
11409
11410
# File 'lib/google/apis/apigee_v1/classes.rb', line 11408

def total_deployed_resources
  @total_deployed_resources
end

#total_monitored_resourcesFixnum

Output only. Total number of monitored resources within this condition. Corresponds to the JSON property totalMonitoredResources

Returns:

  • (Fixnum)


11413
11414
11415
# File 'lib/google/apis/apigee_v1/classes.rb', line 11413

def total_monitored_resources
  @total_monitored_resources
end

#update_timeString

Output only. The time of the security monitoring condition update. Corresponds to the JSON property updateTime

Returns:

  • (String)


11418
11419
11420
# File 'lib/google/apis/apigee_v1/classes.rb', line 11418

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11425
11426
11427
11428
11429
11430
11431
11432
11433
11434
11435
# File 'lib/google/apis/apigee_v1/classes.rb', line 11425

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @include = args[:include] if args.key?(:include)
  @include_all_resources = args[:include_all_resources] if args.key?(:include_all_resources)
  @name = args[:name] if args.key?(:name)
  @profile = args[:profile] if args.key?(:profile)
  @scope = args[:scope] if args.key?(:scope)
  @total_deployed_resources = args[:total_deployed_resources] if args.key?(:total_deployed_resources)
  @total_monitored_resources = args[:total_monitored_resources] if args.key?(:total_monitored_resources)
  @update_time = args[:update_time] if args.key?(:update_time)
end