Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Represents a SecurityProfile resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityProfile

Returns a new instance of GoogleCloudApigeeV1SecurityProfile.



11668
11669
11670
# File 'lib/google/apis/apigee_v1/classes.rb', line 11668

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Description of the security profile. Corresponds to the JSON property description

Returns:

  • (String)


11607
11608
11609
# File 'lib/google/apis/apigee_v1/classes.rb', line 11607

def description
  @description
end

#display_nameString

DEPRECATED: DO NOT USE Display name of the security profile. Corresponds to the JSON property displayName

Returns:

  • (String)


11612
11613
11614
# File 'lib/google/apis/apigee_v1/classes.rb', line 11612

def display_name
  @display_name
end

#environmentsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityProfileEnvironment>

List of environments attached to security profile. Corresponds to the JSON property environments



11617
11618
11619
# File 'lib/google/apis/apigee_v1/classes.rb', line 11617

def environments
  @environments
end

#max_scoreFixnum

Output only. Maximum security score that can be generated by this profile. Corresponds to the JSON property maxScore

Returns:

  • (Fixnum)


11622
11623
11624
# File 'lib/google/apis/apigee_v1/classes.rb', line 11622

def max_score
  @max_score
end

#min_scoreFixnum

Output only. Minimum security score that can be generated by this profile. Corresponds to the JSON property minScore

Returns:

  • (Fixnum)


11627
11628
11629
# File 'lib/google/apis/apigee_v1/classes.rb', line 11627

def min_score
  @min_score
end

#nameString

Immutable. Name of the security profile resource. Format: organizations/org/ securityProfiles/profile Corresponds to the JSON property name

Returns:

  • (String)


11633
11634
11635
# File 'lib/google/apis/apigee_v1/classes.rb', line 11633

def name
  @name
end

#profile_configGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfig

ProfileConfig defines a set of categories and policies which will be used to compute security score. Corresponds to the JSON property profileConfig



11639
11640
11641
# File 'lib/google/apis/apigee_v1/classes.rb', line 11639

def profile_config
  @profile_config
end

#revision_create_timeString

Output only. The time when revision was created. Corresponds to the JSON property revisionCreateTime

Returns:

  • (String)


11644
11645
11646
# File 'lib/google/apis/apigee_v1/classes.rb', line 11644

def revision_create_time
  @revision_create_time
end

#revision_idFixnum

Output only. Revision ID of the security profile. Corresponds to the JSON property revisionId

Returns:

  • (Fixnum)


11649
11650
11651
# File 'lib/google/apis/apigee_v1/classes.rb', line 11649

def revision_id
  @revision_id
end

#revision_publish_timeString

Output only. DEPRECATED: DO NOT USE The time when revision was published. Once published, the security profile revision cannot be updated further and can be attached to environments. Corresponds to the JSON property revisionPublishTime

Returns:

  • (String)


11656
11657
11658
# File 'lib/google/apis/apigee_v1/classes.rb', line 11656

def revision_publish_time
  @revision_publish_time
end

#revision_update_timeString

Output only. The time when revision was updated. Corresponds to the JSON property revisionUpdateTime

Returns:

  • (String)


11661
11662
11663
# File 'lib/google/apis/apigee_v1/classes.rb', line 11661

def revision_update_time
  @revision_update_time
end

#scoring_configsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityProfileScoringConfig>

List of profile scoring configs in this revision. Corresponds to the JSON property scoringConfigs



11666
11667
11668
# File 'lib/google/apis/apigee_v1/classes.rb', line 11666

def scoring_configs
  @scoring_configs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11673
11674
11675
11676
11677
11678
11679
11680
11681
11682
11683
11684
11685
11686
# File 'lib/google/apis/apigee_v1/classes.rb', line 11673

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @environments = args[:environments] if args.key?(:environments)
  @max_score = args[:max_score] if args.key?(:max_score)
  @min_score = args[:min_score] if args.key?(:min_score)
  @name = args[:name] if args.key?(:name)
  @profile_config = args[:profile_config] if args.key?(:profile_config)
  @revision_create_time = args[:revision_create_time] if args.key?(:revision_create_time)
  @revision_id = args[:revision_id] if args.key?(:revision_id)
  @revision_publish_time = args[:revision_publish_time] if args.key?(:revision_publish_time)
  @revision_update_time = args[:revision_update_time] if args.key?(:revision_update_time)
  @scoring_configs = args[:scoring_configs] if args.key?(:scoring_configs)
end