Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Represents a SecurityProfile resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityProfile

Returns a new instance of GoogleCloudApigeeV1SecurityProfile.



11601
11602
11603
# File 'lib/google/apis/apigee_v1/classes.rb', line 11601

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Description of the security profile. Corresponds to the JSON property description

Returns:

  • (String)


11540
11541
11542
# File 'lib/google/apis/apigee_v1/classes.rb', line 11540

def description
  @description
end

#display_nameString

DEPRECATED: DO NOT USE Display name of the security profile. Corresponds to the JSON property displayName

Returns:

  • (String)


11545
11546
11547
# File 'lib/google/apis/apigee_v1/classes.rb', line 11545

def display_name
  @display_name
end

#environmentsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityProfileEnvironment>

List of environments attached to security profile. Corresponds to the JSON property environments



11550
11551
11552
# File 'lib/google/apis/apigee_v1/classes.rb', line 11550

def environments
  @environments
end

#max_scoreFixnum

Output only. Maximum security score that can be generated by this profile. Corresponds to the JSON property maxScore

Returns:

  • (Fixnum)


11555
11556
11557
# File 'lib/google/apis/apigee_v1/classes.rb', line 11555

def max_score
  @max_score
end

#min_scoreFixnum

Output only. Minimum security score that can be generated by this profile. Corresponds to the JSON property minScore

Returns:

  • (Fixnum)


11560
11561
11562
# File 'lib/google/apis/apigee_v1/classes.rb', line 11560

def min_score
  @min_score
end

#nameString

Immutable. Name of the security profile resource. Format: organizations/org/ securityProfiles/profile Corresponds to the JSON property name

Returns:

  • (String)


11566
11567
11568
# File 'lib/google/apis/apigee_v1/classes.rb', line 11566

def name
  @name
end

#profile_configGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfig

ProfileConfig defines a set of categories and policies which will be used to compute security score. Corresponds to the JSON property profileConfig



11572
11573
11574
# File 'lib/google/apis/apigee_v1/classes.rb', line 11572

def profile_config
  @profile_config
end

#revision_create_timeString

Output only. The time when revision was created. Corresponds to the JSON property revisionCreateTime

Returns:

  • (String)


11577
11578
11579
# File 'lib/google/apis/apigee_v1/classes.rb', line 11577

def revision_create_time
  @revision_create_time
end

#revision_idFixnum

Output only. Revision ID of the security profile. Corresponds to the JSON property revisionId

Returns:

  • (Fixnum)


11582
11583
11584
# File 'lib/google/apis/apigee_v1/classes.rb', line 11582

def revision_id
  @revision_id
end

#revision_publish_timeString

Output only. DEPRECATED: DO NOT USE The time when revision was published. Once published, the security profile revision cannot be updated further and can be attached to environments. Corresponds to the JSON property revisionPublishTime

Returns:

  • (String)


11589
11590
11591
# File 'lib/google/apis/apigee_v1/classes.rb', line 11589

def revision_publish_time
  @revision_publish_time
end

#revision_update_timeString

Output only. The time when revision was updated. Corresponds to the JSON property revisionUpdateTime

Returns:

  • (String)


11594
11595
11596
# File 'lib/google/apis/apigee_v1/classes.rb', line 11594

def revision_update_time
  @revision_update_time
end

#scoring_configsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityProfileScoringConfig>

List of profile scoring configs in this revision. Corresponds to the JSON property scoringConfigs



11599
11600
11601
# File 'lib/google/apis/apigee_v1/classes.rb', line 11599

def scoring_configs
  @scoring_configs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11606
11607
11608
11609
11610
11611
11612
11613
11614
11615
11616
11617
11618
11619
# File 'lib/google/apis/apigee_v1/classes.rb', line 11606

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @environments = args[:environments] if args.key?(:environments)
  @max_score = args[:max_score] if args.key?(:max_score)
  @min_score = args[:min_score] if args.key?(:min_score)
  @name = args[:name] if args.key?(:name)
  @profile_config = args[:profile_config] if args.key?(:profile_config)
  @revision_create_time = args[:revision_create_time] if args.key?(:revision_create_time)
  @revision_id = args[:revision_id] if args.key?(:revision_id)
  @revision_publish_time = args[:revision_publish_time] if args.key?(:revision_publish_time)
  @revision_update_time = args[:revision_update_time] if args.key?(:revision_update_time)
  @scoring_configs = args[:scoring_configs] if args.key?(:scoring_configs)
end