Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityProfile
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityProfile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Represents a SecurityProfile resource.
Instance Attribute Summary collapse
-
#description ⇒ String
Description of the security profile.
-
#display_name ⇒ String
DEPRECATED: DO NOT USE Display name of the security profile.
-
#environments ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityProfileEnvironment>
List of environments attached to security profile.
-
#max_score ⇒ Fixnum
Output only.
-
#min_score ⇒ Fixnum
Output only.
-
#name ⇒ String
Immutable.
-
#profile_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfig
ProfileConfig defines a set of categories and policies which will be used to compute security score.
-
#revision_create_time ⇒ String
Output only.
-
#revision_id ⇒ Fixnum
Output only.
-
#revision_publish_time ⇒ String
Output only.
-
#revision_update_time ⇒ String
Output only.
-
#scoring_configs ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityProfileScoringConfig>
List of profile scoring configs in this revision.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityProfile
constructor
A new instance of GoogleCloudApigeeV1SecurityProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityProfile
Returns a new instance of GoogleCloudApigeeV1SecurityProfile.
11506 11507 11508 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11506 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Description of the security profile.
Corresponds to the JSON property description
11445 11446 11447 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11445 def description @description end |
#display_name ⇒ String
DEPRECATED: DO NOT USE Display name of the security profile.
Corresponds to the JSON property displayName
11450 11451 11452 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11450 def display_name @display_name end |
#environments ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityProfileEnvironment>
List of environments attached to security profile.
Corresponds to the JSON property environments
11455 11456 11457 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11455 def environments @environments end |
#max_score ⇒ Fixnum
Output only. Maximum security score that can be generated by this profile.
Corresponds to the JSON property maxScore
11460 11461 11462 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11460 def max_score @max_score end |
#min_score ⇒ Fixnum
Output only. Minimum security score that can be generated by this profile.
Corresponds to the JSON property minScore
11465 11466 11467 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11465 def min_score @min_score end |
#name ⇒ String
Immutable. Name of the security profile resource. Format: organizations/org/
securityProfiles/profile
Corresponds to the JSON property name
11471 11472 11473 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11471 def name @name end |
#profile_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ProfileConfig
ProfileConfig defines a set of categories and policies which will be used to
compute security score.
Corresponds to the JSON property profileConfig
11477 11478 11479 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11477 def profile_config @profile_config end |
#revision_create_time ⇒ String
Output only. The time when revision was created.
Corresponds to the JSON property revisionCreateTime
11482 11483 11484 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11482 def revision_create_time @revision_create_time end |
#revision_id ⇒ Fixnum
Output only. Revision ID of the security profile.
Corresponds to the JSON property revisionId
11487 11488 11489 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11487 def revision_id @revision_id end |
#revision_publish_time ⇒ String
Output only. DEPRECATED: DO NOT USE The time when revision was published. Once
published, the security profile revision cannot be updated further and can be
attached to environments.
Corresponds to the JSON property revisionPublishTime
11494 11495 11496 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11494 def revision_publish_time @revision_publish_time end |
#revision_update_time ⇒ String
Output only. The time when revision was updated.
Corresponds to the JSON property revisionUpdateTime
11499 11500 11501 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11499 def revision_update_time @revision_update_time end |
#scoring_configs ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityProfileScoringConfig>
List of profile scoring configs in this revision.
Corresponds to the JSON property scoringConfigs
11504 11505 11506 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11504 def scoring_configs @scoring_configs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11511 11512 11513 11514 11515 11516 11517 11518 11519 11520 11521 11522 11523 11524 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11511 def update!(**args) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @environments = args[:environments] if args.key?(:environments) @max_score = args[:max_score] if args.key?(:max_score) @min_score = args[:min_score] if args.key?(:min_score) @name = args[:name] if args.key?(:name) @profile_config = args[:profile_config] if args.key?(:profile_config) @revision_create_time = args[:revision_create_time] if args.key?(:revision_create_time) @revision_id = args[:revision_id] if args.key?(:revision_id) @revision_publish_time = args[:revision_publish_time] if args.key?(:revision_publish_time) @revision_update_time = args[:revision_update_time] if args.key?(:revision_update_time) @scoring_configs = args[:scoring_configs] if args.key?(:scoring_configs) end |