Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityProfileEnvironmentAssociation
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityProfileEnvironmentAssociation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Represents a SecurityProfileEnvironmentAssociation resource.
Instance Attribute Summary collapse
-
#attach_time ⇒ String
Output only.
-
#name ⇒ String
Immutable.
-
#security_profile_revision_id ⇒ Fixnum
DEPRECATED: DO NOT USE Revision ID of the security profile.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityProfileEnvironmentAssociation
constructor
A new instance of GoogleCloudApigeeV1SecurityProfileEnvironmentAssociation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityProfileEnvironmentAssociation
Returns a new instance of GoogleCloudApigeeV1SecurityProfileEnvironmentAssociation.
11667 11668 11669 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11667 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attach_time ⇒ String
Output only. The time when environment was attached to the security profile.
Corresponds to the JSON property attachTime
11655 11656 11657 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11655 def attach_time @attach_time end |
#name ⇒ String
Immutable. Name of the environment that the profile is attached to.
Corresponds to the JSON property name
11660 11661 11662 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11660 def name @name end |
#security_profile_revision_id ⇒ Fixnum
DEPRECATED: DO NOT USE Revision ID of the security profile.
Corresponds to the JSON property securityProfileRevisionId
11665 11666 11667 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11665 def security_profile_revision_id @security_profile_revision_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11672 11673 11674 11675 11676 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 11672 def update!(**args) @attach_time = args[:attach_time] if args.key?(:attach_time) @name = args[:name] if args.key?(:name) @security_profile_revision_id = args[:security_profile_revision_id] if args.key?(:security_profile_revision_id) end |