Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityReport

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

SecurityReport saves all the information about the created security report.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityReport

Returns a new instance of GoogleCloudApigeeV1SecurityReport.



11848
11849
11850
# File 'lib/google/apis/apigee_v1/classes.rb', line 11848

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createdString

Creation time of the query. Corresponds to the JSON property created

Returns:

  • (String)


11782
11783
11784
# File 'lib/google/apis/apigee_v1/classes.rb', line 11782

def created
  @created
end

#display_nameString

Display Name specified by the user. Corresponds to the JSON property displayName

Returns:

  • (String)


11787
11788
11789
# File 'lib/google/apis/apigee_v1/classes.rb', line 11787

def display_name
  @display_name
end

#envgroup_hostnameString

Hostname is available only when query is executed at host level. Corresponds to the JSON property envgroupHostname

Returns:

  • (String)


11792
11793
11794
# File 'lib/google/apis/apigee_v1/classes.rb', line 11792

def envgroup_hostname
  @envgroup_hostname
end

#errorString

Error is set when query fails. Corresponds to the JSON property error

Returns:

  • (String)


11797
11798
11799
# File 'lib/google/apis/apigee_v1/classes.rb', line 11797

def error
  @error
end

#execution_timeString

ExecutionTime is available only after the query is completed. Corresponds to the JSON property executionTime

Returns:

  • (String)


11802
11803
11804
# File 'lib/google/apis/apigee_v1/classes.rb', line 11802

def execution_time
  @execution_time
end

#query_paramsGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityReportMetadata

Metadata for the security report. Corresponds to the JSON property queryParams



11807
11808
11809
# File 'lib/google/apis/apigee_v1/classes.rb', line 11807

def query_params
  @query_params
end

#report_definition_idString

Report Definition ID. Corresponds to the JSON property reportDefinitionId

Returns:

  • (String)


11812
11813
11814
# File 'lib/google/apis/apigee_v1/classes.rb', line 11812

def report_definition_id
  @report_definition_id
end

#resultGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityReportResultMetadata

Contains informations about the security report results. Corresponds to the JSON property result



11817
11818
11819
# File 'lib/google/apis/apigee_v1/classes.rb', line 11817

def result
  @result
end

#result_file_sizeString

ResultFileSize is available only after the query is completed. Corresponds to the JSON property resultFileSize

Returns:

  • (String)


11822
11823
11824
# File 'lib/google/apis/apigee_v1/classes.rb', line 11822

def result_file_size
  @result_file_size
end

#result_rowsFixnum

ResultRows is available only after the query is completed. Corresponds to the JSON property resultRows

Returns:

  • (Fixnum)


11827
11828
11829
# File 'lib/google/apis/apigee_v1/classes.rb', line 11827

def result_rows
  @result_rows
end

#selfString

Self link of the query. Example: /organizations/myorg/environments/myenv/ securityReports/9cfc0d85-0f30-46d6-ae6f-318d0cb961bd or following format if query is running at host level: /organizations/myorg/hostSecurityReports/ 9cfc0d85-0f30-46d6-ae6f-318d0cb961bd Corresponds to the JSON property self

Returns:

  • (String)


11835
11836
11837
# File 'lib/google/apis/apigee_v1/classes.rb', line 11835

def self
  @self
end

#stateString

Query state could be "enqueued", "running", "completed", "expired" and "failed" . Corresponds to the JSON property state

Returns:

  • (String)


11841
11842
11843
# File 'lib/google/apis/apigee_v1/classes.rb', line 11841

def state
  @state
end

#updatedString

Output only. Last updated timestamp for the query. Corresponds to the JSON property updated

Returns:

  • (String)


11846
11847
11848
# File 'lib/google/apis/apigee_v1/classes.rb', line 11846

def updated
  @updated
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11853
11854
11855
11856
11857
11858
11859
11860
11861
11862
11863
11864
11865
11866
11867
# File 'lib/google/apis/apigee_v1/classes.rb', line 11853

def update!(**args)
  @created = args[:created] if args.key?(:created)
  @display_name = args[:display_name] if args.key?(:display_name)
  @envgroup_hostname = args[:envgroup_hostname] if args.key?(:envgroup_hostname)
  @error = args[:error] if args.key?(:error)
  @execution_time = args[:execution_time] if args.key?(:execution_time)
  @query_params = args[:query_params] if args.key?(:query_params)
  @report_definition_id = args[:report_definition_id] if args.key?(:report_definition_id)
  @result = args[:result] if args.key?(:result)
  @result_file_size = args[:result_file_size] if args.key?(:result_file_size)
  @result_rows = args[:result_rows] if args.key?(:result_rows)
  @self = args[:self] if args.key?(:self)
  @state = args[:state] if args.key?(:state)
  @updated = args[:updated] if args.key?(:updated)
end