Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityReportQuery
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityReportQuery
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Body structure when user makes a request to create a security report.
Instance Attribute Summary collapse
-
#csv_delimiter ⇒ String
Delimiter used in the CSV file, if
outputFormatis set tocsv. -
#dimensions ⇒ Array<String>
A list of dimensions.
-
#display_name ⇒ String
Security Report display name which users can specify.
-
#envgroup_hostname ⇒ String
Hostname needs to be specified if query intends to run at host level.
-
#filter ⇒ String
Boolean expression that can be used to filter data.
-
#group_by_time_unit ⇒ String
Time unit used to group the result set.
-
#limit ⇒ Fixnum
Maximum number of rows that can be returned in the result.
-
#metrics ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityReportQueryMetric>
A list of Metrics.
-
#mime_type ⇒ String
Valid values include:
csvorjson. -
#report_definition_id ⇒ String
Report Definition ID.
-
#time_range ⇒ Object
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityReportQuery
constructor
A new instance of GoogleCloudApigeeV1SecurityReportQuery.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityReportQuery
Returns a new instance of GoogleCloudApigeeV1SecurityReportQuery.
12105 12106 12107 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12105 def initialize(**args) update!(**args) end |
Instance Attribute Details
#csv_delimiter ⇒ String
Delimiter used in the CSV file, if outputFormat is set to csv. Defaults to
the , (comma) character. Supported delimiter characters include comma (,),
pipe (|), and tab (\t).
Corresponds to the JSON property csvDelimiter
12034 12035 12036 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12034 def csv_delimiter @csv_delimiter end |
#dimensions ⇒ Array<String>
A list of dimensions. https://docs.apigee.com/api-platform/analytics/analytics-
reference#dimensions
Corresponds to the JSON property dimensions
12040 12041 12042 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12040 def dimensions @dimensions end |
#display_name ⇒ String
Security Report display name which users can specify.
Corresponds to the JSON property displayName
12045 12046 12047 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12045 def display_name @display_name end |
#envgroup_hostname ⇒ String
Hostname needs to be specified if query intends to run at host level. This
field is only allowed when query is submitted by CreateHostSecurityReport
where analytics data will be grouped by organization and hostname.
Corresponds to the JSON property envgroupHostname
12052 12053 12054 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12052 def envgroup_hostname @envgroup_hostname end |
#filter ⇒ String
Boolean expression that can be used to filter data. Filter expressions can be
combined using AND/OR terms and should be fully parenthesized to avoid
ambiguity. See Analytics metrics, dimensions, and filters reference https://
docs.apigee.com/api-platform/analytics/analytics-reference for more
information on the fields available to filter on. For more information on the
tokens that you use to build filter expressions, see Filter expression syntax.
https://docs.apigee.com/api-platform/analytics/asynch-reports-api#filter-
expression-syntax
Corresponds to the JSON property filter
12064 12065 12066 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12064 def filter @filter end |
#group_by_time_unit ⇒ String
Time unit used to group the result set. Valid values include: second, minute,
hour, day, week, or month. If a query includes groupByTimeUnit, then the
result is an aggregation based on the specified time unit and the resultant
timestamp does not include milliseconds precision. If a query omits
groupByTimeUnit, then the resultant timestamp includes milliseconds precision.
Corresponds to the JSON property groupByTimeUnit
12073 12074 12075 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12073 def group_by_time_unit @group_by_time_unit end |
#limit ⇒ Fixnum
Maximum number of rows that can be returned in the result.
Corresponds to the JSON property limit
12078 12079 12080 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12078 def limit @limit end |
#metrics ⇒ Array<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityReportQueryMetric>
A list of Metrics.
Corresponds to the JSON property metrics
12083 12084 12085 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12083 def metrics @metrics end |
#mime_type ⇒ String
Valid values include: csv or json. Defaults to json. Note: Configure the
delimiter for CSV output using the csvDelimiter property.
Corresponds to the JSON property mimeType
12089 12090 12091 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12089 def mime_type @mime_type end |
#report_definition_id ⇒ String
Report Definition ID.
Corresponds to the JSON property reportDefinitionId
12094 12095 12096 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12094 def report_definition_id @report_definition_id end |
#time_range ⇒ Object
Required. Time range for the query. Can use the following predefined strings
to specify the time range: last60minutes last24hours last7days Or,
specify the timeRange as a structure describing start and end timestamps in
the ISO format: yyyy-mm-ddThh:mm:ssZ. Example: "timeRange": "start": "2018-
07-29T00:13:00Z", "end": "2018-08-01T00:18:00Z"
Corresponds to the JSON property timeRange
12103 12104 12105 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12103 def time_range @time_range end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12110 12111 12112 12113 12114 12115 12116 12117 12118 12119 12120 12121 12122 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12110 def update!(**args) @csv_delimiter = args[:csv_delimiter] if args.key?(:csv_delimiter) @dimensions = args[:dimensions] if args.key?(:dimensions) @display_name = args[:display_name] if args.key?(:display_name) @envgroup_hostname = args[:envgroup_hostname] if args.key?(:envgroup_hostname) @filter = args[:filter] if args.key?(:filter) @group_by_time_unit = args[:group_by_time_unit] if args.key?(:group_by_time_unit) @limit = args[:limit] if args.key?(:limit) @metrics = args[:metrics] if args.key?(:metrics) @mime_type = args[:mime_type] if args.key?(:mime_type) @report_definition_id = args[:report_definition_id] if args.key?(:report_definition_id) @time_range = args[:time_range] if args.key?(:time_range) end |