Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityReportQuery

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Body structure when user makes a request to create a security report.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityReportQuery

Returns a new instance of GoogleCloudApigeeV1SecurityReportQuery.



11943
11944
11945
# File 'lib/google/apis/apigee_v1/classes.rb', line 11943

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#csv_delimiterString

Delimiter used in the CSV file, if outputFormat is set to csv. Defaults to the , (comma) character. Supported delimiter characters include comma (,), pipe (|), and tab (\t). Corresponds to the JSON property csvDelimiter

Returns:

  • (String)


11872
11873
11874
# File 'lib/google/apis/apigee_v1/classes.rb', line 11872

def csv_delimiter
  @csv_delimiter
end

#dimensionsArray<String>

A list of dimensions. https://docs.apigee.com/api-platform/analytics/analytics- reference#dimensions Corresponds to the JSON property dimensions

Returns:

  • (Array<String>)


11878
11879
11880
# File 'lib/google/apis/apigee_v1/classes.rb', line 11878

def dimensions
  @dimensions
end

#display_nameString

Security Report display name which users can specify. Corresponds to the JSON property displayName

Returns:

  • (String)


11883
11884
11885
# File 'lib/google/apis/apigee_v1/classes.rb', line 11883

def display_name
  @display_name
end

#envgroup_hostnameString

Hostname needs to be specified if query intends to run at host level. This field is only allowed when query is submitted by CreateHostSecurityReport where analytics data will be grouped by organization and hostname. Corresponds to the JSON property envgroupHostname

Returns:

  • (String)


11890
11891
11892
# File 'lib/google/apis/apigee_v1/classes.rb', line 11890

def envgroup_hostname
  @envgroup_hostname
end

#filterString

Boolean expression that can be used to filter data. Filter expressions can be combined using AND/OR terms and should be fully parenthesized to avoid ambiguity. See Analytics metrics, dimensions, and filters reference https:// docs.apigee.com/api-platform/analytics/analytics-reference for more information on the fields available to filter on. For more information on the tokens that you use to build filter expressions, see Filter expression syntax. https://docs.apigee.com/api-platform/analytics/asynch-reports-api#filter- expression-syntax Corresponds to the JSON property filter

Returns:

  • (String)


11902
11903
11904
# File 'lib/google/apis/apigee_v1/classes.rb', line 11902

def filter
  @filter
end

#group_by_time_unitString

Time unit used to group the result set. Valid values include: second, minute, hour, day, week, or month. If a query includes groupByTimeUnit, then the result is an aggregation based on the specified time unit and the resultant timestamp does not include milliseconds precision. If a query omits groupByTimeUnit, then the resultant timestamp includes milliseconds precision. Corresponds to the JSON property groupByTimeUnit

Returns:

  • (String)


11911
11912
11913
# File 'lib/google/apis/apigee_v1/classes.rb', line 11911

def group_by_time_unit
  @group_by_time_unit
end

#limitFixnum

Maximum number of rows that can be returned in the result. Corresponds to the JSON property limit

Returns:

  • (Fixnum)


11916
11917
11918
# File 'lib/google/apis/apigee_v1/classes.rb', line 11916

def limit
  @limit
end

#metricsArray<Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityReportQueryMetric>

A list of Metrics. Corresponds to the JSON property metrics



11921
11922
11923
# File 'lib/google/apis/apigee_v1/classes.rb', line 11921

def metrics
  @metrics
end

#mime_typeString

Valid values include: csv or json. Defaults to json. Note: Configure the delimiter for CSV output using the csvDelimiter property. Corresponds to the JSON property mimeType

Returns:

  • (String)


11927
11928
11929
# File 'lib/google/apis/apigee_v1/classes.rb', line 11927

def mime_type
  @mime_type
end

#report_definition_idString

Report Definition ID. Corresponds to the JSON property reportDefinitionId

Returns:

  • (String)


11932
11933
11934
# File 'lib/google/apis/apigee_v1/classes.rb', line 11932

def report_definition_id
  @report_definition_id
end

#time_rangeObject

Required. Time range for the query. Can use the following predefined strings to specify the time range: last60minutes last24hours last7days Or, specify the timeRange as a structure describing start and end timestamps in the ISO format: yyyy-mm-ddThh:mm:ssZ. Example: "timeRange": "start": "2018- 07-29T00:13:00Z", "end": "2018-08-01T00:18:00Z" Corresponds to the JSON property timeRange

Returns:

  • (Object)


11941
11942
11943
# File 'lib/google/apis/apigee_v1/classes.rb', line 11941

def time_range
  @time_range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11948
11949
11950
11951
11952
11953
11954
11955
11956
11957
11958
11959
11960
# File 'lib/google/apis/apigee_v1/classes.rb', line 11948

def update!(**args)
  @csv_delimiter = args[:csv_delimiter] if args.key?(:csv_delimiter)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @display_name = args[:display_name] if args.key?(:display_name)
  @envgroup_hostname = args[:envgroup_hostname] if args.key?(:envgroup_hostname)
  @filter = args[:filter] if args.key?(:filter)
  @group_by_time_unit = args[:group_by_time_unit] if args.key?(:group_by_time_unit)
  @limit = args[:limit] if args.key?(:limit)
  @metrics = args[:metrics] if args.key?(:metrics)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @report_definition_id = args[:report_definition_id] if args.key?(:report_definition_id)
  @time_range = args[:time_range] if args.key?(:time_range)
end