Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityReportQueryMetric

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Metric of the Query

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityReportQueryMetric

Returns a new instance of GoogleCloudApigeeV1SecurityReportQueryMetric.



12169
12170
12171
# File 'lib/google/apis/apigee_v1/classes.rb', line 12169

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregation_functionString

Aggregation function: avg, min, max, or sum. Corresponds to the JSON property aggregationFunction

Returns:

  • (String)


12146
12147
12148
# File 'lib/google/apis/apigee_v1/classes.rb', line 12146

def aggregation_function
  @aggregation_function
end

#aliasString

Alias for the metric. Alias will be used to replace metric name in query results. Corresponds to the JSON property alias

Returns:

  • (String)


12152
12153
12154
# File 'lib/google/apis/apigee_v1/classes.rb', line 12152

def alias
  @alias
end

#nameString

Required. Metric name. Corresponds to the JSON property name

Returns:

  • (String)


12157
12158
12159
# File 'lib/google/apis/apigee_v1/classes.rb', line 12157

def name
  @name
end

#operatorString

One of +, -, /, %, *. Corresponds to the JSON property operator

Returns:

  • (String)


12162
12163
12164
# File 'lib/google/apis/apigee_v1/classes.rb', line 12162

def operator
  @operator
end

#valueString

Operand value should be provided when operator is set. Corresponds to the JSON property value

Returns:

  • (String)


12167
12168
12169
# File 'lib/google/apis/apigee_v1/classes.rb', line 12167

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12174
12175
12176
12177
12178
12179
12180
# File 'lib/google/apis/apigee_v1/classes.rb', line 12174

def update!(**args)
  @aggregation_function = args[:aggregation_function] if args.key?(:aggregation_function)
  @alias = args[:alias] if args.key?(:alias)
  @name = args[:name] if args.key?(:name)
  @operator = args[:operator] if args.key?(:operator)
  @value = args[:value] if args.key?(:value)
end