Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SecurityReportQueryMetric

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Metric of the Query

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SecurityReportQueryMetric

Returns a new instance of GoogleCloudApigeeV1SecurityReportQueryMetric.



11993
11994
11995
# File 'lib/google/apis/apigee_v1/classes.rb', line 11993

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregation_functionString

Aggregation function: avg, min, max, or sum. Corresponds to the JSON property aggregationFunction

Returns:

  • (String)


11970
11971
11972
# File 'lib/google/apis/apigee_v1/classes.rb', line 11970

def aggregation_function
  @aggregation_function
end

#aliasString

Alias for the metric. Alias will be used to replace metric name in query results. Corresponds to the JSON property alias

Returns:

  • (String)


11976
11977
11978
# File 'lib/google/apis/apigee_v1/classes.rb', line 11976

def alias
  @alias
end

#nameString

Required. Metric name. Corresponds to the JSON property name

Returns:

  • (String)


11981
11982
11983
# File 'lib/google/apis/apigee_v1/classes.rb', line 11981

def name
  @name
end

#operatorString

One of +, -, /, %, *. Corresponds to the JSON property operator

Returns:

  • (String)


11986
11987
11988
# File 'lib/google/apis/apigee_v1/classes.rb', line 11986

def operator
  @operator
end

#valueString

Operand value should be provided when operator is set. Corresponds to the JSON property value

Returns:

  • (String)


11991
11992
11993
# File 'lib/google/apis/apigee_v1/classes.rb', line 11991

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11998
11999
12000
12001
12002
12003
12004
# File 'lib/google/apis/apigee_v1/classes.rb', line 11998

def update!(**args)
  @aggregation_function = args[:aggregation_function] if args.key?(:aggregation_function)
  @alias = args[:alias] if args.key?(:alias)
  @name = args[:name] if args.key?(:name)
  @operator = args[:operator] if args.key?(:operator)
  @value = args[:value] if args.key?(:value)
end