Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SharedFlow
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1SharedFlow
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
The metadata describing a shared flow
Instance Attribute Summary collapse
-
#latest_revision_id ⇒ String
The id of the most recently created revision for this shared flow.
-
#meta_data ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1EntityMetadata
Metadata common to many entities in this API.
-
#name ⇒ String
The ID of the shared flow.
-
#revision ⇒ Array<String>
A list of revisions of this shared flow.
-
#space ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1SharedFlow
constructor
A new instance of GoogleCloudApigeeV1SharedFlow.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1SharedFlow
Returns a new instance of GoogleCloudApigeeV1SharedFlow.
12413 12414 12415 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12413 def initialize(**args) update!(**args) end |
Instance Attribute Details
#latest_revision_id ⇒ String
The id of the most recently created revision for this shared flow.
Corresponds to the JSON property latestRevisionId
12387 12388 12389 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12387 def latest_revision_id @latest_revision_id end |
#meta_data ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1EntityMetadata
Metadata common to many entities in this API.
Corresponds to the JSON property metaData
12392 12393 12394 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12392 def @meta_data end |
#name ⇒ String
The ID of the shared flow.
Corresponds to the JSON property name
12397 12398 12399 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12397 def name @name end |
#revision ⇒ Array<String>
A list of revisions of this shared flow.
Corresponds to the JSON property revision
12402 12403 12404 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12402 def revision @revision end |
#space ⇒ String
Optional. The ID of the space associated with this shared flow. Any IAM
policies applied to the space will control access to this shared flow. To
learn how Spaces can be used to manage resources, read the Apigee Spaces
Overview.
Corresponds to the JSON property space
12411 12412 12413 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12411 def space @space end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12418 12419 12420 12421 12422 12423 12424 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12418 def update!(**args) @latest_revision_id = args[:latest_revision_id] if args.key?(:latest_revision_id) @meta_data = args[:meta_data] if args.key?(:meta_data) @name = args[:name] if args.key?(:name) @revision = args[:revision] if args.key?(:revision) @space = args[:space] if args.key?(:space) end |