Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SharedFlow

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

The metadata describing a shared flow

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SharedFlow

Returns a new instance of GoogleCloudApigeeV1SharedFlow.



12294
12295
12296
# File 'lib/google/apis/apigee_v1/classes.rb', line 12294

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#latest_revision_idString

The id of the most recently created revision for this shared flow. Corresponds to the JSON property latestRevisionId

Returns:

  • (String)


12268
12269
12270
# File 'lib/google/apis/apigee_v1/classes.rb', line 12268

def latest_revision_id
  @latest_revision_id
end

#meta_dataGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1EntityMetadata

Metadata common to many entities in this API. Corresponds to the JSON property metaData



12273
12274
12275
# File 'lib/google/apis/apigee_v1/classes.rb', line 12273

def 
  @meta_data
end

#nameString

The ID of the shared flow. Corresponds to the JSON property name

Returns:

  • (String)


12278
12279
12280
# File 'lib/google/apis/apigee_v1/classes.rb', line 12278

def name
  @name
end

#revisionArray<String>

A list of revisions of this shared flow. Corresponds to the JSON property revision

Returns:

  • (Array<String>)


12283
12284
12285
# File 'lib/google/apis/apigee_v1/classes.rb', line 12283

def revision
  @revision
end

#spaceString

Optional. The ID of the space associated with this shared flow. Any IAM policies applied to the space will control access to this shared flow. To learn how Spaces can be used to manage resources, read the Apigee Spaces Overview. Corresponds to the JSON property space

Returns:

  • (String)


12292
12293
12294
# File 'lib/google/apis/apigee_v1/classes.rb', line 12292

def space
  @space
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12299
12300
12301
12302
12303
12304
12305
# File 'lib/google/apis/apigee_v1/classes.rb', line 12299

def update!(**args)
  @latest_revision_id = args[:latest_revision_id] if args.key?(:latest_revision_id)
  @meta_data = args[:meta_data] if args.key?(:meta_data)
  @name = args[:name] if args.key?(:name)
  @revision = args[:revision] if args.key?(:revision)
  @space = args[:space] if args.key?(:space)
end