Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SharedFlow

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

The metadata describing a shared flow

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SharedFlow

Returns a new instance of GoogleCloudApigeeV1SharedFlow.



12332
12333
12334
# File 'lib/google/apis/apigee_v1/classes.rb', line 12332

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#latest_revision_idString

The id of the most recently created revision for this shared flow. Corresponds to the JSON property latestRevisionId

Returns:

  • (String)


12306
12307
12308
# File 'lib/google/apis/apigee_v1/classes.rb', line 12306

def latest_revision_id
  @latest_revision_id
end

#meta_dataGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1EntityMetadata

Metadata common to many entities in this API. Corresponds to the JSON property metaData



12311
12312
12313
# File 'lib/google/apis/apigee_v1/classes.rb', line 12311

def 
  @meta_data
end

#nameString

The ID of the shared flow. Corresponds to the JSON property name

Returns:

  • (String)


12316
12317
12318
# File 'lib/google/apis/apigee_v1/classes.rb', line 12316

def name
  @name
end

#revisionArray<String>

A list of revisions of this shared flow. Corresponds to the JSON property revision

Returns:

  • (Array<String>)


12321
12322
12323
# File 'lib/google/apis/apigee_v1/classes.rb', line 12321

def revision
  @revision
end

#spaceString

Optional. The ID of the space associated with this shared flow. Any IAM policies applied to the space will control access to this shared flow. To learn how Spaces can be used to manage resources, read the Apigee Spaces Overview. Corresponds to the JSON property space

Returns:

  • (String)


12330
12331
12332
# File 'lib/google/apis/apigee_v1/classes.rb', line 12330

def space
  @space
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12337
12338
12339
12340
12341
12342
12343
# File 'lib/google/apis/apigee_v1/classes.rb', line 12337

def update!(**args)
  @latest_revision_id = args[:latest_revision_id] if args.key?(:latest_revision_id)
  @meta_data = args[:meta_data] if args.key?(:meta_data)
  @name = args[:name] if args.key?(:name)
  @revision = args[:revision] if args.key?(:revision)
  @space = args[:space] if args.key?(:space)
end