Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SharedFlow

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

The metadata describing a shared flow

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SharedFlow

Returns a new instance of GoogleCloudApigeeV1SharedFlow.



12237
12238
12239
# File 'lib/google/apis/apigee_v1/classes.rb', line 12237

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#latest_revision_idString

The id of the most recently created revision for this shared flow. Corresponds to the JSON property latestRevisionId

Returns:

  • (String)


12211
12212
12213
# File 'lib/google/apis/apigee_v1/classes.rb', line 12211

def latest_revision_id
  @latest_revision_id
end

#meta_dataGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1EntityMetadata

Metadata common to many entities in this API. Corresponds to the JSON property metaData



12216
12217
12218
# File 'lib/google/apis/apigee_v1/classes.rb', line 12216

def 
  @meta_data
end

#nameString

The ID of the shared flow. Corresponds to the JSON property name

Returns:

  • (String)


12221
12222
12223
# File 'lib/google/apis/apigee_v1/classes.rb', line 12221

def name
  @name
end

#revisionArray<String>

A list of revisions of this shared flow. Corresponds to the JSON property revision

Returns:

  • (Array<String>)


12226
12227
12228
# File 'lib/google/apis/apigee_v1/classes.rb', line 12226

def revision
  @revision
end

#spaceString

Optional. The ID of the space associated with this shared flow. Any IAM policies applied to the space will control access to this shared flow. To learn how Spaces can be used to manage resources, read the Apigee Spaces Overview. Corresponds to the JSON property space

Returns:

  • (String)


12235
12236
12237
# File 'lib/google/apis/apigee_v1/classes.rb', line 12235

def space
  @space
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12242
12243
12244
12245
12246
12247
12248
# File 'lib/google/apis/apigee_v1/classes.rb', line 12242

def update!(**args)
  @latest_revision_id = args[:latest_revision_id] if args.key?(:latest_revision_id)
  @meta_data = args[:meta_data] if args.key?(:meta_data)
  @name = args[:name] if args.key?(:name)
  @revision = args[:revision] if args.key?(:revision)
  @space = args[:space] if args.key?(:space)
end