Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SharedFlowRevision
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1SharedFlowRevision
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
The metadata describing a shared flow revision.
Instance Attribute Summary collapse
-
#configuration_version ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ConfigVersion
Version of the API proxy configuration schema.
-
#context_info ⇒ String
A textual description of the shared flow revision.
-
#created_at ⇒ Fixnum
Time at which this shared flow revision was created, in milliseconds since epoch.
-
#description ⇒ String
Description of the shared flow revision.
-
#display_name ⇒ String
The human readable name of this shared flow.
-
#entity_meta_data_as_properties ⇒ Hash<String,String>
A Key-Value map of metadata about this shared flow revision.
-
#last_modified_at ⇒ Fixnum
Time at which this shared flow revision was most recently modified, in milliseconds since epoch.
-
#name ⇒ String
The resource ID of the parent shared flow.
-
#policies ⇒ Array<String>
A list of policy names included in this shared flow revision.
-
#resource_files ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ResourceFiles
List of resource files.
-
#resources ⇒ Array<String>
A list of the resources included in this shared flow revision formatted as "
type://name". -
#revision ⇒ String
The resource ID of this revision.
-
#shared_flows ⇒ Array<String>
A list of the shared flow names included in this shared flow revision.
-
#type ⇒ String
The string "Application" Corresponds to the JSON property
type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1SharedFlowRevision
constructor
A new instance of GoogleCloudApigeeV1SharedFlowRevision.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1SharedFlowRevision
Returns a new instance of GoogleCloudApigeeV1SharedFlowRevision.
12395 12396 12397 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12395 def initialize(**args) update!(**args) end |
Instance Attribute Details
#configuration_version ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ConfigVersion
Version of the API proxy configuration schema. Currently, only 4.0 is
supported.
Corresponds to the JSON property configurationVersion
12325 12326 12327 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12325 def configuration_version @configuration_version end |
#context_info ⇒ String
A textual description of the shared flow revision.
Corresponds to the JSON property contextInfo
12330 12331 12332 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12330 def context_info @context_info end |
#created_at ⇒ Fixnum
Time at which this shared flow revision was created, in milliseconds since
epoch.
Corresponds to the JSON property createdAt
12336 12337 12338 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12336 def created_at @created_at end |
#description ⇒ String
Description of the shared flow revision.
Corresponds to the JSON property description
12341 12342 12343 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12341 def description @description end |
#display_name ⇒ String
The human readable name of this shared flow.
Corresponds to the JSON property displayName
12346 12347 12348 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12346 def display_name @display_name end |
#entity_meta_data_as_properties ⇒ Hash<String,String>
A Key-Value map of metadata about this shared flow revision.
Corresponds to the JSON property entityMetaDataAsProperties
12351 12352 12353 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12351 def @entity_meta_data_as_properties end |
#last_modified_at ⇒ Fixnum
Time at which this shared flow revision was most recently modified, in
milliseconds since epoch.
Corresponds to the JSON property lastModifiedAt
12357 12358 12359 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12357 def last_modified_at @last_modified_at end |
#name ⇒ String
The resource ID of the parent shared flow.
Corresponds to the JSON property name
12362 12363 12364 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12362 def name @name end |
#policies ⇒ Array<String>
A list of policy names included in this shared flow revision.
Corresponds to the JSON property policies
12367 12368 12369 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12367 def policies @policies end |
#resource_files ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ResourceFiles
List of resource files.
Corresponds to the JSON property resourceFiles
12372 12373 12374 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12372 def resource_files @resource_files end |
#resources ⇒ Array<String>
A list of the resources included in this shared flow revision formatted as "
type://name".
Corresponds to the JSON property resources
12378 12379 12380 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12378 def resources @resources end |
#revision ⇒ String
The resource ID of this revision.
Corresponds to the JSON property revision
12383 12384 12385 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12383 def revision @revision end |
#shared_flows ⇒ Array<String>
A list of the shared flow names included in this shared flow revision.
Corresponds to the JSON property sharedFlows
12388 12389 12390 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12388 def shared_flows @shared_flows end |
#type ⇒ String
The string "Application"
Corresponds to the JSON property type
12393 12394 12395 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12393 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12400 12401 12402 12403 12404 12405 12406 12407 12408 12409 12410 12411 12412 12413 12414 12415 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12400 def update!(**args) @configuration_version = args[:configuration_version] if args.key?(:configuration_version) @context_info = args[:context_info] if args.key?(:context_info) @created_at = args[:created_at] if args.key?(:created_at) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @entity_meta_data_as_properties = args[:entity_meta_data_as_properties] if args.key?(:entity_meta_data_as_properties) @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at) @name = args[:name] if args.key?(:name) @policies = args[:policies] if args.key?(:policies) @resource_files = args[:resource_files] if args.key?(:resource_files) @resources = args[:resources] if args.key?(:resources) @revision = args[:revision] if args.key?(:revision) @shared_flows = args[:shared_flows] if args.key?(:shared_flows) @type = args[:type] if args.key?(:type) end |