Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SharedFlowRevision
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1SharedFlowRevision
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
The metadata describing a shared flow revision.
Instance Attribute Summary collapse
-
#configuration_version ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ConfigVersion
Version of the API proxy configuration schema.
-
#context_info ⇒ String
A textual description of the shared flow revision.
-
#created_at ⇒ Fixnum
Time at which this shared flow revision was created, in milliseconds since epoch.
-
#description ⇒ String
Description of the shared flow revision.
-
#display_name ⇒ String
The human readable name of this shared flow.
-
#entity_meta_data_as_properties ⇒ Hash<String,String>
A Key-Value map of metadata about this shared flow revision.
-
#last_modified_at ⇒ Fixnum
Time at which this shared flow revision was most recently modified, in milliseconds since epoch.
-
#name ⇒ String
The resource ID of the parent shared flow.
-
#policies ⇒ Array<String>
A list of policy names included in this shared flow revision.
-
#resource_files ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ResourceFiles
List of resource files.
-
#resources ⇒ Array<String>
A list of the resources included in this shared flow revision formatted as "
type://name". -
#revision ⇒ String
The resource ID of this revision.
-
#shared_flows ⇒ Array<String>
A list of the shared flow names included in this shared flow revision.
-
#type ⇒ String
The string "Application" Corresponds to the JSON property
type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1SharedFlowRevision
constructor
A new instance of GoogleCloudApigeeV1SharedFlowRevision.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1SharedFlowRevision
Returns a new instance of GoogleCloudApigeeV1SharedFlowRevision.
12329 12330 12331 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12329 def initialize(**args) update!(**args) end |
Instance Attribute Details
#configuration_version ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ConfigVersion
Version of the API proxy configuration schema. Currently, only 4.0 is
supported.
Corresponds to the JSON property configurationVersion
12259 12260 12261 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12259 def configuration_version @configuration_version end |
#context_info ⇒ String
A textual description of the shared flow revision.
Corresponds to the JSON property contextInfo
12264 12265 12266 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12264 def context_info @context_info end |
#created_at ⇒ Fixnum
Time at which this shared flow revision was created, in milliseconds since
epoch.
Corresponds to the JSON property createdAt
12270 12271 12272 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12270 def created_at @created_at end |
#description ⇒ String
Description of the shared flow revision.
Corresponds to the JSON property description
12275 12276 12277 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12275 def description @description end |
#display_name ⇒ String
The human readable name of this shared flow.
Corresponds to the JSON property displayName
12280 12281 12282 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12280 def display_name @display_name end |
#entity_meta_data_as_properties ⇒ Hash<String,String>
A Key-Value map of metadata about this shared flow revision.
Corresponds to the JSON property entityMetaDataAsProperties
12285 12286 12287 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12285 def @entity_meta_data_as_properties end |
#last_modified_at ⇒ Fixnum
Time at which this shared flow revision was most recently modified, in
milliseconds since epoch.
Corresponds to the JSON property lastModifiedAt
12291 12292 12293 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12291 def last_modified_at @last_modified_at end |
#name ⇒ String
The resource ID of the parent shared flow.
Corresponds to the JSON property name
12296 12297 12298 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12296 def name @name end |
#policies ⇒ Array<String>
A list of policy names included in this shared flow revision.
Corresponds to the JSON property policies
12301 12302 12303 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12301 def policies @policies end |
#resource_files ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1ResourceFiles
List of resource files.
Corresponds to the JSON property resourceFiles
12306 12307 12308 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12306 def resource_files @resource_files end |
#resources ⇒ Array<String>
A list of the resources included in this shared flow revision formatted as "
type://name".
Corresponds to the JSON property resources
12312 12313 12314 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12312 def resources @resources end |
#revision ⇒ String
The resource ID of this revision.
Corresponds to the JSON property revision
12317 12318 12319 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12317 def revision @revision end |
#shared_flows ⇒ Array<String>
A list of the shared flow names included in this shared flow revision.
Corresponds to the JSON property sharedFlows
12322 12323 12324 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12322 def shared_flows @shared_flows end |
#type ⇒ String
The string "Application"
Corresponds to the JSON property type
12327 12328 12329 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12327 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12334 12335 12336 12337 12338 12339 12340 12341 12342 12343 12344 12345 12346 12347 12348 12349 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12334 def update!(**args) @configuration_version = args[:configuration_version] if args.key?(:configuration_version) @context_info = args[:context_info] if args.key?(:context_info) @created_at = args[:created_at] if args.key?(:created_at) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @entity_meta_data_as_properties = args[:entity_meta_data_as_properties] if args.key?(:entity_meta_data_as_properties) @last_modified_at = args[:last_modified_at] if args.key?(:last_modified_at) @name = args[:name] if args.key?(:name) @policies = args[:policies] if args.key?(:policies) @resource_files = args[:resource_files] if args.key?(:resource_files) @resources = args[:resources] if args.key?(:resources) @revision = args[:revision] if args.key?(:revision) @shared_flows = args[:shared_flows] if args.key?(:shared_flows) @type = args[:type] if args.key?(:type) end |