Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SyncAuthorization
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1SyncAuthorization
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
Entity tag (ETag) used for optimistic concurrency control as a way to help prevent simultaneous updates from overwriting each other.
-
#identities ⇒ Array<String>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1SyncAuthorization
constructor
A new instance of GoogleCloudApigeeV1SyncAuthorization.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1SyncAuthorization
Returns a new instance of GoogleCloudApigeeV1SyncAuthorization.
12649 12650 12651 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12649 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Entity tag (ETag) used for optimistic concurrency control as a way to help
prevent simultaneous updates from overwriting each other. For example, when
you call getSyncAuthorization an ETag is
returned in the response. Pass that ETag when calling the
setSyncAuthorization to ensure that you
are updating the correct version. If you don't pass the ETag in the call to
setSyncAuthorization, then the existing authorization is overwritten
indiscriminately. Note: We strongly recommend that you use the ETag in the
read-modify-write cycle to avoid race conditions.
Corresponds to the JSON property etag
NOTE: Values are automatically base64 encoded/decoded in the client library.
12634 12635 12636 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12634 def etag @etag end |
#identities ⇒ Array<String>
Required. Array of service accounts to grant access to control plane resources,
each specified using the following format: serviceAccount: service-account-
name. The service-account-name is formatted like an email address. For example:
my-synchronizer-manager-service_account@my_project_id.iam.gserviceaccount.
com You might specify multiple service accounts, for example, if you have
multiple environments and wish to assign a unique service account to each one.
The service accounts must have Apigee Synchronizer Manager role. See also
Create service accounts.
Corresponds to the JSON property identities
12647 12648 12649 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12647 def identities @identities end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12654 12655 12656 12657 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12654 def update!(**args) @etag = args[:etag] if args.key?(:etag) @identities = args[:identities] if args.key?(:identities) end |