Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1SyncAuthorization

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1SyncAuthorization

Returns a new instance of GoogleCloudApigeeV1SyncAuthorization.



12554
12555
12556
# File 'lib/google/apis/apigee_v1/classes.rb', line 12554

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Entity tag (ETag) used for optimistic concurrency control as a way to help prevent simultaneous updates from overwriting each other. For example, when you call getSyncAuthorization an ETag is returned in the response. Pass that ETag when calling the setSyncAuthorization to ensure that you are updating the correct version. If you don't pass the ETag in the call to setSyncAuthorization, then the existing authorization is overwritten indiscriminately. Note: We strongly recommend that you use the ETag in the read-modify-write cycle to avoid race conditions. Corresponds to the JSON property etag NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


12539
12540
12541
# File 'lib/google/apis/apigee_v1/classes.rb', line 12539

def etag
  @etag
end

#identitiesArray<String>

Required. Array of service accounts to grant access to control plane resources, each specified using the following format: serviceAccount: service-account- name. The service-account-name is formatted like an email address. For example: my-synchronizer-manager-service_account@my_project_id.iam.gserviceaccount. com You might specify multiple service accounts, for example, if you have multiple environments and wish to assign a unique service account to each one. The service accounts must have Apigee Synchronizer Manager role. See also Create service accounts. Corresponds to the JSON property identities

Returns:

  • (Array<String>)


12552
12553
12554
# File 'lib/google/apis/apigee_v1/classes.rb', line 12552

def identities
  @identities
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12559
12560
12561
12562
# File 'lib/google/apis/apigee_v1/classes.rb', line 12559

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @identities = args[:identities] if args.key?(:identities)
end