Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1TargetServer
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1TargetServer
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
TargetServer configuration. TargetServers are used to decouple a proxy TargetEndpoint HTTPTargetConnections from concrete URLs for backend services.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#host ⇒ String
Required.
-
#is_enabled ⇒ Boolean
(also: #is_enabled?)
Optional.
-
#name ⇒ String
Required.
-
#port ⇒ Fixnum
Required.
-
#protocol ⇒ String
Immutable.
-
#s_sl_info ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1TlsInfo
TLS configuration information for virtual hosts and TargetServers.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1TargetServer
constructor
A new instance of GoogleCloudApigeeV1TargetServer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1TargetServer
Returns a new instance of GoogleCloudApigeeV1TargetServer.
12773 12774 12775 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12773 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. A human-readable description of this TargetServer.
Corresponds to the JSON property description
12735 12736 12737 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12735 def description @description end |
#host ⇒ String
Required. The host name this target connects to. Value must be a valid
hostname as described by RFC-1123.
Corresponds to the JSON property host
12741 12742 12743 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12741 def host @host end |
#is_enabled ⇒ Boolean Also known as: is_enabled?
Optional. Enabling/disabling a TargetServer is useful when TargetServers are
used in load balancing configurations, and one or more TargetServers need to
taken out of rotation periodically. Defaults to true.
Corresponds to the JSON property isEnabled
12748 12749 12750 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12748 def is_enabled @is_enabled end |
#name ⇒ String
Required. The resource id of this target server. Values must match the regular
expression
Corresponds to the JSON property name
12755 12756 12757 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12755 def name @name end |
#port ⇒ Fixnum
Required. The port number this target connects to on the given host. Value
must be between 1 and 65535, inclusive.
Corresponds to the JSON property port
12761 12762 12763 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12761 def port @port end |
#protocol ⇒ String
Immutable. The protocol used by this TargetServer.
Corresponds to the JSON property protocol
12766 12767 12768 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12766 def protocol @protocol end |
#s_sl_info ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1TlsInfo
TLS configuration information for virtual hosts and TargetServers.
Corresponds to the JSON property sSLInfo
12771 12772 12773 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12771 def s_sl_info @s_sl_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12778 12779 12780 12781 12782 12783 12784 12785 12786 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12778 def update!(**args) @description = args[:description] if args.key?(:description) @host = args[:host] if args.key?(:host) @is_enabled = args[:is_enabled] if args.key?(:is_enabled) @name = args[:name] if args.key?(:name) @port = args[:port] if args.key?(:port) @protocol = args[:protocol] if args.key?(:protocol) @s_sl_info = args[:s_sl_info] if args.key?(:s_sl_info) end |