Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1TargetServer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

TargetServer configuration. TargetServers are used to decouple a proxy TargetEndpoint HTTPTargetConnections from concrete URLs for backend services.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1TargetServer

Returns a new instance of GoogleCloudApigeeV1TargetServer.



12677
12678
12679
# File 'lib/google/apis/apigee_v1/classes.rb', line 12677

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Optional. A human-readable description of this TargetServer. Corresponds to the JSON property description

Returns:

  • (String)


12639
12640
12641
# File 'lib/google/apis/apigee_v1/classes.rb', line 12639

def description
  @description
end

#hostString

Required. The host name this target connects to. Value must be a valid hostname as described by RFC-1123. Corresponds to the JSON property host

Returns:

  • (String)


12645
12646
12647
# File 'lib/google/apis/apigee_v1/classes.rb', line 12645

def host
  @host
end

#is_enabledBoolean Also known as: is_enabled?

Optional. Enabling/disabling a TargetServer is useful when TargetServers are used in load balancing configurations, and one or more TargetServers need to taken out of rotation periodically. Defaults to true. Corresponds to the JSON property isEnabled

Returns:

  • (Boolean)


12652
12653
12654
# File 'lib/google/apis/apigee_v1/classes.rb', line 12652

def is_enabled
  @is_enabled
end

#nameString

Required. The resource id of this target server. Values must match the regular expression Corresponds to the JSON property name

Returns:

  • (String)


12659
12660
12661
# File 'lib/google/apis/apigee_v1/classes.rb', line 12659

def name
  @name
end

#portFixnum

Required. The port number this target connects to on the given host. Value must be between 1 and 65535, inclusive. Corresponds to the JSON property port

Returns:

  • (Fixnum)


12665
12666
12667
# File 'lib/google/apis/apigee_v1/classes.rb', line 12665

def port
  @port
end

#protocolString

Immutable. The protocol used by this TargetServer. Corresponds to the JSON property protocol

Returns:

  • (String)


12670
12671
12672
# File 'lib/google/apis/apigee_v1/classes.rb', line 12670

def protocol
  @protocol
end

#s_sl_infoGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1TlsInfo

TLS configuration information for virtual hosts and TargetServers. Corresponds to the JSON property sSLInfo



12675
12676
12677
# File 'lib/google/apis/apigee_v1/classes.rb', line 12675

def s_sl_info
  @s_sl_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12682
12683
12684
12685
12686
12687
12688
12689
12690
# File 'lib/google/apis/apigee_v1/classes.rb', line 12682

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @host = args[:host] if args.key?(:host)
  @is_enabled = args[:is_enabled] if args.key?(:is_enabled)
  @name = args[:name] if args.key?(:name)
  @port = args[:port] if args.key?(:port)
  @protocol = args[:protocol] if args.key?(:protocol)
  @s_sl_info = args[:s_sl_info] if args.key?(:s_sl_info)
end