Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1TargetServer
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1TargetServer
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
TargetServer configuration. TargetServers are used to decouple a proxy TargetEndpoint HTTPTargetConnections from concrete URLs for backend services.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#host ⇒ String
Required.
-
#is_enabled ⇒ Boolean
(also: #is_enabled?)
Optional.
-
#name ⇒ String
Required.
-
#port ⇒ Fixnum
Required.
-
#protocol ⇒ String
Immutable.
-
#s_sl_info ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1TlsInfo
TLS configuration information for virtual hosts and TargetServers.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1TargetServer
constructor
A new instance of GoogleCloudApigeeV1TargetServer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1TargetServer
Returns a new instance of GoogleCloudApigeeV1TargetServer.
12668 12669 12670 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12668 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. A human-readable description of this TargetServer.
Corresponds to the JSON property description
12630 12631 12632 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12630 def description @description end |
#host ⇒ String
Required. The host name this target connects to. Value must be a valid
hostname as described by RFC-1123.
Corresponds to the JSON property host
12636 12637 12638 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12636 def host @host end |
#is_enabled ⇒ Boolean Also known as: is_enabled?
Optional. Enabling/disabling a TargetServer is useful when TargetServers are
used in load balancing configurations, and one or more TargetServers need to
taken out of rotation periodically. Defaults to true.
Corresponds to the JSON property isEnabled
12643 12644 12645 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12643 def is_enabled @is_enabled end |
#name ⇒ String
Required. The resource id of this target server. Values must match the regular
expression
Corresponds to the JSON property name
12650 12651 12652 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12650 def name @name end |
#port ⇒ Fixnum
Required. The port number this target connects to on the given host. Value
must be between 1 and 65535, inclusive.
Corresponds to the JSON property port
12656 12657 12658 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12656 def port @port end |
#protocol ⇒ String
Immutable. The protocol used by this TargetServer.
Corresponds to the JSON property protocol
12661 12662 12663 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12661 def protocol @protocol end |
#s_sl_info ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1TlsInfo
TLS configuration information for virtual hosts and TargetServers.
Corresponds to the JSON property sSLInfo
12666 12667 12668 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12666 def s_sl_info @s_sl_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12673 12674 12675 12676 12677 12678 12679 12680 12681 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12673 def update!(**args) @description = args[:description] if args.key?(:description) @host = args[:host] if args.key?(:host) @is_enabled = args[:is_enabled] if args.key?(:is_enabled) @name = args[:name] if args.key?(:name) @port = args[:port] if args.key?(:port) @protocol = args[:protocol] if args.key?(:protocol) @s_sl_info = args[:s_sl_info] if args.key?(:s_sl_info) end |