Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1TestDatastoreResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

The response for TestDatastore

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1TestDatastoreResponse

Returns a new instance of GoogleCloudApigeeV1TestDatastoreResponse.



12693
12694
12695
# File 'lib/google/apis/apigee_v1/classes.rb', line 12693

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorString

Output only. Error message of test connection failure Corresponds to the JSON property error

Returns:

  • (String)


12686
12687
12688
# File 'lib/google/apis/apigee_v1/classes.rb', line 12686

def error
  @error
end

#stateString

Output only. It could be completed or failed Corresponds to the JSON property state

Returns:

  • (String)


12691
12692
12693
# File 'lib/google/apis/apigee_v1/classes.rb', line 12691

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12698
12699
12700
12701
# File 'lib/google/apis/apigee_v1/classes.rb', line 12698

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @state = args[:state] if args.key?(:state)
end