Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1TlsInfo
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1TlsInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
TLS configuration information for virtual hosts and TargetServers.
Instance Attribute Summary collapse
-
#ciphers ⇒ Array<String>
The SSL/TLS cipher suites to be used.
-
#client_auth_enabled ⇒ Boolean
(also: #client_auth_enabled?)
Optional.
-
#common_name ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1TlsInfoCommonName
The TLS Common Name of the certificate.
-
#enabled ⇒ Boolean
(also: #enabled?)
Required.
-
#enforce ⇒ Boolean
(also: #enforce?)
TLS is strictly enforced.
-
#ignore_validation_errors ⇒ Boolean
(also: #ignore_validation_errors?)
If true, Edge ignores TLS certificate errors.
-
#key_alias ⇒ String
Required if
client_auth_enabledis true. -
#key_store ⇒ String
Required if
client_auth_enabledis true. -
#protocols ⇒ Array<String>
The TLS versioins to be used.
-
#trust_store ⇒ String
The resource ID of the truststore.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1TlsInfo
constructor
A new instance of GoogleCloudApigeeV1TlsInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1TlsInfo
Returns a new instance of GoogleCloudApigeeV1TlsInfo.
13097 13098 13099 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13097 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ciphers ⇒ Array<String>
The SSL/TLS cipher suites to be used. For programmable proxies, it must be one
of the cipher suite names listed in: http://docs.oracle.com/javase/8/docs/
technotes/guides/security/StandardNames.html#ciphersuites. For configurable
proxies, it must follow the configuration specified in: https://
commondatastorage.googleapis.com/chromium-boringssl-docs/ssl.h.html#Cipher-
suite-configuration. This setting has no effect for configurable proxies when
negotiating TLS 1.3.
Corresponds to the JSON property ciphers
13039 13040 13041 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13039 def ciphers @ciphers end |
#client_auth_enabled ⇒ Boolean Also known as: client_auth_enabled?
Optional. Enables two-way TLS.
Corresponds to the JSON property clientAuthEnabled
13044 13045 13046 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13044 def client_auth_enabled @client_auth_enabled end |
#common_name ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1TlsInfoCommonName
The TLS Common Name of the certificate.
Corresponds to the JSON property commonName
13050 13051 13052 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13050 def common_name @common_name end |
#enabled ⇒ Boolean Also known as: enabled?
Required. Enables TLS. If false, neither one-way nor two-way TLS will be
enabled.
Corresponds to the JSON property enabled
13056 13057 13058 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13056 def enabled @enabled end |
#enforce ⇒ Boolean Also known as: enforce?
TLS is strictly enforced.
Corresponds to the JSON property enforce
13062 13063 13064 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13062 def enforce @enforce end |
#ignore_validation_errors ⇒ Boolean Also known as: ignore_validation_errors?
If true, Edge ignores TLS certificate errors. Valid when configuring TLS for
target servers and target endpoints, and when configuring virtual hosts that
use 2-way TLS. When used with a target endpoint/target server, if the backend
system uses SNI and returns a cert with a subject Distinguished Name (DN) that
does not match the hostname, there is no way to ignore the error and the
connection fails.
Corresponds to the JSON property ignoreValidationErrors
13073 13074 13075 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13073 def ignore_validation_errors @ignore_validation_errors end |
#key_alias ⇒ String
Required if client_auth_enabled is true. The resource ID for the alias
containing the private key and cert.
Corresponds to the JSON property keyAlias
13080 13081 13082 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13080 def key_alias @key_alias end |
#key_store ⇒ String
Required if client_auth_enabled is true. The resource ID of the keystore.
Corresponds to the JSON property keyStore
13085 13086 13087 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13085 def key_store @key_store end |
#protocols ⇒ Array<String>
The TLS versioins to be used.
Corresponds to the JSON property protocols
13090 13091 13092 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13090 def protocols @protocols end |
#trust_store ⇒ String
The resource ID of the truststore.
Corresponds to the JSON property trustStore
13095 13096 13097 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13095 def trust_store @trust_store end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13102 13103 13104 13105 13106 13107 13108 13109 13110 13111 13112 13113 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13102 def update!(**args) @ciphers = args[:ciphers] if args.key?(:ciphers) @client_auth_enabled = args[:client_auth_enabled] if args.key?(:client_auth_enabled) @common_name = args[:common_name] if args.key?(:common_name) @enabled = args[:enabled] if args.key?(:enabled) @enforce = args[:enforce] if args.key?(:enforce) @ignore_validation_errors = args[:ignore_validation_errors] if args.key?(:ignore_validation_errors) @key_alias = args[:key_alias] if args.key?(:key_alias) @key_store = args[:key_store] if args.key?(:key_store) @protocols = args[:protocols] if args.key?(:protocols) @trust_store = args[:trust_store] if args.key?(:trust_store) end |