Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1TlsInfoConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1TlsInfoConfig

Returns a new instance of GoogleCloudApigeeV1TlsInfoConfig.



13047
13048
13049
# File 'lib/google/apis/apigee_v1/classes.rb', line 13047

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ciphersArray<String>

List of ciphers that are granted access. Corresponds to the JSON property ciphers

Returns:

  • (Array<String>)


12989
12990
12991
# File 'lib/google/apis/apigee_v1/classes.rb', line 12989

def ciphers
  @ciphers
end

#client_auth_enabledBoolean Also known as: client_auth_enabled?

Flag that specifies whether client-side authentication is enabled for the target server. Enables two-way TLS. Corresponds to the JSON property clientAuthEnabled

Returns:

  • (Boolean)


12995
12996
12997
# File 'lib/google/apis/apigee_v1/classes.rb', line 12995

def client_auth_enabled
  @client_auth_enabled
end

#common_nameGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1CommonNameConfig

Common name to validate the target server against. Corresponds to the JSON property commonName



13001
13002
13003
# File 'lib/google/apis/apigee_v1/classes.rb', line 13001

def common_name
  @common_name
end

#enabledBoolean Also known as: enabled?

Flag that specifies whether one-way TLS is enabled. Set to true to enable one-way TLS. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


13007
13008
13009
# File 'lib/google/apis/apigee_v1/classes.rb', line 13007

def enabled
  @enabled
end

#enforceBoolean Also known as: enforce?

Flag that enforces TLS settings Corresponds to the JSON property enforce

Returns:

  • (Boolean)


13013
13014
13015
# File 'lib/google/apis/apigee_v1/classes.rb', line 13013

def enforce
  @enforce
end

#ignore_validation_errorsBoolean Also known as: ignore_validation_errors?

Flag that specifies whether to ignore TLS certificate validation errors. Set to true to ignore errors. Corresponds to the JSON property ignoreValidationErrors

Returns:

  • (Boolean)


13020
13021
13022
# File 'lib/google/apis/apigee_v1/classes.rb', line 13020

def ignore_validation_errors
  @ignore_validation_errors
end

#key_aliasString

Name of the alias used for client-side authentication in the following format: organizations/org/environments/env/keystores/keystore/aliases/alias` Corresponds to the JSON propertykeyAlias`

Returns:

  • (String)


13027
13028
13029
# File 'lib/google/apis/apigee_v1/classes.rb', line 13027

def key_alias
  @key_alias
end

#key_alias_referenceGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1KeyAliasReference

Reference name and alias pair to use for client-side authentication. Corresponds to the JSON property keyAliasReference



13032
13033
13034
# File 'lib/google/apis/apigee_v1/classes.rb', line 13032

def key_alias_reference
  @key_alias_reference
end

#protocolsArray<String>

List of TLS protocols that are granted access. Corresponds to the JSON property protocols

Returns:

  • (Array<String>)


13037
13038
13039
# File 'lib/google/apis/apigee_v1/classes.rb', line 13037

def protocols
  @protocols
end

#trust_storeString

Name of the keystore or keystore reference containing trusted certificates for the server in the following format: organizations/org/environments/env/ keystores/keystoreor `organizations/`org`/environments/`env`/references/` reference Corresponds to the JSON property trustStore

Returns:

  • (String)


13045
13046
13047
# File 'lib/google/apis/apigee_v1/classes.rb', line 13045

def trust_store
  @trust_store
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13052
13053
13054
13055
13056
13057
13058
13059
13060
13061
13062
13063
# File 'lib/google/apis/apigee_v1/classes.rb', line 13052

def update!(**args)
  @ciphers = args[:ciphers] if args.key?(:ciphers)
  @client_auth_enabled = args[:client_auth_enabled] if args.key?(:client_auth_enabled)
  @common_name = args[:common_name] if args.key?(:common_name)
  @enabled = args[:enabled] if args.key?(:enabled)
  @enforce = args[:enforce] if args.key?(:enforce)
  @ignore_validation_errors = args[:ignore_validation_errors] if args.key?(:ignore_validation_errors)
  @key_alias = args[:key_alias] if args.key?(:key_alias)
  @key_alias_reference = args[:key_alias_reference] if args.key?(:key_alias_reference)
  @protocols = args[:protocols] if args.key?(:protocols)
  @trust_store = args[:trust_store] if args.key?(:trust_store)
end