Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1TlsInfoConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1TlsInfoConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Instance Attribute Summary collapse
-
#ciphers ⇒ Array<String>
List of ciphers that are granted access.
-
#client_auth_enabled ⇒ Boolean
(also: #client_auth_enabled?)
Flag that specifies whether client-side authentication is enabled for the target server.
-
#common_name ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1CommonNameConfig
Common name to validate the target server against.
-
#enabled ⇒ Boolean
(also: #enabled?)
Flag that specifies whether one-way TLS is enabled.
-
#enforce ⇒ Boolean
(also: #enforce?)
Flag that enforces TLS settings Corresponds to the JSON property
enforce. -
#ignore_validation_errors ⇒ Boolean
(also: #ignore_validation_errors?)
Flag that specifies whether to ignore TLS certificate validation errors.
-
#key_alias ⇒ String
Name of the alias used for client-side authentication in the following format:
organizations/org/environments/env/keystores/keystore/aliases/alias`Corresponds to the JSON propertykeyAlias`. -
#key_alias_reference ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1KeyAliasReference
Reference name and alias pair to use for client-side authentication.
-
#protocols ⇒ Array<String>
List of TLS protocols that are granted access.
-
#trust_store ⇒ String
Name of the keystore or keystore reference containing trusted certificates for the server in the following format:
organizations/org/environments/env/ keystores/keystoreor `organizations/`org`/environments/`env`/references/` referenceCorresponds to the JSON propertytrustStore.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1TlsInfoConfig
constructor
A new instance of GoogleCloudApigeeV1TlsInfoConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1TlsInfoConfig
Returns a new instance of GoogleCloudApigeeV1TlsInfoConfig.
12885 12886 12887 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12885 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ciphers ⇒ Array<String>
List of ciphers that are granted access.
Corresponds to the JSON property ciphers
12827 12828 12829 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12827 def ciphers @ciphers end |
#client_auth_enabled ⇒ Boolean Also known as: client_auth_enabled?
Flag that specifies whether client-side authentication is enabled for the
target server. Enables two-way TLS.
Corresponds to the JSON property clientAuthEnabled
12833 12834 12835 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12833 def client_auth_enabled @client_auth_enabled end |
#common_name ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1CommonNameConfig
Common name to validate the target server against.
Corresponds to the JSON property commonName
12839 12840 12841 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12839 def common_name @common_name end |
#enabled ⇒ Boolean Also known as: enabled?
Flag that specifies whether one-way TLS is enabled. Set to true to enable
one-way TLS.
Corresponds to the JSON property enabled
12845 12846 12847 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12845 def enabled @enabled end |
#enforce ⇒ Boolean Also known as: enforce?
Flag that enforces TLS settings
Corresponds to the JSON property enforce
12851 12852 12853 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12851 def enforce @enforce end |
#ignore_validation_errors ⇒ Boolean Also known as: ignore_validation_errors?
Flag that specifies whether to ignore TLS certificate validation errors. Set
to true to ignore errors.
Corresponds to the JSON property ignoreValidationErrors
12858 12859 12860 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12858 def ignore_validation_errors @ignore_validation_errors end |
#key_alias ⇒ String
Name of the alias used for client-side authentication in the following format:
organizations/org/environments/env/keystores/keystore/aliases/alias`
Corresponds to the JSON propertykeyAlias`
12865 12866 12867 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12865 def key_alias @key_alias end |
#key_alias_reference ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1KeyAliasReference
Reference name and alias pair to use for client-side authentication.
Corresponds to the JSON property keyAliasReference
12870 12871 12872 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12870 def key_alias_reference @key_alias_reference end |
#protocols ⇒ Array<String>
List of TLS protocols that are granted access.
Corresponds to the JSON property protocols
12875 12876 12877 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12875 def protocols @protocols end |
#trust_store ⇒ String
Name of the keystore or keystore reference containing trusted certificates for
the server in the following format: organizations/org/environments/env/
keystores/keystoreor `organizations/`org`/environments/`env`/references/`
reference
Corresponds to the JSON property trustStore
12883 12884 12885 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12883 def trust_store @trust_store end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12890 12891 12892 12893 12894 12895 12896 12897 12898 12899 12900 12901 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12890 def update!(**args) @ciphers = args[:ciphers] if args.key?(:ciphers) @client_auth_enabled = args[:client_auth_enabled] if args.key?(:client_auth_enabled) @common_name = args[:common_name] if args.key?(:common_name) @enabled = args[:enabled] if args.key?(:enabled) @enforce = args[:enforce] if args.key?(:enforce) @ignore_validation_errors = args[:ignore_validation_errors] if args.key?(:ignore_validation_errors) @key_alias = args[:key_alias] if args.key?(:key_alias) @key_alias_reference = args[:key_alias_reference] if args.key?(:key_alias_reference) @protocols = args[:protocols] if args.key?(:protocols) @trust_store = args[:trust_store] if args.key?(:trust_store) end |