Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1TraceConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1TraceConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
TraceConfig defines the configurations in an environment of distributed trace.
Instance Attribute Summary collapse
-
#endpoint ⇒ String
Required.
-
#exporter ⇒ String
Required.
-
#sampling_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1TraceSamplingConfig
TraceSamplingConfig represents the detail settings of distributed tracing.
-
#span_semantics ⇒ String
Optional.
-
#trace_protocol ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1TraceConfig
constructor
A new instance of GoogleCloudApigeeV1TraceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1TraceConfig
Returns a new instance of GoogleCloudApigeeV1TraceConfig.
13119 13120 13121 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13119 def initialize(**args) update!(**args) end |
Instance Attribute Details
#endpoint ⇒ String
Required. Endpoint of the exporter.
Corresponds to the JSON property endpoint
13087 13088 13089 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13087 def endpoint @endpoint end |
#exporter ⇒ String
Required. Exporter that is used to view the distributed trace captured using
the chosen trace protocol. An exporter sends traces to any backend that is
capable of consuming them. Recorded spans can be exported by registered
exporters.
Corresponds to the JSON property exporter
13095 13096 13097 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13095 def exporter @exporter end |
#sampling_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1TraceSamplingConfig
TraceSamplingConfig represents the detail settings of distributed tracing.
Only the fields that are defined in the distributed trace configuration can be
overridden using the distribute trace configuration override APIs.
Corresponds to the JSON property samplingConfig
13102 13103 13104 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13102 def sampling_config @sampling_config end |
#span_semantics ⇒ String
Optional. The span semantics to use. Configuration Requirements (if
span_semantics is OTEL): - trace_protocol must be OTLP.
Corresponds to the JSON property spanSemantics
13108 13109 13110 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13108 def span_semantics @span_semantics end |
#trace_protocol ⇒ String
Optional. The trace protocol to use. Configuration Requirements (if
trace_protocol is OTLP): - Allowed Exporters: CLOUD_TRACE or
OPEN_TELEMETRY_COLLECTOR. - If Exporter is OPEN_TELEMETRY_COLLECTOR: -
endpoint refers to a valid OTLP collector URL. - If Exporter is CLOUD_TRACE: -
endpoint refers to a valid project ID.
Corresponds to the JSON property traceProtocol
13117 13118 13119 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13117 def trace_protocol @trace_protocol end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13124 13125 13126 13127 13128 13129 13130 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13124 def update!(**args) @endpoint = args[:endpoint] if args.key?(:endpoint) @exporter = args[:exporter] if args.key?(:exporter) @sampling_config = args[:sampling_config] if args.key?(:sampling_config) @span_semantics = args[:span_semantics] if args.key?(:span_semantics) @trace_protocol = args[:trace_protocol] if args.key?(:trace_protocol) end |