Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1TraceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

TraceConfig defines the configurations in an environment of distributed trace.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1TraceConfig

Returns a new instance of GoogleCloudApigeeV1TraceConfig.



12994
12995
12996
# File 'lib/google/apis/apigee_v1/classes.rb', line 12994

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endpointString

Required. Endpoint of the exporter. Corresponds to the JSON property endpoint

Returns:

  • (String)


12977
12978
12979
# File 'lib/google/apis/apigee_v1/classes.rb', line 12977

def endpoint
  @endpoint
end

#exporterString

Required. Exporter that is used to view the distributed trace captured using the chosen trace protocol. An exporter sends traces to any backend that is capable of consuming them. Recorded spans can be exported by registered exporters. Corresponds to the JSON property exporter

Returns:

  • (String)


12985
12986
12987
# File 'lib/google/apis/apigee_v1/classes.rb', line 12985

def exporter
  @exporter
end

#sampling_configGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1TraceSamplingConfig

TraceSamplingConfig represents the detail settings of distributed tracing. Only the fields that are defined in the distributed trace configuration can be overridden using the distribute trace configuration override APIs. Corresponds to the JSON property samplingConfig



12992
12993
12994
# File 'lib/google/apis/apigee_v1/classes.rb', line 12992

def sampling_config
  @sampling_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12999
13000
13001
13002
13003
# File 'lib/google/apis/apigee_v1/classes.rb', line 12999

def update!(**args)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @exporter = args[:exporter] if args.key?(:exporter)
  @sampling_config = args[:sampling_config] if args.key?(:sampling_config)
end