Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1TraceConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1TraceConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
TraceConfig defines the configurations in an environment of distributed trace.
Instance Attribute Summary collapse
-
#endpoint ⇒ String
Required.
-
#exporter ⇒ String
Required.
-
#sampling_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1TraceSamplingConfig
TraceSamplingConfig represents the detail settings of distributed tracing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1TraceConfig
constructor
A new instance of GoogleCloudApigeeV1TraceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1TraceConfig
Returns a new instance of GoogleCloudApigeeV1TraceConfig.
12985 12986 12987 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12985 def initialize(**args) update!(**args) end |
Instance Attribute Details
#endpoint ⇒ String
Required. Endpoint of the exporter.
Corresponds to the JSON property endpoint
12968 12969 12970 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12968 def endpoint @endpoint end |
#exporter ⇒ String
Required. Exporter that is used to view the distributed trace captured using
the chosen trace protocol. An exporter sends traces to any backend that is
capable of consuming them. Recorded spans can be exported by registered
exporters.
Corresponds to the JSON property exporter
12976 12977 12978 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12976 def exporter @exporter end |
#sampling_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1TraceSamplingConfig
TraceSamplingConfig represents the detail settings of distributed tracing.
Only the fields that are defined in the distributed trace configuration can be
overridden using the distribute trace configuration override APIs.
Corresponds to the JSON property samplingConfig
12983 12984 12985 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12983 def sampling_config @sampling_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12990 12991 12992 12993 12994 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12990 def update!(**args) @endpoint = args[:endpoint] if args.key?(:endpoint) @exporter = args[:exporter] if args.key?(:exporter) @sampling_config = args[:sampling_config] if args.key?(:sampling_config) end |