Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1TraceConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

TraceConfig defines the configurations in an environment of distributed trace.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1TraceConfig

Returns a new instance of GoogleCloudApigeeV1TraceConfig.



13022
13023
13024
# File 'lib/google/apis/apigee_v1/classes.rb', line 13022

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endpointString

Required. Endpoint of the exporter. Corresponds to the JSON property endpoint

Returns:

  • (String)


13006
13007
13008
# File 'lib/google/apis/apigee_v1/classes.rb', line 13006

def endpoint
  @endpoint
end

#exporterString

Required. Exporter that is used to view the distributed trace captured using OpenCensus. An exporter sends traces to any backend that is capable of consuming them. Recorded spans can be exported by registered exporters. Corresponds to the JSON property exporter

Returns:

  • (String)


13013
13014
13015
# File 'lib/google/apis/apigee_v1/classes.rb', line 13013

def exporter
  @exporter
end

#sampling_configGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1TraceSamplingConfig

TraceSamplingConfig represents the detail settings of distributed tracing. Only the fields that are defined in the distributed trace configuration can be overridden using the distribute trace configuration override APIs. Corresponds to the JSON property samplingConfig



13020
13021
13022
# File 'lib/google/apis/apigee_v1/classes.rb', line 13020

def sampling_config
  @sampling_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13027
13028
13029
13030
13031
# File 'lib/google/apis/apigee_v1/classes.rb', line 13027

def update!(**args)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @exporter = args[:exporter] if args.key?(:exporter)
  @sampling_config = args[:sampling_config] if args.key?(:sampling_config)
end