Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1TraceConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1TraceConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
TraceConfig defines the configurations in an environment of distributed trace.
Instance Attribute Summary collapse
-
#endpoint ⇒ String
Required.
-
#exporter ⇒ String
Required.
-
#sampling_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1TraceSamplingConfig
TraceSamplingConfig represents the detail settings of distributed tracing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1TraceConfig
constructor
A new instance of GoogleCloudApigeeV1TraceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1TraceConfig
Returns a new instance of GoogleCloudApigeeV1TraceConfig.
12927 12928 12929 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12927 def initialize(**args) update!(**args) end |
Instance Attribute Details
#endpoint ⇒ String
Required. Endpoint of the exporter.
Corresponds to the JSON property endpoint
12911 12912 12913 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12911 def endpoint @endpoint end |
#exporter ⇒ String
Required. Exporter that is used to view the distributed trace captured using
OpenCensus. An exporter sends traces to any backend that is capable of
consuming them. Recorded spans can be exported by registered exporters.
Corresponds to the JSON property exporter
12918 12919 12920 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12918 def exporter @exporter end |
#sampling_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1TraceSamplingConfig
TraceSamplingConfig represents the detail settings of distributed tracing.
Only the fields that are defined in the distributed trace configuration can be
overridden using the distribute trace configuration override APIs.
Corresponds to the JSON property samplingConfig
12925 12926 12927 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12925 def sampling_config @sampling_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12932 12933 12934 12935 12936 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 12932 def update!(**args) @endpoint = args[:endpoint] if args.key?(:endpoint) @exporter = args[:exporter] if args.key?(:exporter) @sampling_config = args[:sampling_config] if args.key?(:sampling_config) end |