Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1TraceConfigOverride
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1TraceConfigOverride
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
A representation of a configuration override.
Instance Attribute Summary collapse
-
#api_proxy ⇒ String
ID of the API proxy that will have its trace configuration overridden.
-
#name ⇒ String
ID of the trace configuration override specified as a system-generated UUID.
-
#sampling_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1TraceSamplingConfig
TraceSamplingConfig represents the detail settings of distributed tracing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1TraceConfigOverride
constructor
A new instance of GoogleCloudApigeeV1TraceConfigOverride.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1TraceConfigOverride
Returns a new instance of GoogleCloudApigeeV1TraceConfigOverride.
13154 13155 13156 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13154 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_proxy ⇒ String
ID of the API proxy that will have its trace configuration overridden.
Corresponds to the JSON property apiProxy
13140 13141 13142 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13140 def api_proxy @api_proxy end |
#name ⇒ String
ID of the trace configuration override specified as a system-generated UUID.
Corresponds to the JSON property name
13145 13146 13147 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13145 def name @name end |
#sampling_config ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1TraceSamplingConfig
TraceSamplingConfig represents the detail settings of distributed tracing.
Only the fields that are defined in the distributed trace configuration can be
overridden using the distribute trace configuration override APIs.
Corresponds to the JSON property samplingConfig
13152 13153 13154 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13152 def sampling_config @sampling_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13159 13160 13161 13162 13163 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13159 def update!(**args) @api_proxy = args[:api_proxy] if args.key?(:api_proxy) @name = args[:name] if args.key?(:name) @sampling_config = args[:sampling_config] if args.key?(:sampling_config) end |