Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1TraceConfigOverride

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

A representation of a configuration override.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1TraceConfigOverride

Returns a new instance of GoogleCloudApigeeV1TraceConfigOverride.



12960
12961
12962
# File 'lib/google/apis/apigee_v1/classes.rb', line 12960

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_proxyString

ID of the API proxy that will have its trace configuration overridden. Corresponds to the JSON property apiProxy

Returns:

  • (String)


12946
12947
12948
# File 'lib/google/apis/apigee_v1/classes.rb', line 12946

def api_proxy
  @api_proxy
end

#nameString

ID of the trace configuration override specified as a system-generated UUID. Corresponds to the JSON property name

Returns:

  • (String)


12951
12952
12953
# File 'lib/google/apis/apigee_v1/classes.rb', line 12951

def name
  @name
end

#sampling_configGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1TraceSamplingConfig

TraceSamplingConfig represents the detail settings of distributed tracing. Only the fields that are defined in the distributed trace configuration can be overridden using the distribute trace configuration override APIs. Corresponds to the JSON property samplingConfig



12958
12959
12960
# File 'lib/google/apis/apigee_v1/classes.rb', line 12958

def sampling_config
  @sampling_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12965
12966
12967
12968
12969
# File 'lib/google/apis/apigee_v1/classes.rb', line 12965

def update!(**args)
  @api_proxy = args[:api_proxy] if args.key?(:api_proxy)
  @name = args[:name] if args.key?(:name)
  @sampling_config = args[:sampling_config] if args.key?(:sampling_config)
end