Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1TraceSamplingConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1TraceSamplingConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
TraceSamplingConfig represents the detail settings of distributed tracing. Only the fields that are defined in the distributed trace configuration can be overridden using the distribute trace configuration override APIs.
Instance Attribute Summary collapse
-
#sampler ⇒ String
Sampler of distributed tracing.
-
#sampling_rate ⇒ Float
Field sampling rate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1TraceSamplingConfig
constructor
A new instance of GoogleCloudApigeeV1TraceSamplingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1TraceSamplingConfig
Returns a new instance of GoogleCloudApigeeV1TraceSamplingConfig.
13183 13184 13185 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13183 def initialize(**args) update!(**args) end |
Instance Attribute Details
#sampler ⇒ String
Sampler of distributed tracing. OFF is the default value.
Corresponds to the JSON property sampler
13175 13176 13177 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13175 def sampler @sampler end |
#sampling_rate ⇒ Float
Field sampling rate. This value is only applicable when using the PROBABILITY
sampler. The supported values are > 0 and <= 0.5.
Corresponds to the JSON property samplingRate
13181 13182 13183 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13181 def sampling_rate @sampling_rate end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13188 13189 13190 13191 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13188 def update!(**args) @sampler = args[:sampler] if args.key?(:sampler) @sampling_rate = args[:sampling_rate] if args.key?(:sampling_rate) end |