Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1TraceSamplingConfig
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1TraceSamplingConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
TraceSamplingConfig represents the detail settings of distributed tracing. Only the fields that are defined in the distributed trace configuration can be overridden using the distribute trace configuration override APIs.
Instance Attribute Summary collapse
-
#sampler ⇒ String
Sampler of distributed tracing.
-
#sampling_rate ⇒ Float
Field sampling rate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1TraceSamplingConfig
constructor
A new instance of GoogleCloudApigeeV1TraceSamplingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1TraceSamplingConfig
Returns a new instance of GoogleCloudApigeeV1TraceSamplingConfig.
13056 13057 13058 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13056 def initialize(**args) update!(**args) end |
Instance Attribute Details
#sampler ⇒ String
Sampler of distributed tracing. OFF is the default value.
Corresponds to the JSON property sampler
13048 13049 13050 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13048 def sampler @sampler end |
#sampling_rate ⇒ Float
Field sampling rate. This value is only applicable when using the PROBABILITY
sampler. The supported values are > 0 and <= 0.5.
Corresponds to the JSON property samplingRate
13054 13055 13056 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13054 def sampling_rate @sampling_rate end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13061 13062 13063 13064 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13061 def update!(**args) @sampler = args[:sampler] if args.key?(:sampler) @sampling_rate = args[:sampling_rate] if args.key?(:sampling_rate) end |