Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1TraceSamplingConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

TraceSamplingConfig represents the detail settings of distributed tracing. Only the fields that are defined in the distributed trace configuration can be overridden using the distribute trace configuration override APIs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1TraceSamplingConfig

Returns a new instance of GoogleCloudApigeeV1TraceSamplingConfig.



13084
13085
13086
# File 'lib/google/apis/apigee_v1/classes.rb', line 13084

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#samplerString

Sampler of distributed tracing. OFF is the default value. Corresponds to the JSON property sampler

Returns:

  • (String)


13076
13077
13078
# File 'lib/google/apis/apigee_v1/classes.rb', line 13076

def sampler
  @sampler
end

#sampling_rateFloat

Field sampling rate. This value is only applicable when using the PROBABILITY sampler. The supported values are > 0 and <= 0.5. Corresponds to the JSON property samplingRate

Returns:

  • (Float)


13082
13083
13084
# File 'lib/google/apis/apigee_v1/classes.rb', line 13082

def sampling_rate
  @sampling_rate
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13089
13090
13091
13092
# File 'lib/google/apis/apigee_v1/classes.rb', line 13089

def update!(**args)
  @sampler = args[:sampler] if args.key?(:sampler)
  @sampling_rate = args[:sampling_rate] if args.key?(:sampling_rate)
end