Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1UpdateAppGroupAppKeyRequest
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1UpdateAppGroupAppKeyRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Request for UpdateAppGroupAppKey
Instance Attribute Summary collapse
-
#action ⇒ String
Approve or revoke the consumer key by setting this value to
approveorrevokerespectively. -
#api_products ⇒ Array<String>
The list of API products that will be associated with the credential.
-
#app_group_app_key ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1AppGroupAppKey
AppGroupAppKey contains all the information associated with the credentials.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1UpdateAppGroupAppKeyRequest
constructor
A new instance of GoogleCloudApigeeV1UpdateAppGroupAppKeyRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1UpdateAppGroupAppKeyRequest
Returns a new instance of GoogleCloudApigeeV1UpdateAppGroupAppKeyRequest.
13449 13450 13451 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13449 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
Approve or revoke the consumer key by setting this value to approve or
revoke respectively. The Content-Type header, if set, must be set to
application/octet-stream, with empty body.
Corresponds to the JSON property action
13435 13436 13437 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13435 def action @action end |
#api_products ⇒ Array<String>
The list of API products that will be associated with the credential. This
list will be appended to the existing list of associated API Products for this
App Key. Duplicates will be ignored.
Corresponds to the JSON property apiProducts
13442 13443 13444 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13442 def api_products @api_products end |
#app_group_app_key ⇒ Google::Apis::ApigeeV1::GoogleCloudApigeeV1AppGroupAppKey
AppGroupAppKey contains all the information associated with the credentials.
Corresponds to the JSON property appGroupAppKey
13447 13448 13449 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13447 def app_group_app_key @app_group_app_key end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13454 13455 13456 13457 13458 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13454 def update!(**args) @action = args[:action] if args.key?(:action) @api_products = args[:api_products] if args.key?(:api_products) @app_group_app_key = args[:app_group_app_key] if args.key?(:app_group_app_key) end |