Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1UpdateAppGroupAppKeyRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Request for UpdateAppGroupAppKey

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1UpdateAppGroupAppKeyRequest

Returns a new instance of GoogleCloudApigeeV1UpdateAppGroupAppKeyRequest.



13217
13218
13219
# File 'lib/google/apis/apigee_v1/classes.rb', line 13217

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Approve or revoke the consumer key by setting this value to approve or revoke respectively. The Content-Type header, if set, must be set to application/octet-stream, with empty body. Corresponds to the JSON property action

Returns:

  • (String)


13203
13204
13205
# File 'lib/google/apis/apigee_v1/classes.rb', line 13203

def action
  @action
end

#api_productsArray<String>

The list of API products that will be associated with the credential. This list will be appended to the existing list of associated API Products for this App Key. Duplicates will be ignored. Corresponds to the JSON property apiProducts

Returns:

  • (Array<String>)


13210
13211
13212
# File 'lib/google/apis/apigee_v1/classes.rb', line 13210

def api_products
  @api_products
end

#app_group_app_keyGoogle::Apis::ApigeeV1::GoogleCloudApigeeV1AppGroupAppKey

AppGroupAppKey contains all the information associated with the credentials. Corresponds to the JSON property appGroupAppKey



13215
13216
13217
# File 'lib/google/apis/apigee_v1/classes.rb', line 13215

def app_group_app_key
  @app_group_app_key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13222
13223
13224
13225
13226
# File 'lib/google/apis/apigee_v1/classes.rb', line 13222

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @api_products = args[:api_products] if args.key?(:api_products)
  @app_group_app_key = args[:app_group_app_key] if args.key?(:app_group_app_key)
end