Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1UpdateError

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Details on why a resource update failed in the runtime.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudApigeeV1UpdateError

Returns a new instance of GoogleCloudApigeeV1UpdateError.



13128
13129
13130
# File 'lib/google/apis/apigee_v1/classes.rb', line 13128

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

Status code. Corresponds to the JSON property code

Returns:

  • (String)


13109
13110
13111
# File 'lib/google/apis/apigee_v1/classes.rb', line 13109

def code
  @code
end

#messageString

User-friendly error message. Corresponds to the JSON property message

Returns:

  • (String)


13114
13115
13116
# File 'lib/google/apis/apigee_v1/classes.rb', line 13114

def message
  @message
end

#resourceString

The sub resource specific to this error (e.g. a proxy deployed within the EnvironmentConfig). If empty the error refers to the top level resource. Corresponds to the JSON property resource

Returns:

  • (String)


13120
13121
13122
# File 'lib/google/apis/apigee_v1/classes.rb', line 13120

def resource
  @resource
end

#typeString

A string that uniquely identifies the type of error. This provides a more reliable means to deduplicate errors across revisions and instances. Corresponds to the JSON property type

Returns:

  • (String)


13126
13127
13128
# File 'lib/google/apis/apigee_v1/classes.rb', line 13126

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13133
13134
13135
13136
13137
13138
# File 'lib/google/apis/apigee_v1/classes.rb', line 13133

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @message = args[:message] if args.key?(:message)
  @resource = args[:resource] if args.key?(:resource)
  @type = args[:type] if args.key?(:type)
end