Class: Google::Apis::ApigeeV1::GoogleCloudApigeeV1UpdateError
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleCloudApigeeV1UpdateError
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Details on why a resource update failed in the runtime.
Instance Attribute Summary collapse
-
#code ⇒ String
Status code.
-
#message ⇒ String
User-friendly error message.
-
#resource ⇒ String
The sub resource specific to this error (e.g. a proxy deployed within the EnvironmentConfig).
-
#type ⇒ String
A string that uniquely identifies the type of error.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudApigeeV1UpdateError
constructor
A new instance of GoogleCloudApigeeV1UpdateError.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudApigeeV1UpdateError
Returns a new instance of GoogleCloudApigeeV1UpdateError.
13061 13062 13063 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13061 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
Status code.
Corresponds to the JSON property code
13042 13043 13044 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13042 def code @code end |
#message ⇒ String
User-friendly error message.
Corresponds to the JSON property message
13047 13048 13049 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13047 def @message end |
#resource ⇒ String
The sub resource specific to this error (e.g. a proxy deployed within the
EnvironmentConfig). If empty the error refers to the top level resource.
Corresponds to the JSON property resource
13053 13054 13055 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13053 def resource @resource end |
#type ⇒ String
A string that uniquely identifies the type of error. This provides a more
reliable means to deduplicate errors across revisions and instances.
Corresponds to the JSON property type
13059 13060 13061 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13059 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13066 13067 13068 13069 13070 13071 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13066 def update!(**args) @code = args[:code] if args.key?(:code) @message = args[:message] if args.key?(:message) @resource = args[:resource] if args.key?(:resource) @type = args[:type] if args.key?(:type) end |