Class: Google::Apis::ApigeeV1::GoogleIamV1AuditConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb

Overview

Specifies the audit configuration for a service. The configuration determines which permission types are logged, and what identities, if any, are exempted from logging. An AuditConfig must have one or more AuditLogConfigs. If there are AuditConfigs for both allServices and a specific service, the union of the two AuditConfigs is used for that service: the log_types specified in each AuditConfig are enabled, and the exempted_members in each AuditLogConfig are exempted. Example Policy with multiple AuditConfigs: "audit_configs": [ " service": "allServices", "audit_log_configs": [ "log_type": "DATA_READ", " exempted_members": [ "user:jose@example.com" ], "log_type": "DATA_WRITE", "log_type": "ADMIN_READ" ] , "service": "sampleservice.googleapis.com", "audit_log_configs": [ "log_type": "DATA_READ", "log_type": "DATA_WRITE" , "exempted_members": [ "user:aliya@example.com" ] ] ] For sampleservice, this policy enables DATA_READ, DATA_WRITE and ADMIN_READ logging. It also exempts jose@example.com from DATA_READ logging, and aliya@example.com from DATA_WRITE logging.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleIamV1AuditConfig

Returns a new instance of GoogleIamV1AuditConfig.



13130
13131
13132
# File 'lib/google/apis/apigee_v1/classes.rb', line 13130

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audit_log_configsArray<Google::Apis::ApigeeV1::GoogleIamV1AuditLogConfig>

The configuration for logging of each type of permission. Corresponds to the JSON property auditLogConfigs



13121
13122
13123
# File 'lib/google/apis/apigee_v1/classes.rb', line 13121

def audit_log_configs
  @audit_log_configs
end

#serviceString

Specifies a service that will be enabled for audit logging. For example, storage.googleapis.com, cloudsql.googleapis.com. allServices is a special value that covers all services. Corresponds to the JSON property service

Returns:

  • (String)


13128
13129
13130
# File 'lib/google/apis/apigee_v1/classes.rb', line 13128

def service
  @service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13135
13136
13137
13138
# File 'lib/google/apis/apigee_v1/classes.rb', line 13135

def update!(**args)
  @audit_log_configs = args[:audit_log_configs] if args.key?(:audit_log_configs)
  @service = args[:service] if args.key?(:service)
end