Class: Google::Apis::ApigeeV1::GoogleTypeExpr
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleTypeExpr
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Represents a textual expression in the Common Expression Language (CEL) syntax. CEL is a C-like expression language. The syntax and semantics of CEL are documented at https://github.com/google/cel-spec. Example (Comparison): title: "Summary size limit" description: "Determines if a summary is less than 100 chars" expression: "document.summary.size() < 100" Example (Equality): title: " Requestor is owner" description: "Determines if requestor is the document owner" expression: "document.owner == request.auth.claims.email" Example ( Logic): title: "Public documents" description: "Determine whether the document should be publicly visible" expression: "document.type != 'private' && document.type != 'internal'" Example (Data Manipulation): title: "Notification string" description: "Create a notification string with a timestamp." expression: "'New message received at ' + string(document.create_time)" The exact variables and functions that may be referenced within an expression are determined by the service that evaluates it. See the service documentation for additional information.
Instance Attribute Summary collapse
-
#description ⇒ String
Optional.
-
#expression ⇒ String
Textual representation of an expression in Common Expression Language syntax.
-
#location ⇒ String
Optional.
-
#title ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleTypeExpr
constructor
A new instance of GoogleTypeExpr.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleTypeExpr
Returns a new instance of GoogleTypeExpr.
13883 13884 13885 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13883 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Optional. Description of the expression. This is a longer text which describes
the expression, e.g. when hovered over it in a UI.
Corresponds to the JSON property description
13864 13865 13866 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13864 def description @description end |
#expression ⇒ String
Textual representation of an expression in Common Expression Language syntax.
Corresponds to the JSON property expression
13869 13870 13871 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13869 def expression @expression end |
#location ⇒ String
Optional. String indicating the location of the expression for error reporting,
e.g. a file name and a position in the file.
Corresponds to the JSON property location
13875 13876 13877 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13875 def location @location end |
#title ⇒ String
Optional. Title for the expression, i.e. a short string describing its purpose.
This can be used e.g. in UIs which allow to enter the expression.
Corresponds to the JSON property title
13881 13882 13883 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13881 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13888 13889 13890 13891 13892 13893 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13888 def update!(**args) @description = args[:description] if args.key?(:description) @expression = args[:expression] if args.key?(:expression) @location = args[:location] if args.key?(:location) @title = args[:title] if args.key?(:title) end |