Class: Google::Apis::ApigeeV1::GoogleTypeMoney
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleTypeMoney
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Represents an amount of money with its currency type.
Instance Attribute Summary collapse
-
#currency_code ⇒ String
The three-letter currency code defined in ISO 4217.
-
#nanos ⇒ Fixnum
Number of nano (10^-9) units of the amount.
-
#units ⇒ Fixnum
The whole units of the amount.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleTypeMoney
constructor
A new instance of GoogleTypeMoney.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleTypeMoney
Returns a new instance of GoogleTypeMoney.
13835 13836 13837 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13835 def initialize(**args) update!(**args) end |
Instance Attribute Details
#currency_code ⇒ String
The three-letter currency code defined in ISO 4217.
Corresponds to the JSON property currencyCode
13818 13819 13820 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13818 def currency_code @currency_code end |
#nanos ⇒ Fixnum
Number of nano (10^-9) units of the amount. The value must be between -999,999,
999 and +999,999,999 inclusive. If units is positive, nanos must be
positive or zero. If units is zero, nanos can be positive, zero, or
negative. If units is negative, nanos must be negative or zero. For
example $-1.75 is represented as units=-1 and nanos=-750,000,000.
Corresponds to the JSON property nanos
13827 13828 13829 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13827 def nanos @nanos end |
#units ⇒ Fixnum
The whole units of the amount. For example if currencyCode is "USD", then
1 unit is one US dollar.
Corresponds to the JSON property units
13833 13834 13835 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13833 def units @units end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13840 13841 13842 13843 13844 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13840 def update!(**args) @currency_code = args[:currency_code] if args.key?(:currency_code) @nanos = args[:nanos] if args.key?(:nanos) @units = args[:units] if args.key?(:units) end |