Class: Google::Apis::ApigeeV1::GoogleTypeTimeOfDay
- Inherits:
-
Object
- Object
- Google::Apis::ApigeeV1::GoogleTypeTimeOfDay
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigee_v1/classes.rb,
lib/google/apis/apigee_v1/representations.rb,
lib/google/apis/apigee_v1/representations.rb
Overview
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Instance Attribute Summary collapse
-
#hours ⇒ Fixnum
Hours of a day in 24 hour format.
-
#minutes ⇒ Fixnum
Minutes of an hour.
-
#nanos ⇒ Fixnum
Fractions of seconds, in nanoseconds.
-
#seconds ⇒ Fixnum
Seconds of a minute.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleTypeTimeOfDay
constructor
A new instance of GoogleTypeTimeOfDay.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleTypeTimeOfDay
Returns a new instance of GoogleTypeTimeOfDay.
13821 13822 13823 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13821 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hours ⇒ Fixnum
Hours of a day in 24 hour format. Must be greater than or equal to 0 and
typically must be less than or equal to 23. An API may choose to allow the
value "24:00:00" for scenarios like business closing time.
Corresponds to the JSON property hours
13800 13801 13802 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13800 def hours @hours end |
#minutes ⇒ Fixnum
Minutes of an hour. Must be greater than or equal to 0 and less than or equal
to 59.
Corresponds to the JSON property minutes
13806 13807 13808 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13806 def minutes @minutes end |
#nanos ⇒ Fixnum
Fractions of seconds, in nanoseconds. Must be greater than or equal to 0 and
less than or equal to 999,999,999.
Corresponds to the JSON property nanos
13812 13813 13814 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13812 def nanos @nanos end |
#seconds ⇒ Fixnum
Seconds of a minute. Must be greater than or equal to 0 and typically must be
less than or equal to 59. An API may allow the value 60 if it allows leap-
seconds.
Corresponds to the JSON property seconds
13819 13820 13821 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13819 def seconds @seconds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13826 13827 13828 13829 13830 13831 |
# File 'lib/google/apis/apigee_v1/classes.rb', line 13826 def update!(**args) @hours = args[:hours] if args.key?(:hours) @minutes = args[:minutes] if args.key?(:minutes) @nanos = args[:nanos] if args.key?(:nanos) @seconds = args[:seconds] if args.key?(:seconds) end |